import { SwimlaneItem } from '../workflow-designer.types';
import { Tag } from '../../../models/Tag';
import { WorkflowDesignerState } from '../workflow-designer.state';
import * as i0 from "@angular/core";
export declare class SwimlaneService {
    private state;
    readonly swimlaneHeight = 263;
    constructor(state: WorkflowDesignerState);
    /**
     * Add a new swimlane
     */
    addSwimlane(name: string, tags: Tag[]): SwimlaneItem;
    /**
     * Update an existing swimlane
     */
    updateSwimlane(index: number, name: string, tags: Tag[]): boolean;
    /**
     * Reorder swimlanes (move a swimlane up or down in the list)
     */
    reorderSwimlane(fromIndex: number, toIndex: number): boolean;
    /**
     * Delete a swimlane by index
     */
    deleteSwimlane(index: number): boolean;
    /**
     * Get all swimlanes
     */
    getSwimlanes(): SwimlaneItem[];
    /**
     * Get swimlane by index
     */
    getSwimlane(index: number): SwimlaneItem | null;
    /**
     * Calculate total canvas height needed for all swimlanes
     */
    calculateCanvasHeight(minHeight?: number): number;
    /**
     * Check if a Y position is within any swimlane
     */
    isPositionInsideSwimlane(y: number): boolean;
    /**
     * Calculate swimlane index from Y position
     */
    getSwimlaneIndexFromPosition(y: number): number;
    /**
     * Find swimlane index by Lane ID
     */
    findSwimlaneIndexByLaneId(laneId: string): number;
    static ɵfac: i0.ɵɵFactoryDeclaration<SwimlaneService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SwimlaneService>;
}
