import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, signal, computed, effect, Component, ViewChild, Optional, EventEmitter, Input, Output, Pipe, NgModule, input, HostListener, inject, ViewChildren } from '@angular/core';
import * as i1$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i8 from 'verben-ng-ui';
import { DataFilterType, UTIL_SERVICE, DataTableModule, CardModule, SvgModule, DataViewModule, CardDataViewModule, SortTableModule, VisibleColumnModule, TableFilterModule, DataExportModule, VerbenaInputModule, VerbenaButtonModule, VerbenaBadgeModule, VerbenDialogueModule, DropDownModule, VerbenaTextareaModule, VerbenaSwitchModule, VerbenPopUpModule, ChipModule, DatePickerModule, DataColumnsModule, DataXportModule, DataSortModule, DataFilterModule, ConditionalOptions } from 'verben-ng-ui';
import { BehaviorSubject, lastValueFrom, interval, of, from, Subject, debounceTime, distinctUntilChanged, takeUntil } from 'rxjs';
import * as i1 from '@angular/common/http';
import * as i5 from '@angular/router';
import { RouterLink, RouterModule } from '@angular/router';
import * as i1$2 from '@angular/forms';
import { Validators, FormsModule as FormsModule$1, ReactiveFormsModule, FormControl } from '@angular/forms';
import * as i8$1 from 'verben-reporting-ui';
import { EditorModule, EditorMode } from 'verben-reporting-ui';

// In your library's services/environment.service.ts
// import { ENVIRONMENT } from '../models/ENVIRONMENT_TOKEN';
const ENVIRONMENT = new InjectionToken('environment');
class EnvironmentService {
    env;
    constructor(env) {
        this.env = env;
        console.log('Instantiated');
    }
    get environment() {
        return this.env;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnvironmentService, deps: [{ token: ENVIRONMENT }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnvironmentService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: EnvironmentService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [ENVIRONMENT]
                }] }] });

const baseStyle$4 = {
    width: '100%',
    fontFamily: '"Fraunces", serif',
    fontSize: '125%',
    whiteSpace: 'nowrap',
    margin: '0',
    border: '1px solid #D4A007',
    borderRadius: '16px',
    borderCollapse: 'separate',
    borderSpacing: '0',
    // tableLayout: 'fixed',
    overflow: 'hidden',
    rows: {
        even: {
            backgroundColor: '#FDFDFD',
        },
        odd: {
            backgroundColor: '#F1F4FB',
        },
        height: '68px',
    },
    cells: {
        padding: '0.5rem 1rem',
    },
    header: {
        // stickyTop: true,
        // zIndex: 2,
        backgroundColor: '#EFF2FB',
        fontWeight: 'bold',
        textAlign: 'left',
        padding: '12px 16px',
        height: '40px',
    },
    footer: {
        // stickyBottom: true,
        // zIndex: 2,
        padding: '3px',
    },
    //   body: {
    //     background: '#fff',
    //     padding: '4px 5px',
    //     textAlign: 'center',
    //   },
    // firstColumn: {
    //   stickyLeft: true,
    //   zIndex: 1,
    // },
    lastColumn: {
    // stickyRight: true,
    // zIndex: 1,
    },
};

class BaseDataViewComponent {
    cardDataView;
    dataView;
    styles = baseStyle$4;
    // Signals for reactive data management
    data = signal([]);
    cardData = computed(() => this.data().map(this.config.cardDataMapper));
    // View state management
    currentData = null;
    isGridView = true;
    selected = null;
    // Filtering and sorting state
    visibleColumns = [];
    filterArray = [];
    sortOptions = [];
    selectedColumnCount = 0;
    selectedFilterTableCount = 0;
    selectedSortCount = 0;
    constructor() {
        effect(() => {
            const possiblyNewCard = this.cardData().find((c) => !c.data.Name) ?? null;
            if (possiblyNewCard) {
                console.log(possiblyNewCard);
                possiblyNewCard.selected = true;
                this.currentData = this.cardDataView.onItemClick(possiblyNewCard);
            }
        });
        this.initializeConfig();
    }
    ngOnInit() {
        this.loadInitialData();
    }
    // To be implemented by child classes if needed
    loadInitialData() {
        // Default implementation can be overridden
        this.data.set(this.config.dataSource);
    }
    initializeConfig() {
        // Initialize filter and column configurations
        this.visibleColumns = this.config?.columns?.map((col) => ({
            checked: true,
            name: typeof col.header === 'string' ? col.header : col.id,
            type: DataFilterType.Bool,
        }));
        this.filterArray = this.config?.filterOptions || [];
        this.sortOptions = this.config?.sortOptions || [];
    }
    // Generic view and interaction methods
    openDetailView(identifier) {
        const cardItem = this.getCardDataByIdentifier(identifier);
        if (cardItem && this.cardDataView) {
            this.resetSelections();
            cardItem.selected = true;
            this.currentData = this.cardDataView.onItemClick(cardItem);
            this.dataView.toggleView();
        }
    }
    resetSelections() {
        this.cardData().forEach((item) => {
            item.selected = false;
            item.children?.forEach((child) => (child.selected = false));
        });
    }
    // Common utility methods
    downloadCSV(data) {
        // const headers = Object.keys(data[0]);
        // const csvContent = [
        //   headers.join(','),
        //   ...data.map((row) => headers.map((header) => row[header]).join(',')),
        // ].join('\n');
        // const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        // const link = document.createElement('a');
        // if (link.download !== undefined) {
        //   const url = URL.createObjectURL(blob);
        //   link.setAttribute('href', url);
        //   link.setAttribute('download', 'export.csv');
        //   link.style.visibility = 'hidden';
        //   document.body.appendChild(link);
        //   link.click();
        //   document.body.removeChild(link);
        // }
    }
    // Event handlers
    onViewChange(isGridView) {
        // this.isGridView = isGridView;
        // if (this.currentData) {
        //   this.cardDataView?.clearData();
        //   this.currentData = null;
        // }
    }
    onColumnsUpdated(updatedColumns) {
        // Update visible columns logic
        this.selectedColumnCount = updatedColumns.length;
        // Additional column update logic can be added here
    }
    onSortUpdated(updatedSorts) {
        this.selectedSortCount = updatedSorts.length;
    }
    onSelectionChange(selectedRows) {
        console.log('Selection changed:', selectedRows);
    }
    onStateChange(event) {
        console.log(`State changed for ${event.key}:`, event.value);
    }
    handleExport(exportedData) {
        console.log('Exported data:', exportedData);
        this.downloadCSV(exportedData);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BaseDataViewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: BaseDataViewComponent, selector: "ng-component", viewQueries: [{ propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }], ngImport: i0, template: '', isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: BaseDataViewComponent, decorators: [{
            type: Component,
            args: [{
                    template: '',
                }]
        }], ctorParameters: () => [], propDecorators: { cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }] } });

const columns$4 = [
    {
        id: 'workflow',
        header: 'WORKFLOW',
        accessorKey: 'WorkflowCode',
    },
    {
        id: 'task',
        header: 'TASK',
        accessorKey: 'Name',
    },
    {
        id: 'stage',
        header: 'STAGE',
        accessorFn: (row) => row.CurrentStages?.join(', '),
    },
    {
        id: 'status',
        header: 'STATUS',
        accessorKey: 'Status',
    },
    {
        id: 'followers',
        header: 'FOLLOWERS',
        accessorFn: (row) => row.Followers?.map((flwr) => flwr.Name).join(', '),
    },
    {
        id: 'history',
        header: 'HISTORY',
        accessorKey: 'Id',
    },
    { id: 'actions', header: 'Actions' },
];

var ObjectState;
(function (ObjectState) {
    ObjectState["New"] = "New";
    ObjectState["Changed"] = "Changed";
    ObjectState["Unchanged"] = "Unchanged";
    ObjectState["Removed"] = "Removed";
})(ObjectState || (ObjectState = {}));

class ResourceModel {
    _DataState;
    Id;
    CreatedAt;
    UpdatedAt;
    TenantId;
    Code;
    ServiceName;
    id;
    // public columns: ColumnDefinition<T>[];
    constructor(model) {
        if (model) {
            Object.assign(this, model);
        }
        this.Id = model?.Id || '';
        this.CreatedAt = model?.CreatedAt ? new Date(model.CreatedAt) : new Date();
        this.UpdatedAt = model?.UpdatedAt ? new Date(model.UpdatedAt) : new Date();
        this._DataState = model?.DataState ?? ObjectState.New;
        this.TenantId = model?.TenantId ?? '';
        this.Code = model?.Code ?? '';
        this.ServiceName = model?.ServiceName ?? '';
        this.id = this._key() ?? new Date();
    }
    get DataState() {
        return this._DataState;
    }
    set DataState(value) {
        this._DataState =
            value === ObjectState.Unchanged ? ObjectState.Changed : value;
    }
    /**
     * Override to set custom unique identifier
     * E.g this.Name + this.CreatedAt.toString()
     * @returns unique string identifier for this resource
     */
    _key() {
        return this.Code;
    }
    toJson() {
        return JSON.parse(JSON.stringify(this));
    }
}

class TaskModel extends ResourceModel {
}

var TaskStatus;
(function (TaskStatus) {
    TaskStatus["Active"] = "Active";
    TaskStatus["InActive"] = "InActive";
    TaskStatus["OnHold"] = "OnHold";
    TaskStatus["Cancelled"] = "Cancelled";
    TaskStatus["Completed"] = "Completed";
})(TaskStatus || (TaskStatus = {}));

class ErrorResponse {
    ErrorMsg;
    StatusCode;
    FullLog;
    constructor(ErrorMsg, StatusCode, FullLog) {
        this.ErrorMsg = ErrorMsg;
        this.StatusCode = StatusCode;
        this.FullLog = FullLog;
    }
}

class HttpWebRequestService {
    http;
    envSvc;
    notificationService;
    isProd;
    constructor(http, envSvc, notificationService) {
        this.http = http;
        this.envSvc = envSvc;
        this.notificationService = notificationService;
        this.isProd = this.envSvc.environment.production;
    }
    buildHeaders() {
        return {
            'Content-Type': 'application/json',
            Authorization: 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJNYWlsQWRkcmVzcyI6InZlcmJlbmFAZ21haWwuY29tIiwiQXBwbGljYXRpb24iOiIiLCJOYW1lIjoiVmVyYmVuYSBMb2dpYyBMaW1pdGVkIiwiUm9sZUlEIjoiUk9MLVpYQVhYVCIsIlRlbmFudElkIjoiUERMVEM2IiwiU2VydmljZU5hbWUiOiJXaGl0ZTM2MCIsIkNvbXBhbnkiOiJDT00tNkxJNjNIIiwibmJmIjoxNzQ3ODE3MDI0LCJleHAiOjE3NDgwMzMwMjQsImlhdCI6MTc0NzgxNzAyNH0.X5R-gEDXJNy7iMUjHzgbUzLadHLkxJAiEhJDfCdJjYM',
        };
    }
    buildUrl(url, baseUrl) {
        return `${baseUrl}/${url}`;
    }
    handleError(err) {
        const msg = err?.ErrorMsg ||
            err?.errors?.values?.toString() ||
            `Error occurred`;
        this.notificationService.error(msg, { timeout: 10000 });
        return new ErrorResponse(msg);
    }
    request(method, url, body, baseUrl = this.envSvc.environment.WorkFlowAPI) {
        const options = {
            headers: this.buildHeaders(),
        };
        const requestUrl = this.buildUrl(url, baseUrl);
        switch (method) {
            case 'GET':
                return new Promise((resolve) => this.http.get(requestUrl, options).subscribe({
                    next: resolve,
                    error: (err) => resolve(this.handleError(err)),
                }));
            case 'POST':
                return new Promise((resolve) => this.http.post(requestUrl, body, options).subscribe({
                    next: resolve,
                    error: (err) => resolve(this.handleError(err)),
                }));
            case 'PUT':
                return this.http.put(requestUrl, body, options);
            case 'DELETE':
                return this.http.delete(requestUrl, options);
        }
    }
    get(url, baseUrl) {
        return this.request('GET', url, undefined, baseUrl);
    }
    post(url, body, baseUrl) {
        return this.request('POST', url, JSON.stringify(body), baseUrl);
    }
    postFile(url, formData, baseUrl) {
        return new Promise((resolve) => this.http
            .post(this.buildUrl(url, baseUrl || this.envSvc.environment.WorkFlowAPI), formData)
            .subscribe({
            next: resolve,
            error: (err) => resolve(this.handleError(err)),
        }));
    }
    put(url, body, baseUrl) {
        return this.request('PUT', url, body, baseUrl);
    }
    delete(url, baseUrl) {
        return this.request('DELETE', url, undefined, baseUrl);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HttpWebRequestService, deps: [{ token: i1.HttpClient }, { token: EnvironmentService }, { token: i8.NotificationService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HttpWebRequestService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HttpWebRequestService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: i1.HttpClient }, { type: EnvironmentService }, { type: i8.NotificationService }] });

class TasksService {
    httpService;
    BASE_URL = 'Task';
    WORKFLOW_URL = 'Workflow';
    FORM_URL = 'Form';
    constructor(httpService) {
        this.httpService = httpService;
    }
    /**
     * Get tasks with pagination and sorting
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the tasks
     */
    getTasks(skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetTasks/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get tasks with additional parameter, pagination and sorting
     * @param param Search parameter
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the filtered tasks
     */
    getTaskWithParam(param, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetTaskWithParam/${param}/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Save multiple tasks
     * @param requests Array of tasks to save
     * @returns Promise containing the save operation result
     */
    saveTasks(requests) {
        const url = `${this.BASE_URL}/SaveTasks`;
        return this.httpService.post(url, requests);
    }
    /**
     * Approve or reject multiple tasks
     * @param requests Array of tasks to save
     * @param isApproval True for approval, false for decline
     * @returns Promise containing the save operation result
     */
    processTasks(requests, isApproval) {
        const url = `${this.BASE_URL}/TaskAction/${isApproval}`;
        return this.httpService.post(url, requests);
    }
    /**
     * Delete multiple tasks
     * @param requestIds Array of request IDs to delete
     * @returns Observable containing the delete operation result
     */
    deleteTasks(requestIds) {
        const url = `${this.BASE_URL}/DeleteTasks`;
        return this.httpService.delete(`${url}?data=${requestIds.join(',')}`);
    }
    getWorkflows() {
        const url = `${this.WORKFLOW_URL}/GetWorkflows/0/0`;
        return this.httpService.get(url);
    }
    getFormWithParam(param) {
        const url = `${this.FORM_URL}/GetFormsWithParam/${param}/0/1`;
        return this.httpService.get(url);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksService, deps: [{ token: HttpWebRequestService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: HttpWebRequestService }] });

var SortDirection;
(function (SortDirection) {
    SortDirection["Asc"] = "Asc";
    SortDirection["Desc"] = "Desc";
    SortDirection["None"] = "None";
})(SortDirection || (SortDirection = {}));

class TaskState {
    updating$ = new BehaviorSubject(false);
    tasks$ = new BehaviorSubject([]);
    queryParams$ = new BehaviorSubject({
        skip: 0,
        limit: 40,
        sortParam: 'CreatedAt',
        sortOrder: SortDirection.Desc,
    });
    workflows$ = new BehaviorSubject([]);
    forms$ = new BehaviorSubject([]);
    isUpdating$() {
        return this.updating$.asObservable();
    }
    setUpdating(isUpdating) {
        this.updating$.next(isUpdating);
    }
    getRequests$() {
        return this.tasks$.asObservable();
    }
    setRequests(tasks) {
        this.tasks$.next(tasks);
    }
    getWorkflows$() {
        return this.workflows$.asObservable();
    }
    setWorkflows(workflows) {
        this.workflows$.next(workflows);
    }
    getForms$() {
        return this.forms$.asObservable();
    }
    setForms(forms) {
        this.forms$.next(forms);
    }
    getQueryParams$() {
        return this.queryParams$.asObservable();
    }
    getQueryParamsValue() {
        return this.queryParams$.getValue();
    }
    updateQueryParams(params) {
        this.queryParams$.next({ ...this.queryParams$.getValue(), ...params });
    }
    addRequest(task) {
        const currentValue = this.tasks$.getValue();
        this.tasks$.next([task, ...currentValue]);
    }
    updateRequest(updatedRequest) {
        const tasks = this.tasks$.getValue();
        const index = tasks.findIndex((r) => r.Id === updatedRequest.Id);
        if (index !== -1) {
            tasks[index] = updatedRequest;
            this.tasks$.next([...tasks]);
        }
    }
    removeRequest(taskId) {
        const currentValue = this.tasks$.getValue();
        this.tasks$.next(currentValue.filter((r) => r.Id !== taskId));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskState, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskState, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskState, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class UtilService {
    parentUtilService;
    constructor(parentUtilService) {
        this.parentUtilService = parentUtilService;
    }
    sendBI(state) {
        console.log({ Service: this.parentUtilService });
        if (this.parentUtilService && this.parentUtilService.sendBI) {
            this.parentUtilService.sendBI(state);
        }
        else {
            console.warn('Util Service is not provided');
        }
    }
    showInfo(message) {
        if (this.parentUtilService && this.parentUtilService.showInfo) {
            this.parentUtilService.showInfo(message);
        }
        else {
            console.warn('Util Service is not provided');
        }
    }
    showSuccess(message) {
        if (this.parentUtilService && this.parentUtilService.showSuccess) {
            this.parentUtilService.showSuccess(message);
        }
        else {
            console.warn('Util Service is not provided');
        }
    }
    showError(message) {
        if (this.parentUtilService && this.parentUtilService.showError) {
            this.parentUtilService.showError(message);
        }
        else {
            console.warn('Util Service is not provided');
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UtilService, deps: [{ token: UTIL_SERVICE, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UtilService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: UtilService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [UTIL_SERVICE]
                }] }] });

class TaskFacade {
    taskService;
    taskState;
    utilService;
    constructor(taskService, taskState, utilService) {
        this.taskService = taskService;
        this.taskState = taskState;
        this.utilService = utilService;
        this.isUpdating$().subscribe((loading) => {
            this.utilService.sendBI(loading);
        });
    }
    isUpdating$() {
        return this.taskState.isUpdating$();
    }
    getRequests$() {
        return this.taskState.getRequests$();
    }
    getWorkflow$() {
        return this.taskState.getWorkflows$();
    }
    getForms$() {
        return this.taskState.getForms$();
    }
    getQueryParams$() {
        return this.taskState.getQueryParams$();
    }
    addNewRequest(task) {
        this.taskState.addRequest(task);
    }
    async loadRequests() {
        try {
            this.taskState.setUpdating(true);
            const params = this.taskState.getQueryParamsValue();
            const requests = await this.taskService.getTasks(params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder);
            this.taskState.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests:', error);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    async loadRequestsWithParam(param) {
        try {
            this.taskState.setUpdating(true);
            const params = this.taskState.getQueryParamsValue();
            const requests = await this.taskService.getTaskWithParam(param, params.skip, params.limit, params.sortParam || 'CreatedDate', params.sortOrder);
            this.taskState.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    updateQueryParams(params) {
        this.taskState.updateQueryParams(params);
        this.loadRequests();
    }
    async addRequest(request) {
        try {
            this.taskState.setUpdating(true);
            const newRequest = { ...request, TaskForms: [] };
            this.taskState.addRequest(newRequest);
            await this.taskService.saveTasks([newRequest]);
            await this.loadRequests(); // Reload to get server-side changes
        }
        catch (error) {
            console.error('Failed to add request:', error);
            this.taskState.removeRequest(request.Id);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    async updateRequest(request) {
        try {
            this.taskState.setUpdating(true);
            await this.taskService.saveTasks([request]);
            this.taskState.updateRequest(request);
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    async deleteRequest(requestId) {
        try {
            this.taskState.setUpdating(true);
            await lastValueFrom(this.taskService.deleteTasks([requestId]));
            this.taskState.removeRequest(requestId);
        }
        catch (error) {
            console.error('Failed to delete request:', error);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    async approveRequest(request) {
        try {
            this.taskState.setUpdating(true);
            const response = await this.taskService.processTasks([request], true);
            // console.log(response);
            const data = response?.[0];
            if (data) {
                this.taskState.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    async loadWorkflows() {
        try {
            const requests = await this.taskService.getWorkflows();
            this.taskState.setWorkflows(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests:', error);
            throw error;
        }
        finally {
        }
    }
    async loadFormsWithParam(param) {
        try {
            this.taskState.setUpdating(true);
            const requests = await this.taskService.getFormWithParam(param);
            const form = requests.Result[0];
            if (form)
                return form;
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.taskState.setUpdating(false);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFacade, deps: [{ token: TasksService }, { token: TaskState }, { token: UtilService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFacade, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFacade, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: TasksService }, { type: TaskState }, { type: UtilService }] });

var Status;
(function (Status) {
    Status["InActive"] = "InActive";
    Status["Active"] = "Active";
})(Status || (Status = {}));

var DataType;
(function (DataType) {
    DataType["Text"] = "Text";
    DataType["MultilineText"] = "MultilineText";
    DataType["MailAddress"] = "MailAddress";
    DataType["PhoneNumber"] = "PhoneNumber";
    DataType["Number"] = "Number";
    DataType["Decimal"] = "Decimal";
    DataType["YesNo"] = "YesNo";
    DataType["URL"] = "URL";
    DataType["Image"] = "Image";
    DataType["SingleSelection"] = "SingleSelection";
    DataType["MultiSelection"] = "MultiSelection";
    DataType["Colour"] = "Colour";
    DataType["Video"] = "Video";
    DataType["Audio"] = "Audio";
    DataType["SingleFileSelection"] = "SingleFileSelection";
    DataType["MultiFileSelection"] = "MultiFileSelection";
})(DataType || (DataType = {}));

class FileUploadComponent {
    multiple = false;
    label = '';
    accept = '';
    selectedFiles = [];
    selectedFilesChange = new EventEmitter();
    // Define maximum file size (5MB)
    MAX_FILE_SIZE = 5 * 1024 * 1024; // 5MB in bytes
    onFileSelected(event) {
        const files = Array.from(event.target.files);
        this.processFiles(files);
    }
    onDrop(event) {
        event.preventDefault();
        const acceptedTypes = [this.accept];
        if (event.dataTransfer?.files) {
            const files = Array.from(event.dataTransfer.files).filter(file => acceptedTypes.includes(file.type));
            if (files.length > 0) {
                this.processFiles(files);
            }
            else {
                console.error('Unsupported file type.');
                return;
            }
        }
    }
    onDragOver(event) {
        event.preventDefault();
    }
    processFiles(files) {
        for (const file of files) {
            if (file.size > this.MAX_FILE_SIZE) {
                alert(`The file "${file.name}" is too large. Maximum size allowed is 5MB.`);
                return; // Stop processing if a file exceeds the size limit
            }
        }
        if (this.multiple) {
            this.selectedFiles.push(...files);
        }
        else {
            this.selectedFiles = [files[0]];
        }
        this.selectedFilesChange.emit(this.selectedFiles);
    }
    removeFile(index) {
        this.selectedFiles.splice(index, 1);
        this.selectedFilesChange.emit(this.selectedFiles);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileUploadComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FileUploadComponent, selector: "file-upload", inputs: { multiple: "multiple", label: "label", accept: "accept", selectedFiles: "selectedFiles" }, outputs: { selectedFilesChange: "selectedFilesChange" }, ngImport: i0, template: "<div class=\"file-upload-container\" (dragover)=\"onDragOver($event)\" (drop)=\"onDrop($event)\">\n    <label>{{label}}</label>\n    \n    <div *ngIf=\"multiple\" class=\"py-6 px-3 border rounded-lg flex gap-2 flex-wrap border-[#9A9FBF66] mt-2 mb-3\">\n      <span class=\"flex items-center gap-1 bg-[#1A237E33] px-1 py-1 rounded-lg w-fit\" *ngFor=\"let file of selectedFiles; let i = index\">\n        {{ file.name | slice:0:10 }}{{ file.name.length > 10 ? '...' : '' }}  \n        <verben-svg [stroke]=\"'#D4A007'\" [icon]=\"'close'\" [width]=\"10\" [height]=\"10\" (click)=\"removeFile(i)\"></verben-svg>\n      </span>\n      <button (click)=\"fileInput.click()\" class=\"flex items-center gap-1 bg-[#1A237E33] px-1 py-1 rounded-lg\">\n        <verben-svg [icon]=\"'plus'\" [width]=\"12\" [height]=\"12\"></verben-svg> Add File\n      </button>\n      <input #fileInput type=\"file\" [accept]=\"accept\" (change)=\"onFileSelected($event)\" class=\"hidden\"/>\n    </div>\n    \n    <div *ngIf=\"!multiple\" class=\"border rounded-lg flex justify-between border-[#9A9FBF66] mt-2 mb-3\">\n      <div>\n        <span class=\"flex items-center gap-1 m-2 text-[#0000FF] px-1 py-1 rounded-lg w-fit\" *ngFor=\"let file of selectedFiles; let i = index\">\n          {{ file.name | slice:0:10 }}{{ file.name.length > 10 ? '...' : '' }}  \n          <verben-svg [stroke]=\"'#0000FF'\" [icon]=\"'close'\" [width]=\"10\" [height]=\"10\" (click)=\"removeFile(i)\"></verben-svg>\n        </span>\n      </div>\n      <verbena-button [bgColor]=\"'#D9D9D980'\" (click)=\"fileInput.click()\" [text]=\"'Browse Files'\"></verbena-button>\n    </div>\n    \n    <input [accept]=\"accept\" type=\"file\" [multiple]=\"multiple\" (change)=\"onFileSelected($event)\" hidden #fileInput/>\n    \n    <div class=\"drop-area border border-dashed w-full flex flex-col justify-center items-center border-[#9A9FBF66] p-4 rounded-lg bg-[#9a9fbf27] min-h-[200px]\" (click)=\"fileInput.click()\">\n      <verben-svg [icon]=\"'upload-icon'\" [width]=\"90\" [height]=\"90\"></verben-svg>\n      <p class=\"text-[#000000B2]\">Drag and drop files here</p>\n    </div>\n  </div>\n  ", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "pipe", type: i1$1.SlicePipe, name: "slice" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileUploadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'file-upload', template: "<div class=\"file-upload-container\" (dragover)=\"onDragOver($event)\" (drop)=\"onDrop($event)\">\n    <label>{{label}}</label>\n    \n    <div *ngIf=\"multiple\" class=\"py-6 px-3 border rounded-lg flex gap-2 flex-wrap border-[#9A9FBF66] mt-2 mb-3\">\n      <span class=\"flex items-center gap-1 bg-[#1A237E33] px-1 py-1 rounded-lg w-fit\" *ngFor=\"let file of selectedFiles; let i = index\">\n        {{ file.name | slice:0:10 }}{{ file.name.length > 10 ? '...' : '' }}  \n        <verben-svg [stroke]=\"'#D4A007'\" [icon]=\"'close'\" [width]=\"10\" [height]=\"10\" (click)=\"removeFile(i)\"></verben-svg>\n      </span>\n      <button (click)=\"fileInput.click()\" class=\"flex items-center gap-1 bg-[#1A237E33] px-1 py-1 rounded-lg\">\n        <verben-svg [icon]=\"'plus'\" [width]=\"12\" [height]=\"12\"></verben-svg> Add File\n      </button>\n      <input #fileInput type=\"file\" [accept]=\"accept\" (change)=\"onFileSelected($event)\" class=\"hidden\"/>\n    </div>\n    \n    <div *ngIf=\"!multiple\" class=\"border rounded-lg flex justify-between border-[#9A9FBF66] mt-2 mb-3\">\n      <div>\n        <span class=\"flex items-center gap-1 m-2 text-[#0000FF] px-1 py-1 rounded-lg w-fit\" *ngFor=\"let file of selectedFiles; let i = index\">\n          {{ file.name | slice:0:10 }}{{ file.name.length > 10 ? '...' : '' }}  \n          <verben-svg [stroke]=\"'#0000FF'\" [icon]=\"'close'\" [width]=\"10\" [height]=\"10\" (click)=\"removeFile(i)\"></verben-svg>\n        </span>\n      </div>\n      <verbena-button [bgColor]=\"'#D9D9D980'\" (click)=\"fileInput.click()\" [text]=\"'Browse Files'\"></verbena-button>\n    </div>\n    \n    <input [accept]=\"accept\" type=\"file\" [multiple]=\"multiple\" (change)=\"onFileSelected($event)\" hidden #fileInput/>\n    \n    <div class=\"drop-area border border-dashed w-full flex flex-col justify-center items-center border-[#9A9FBF66] p-4 rounded-lg bg-[#9a9fbf27] min-h-[200px]\" (click)=\"fileInput.click()\">\n      <verben-svg [icon]=\"'upload-icon'\" [width]=\"90\" [height]=\"90\"></verben-svg>\n      <p class=\"text-[#000000B2]\">Drag and drop files here</p>\n    </div>\n  </div>\n  " }]
        }], propDecorators: { multiple: [{
                type: Input
            }], label: [{
                type: Input
            }], accept: [{
                type: Input
            }], selectedFiles: [{
                type: Input
            }], selectedFilesChange: [{
                type: Output
            }] } });

class FormControlComponent {
    dataType;
    value = '';
    boolInputType = 'checkbox';
    formProperties = [];
    ngOnInit() {
        this.initializeDefaultValue();
    }
    initializeDefaultValue() {
        if (this.dataType === DataType.YesNo && this.value === '') {
            this.value = false;
        }
        else if (!this.value) {
            this.value = '';
        }
    }
    onFileSelect(event, property) {
        const files = event.target.files;
        property.Value = files.length > 1 ? Array.from(files) : files[0];
    }
    formatLabel(property) {
        return property.IsRequired ? `${property.Name} *` : `${property.Name} (Optional)`;
    }
    optionsArray(property) {
        property.Options?.split(',').map((option) => (option.trim()));
        return property.Options?.split(',').map((option) => (option.trim()));
    }
    onSelectedFileChange(files) {
        console.log(files);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormControlComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FormControlComponent, selector: "form-control", inputs: { dataType: "dataType", value: "value", boolInputType: "boolInputType", formProperties: "formProperties" }, ngImport: i0, template: "<div class=\"flex flex-col gap-6 w-full\">\n  <div *ngFor=\"let property of formProperties\">\n    <ng-container [ngSwitch]=\"property.DataType\">\n      <!-- Text, URL, and Color -->\n      <verbena-input *ngSwitchCase=\"'Text'\" [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\"  [type]=\"'text'\" [placeHolder]=\"'Enter text'\"></verbena-input>\n      <verbena-input *ngSwitchCase=\"'MailAddress'\" [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\"  [type]=\"'email'\" [placeHolder]=\"'Enter email'\"></verbena-input>\n      <verbena-input *ngSwitchCase=\"'URL'\" [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [type]=\"'url'\" [placeHolder]=\"'https://example.com'\"></verbena-input>\n       <div *ngSwitchCase=\"'Colour'\">\n        <label [htmlFor]=\"property.id\">\n          {{formatLabel(property)}}\n         <span class=\"flex items-center gap-1\">\n          <input [id]=\"property.id\" [(ngModel)]=\"property.Value\"  class=\"block mt-2 w-[100px]\"  [type]=\"'color'\"/> <span *ngIf=\"property.Value!==''\" class=\"font-semibold\" [style.color]=\"property.Value\">:{{property.Value}}</span>\n         </span>\n        </label>\n       \n\n       </div>\n      <verbena-textarea [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'MultilineText'\" [label]=\"formatLabel(property)\"></verbena-textarea>\n      <verbena-input [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'PhoneNumber'\" [label]=\"formatLabel(property)\"  [type]=\"'text'\" [placeHolder]=\"'Enter text'\"></verbena-input>\n\n      <!-- Numeric inputs -->\n      <verbena-input [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'Number'\" [label]=\"formatLabel(property)\"  [type]=\"'number'\" [placeHolder]=\"'Enter an integer'\" [max]=\"property.MaxValue\" [min]=\"property.MinValue\"></verbena-input>\n      <verbena-input [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'Decimal'\" [label]=\"formatLabel(property)\"  [type]=\"'text'\" [placeHolder]=\"'Enter decimal value'\"></verbena-input>\n\n      <!-- Boolean input -->\n      <ng-container *ngSwitchCase=\"'YesNo'\" >\n        <label [htmlFor]=\"property.id\" class=\"block mb-2\">{{formatLabel(property)}}</label>\n        <verbena-switch [(ngModel)]=\"property.Value\" [onText]=\"''\" [offText]=\"''\" [onColor]=\"'#1A237E'\" [label]=\"formatLabel(property)\" ></verbena-switch>\n      </ng-container>\n\n      <!-- File selection for Video, Audio -->\n      <div *ngSwitchCase=\"'Video'\">\n        <file-upload [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [accept]=\"'video/*'\" [multiple]=\"false\"></file-upload>\n      </div>\n      <div *ngSwitchCase=\"'Image'\">\n        <file-upload [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [accept]=\"'image/*'\" [multiple]=\"false\"></file-upload>\n      </div>\n      <div  *ngSwitchCase=\"'Audio'\">\n        <file-upload [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [accept]=\"'audio/*'\" [multiple]=\"false\"></file-upload>\n      </div>\n\n      <!-- Multi/Single selection -->\n      <div *ngSwitchCase=\"'SingleSelection'\">\n        <div class=\"mb-2\">{{formatLabel(property)}}</div>\n        <verben-drop-down width=\"100%\" [placeholder]=\"property.Name\" [filter]=\"true\" [options]=\"optionsArray(property)\" [(ngModel)]=\"property.Value\"></verben-drop-down>\n      </div>\n      <div *ngSwitchCase=\"'MultiSelection'\">\n        <div class=\"mb-2\">{{formatLabel(property)}}</div>\n        <verben-drop-down width=\"100%\" [multiselect]=\"true\" [placeholder]=\"property.Name\" [options]=\"optionsArray(property)\" [(ngModel)]=\"property.Value\"></verben-drop-down>\n      </div>\n\n      <!-- Single and Multi file selection -->\n      <div *ngSwitchCase=\"'SingleFileSelection'\">\n        <file-upload [multiple]=\"false\" [label]=\"formatLabel(property)\"></file-upload>\n      </div>\n      <div *ngSwitchCase=\"'MultiFileSelection'\">\n        <file-upload (selectedFilesChange)=\"onSelectedFileChange($event)\"  [multiple]=\"true\" [label]=\"formatLabel(property)\"></file-upload>\n      </div>\n\n      <!-- Fallback for unsupported types -->\n      <div *ngSwitchDefault>\n        Unsupported data type: {{ property.DataType }}\n      </div>\n    </ng-container>\n  </div>\n</div>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1$1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i1$1.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.VerbenaSwitchComponent, selector: "verbena-switch", inputs: ["label", "checked", "disabled", "offColor", "onColor", "onText", "offText", "width", "height", "customStyles"], outputs: ["change"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: FileUploadComponent, selector: "file-upload", inputs: ["multiple", "label", "accept", "selectedFiles"], outputs: ["selectedFilesChange"] }, { kind: "component", type: i8.VerbenaTextareaComponent, selector: "verbena-textarea", inputs: ["label", "required", "rows", "cols", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "value", "errorMessageColor"], outputs: ["valueChange"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormControlComponent, decorators: [{
            type: Component,
            args: [{ selector: 'form-control', template: "<div class=\"flex flex-col gap-6 w-full\">\n  <div *ngFor=\"let property of formProperties\">\n    <ng-container [ngSwitch]=\"property.DataType\">\n      <!-- Text, URL, and Color -->\n      <verbena-input *ngSwitchCase=\"'Text'\" [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\"  [type]=\"'text'\" [placeHolder]=\"'Enter text'\"></verbena-input>\n      <verbena-input *ngSwitchCase=\"'MailAddress'\" [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\"  [type]=\"'email'\" [placeHolder]=\"'Enter email'\"></verbena-input>\n      <verbena-input *ngSwitchCase=\"'URL'\" [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [type]=\"'url'\" [placeHolder]=\"'https://example.com'\"></verbena-input>\n       <div *ngSwitchCase=\"'Colour'\">\n        <label [htmlFor]=\"property.id\">\n          {{formatLabel(property)}}\n         <span class=\"flex items-center gap-1\">\n          <input [id]=\"property.id\" [(ngModel)]=\"property.Value\"  class=\"block mt-2 w-[100px]\"  [type]=\"'color'\"/> <span *ngIf=\"property.Value!==''\" class=\"font-semibold\" [style.color]=\"property.Value\">:{{property.Value}}</span>\n         </span>\n        </label>\n       \n\n       </div>\n      <verbena-textarea [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'MultilineText'\" [label]=\"formatLabel(property)\"></verbena-textarea>\n      <verbena-input [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'PhoneNumber'\" [label]=\"formatLabel(property)\"  [type]=\"'text'\" [placeHolder]=\"'Enter text'\"></verbena-input>\n\n      <!-- Numeric inputs -->\n      <verbena-input [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'Number'\" [label]=\"formatLabel(property)\"  [type]=\"'number'\" [placeHolder]=\"'Enter an integer'\" [max]=\"property.MaxValue\" [min]=\"property.MinValue\"></verbena-input>\n      <verbena-input [(ngModel)]=\"property.Value\" *ngSwitchCase=\"'Decimal'\" [label]=\"formatLabel(property)\"  [type]=\"'text'\" [placeHolder]=\"'Enter decimal value'\"></verbena-input>\n\n      <!-- Boolean input -->\n      <ng-container *ngSwitchCase=\"'YesNo'\" >\n        <label [htmlFor]=\"property.id\" class=\"block mb-2\">{{formatLabel(property)}}</label>\n        <verbena-switch [(ngModel)]=\"property.Value\" [onText]=\"''\" [offText]=\"''\" [onColor]=\"'#1A237E'\" [label]=\"formatLabel(property)\" ></verbena-switch>\n      </ng-container>\n\n      <!-- File selection for Video, Audio -->\n      <div *ngSwitchCase=\"'Video'\">\n        <file-upload [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [accept]=\"'video/*'\" [multiple]=\"false\"></file-upload>\n      </div>\n      <div *ngSwitchCase=\"'Image'\">\n        <file-upload [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [accept]=\"'image/*'\" [multiple]=\"false\"></file-upload>\n      </div>\n      <div  *ngSwitchCase=\"'Audio'\">\n        <file-upload [(ngModel)]=\"property.Value\" [label]=\"formatLabel(property)\" [accept]=\"'audio/*'\" [multiple]=\"false\"></file-upload>\n      </div>\n\n      <!-- Multi/Single selection -->\n      <div *ngSwitchCase=\"'SingleSelection'\">\n        <div class=\"mb-2\">{{formatLabel(property)}}</div>\n        <verben-drop-down width=\"100%\" [placeholder]=\"property.Name\" [filter]=\"true\" [options]=\"optionsArray(property)\" [(ngModel)]=\"property.Value\"></verben-drop-down>\n      </div>\n      <div *ngSwitchCase=\"'MultiSelection'\">\n        <div class=\"mb-2\">{{formatLabel(property)}}</div>\n        <verben-drop-down width=\"100%\" [multiselect]=\"true\" [placeholder]=\"property.Name\" [options]=\"optionsArray(property)\" [(ngModel)]=\"property.Value\"></verben-drop-down>\n      </div>\n\n      <!-- Single and Multi file selection -->\n      <div *ngSwitchCase=\"'SingleFileSelection'\">\n        <file-upload [multiple]=\"false\" [label]=\"formatLabel(property)\"></file-upload>\n      </div>\n      <div *ngSwitchCase=\"'MultiFileSelection'\">\n        <file-upload (selectedFilesChange)=\"onSelectedFileChange($event)\"  [multiple]=\"true\" [label]=\"formatLabel(property)\"></file-upload>\n      </div>\n\n      <!-- Fallback for unsupported types -->\n      <div *ngSwitchDefault>\n        Unsupported data type: {{ property.DataType }}\n      </div>\n    </ng-container>\n  </div>\n</div>\n" }]
        }], propDecorators: { dataType: [{
                type: Input
            }], value: [{
                type: Input
            }], boolInputType: [{
                type: Input
            }], formProperties: [{
                type: Input
            }] } });

class FormTimerComponent {
    expiryDate = '2025-02-12';
    remainingTime;
    subscription;
    ngOnInit() {
        if (this.expiryDate) {
            this.startCountdown(new Date(this.expiryDate).getTime());
        }
        else {
            console.error('expiryDate is required');
        }
    }
    startCountdown(targetTime) {
        this.subscription = interval(1000).subscribe(() => {
            const now = new Date().getTime();
            const timeLeft = targetTime - now;
            if (timeLeft <= 0) {
                this.remainingTime = { days: 0, hours: 0, minutes: 0, seconds: 0 };
                this.subscription.unsubscribe();
                return;
            }
            this.remainingTime = this.calculateTimeUnits(timeLeft);
        });
    }
    calculateTimeUnits(timeLeft) {
        const days = Math.floor(timeLeft / (1000 * 60 * 60 * 24));
        const hours = Math.floor((timeLeft % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
        const minutes = Math.floor((timeLeft % (1000 * 60 * 60)) / (1000 * 60));
        const seconds = Math.floor((timeLeft % (1000 * 60)) / 1000);
        return { days, hours, minutes, seconds };
    }
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormTimerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FormTimerComponent, selector: "app-form-timer", inputs: { expiryDate: "expiryDate" }, ngImport: i0, template: "<div class=\"bg-[#fff] flex justify-center gap-4 p-6\" *ngIf=\"remainingTime\">\n  <h2 class=\"mt-3 text-lg\">Form closes in</h2>\n  <div class=\"flex items-center gap-4\">\n    <div>\n        <div class=\"flex gap-1 items-center\">\n      <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.days }}\n      </p>\n      <span class=\"ml-2 font-bold text-2xl\">:</span>\n      </div>\n      <span>Days</span>\n    </div>\n    <div>\n     <div class=\"flex gap-1 items-center\">\n        <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.hours }}\n      </p>\n      <span class=\"ml-2 font-bold text-2xl\">:</span>\n     </div>\n      <span>Hours</span>\n      \n    </div>\n    <div>\n        <div class=\"flex gap-1 items-center\">\n      <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.minutes }}\n      </p>\n      <span class=\"ml-2 font-bold text-2xl\">:</span>\n    </div>\n      <span>Minutes</span>\n    </div>\n    <div>\n      <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.seconds }}\n      </p>\n      <span>Seconds</span>\n    </div>\n  </div>\n</div>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormTimerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-form-timer', template: "<div class=\"bg-[#fff] flex justify-center gap-4 p-6\" *ngIf=\"remainingTime\">\n  <h2 class=\"mt-3 text-lg\">Form closes in</h2>\n  <div class=\"flex items-center gap-4\">\n    <div>\n        <div class=\"flex gap-1 items-center\">\n      <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.days }}\n      </p>\n      <span class=\"ml-2 font-bold text-2xl\">:</span>\n      </div>\n      <span>Days</span>\n    </div>\n    <div>\n     <div class=\"flex gap-1 items-center\">\n        <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.hours }}\n      </p>\n      <span class=\"ml-2 font-bold text-2xl\">:</span>\n     </div>\n      <span>Hours</span>\n      \n    </div>\n    <div>\n        <div class=\"flex gap-1 items-center\">\n      <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.minutes }}\n      </p>\n      <span class=\"ml-2 font-bold text-2xl\">:</span>\n    </div>\n      <span>Minutes</span>\n    </div>\n    <div>\n      <p\n        class=\"bg-[#FFE681] w-[50px] font-bold text-[20px] flex items-center justify-center h-[40px] rounded-md\"\n      >\n        {{ remainingTime.seconds }}\n      </p>\n      <span>Seconds</span>\n    </div>\n  </div>\n</div>\n" }]
        }], propDecorators: { expiryDate: [{
                type: Input
            }] } });

class TasksFormComponent {
    fb;
    taskFacade;
    get currentData() {
        return this._currentData;
    }
    set currentData(value) {
        this._currentData = value;
        console.log(value?.data);
        if (value?.data) {
            this.form.patchValue({
                Name: value.data.Name || '',
                Description: value.data.Description || '',
                WorkflowCode: value.data.WorkflowCode || '',
                Status: value.data.Status || '',
            });
        }
        else {
            this.form.reset();
        }
    }
    _currentData = null;
    taskForm = null;
    active = 0;
    dataType = DataType.Text;
    onTaskFormSave = new EventEmitter();
    onSave = new EventEmitter();
    form;
    statuses = Object.values(Status);
    workflows = [];
    loadingTaskForm = false;
    taskFormView = false;
    // active: boolean = false;
    constructor(fb, taskFacade) {
        this.fb = fb;
        this.taskFacade = taskFacade;
        this.taskFacade.getWorkflow$().subscribe((workflows) => {
            this.workflows = workflows;
        });
        this.form = this.fb.group({
            Name: ['', { validators: [Validators.required] }],
            Description: ['', { validators: [Validators.required] }],
            WorkflowCode: ['', { validators: [Validators.required] }],
            Status: ['', { validators: [Validators.required] }],
            TaskForms: [],
        });
    }
    ngOnInit() {
        try {
            this.taskFacade.loadWorkflows().then(() => { });
        }
        catch (error) {
            // Handle error
        }
        this.form.get('WorkflowCode')?.valueChanges.subscribe((value) => {
            if (value) {
                const selectedWorkflow = this.workflows.find(({ Code }) => Code === value);
                if (selectedWorkflow?.Form) {
                    this.loadingTaskForm = true;
                    this.taskFacade
                        .loadFormsWithParam(selectedWorkflow.Form)
                        .then((form) => {
                        if (form) {
                            this.taskForm = form;
                        }
                    })
                        .finally(() => {
                        this.loadingTaskForm = false;
                    });
                }
                else {
                    this.taskForm = null;
                }
            }
        });
    }
    handleSubmit() {
        if (this.form.valid) {
            // Emit save event with form value
            console.log('Form saved:', this.form.value);
            if (!this.taskForm ||
                this.form.get('TaskForms')?.value?.length > 0) {
                this.onSave.emit(this.form.value);
            }
        }
    }
    onDelete() {
        // Emit delete event
        console.log('Delete requested');
    }
    sendTaskForm() {
        if (this.taskForm) {
            this.form
                .get('TaskForms')
                ?.setValue([{ ...this.taskForm, Swimlane: '' }]);
            this.taskFormView = false;
            this.onTaskFormSave.emit(this.taskForm);
        }
    }
    areRequiredPropertiesFilled() {
        const properties = this.taskForm?.Entities[this.active].Properties || [];
        // Check if all required properties have valid values
        // return properties.every((property: any) => {
        //   console.log(property);
        //   return (
        //     !property.isRequired ||
        //     (property.Value !== undefined &&
        //       property.Value !== null &&
        //       property.Value !== '')
        //   );
        // });
        return true;
    }
    disableProcessing() {
        const selectedWorkflow = this.workflows.find(({ Code }) => Code === this.form.get('WorkflowCode')?.value);
        if (selectedWorkflow?.Form &&
            this.currentData?.data?.TaskForms?.length === 0) {
            return true;
        }
        else
            return this.form.invalid;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksFormComponent, deps: [{ token: i1$2.FormBuilder }, { token: TaskFacade }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: TasksFormComponent, selector: "tasks-form", inputs: { currentData: "currentData" }, outputs: { onTaskFormSave: "onTaskFormSave", onSave: "onSave" }, ngImport: i0, template: "@if (taskFormView && taskForm) {\n<div\n  *ngIf=\"taskForm.Entities[active]\"\n  class=\"flex flex-wrap bg-[#9A9FBF80] rounded-xl px-3 py-2 w-full relative gap-6\"\n>\n  <app-form-timer></app-form-timer>\n  <div *ngFor=\"let group of taskForm.Entities; let index = index\">\n    <p\n      (click)=\"active = index\"\n      [ngClass]=\"{\n        'bg-[#fff] text-primary rounded-lg shadow-lg': active === index\n      }\"\n      class=\"px-6 py-2 cursor-pointer\"\n    >\n      {{ group.Name }}group\n    </p>\n  </div>\n</div>\n\n<div *ngIf=\"taskForm.Entities[active]; else emptyState\" class=\"mt-4\">\n  <form-control\n    [dataType]=\"dataType\"\n    [formProperties]=\"taskForm.Entities[active].Properties\"\n  ></form-control>\n\n  <div class=\"flex gap-3 justify-end\">\n    <verbena-button\n      (click)=\"areRequiredPropertiesFilled()\"\n      text=\"CHECK\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n\n    <verbena-button\n      (click)=\"taskFormView = false\"\n      text=\"Close task form\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n\n    <verbena-button\n      class=\"verben-primary-button\"\n      (click)=\"sendTaskForm()\"\n      [disable]=\"!areRequiredPropertiesFilled()\"\n      text=\"Save\"\n    ></verbena-button>\n  </div>\n</div>\n\n<!-- Empty state template -->\n<ng-template #emptyState>\n  <p class=\"mt-4 p-4 text-gray-600 text-center\">\n    No entries available for the selected form group.\n  </p>\n</ng-template>\n\n} @else {\n<form\n  [formGroup]=\"form\"\n  class=\"flex flex-col px-3 pb-3 rounded-xl h-full w-full relative space-y-4\"\n  (ngSubmit)=\"handleSubmit()\"\n>\n  <verbena-input\n    name=\"Name\"\n    label=\"Name\"\n    formControlName=\"Name\"\n    placeHolder=\"Enter Name\"\n  />\n  <verbena-input\n    name=\"Description\"\n    label=\"Description\"\n    formControlName=\"Description\"\n    placeHolder=\"Enter Description\"\n  />\n\n  <div class=\"space-y-1\">\n    <label for=\"workflow\">Workflow</label>\n\n    <verben-drop-down\n      label=\"Workflow\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      placeholder=\"Select\"\n      [options]=\"workflows\"\n      optionLabel=\"Name\"\n      optionValue=\"Code\"\n      id=\"workflow\"\n      formControlName=\"WorkflowCode\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <div class=\"space-y-1\">\n    <label for=\"status\">Status</label>\n\n    <verben-drop-down\n      label=\"Status\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      [showClear]=\"true\"\n      placeholder=\"Null\"\n      [(options)]=\"statuses\"\n      id=\"status\"\n      formControlName=\"Status\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <!-- buttons -->\n  <div class=\"flex justify-between gap-4 my-2\">\n    <verbena-button\n      width=\"114px\"\n      height=\"39px\"\n      text=\"Delete\"\n      bgColor=\"#999999\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n    <verbena-button\n      [disable]=\"!taskForm || loadingTaskForm\"\n      (click)=\"taskFormView = true\"\n      [text]=\"loadingTaskForm ? 'Checking for form' : 'Fill task form'\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n    <verbena-button\n      type=\"submit\"\n      text=\"Save\"\n      bgColor=\"#FFE681\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      pd=\"10px 20px\"\n      width=\"114px\"\n      height=\"39px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n  </div>\n</form>\n}\n", dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1$2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1$2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: FormControlComponent, selector: "form-control", inputs: ["dataType", "value", "boolInputType", "formProperties"] }, { kind: "component", type: FormTimerComponent, selector: "app-form-timer", inputs: ["expiryDate"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tasks-form', template: "@if (taskFormView && taskForm) {\n<div\n  *ngIf=\"taskForm.Entities[active]\"\n  class=\"flex flex-wrap bg-[#9A9FBF80] rounded-xl px-3 py-2 w-full relative gap-6\"\n>\n  <app-form-timer></app-form-timer>\n  <div *ngFor=\"let group of taskForm.Entities; let index = index\">\n    <p\n      (click)=\"active = index\"\n      [ngClass]=\"{\n        'bg-[#fff] text-primary rounded-lg shadow-lg': active === index\n      }\"\n      class=\"px-6 py-2 cursor-pointer\"\n    >\n      {{ group.Name }}group\n    </p>\n  </div>\n</div>\n\n<div *ngIf=\"taskForm.Entities[active]; else emptyState\" class=\"mt-4\">\n  <form-control\n    [dataType]=\"dataType\"\n    [formProperties]=\"taskForm.Entities[active].Properties\"\n  ></form-control>\n\n  <div class=\"flex gap-3 justify-end\">\n    <verbena-button\n      (click)=\"areRequiredPropertiesFilled()\"\n      text=\"CHECK\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n\n    <verbena-button\n      (click)=\"taskFormView = false\"\n      text=\"Close task form\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n\n    <verbena-button\n      class=\"verben-primary-button\"\n      (click)=\"sendTaskForm()\"\n      [disable]=\"!areRequiredPropertiesFilled()\"\n      text=\"Save\"\n    ></verbena-button>\n  </div>\n</div>\n\n<!-- Empty state template -->\n<ng-template #emptyState>\n  <p class=\"mt-4 p-4 text-gray-600 text-center\">\n    No entries available for the selected form group.\n  </p>\n</ng-template>\n\n} @else {\n<form\n  [formGroup]=\"form\"\n  class=\"flex flex-col px-3 pb-3 rounded-xl h-full w-full relative space-y-4\"\n  (ngSubmit)=\"handleSubmit()\"\n>\n  <verbena-input\n    name=\"Name\"\n    label=\"Name\"\n    formControlName=\"Name\"\n    placeHolder=\"Enter Name\"\n  />\n  <verbena-input\n    name=\"Description\"\n    label=\"Description\"\n    formControlName=\"Description\"\n    placeHolder=\"Enter Description\"\n  />\n\n  <div class=\"space-y-1\">\n    <label for=\"workflow\">Workflow</label>\n\n    <verben-drop-down\n      label=\"Workflow\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      placeholder=\"Select\"\n      [options]=\"workflows\"\n      optionLabel=\"Name\"\n      optionValue=\"Code\"\n      id=\"workflow\"\n      formControlName=\"WorkflowCode\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <div class=\"space-y-1\">\n    <label for=\"status\">Status</label>\n\n    <verben-drop-down\n      label=\"Status\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      [showClear]=\"true\"\n      placeholder=\"Null\"\n      [(options)]=\"statuses\"\n      id=\"status\"\n      formControlName=\"Status\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <!-- buttons -->\n  <div class=\"flex justify-between gap-4 my-2\">\n    <verbena-button\n      width=\"114px\"\n      height=\"39px\"\n      text=\"Delete\"\n      bgColor=\"#999999\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n    <verbena-button\n      [disable]=\"!taskForm || loadingTaskForm\"\n      (click)=\"taskFormView = true\"\n      [text]=\"loadingTaskForm ? 'Checking for form' : 'Fill task form'\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n    <verbena-button\n      type=\"submit\"\n      text=\"Save\"\n      bgColor=\"#FFE681\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      pd=\"10px 20px\"\n      width=\"114px\"\n      height=\"39px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n  </div>\n</form>\n}\n" }]
        }], ctorParameters: () => [{ type: i1$2.FormBuilder }, { type: TaskFacade }], propDecorators: { currentData: [{
                type: Input
            }], onTaskFormSave: [{
                type: Output
            }], onSave: [{
                type: Output
            }] } });

class TasksComponent extends BaseDataViewComponent {
    cdr;
    taskFacade;
    config = {
        dataSource: [], // Populate from service
        columns: columns$4, // Your existing column definitions
        cardDataMapper: (task) => ({
            selected: false,
            title: task.Name,
            data: task,
            body: [
                { title: 'Name', value: task.Name },
                { title: 'Status', value: task.Status },
            ],
            children: [],
        }),
        onDetailView: (task) => {
            // Custom detail view logic
        },
    };
    tableRowActions = [
        { label: 'Pick Task', action: (data) => { }, divider: false },
        { label: 'Release Task', action: (data) => { }, divider: false },
        { label: 'Follow Task', action: (data) => { }, divider: true },
        { label: 'Pass On', action: (data) => { }, divider: false },
        { label: 'Pass Back', action: (data) => { }, divider: false },
        { label: 'Re-Assign', action: (data) => { }, divider: true },
        { label: 'View Operation', action: (data) => { }, divider: false },
    ];
    constructor(cdr, taskFacade) {
        super();
        this.cdr = cdr;
        this.taskFacade = taskFacade;
    }
    loadInitialData() {
        // this.userService.getRequests().subscribe(
        //   tasks => this.data.set(tasks)
        // );
        // this.data.set(generateWorkflows(5));
        super.loadInitialData();
        // this.data = this.service.getMockUserRequests();
        this.taskFacade.getRequests$().subscribe((data) => {
            this.data.set(data);
        });
        // this.userAccessRequestFacade.getRoles$().subscribe((data) => {
        //   this.roles.set(data);
        // });
        try {
            this.taskFacade.loadRequests().then(() => { });
        }
        catch (error) {
            // Handle error
        }
    }
    onStateChange(event) {
        switch (event.key) {
            case 'create':
                var newItem = new TaskModel({
                    WorkflowCode: '',
                    Status: TaskStatus.Active,
                    Flowable: '',
                    FlowableData: null,
                    CurrentActors: [],
                });
                this.taskFacade.addNewRequest(newItem);
                // const cardData: CardData = {
                //   selected: false,
                //   title: ,
                //   data: newGroup,
                //   body: [],
                //   children: [],
                // };
                // this.data = this.data.concat([newGroup]);
                // this.cardData.push(cardData);
                // this.userCardClicked(cardData);
                this.dataView.isTableView = false;
                break;
            // case 'filter':
            //   this.showFilter = event.value;
            //   break;
            // case 'sort':
            //   this.showSort = event.value;
            //   break;
            // case 'column':
            //   this.showColumn = event.value;
            //   break;
            default:
                break;
        }
    }
    getCardDataByIdentifier(code) {
        return this.cardData().find(({ data }) => data.data.Code === code);
    }
    loadMore() {
        // this.cardData = this.cardData.concat(this.cardData);
    }
    async onSave(data) {
        const payload = {
            ...this.currentData?.data,
            ...data,
        };
        await this.taskFacade.addRequest(payload);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: TaskFacade }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: TasksComponent, selector: "lib-tasks", usesInheritance: true, ngImport: i0, template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: true,\n      isToggle: true,\n    }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div table-content>\n      <lib-data-table\n        [data]=\"data()\"\n        [columns]=\"config.columns\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n      >\n        <ng-container libColumn=\"history\">\n          <ng-template #cell let-value let-deleteRow>\n            <a\n              [routerLink]=\"['/history']\"\n              routerLinkActive=\"router-link-active\"\n              class=\"underline text-[#0000FF]\"\n              >view history</a\n            >\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-row let-deleteRow>\n            <verben-pop-Up\n              #popup\n              [customStyles]=\"{ 'z-index': '99' }\"\n              [enableMouseLeave]=\"false\"\n              [customStyles]=\"{\n                border: '1px solid #d4a10780',\n                borderRadius: '5px',\n                backgroundColor: 'white'\n              }\"\n            >\n              <verben-svg\n                dropdown-trigger\n                icon=\"dots\"\n                [width]=\"2\"\n                [height]=\"12\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n              <div class=\"bg-white rounded-sm\" dropdown-content>\n                @for (item of tableRowActions; track item.label) {\n                <div\n                  (click)=\"item.action(row); popup.toggleDropdown()\"\n                  class=\"cursor-pointer py-2 px-2.5 hover:bg-primary\"\n                >\n                  {{ item.label }}\n                </div>\n                @if (item.divider) {\n                <hr class=\"bg-[#FFE681] h-1 rounded-xl border-0\" />\n                } }\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #header>\n            <strong>Actions</strong>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        (loadMoreClick)=\"loadMore()\"\n        #vdcv\n        dataId=\"Id\"\n        border=\"5px\"\n        [cardDataList]=\"cardData()\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"20px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"Id\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData()\"\n          >\n            <ng-template #card let-item>\n              <div (click)=\"currentData = vdcv.onItemClick(item)\" class=\"flex\">\n                <div\n                  (click)=\"currentData = vdcv.onItemClick(item)\"\n                  class=\"flex cursor-pointer w-full bg-secondary rounded-xl\"\n                >\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"flex flex-col py-2 px-4 w-full\">\n                    <div class=\"flex items-center gap-4 justify-between\">\n                      <div class=\"grid gap-y-2\">\n                        <span class=\"font-semibold text-[#404040]\">{{\n                          item.title\n                        }}</span>\n                        <p class=\"flex items-center\">\n                          <label for=\"phone\" class=\"text-[10px] font-light\"\n                            >Status:</label\n                          >\n                          <span id=\"phone\" class=\"text-sm\">{{\n                            item.data.Status\n                          }}</span>\n                        </p>\n                      </div>\n\n                      <div class=\"grid gap-y-2\">\n                        <span for=\"role\" class=\"font-light\">{{\n                          item.data.WorkflowCode\n                        }}</span>\n                        <a\n                          [routerLink]=\"['/history']\"\n                          routerLinkActive=\"router-link-active\"\n                          class=\"underline text-[#0000FF] text-xs\"\n                          >view history</a\n                        >\n                      </div>\n                    </div>\n\n                    <!-- <div class=\"flex\">\n                      <span class=\"font-normal text-sm\">{{ item.title }}</span>\n                    </div>\n                    @for (ciItem of item.body; track ciItem.value) {\n                    <div class=\"\">\n                      <span class=\"text-muted font-light text-xs\"\n                        >{{ ciItem.title }}:</span\n                      >\n                      <span class=\"text-black\">{{ ciItem.value }}</span>\n                    </div>\n                    } -->\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <!-- <lib-user-request-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onApproval)=\"onApprove($event)\"\n            ></lib-user-request-form> -->\n            <tasks-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onSave)=\"onSave($event)\"\n            ></tasks-form>\n          </ng-template>\n        </verben-right-card-data-view>\n\n        <verben-card-data-view-footer class=\"float-right\">\n          <div class=\"flex gap-2\">\n            <!-- <span class=\"paginator-text\"\n              >{{ data().length }} records loaded</span\n            > -->\n            <span></span>\n            <button (click)=\"loadMore()\" class=\"load-more\">Load more</button>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <lib-data-columns\n        [columns]=\"config.columns\"\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n      ></lib-data-columns>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <lib-data-sort\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (sortApplied)=\"onSortUpdated($event)\"\n      ></lib-data-sort>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data()\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n</div>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: i8.DataColumnsComponent, selector: "lib-data-columns", inputs: ["columns", "enableDragAndDrop", "maxVisibleItems"], outputs: ["columnsUpdated"] }, { kind: "component", type: i8.DataSortComponent, selector: "lib-data-sort", inputs: ["columns", "data", "enableDragAndDrop"], outputs: ["sortApplied", "resetFilter"] }, { kind: "directive", type: i5.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "component", type: TasksFormComponent, selector: "tasks-form", inputs: ["currentData"], outputs: ["onTaskFormSave", "onSave"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-tasks', template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: true,\n      isToggle: true,\n    }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div table-content>\n      <lib-data-table\n        [data]=\"data()\"\n        [columns]=\"config.columns\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n      >\n        <ng-container libColumn=\"history\">\n          <ng-template #cell let-value let-deleteRow>\n            <a\n              [routerLink]=\"['/history']\"\n              routerLinkActive=\"router-link-active\"\n              class=\"underline text-[#0000FF]\"\n              >view history</a\n            >\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-row let-deleteRow>\n            <verben-pop-Up\n              #popup\n              [customStyles]=\"{ 'z-index': '99' }\"\n              [enableMouseLeave]=\"false\"\n              [customStyles]=\"{\n                border: '1px solid #d4a10780',\n                borderRadius: '5px',\n                backgroundColor: 'white'\n              }\"\n            >\n              <verben-svg\n                dropdown-trigger\n                icon=\"dots\"\n                [width]=\"2\"\n                [height]=\"12\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n              <div class=\"bg-white rounded-sm\" dropdown-content>\n                @for (item of tableRowActions; track item.label) {\n                <div\n                  (click)=\"item.action(row); popup.toggleDropdown()\"\n                  class=\"cursor-pointer py-2 px-2.5 hover:bg-primary\"\n                >\n                  {{ item.label }}\n                </div>\n                @if (item.divider) {\n                <hr class=\"bg-[#FFE681] h-1 rounded-xl border-0\" />\n                } }\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #header>\n            <strong>Actions</strong>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        (loadMoreClick)=\"loadMore()\"\n        #vdcv\n        dataId=\"Id\"\n        border=\"5px\"\n        [cardDataList]=\"cardData()\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"20px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"Id\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData()\"\n          >\n            <ng-template #card let-item>\n              <div (click)=\"currentData = vdcv.onItemClick(item)\" class=\"flex\">\n                <div\n                  (click)=\"currentData = vdcv.onItemClick(item)\"\n                  class=\"flex cursor-pointer w-full bg-secondary rounded-xl\"\n                >\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"flex flex-col py-2 px-4 w-full\">\n                    <div class=\"flex items-center gap-4 justify-between\">\n                      <div class=\"grid gap-y-2\">\n                        <span class=\"font-semibold text-[#404040]\">{{\n                          item.title\n                        }}</span>\n                        <p class=\"flex items-center\">\n                          <label for=\"phone\" class=\"text-[10px] font-light\"\n                            >Status:</label\n                          >\n                          <span id=\"phone\" class=\"text-sm\">{{\n                            item.data.Status\n                          }}</span>\n                        </p>\n                      </div>\n\n                      <div class=\"grid gap-y-2\">\n                        <span for=\"role\" class=\"font-light\">{{\n                          item.data.WorkflowCode\n                        }}</span>\n                        <a\n                          [routerLink]=\"['/history']\"\n                          routerLinkActive=\"router-link-active\"\n                          class=\"underline text-[#0000FF] text-xs\"\n                          >view history</a\n                        >\n                      </div>\n                    </div>\n\n                    <!-- <div class=\"flex\">\n                      <span class=\"font-normal text-sm\">{{ item.title }}</span>\n                    </div>\n                    @for (ciItem of item.body; track ciItem.value) {\n                    <div class=\"\">\n                      <span class=\"text-muted font-light text-xs\"\n                        >{{ ciItem.title }}:</span\n                      >\n                      <span class=\"text-black\">{{ ciItem.value }}</span>\n                    </div>\n                    } -->\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <!-- <lib-user-request-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onApproval)=\"onApprove($event)\"\n            ></lib-user-request-form> -->\n            <tasks-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onSave)=\"onSave($event)\"\n            ></tasks-form>\n          </ng-template>\n        </verben-right-card-data-view>\n\n        <verben-card-data-view-footer class=\"float-right\">\n          <div class=\"flex gap-2\">\n            <!-- <span class=\"paginator-text\"\n              >{{ data().length }} records loaded</span\n            > -->\n            <span></span>\n            <button (click)=\"loadMore()\" class=\"load-more\">Load more</button>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <lib-data-columns\n        [columns]=\"config.columns\"\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n      ></lib-data-columns>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <lib-data-sort\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (sortApplied)=\"onSortUpdated($event)\"\n      ></lib-data-sort>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data()\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: TaskFacade }] });

var SearchOperator;
(function (SearchOperator) {
    SearchOperator["And"] = "And";
    SearchOperator["Or"] = "Or";
})(SearchOperator || (SearchOperator = {}));

var SearchPropertySign;
(function (SearchPropertySign) {
    SearchPropertySign["EQ"] = "EQ";
    SearchPropertySign["NEQ"] = "NEQ";
    SearchPropertySign["GT"] = "GT";
    SearchPropertySign["GTE"] = "GTE";
    SearchPropertySign["LT"] = "LT";
    SearchPropertySign["LTE"] = "LTE";
    SearchPropertySign["LIKE"] = "LIKE";
})(SearchPropertySign || (SearchPropertySign = {}));

class LabelService {
    utilService;
    server;
    cache = new Map();
    inFlightRequests = new Map();
    constructor(utilService, server) {
        this.utilService = utilService;
        this.server = server;
    }
    async getAsyncLabel(value, entity, labelProp, env, key = 'Code') {
        const cacheKey = `${entity}_${labelProp}_${value}_${env}_${key}`;
        if (this.cache.has(cacheKey)) {
            const value = this.cache.get(cacheKey);
            return value;
        }
        var payload = {
            Fields: [labelProp],
            SearchKeyValues: [
                {
                    PropertyName: key,
                    EntityValue: value,
                    Operator: SearchOperator.And,
                    Sign: SearchPropertySign.EQ,
                }
            ],
        };
        this.utilService.sendBI(true);
        const res = await this.server.post(`SearchDynamic${entity}/0/1`, payload, env);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return '';
        }
        else {
            const result = res.Result;
            const label = result.length > 0 ? result[0] : value;
            this.cache.set(cacheKey, label);
            return label;
        }
    }
    async getAsyncLabelWithRequestTracking(value, entity, labelProp, env, key = 'Code') {
        const cacheKey = `${entity}_${labelProp}_${value}_${env}_${key}`;
        if (this.cache.has(cacheKey)) {
            return this.cache.get(cacheKey);
        }
        if (this.inFlightRequests.has(cacheKey)) {
            return this.inFlightRequests.get(cacheKey);
        }
        const requestPromise = (async () => {
            const payload = {
                Fields: [labelProp],
                SearchKeyValues: [
                    {
                        PropertyName: key,
                        EntityValue: value,
                        Operator: SearchOperator.And,
                        Sign: SearchPropertySign.EQ,
                    },
                ],
            };
            this.utilService.sendBI(true);
            const res = await this.server.post(`SearchDynamic${entity}/0/1`, payload, env);
            this.utilService.sendBI(false);
            let label;
            if (res instanceof ErrorResponse) {
                label = '';
            }
            else {
                const result = res.Result;
                label = result.length > 0 ? result[0] : value;
            }
            this.cache.set(cacheKey, label);
            this.inFlightRequests.delete(cacheKey);
            return label;
        })();
        // Save the in-flight request
        this.inFlightRequests.set(cacheKey, requestPromise);
        return requestPromise;
    }
    async getAsyncLabelWithRequestTrackingNoGateway(value, entity, labelProp, env, controller, key = 'Code') {
        const cacheKey = `${entity}_${labelProp}_${value}_${env}_${key}_${controller}`;
        if (this.cache.has(cacheKey)) {
            return this.cache.get(cacheKey);
        }
        if (this.inFlightRequests.has(cacheKey)) {
            return this.inFlightRequests.get(cacheKey);
        }
        const requestPromise = (async () => {
            const payload = {
                Fields: [labelProp],
                SearchKeyValues: [
                    {
                        PropertyName: key,
                        EntityValue: value,
                        Operator: SearchOperator.And,
                        Sign: SearchPropertySign.EQ,
                    },
                ],
            };
            this.utilService.sendBI(true);
            const res = await this.server.post(`${controller}/SearchDynamic${entity}s/0/1`, payload, env);
            this.utilService.sendBI(false);
            let label;
            if (res instanceof ErrorResponse) {
                label = '';
            }
            else {
                const result = res.Result;
                label = result.length > 0 ? result[0] : value;
            }
            this.cache.set(cacheKey, label);
            this.inFlightRequests.delete(cacheKey);
            return label;
        })();
        // Save the in-flight request
        this.inFlightRequests.set(cacheKey, requestPromise);
        return requestPromise;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelService, deps: [{ token: UtilService }, { token: HttpWebRequestService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }] });

class AsyncLabelPipe {
    labelService;
    constructor(labelService) {
        this.labelService = labelService;
    }
    transform(code, entity, labelProp, env, key = 'Code') {
        if (!code)
            return of('');
        return from(this.labelService.getAsyncLabelWithRequestTracking(code, entity, labelProp, env, key));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AsyncLabelPipe, deps: [{ token: LabelService }], target: i0.ɵɵFactoryTarget.Pipe });
    static ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: AsyncLabelPipe, isStandalone: true, name: "asyncLabel" });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: AsyncLabelPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'asyncLabel',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: LabelService }] });

class SharedModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SharedModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: SharedModule, imports: [CommonModule, AsyncLabelPipe], exports: [CommonModule,
            DataTableModule,
            CardModule,
            SvgModule,
            DataViewModule,
            CardDataViewModule,
            SortTableModule,
            VisibleColumnModule,
            TableFilterModule,
            DataExportModule,
            FormsModule$1,
            ReactiveFormsModule,
            VerbenaInputModule,
            VerbenaButtonModule,
            VerbenaBadgeModule,
            VerbenDialogueModule,
            DropDownModule,
            VerbenaTextareaModule,
            VerbenaSwitchModule,
            VerbenPopUpModule,
            ChipModule,
            DatePickerModule,
            DataColumnsModule,
            DataXportModule,
            DataSortModule,
            DataFilterModule,
            AsyncLabelPipe,
            EditorModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SharedModule, imports: [CommonModule, CommonModule,
            DataTableModule,
            CardModule,
            SvgModule,
            DataViewModule,
            CardDataViewModule,
            SortTableModule,
            VisibleColumnModule,
            TableFilterModule,
            DataExportModule,
            FormsModule$1,
            ReactiveFormsModule,
            VerbenaInputModule,
            VerbenaButtonModule,
            VerbenaBadgeModule,
            VerbenDialogueModule,
            DropDownModule,
            VerbenaTextareaModule,
            VerbenaSwitchModule,
            VerbenPopUpModule,
            ChipModule,
            DatePickerModule,
            DataColumnsModule,
            DataXportModule,
            DataSortModule,
            DataFilterModule,
            EditorModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SharedModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [CommonModule, AsyncLabelPipe],
                    exports: [
                        CommonModule,
                        DataTableModule,
                        CardModule,
                        SvgModule,
                        DataViewModule,
                        CardDataViewModule,
                        SortTableModule,
                        VisibleColumnModule,
                        TableFilterModule,
                        DataExportModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        VerbenaInputModule,
                        VerbenaButtonModule,
                        VerbenaBadgeModule,
                        VerbenDialogueModule,
                        DropDownModule,
                        VerbenaTextareaModule,
                        VerbenaSwitchModule,
                        VerbenPopUpModule,
                        ChipModule,
                        DatePickerModule,
                        DataColumnsModule,
                        DataXportModule,
                        DataSortModule,
                        DataFilterModule,
                        AsyncLabelPipe,
                        EditorModule
                    ],
                }]
        }] });

class TaskFormComponent {
    form = input.required();
    active = 0;
    dataType = DataType.Text;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "18.2.13", type: TaskFormComponent, selector: "lib-task-form", inputs: { form: { classPropertyName: "form", publicName: "form", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0, template: "<div\n  *ngIf=\"form().Entities[active]\"\n  class=\"flex flex-wrap bg-[#9A9FBF80] rounded-xl px-3 py-2 w-full relative gap-6\"\n>\n  <app-form-timer></app-form-timer>\n  <div *ngFor=\"let group of form().Entities; let index = index\">\n    <p\n      (click)=\"active = index\"\n      [ngClass]=\"{\n        'bg-[#fff] text-primary rounded-lg shadow-lg': active === index\n      }\"\n      class=\"px-6 py-2 cursor-pointer\"\n    >\n      {{ group.Name }}group\n    </p>\n  </div>\n</div>\n\n<div *ngIf=\"form().Entities[active]; else emptyState\" class=\"mt-4\">\n  <form-control\n    [dataType]=\"dataType\"\n    [formProperties]=\"form().Entities[active].Properties\"\n  ></form-control>\n\n  <!-- <verbena-button\nclass=\"verben-primary-button\"\n(click)=\"saveUser()\"\n[disable]=\"areRequiredPropertiesFilled(form())\"\ntext=\"Save\"\n></verbena-button> -->\n</div>\n\n<!-- Empty state template -->\n<ng-template #emptyState>\n  <p class=\"mt-4 p-4 text-gray-600 text-center\">\n    No entries available for the selected form group.\n  </p>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: FormControlComponent, selector: "form-control", inputs: ["dataType", "value", "boolInputType", "formProperties"] }, { kind: "component", type: FormTimerComponent, selector: "app-form-timer", inputs: ["expiryDate"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-task-form', template: "<div\n  *ngIf=\"form().Entities[active]\"\n  class=\"flex flex-wrap bg-[#9A9FBF80] rounded-xl px-3 py-2 w-full relative gap-6\"\n>\n  <app-form-timer></app-form-timer>\n  <div *ngFor=\"let group of form().Entities; let index = index\">\n    <p\n      (click)=\"active = index\"\n      [ngClass]=\"{\n        'bg-[#fff] text-primary rounded-lg shadow-lg': active === index\n      }\"\n      class=\"px-6 py-2 cursor-pointer\"\n    >\n      {{ group.Name }}group\n    </p>\n  </div>\n</div>\n\n<div *ngIf=\"form().Entities[active]; else emptyState\" class=\"mt-4\">\n  <form-control\n    [dataType]=\"dataType\"\n    [formProperties]=\"form().Entities[active].Properties\"\n  ></form-control>\n\n  <!-- <verbena-button\nclass=\"verben-primary-button\"\n(click)=\"saveUser()\"\n[disable]=\"areRequiredPropertiesFilled(form())\"\ntext=\"Save\"\n></verbena-button> -->\n</div>\n\n<!-- Empty state template -->\n<ng-template #emptyState>\n  <p class=\"mt-4 p-4 text-gray-600 text-center\">\n    No entries available for the selected form group.\n  </p>\n</ng-template>\n" }]
        }] });

class FileUploadModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileUploadModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FileUploadModule, declarations: [FileUploadComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            TableFilterModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule], exports: [FileUploadComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileUploadModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            TableFilterModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FileUploadModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FileUploadComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        DataTableModule,
                        SvgModule,
                        DataViewModule, VerbenaButtonModule,
                        CardDataViewModule,
                        DropDownModule,
                        TableFilterModule,
                        SortTableModule,
                        DataExportModule,
                        VerbenaInputModule,
                    ],
                    exports: [FileUploadComponent],
                }]
        }] });

class FormControlerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormControlerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FormControlerModule, declarations: [FormControlComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            VerbenaSwitchModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            FileUploadModule,
            VerbenaTextareaModule], exports: [FormControlComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormControlerModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            VerbenaSwitchModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            FileUploadModule,
            VerbenaTextareaModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormControlerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FormControlComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        DataTableModule,
                        SvgModule,
                        VerbenPopUpModule,
                        DataViewModule, VerbenaButtonModule,
                        CardDataViewModule,
                        DropDownModule,
                        VerbenaSwitchModule,
                        TableFilterModule,
                        VisibleColumnModule,
                        SortTableModule,
                        DataExportModule,
                        VerbenaInputModule,
                        FileUploadModule,
                        VerbenaTextareaModule,
                    ],
                    exports: [FormControlComponent],
                }]
        }] });

class FormTimerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormTimerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FormTimerModule, declarations: [FormTimerComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule], exports: [FormTimerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormTimerModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormTimerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FormTimerComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                    ],
                    exports: [FormTimerComponent],
                }]
        }] });

class TaskFormModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFormModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: TaskFormModule, declarations: [TaskFormComponent], imports: [CommonModule,
            // FormsModule,
            // ReactiveFormsModule,
            // DataTableModule,
            // SvgModule,
            // VerbenPopUpModule,
            // DataViewModule,
            // VerbenaButtonModule,
            // CardDataViewModule,
            // DropDownModule,
            // VerbenaSwitchModule,
            // TableFilterModule,
            // VisibleColumnModule,
            // SortTableModule,
            // DataExportModule,
            // VerbenaInputModule,
            FormControlerModule,
            FormTimerModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFormModule, imports: [CommonModule,
            // FormsModule,
            // ReactiveFormsModule,
            // DataTableModule,
            // SvgModule,
            // VerbenPopUpModule,
            // DataViewModule,
            // VerbenaButtonModule,
            // CardDataViewModule,
            // DropDownModule,
            // VerbenaSwitchModule,
            // TableFilterModule,
            // VisibleColumnModule,
            // SortTableModule,
            // DataExportModule,
            // VerbenaInputModule,
            FormControlerModule,
            FormTimerModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskFormModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TaskFormComponent],
                    imports: [
                        CommonModule,
                        // FormsModule,
                        // ReactiveFormsModule,
                        // DataTableModule,
                        // SvgModule,
                        // VerbenPopUpModule,
                        // DataViewModule,
                        // VerbenaButtonModule,
                        // CardDataViewModule,
                        // DropDownModule,
                        // VerbenaSwitchModule,
                        // TableFilterModule,
                        // VisibleColumnModule,
                        // SortTableModule,
                        // DataExportModule,
                        // VerbenaInputModule,
                        FormControlerModule,
                        FormTimerModule,
                    ],
                }]
        }] });

class TasksModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: TasksModule, declarations: [TasksComponent, TasksFormComponent], imports: [CommonModule,
            SharedModule,
            TaskFormModule,
            FormControlerModule,
            FormTimerModule,
            RouterLink], exports: [TasksComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksModule, providers: [TasksService], imports: [CommonModule,
            SharedModule,
            TaskFormModule,
            FormControlerModule,
            FormTimerModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TasksModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TasksComponent, TasksFormComponent],
                    imports: [
                        CommonModule,
                        SharedModule,
                        TaskFormModule,
                        FormControlerModule,
                        FormTimerModule,
                        RouterLink,
                    ],
                    providers: [TasksService],
                    exports: [TasksComponent],
                }]
        }] });

const columns$3 = [
    {
        id: 'task',
        header: 'TASK',
        accessorKey: 'Name',
    },
    {
        id: 'stage',
        header: 'STAGE',
        accessorFn: (row) => row.FullStages?.slice(0, 3)
            ?.map(({ Name }) => Name)
            .join(', ') +
            (row.FullStages?.length && row.FullStages?.length > 3
                ? ` ... + ${row.FullStages?.length - 3}`
                : ''),
    },
    {
        id: 'history',
        header: 'HISTORY',
        accessorKey: 'Id',
    },
    { id: 'actions', header: 'Actions' },
];

class MyQueueService {
    httpService;
    BASE_URL = 'Task';
    constructor(httpService) {
        this.httpService = httpService;
    }
    /**
     * Get tasks with pagination and sorting
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the tasks
     */
    getTasks(skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetTasks/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get tasks with additional parameter, pagination and sorting
     * @param param Search parameter
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the filtered tasks
     */
    getTaskWithParam(param, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetTaskWithParam/${param}/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Save multiple tasks
     * @param requests Array of tasks to save
     * @returns Promise containing the save operation result
     */
    saveTasks(requests) {
        const url = `${this.BASE_URL}/SaveTasks`;
        return this.httpService.post(url, requests);
    }
    /**
     * Approve or reject multiple tasks
     * @param requests Array of tasks to save
     * @param isApproval True for approval, false for decline
     * @returns Promise containing the save operation result
     */
    processTasks(requests, isApproval) {
        const url = `${this.BASE_URL}/TaskAction/${isApproval}`;
        return this.httpService.post(url, requests);
    }
    /**
     * Delete multiple tasks
     * @param requestIds Array of request IDs to delete
     * @returns Observable containing the delete operation result
     */
    deleteTasks(requestIds) {
        const url = `${this.BASE_URL}/DeleteTasks`;
        return this.httpService.delete(`${url}?data=${requestIds.join(',')}`);
    }
    getTasksForUser(user, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetTasksForUser/${skip}/${limit}/${sortParam}/${sortOrder}/${user}`;
        return this.httpService.get(url);
    }
    getQueueTasksForUser(user, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetQueueTasksForUser/${skip}/${limit}/${sortParam}/${sortOrder}/${user}`;
        return this.httpService.get(url);
    }
    getPossibleTasksForUser(user, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetPossibleTasksForUser/${skip}/${limit}/${sortParam}/${sortOrder}/${user}`;
        return this.httpService.get(url);
    }
    getNextActions(taskCode) {
        const url = `${this.BASE_URL}/GetNextActions/${taskCode}`;
        return this.httpService.get(url);
    }
    getPreviousActions(taskCode) {
        const url = `${this.BASE_URL}/GetPreviousActions/${taskCode}`;
        return this.httpService.get(url);
    }
    getAllPreviousActions(taskCode) {
        const url = `${this.BASE_URL}/GetAllPreviousActions/${taskCode}`;
        return this.httpService.get(url);
    }
    getNextActors(taskCode, stageCode) {
        const url = `${this.BASE_URL}/GetNextActors/${taskCode}${stageCode ? '/' + stageCode : ''}`;
        return this.httpService.get(url);
    }
    passOn(fromStage, toStage, task, comment, recipient) {
        const url = `${this.BASE_URL}/PassOn/${fromStage}/${toStage}/${comment}${recipient ? '/' + recipient : ''}`;
        return this.httpService.post(url, task);
    }
    passBack(fromStage, toStage, task, comment, recipient) {
        const url = `${this.BASE_URL}/PassBack/${fromStage}/${toStage}/${comment}${recipient ? '/' + recipient : ''}`;
        return this.httpService.post(url, task);
    }
    pickTask(targetStage, task, comment, recipient) {
        const url = `${this.BASE_URL}/PickTask/${comment}/${targetStage}${recipient ? '/' + recipient : ''}`;
        return this.httpService.post(url, task);
    }
    unPickTask(targetStage, task, comment, recipient) {
        const url = `${this.BASE_URL}/UnPickTask/${comment}/${targetStage}${recipient ? '/' + recipient : ''}`;
        return this.httpService.post(url, task);
    }
    followTask(actorId, task) {
        const url = `${this.BASE_URL}/FollowTask/${actorId}`;
        return this.httpService.post(url, task);
    }
    unFollowTask(taskId, actorId
    // task: Task,
    ) {
        const url = `${this.BASE_URL}/UnFollowTask/${taskId}/${actorId}`;
        return this.httpService.post(url, {});
    }
    reAssign(task, comment, fromUser, toUser) {
        const url = `${this.BASE_URL}/Reassign/${comment}/${toUser}/${fromUser}`;
        return this.httpService.post(url, task);
    }
    skipTo(fromStage, toStage, task, comment, recipient, isBackward = false) {
        const url = `${this.BASE_URL}/SkipTo/${fromStage}/${toStage}/${comment}${recipient ? '/' + recipient : ''}/${isBackward}`;
        return this.httpService.post(url, task);
    }
    getCurrentFormsForTask(taskCode) {
        const url = `Task/GetCurrentFormsForTask/${taskCode}`;
        return this.httpService.get(url);
    }
    fillForm(form, taskCode) {
        const url = `Task/FillForm/${taskCode}`;
        return this.httpService.post(url, form);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueService, deps: [{ token: HttpWebRequestService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: HttpWebRequestService }] });

class MyQueueState {
    updating$ = new BehaviorSubject(false);
    tasks$ = new BehaviorSubject([]);
    queryParams$ = new BehaviorSubject({
        skip: 0,
        limit: 40,
        sortParam: 'CreatedAt',
        sortOrder: SortDirection.Asc,
    });
    nextActions$ = new BehaviorSubject([]);
    nextActors$ = new BehaviorSubject([]);
    taskForms$ = new BehaviorSubject([]);
    isUpdating$() {
        return this.updating$.asObservable();
    }
    setUpdating(isUpdating) {
        this.updating$.next(isUpdating);
    }
    getRequests$() {
        return this.tasks$.asObservable();
    }
    setRequests(tasks) {
        this.tasks$.next(tasks);
    }
    getNextActions$() {
        return this.nextActions$.asObservable();
    }
    getNextActors$() {
        return this.nextActors$.asObservable();
    }
    getTaskForms$() {
        return this.taskForms$.asObservable();
    }
    setNextActions(nextActions) {
        this.nextActions$.next(nextActions);
    }
    setNextActors(nextActors) {
        this.nextActors$.next(nextActors);
    }
    setTaskForms(taskForms) {
        this.taskForms$.next(taskForms);
    }
    getQueryParams$() {
        return this.queryParams$.asObservable();
    }
    getQueryParamsValue() {
        return this.queryParams$.getValue();
    }
    updateQueryParams(params) {
        this.queryParams$.next({ ...this.queryParams$.getValue(), ...params });
    }
    addRequest(task) {
        const currentValue = this.tasks$.getValue();
        this.tasks$.next([...currentValue, task]);
    }
    updateRequest(updatedRequest) {
        const tasks = this.tasks$.getValue();
        const index = tasks.findIndex((r) => r.Id === updatedRequest.Id);
        if (index !== -1) {
            tasks[index] = updatedRequest;
            this.tasks$.next([...tasks]);
        }
    }
    removeRequest(taskId) {
        const currentValue = this.tasks$.getValue();
        this.tasks$.next(currentValue.filter((r) => r.Id !== taskId));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueState, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueState, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueState, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class MyQueueFacade {
    service;
    state;
    utilService;
    constructor(service, state, utilService) {
        this.service = service;
        this.state = state;
        this.utilService = utilService;
        this.isUpdating$().subscribe((loading) => {
            this.utilService.sendBI(loading);
        });
    }
    isUpdating$() {
        return this.state.isUpdating$();
    }
    getRequests$() {
        return this.state.getRequests$();
    }
    getNextActions$() {
        return this.state.getNextActions$();
    }
    getNextActors$() {
        return this.state.getNextActors$();
    }
    getTaskForms$() {
        return this.state.getTaskForms$();
    }
    getQueryParams$() {
        return this.state.getQueryParams$();
    }
    async loadRequests(queue = false) {
        try {
            this.state.setUpdating(true);
            const params = this.state.getQueryParamsValue();
            const requests = queue
                ? await this.service.getQueueTasksForUser(params.user || '', params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder)
                : await this.service.getTasksForUser(params.user || '', params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder);
            this.state.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async loadRequestsWithParam(param) {
        try {
            this.state.setUpdating(true);
            const params = this.state.getQueryParamsValue();
            const requests = await this.service.getTaskWithParam(param, params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder);
            this.state.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    updateQueryParams(params) {
        this.state.updateQueryParams(params);
        // this.loadRequests();
    }
    async addRequest(request) {
        try {
            this.state.setUpdating(true);
            const newRequest = { ...request };
            this.state.addRequest(newRequest);
            await this.service.saveTasks([newRequest]);
            await this.loadRequests(); // Reload to get server-side changes
        }
        catch (error) {
            console.error('Failed to add request:', error);
            this.state.removeRequest(request.Id);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async updateRequest(request) {
        try {
            this.state.setUpdating(true);
            await this.service.saveTasks([request]);
            this.state.updateRequest(request);
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async deleteRequest(requestId) {
        try {
            this.state.setUpdating(true);
            await lastValueFrom(this.service.deleteTasks([requestId]));
            this.state.removeRequest(requestId);
        }
        catch (error) {
            console.error('Failed to delete request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async approveRequest(request) {
        try {
            this.state.setUpdating(true);
            const response = await this.service.processTasks([request], true);
            // console.log(response);
            const data = response?.[0];
            if (data) {
                this.state.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async loadNextActions(taskCode) {
        try {
            this.state.setUpdating(true);
            const params = this.state.getQueryParamsValue();
            const requests = await this.service.getNextActions(taskCode);
            this.state.setNextActions(requests);
            return requests;
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async loadPreviousActions(taskCode) {
        try {
            this.state.setUpdating(true);
            const requests = await this.service.getPreviousActions(taskCode);
            this.state.setNextActions(requests);
            return requests;
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async loadAllPreviousActions(taskCode) {
        try {
            this.state.setUpdating(true);
            const requests = await this.service.getAllPreviousActions(taskCode);
            this.state.setNextActions(requests);
            return requests;
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async loadNextActors(taskCode, stageCode) {
        try {
            this.state.setUpdating(true);
            const params = this.state.getQueryParamsValue();
            const requests = await this.service.getNextActors(taskCode, stageCode);
            this.state.setNextActors(requests);
            return requests;
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async loadTaskForms(taskCode) {
        try {
            this.state.setUpdating(true);
            const requests = await this.service.getCurrentFormsForTask(taskCode);
            this.state.setTaskForms(requests);
            return requests;
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async passOn(action, request, comment, recipient) {
        try {
            this.state.setUpdating(true);
            const response = await this.service.passOn(action.FromStage, action.ToStage, {
                ...request,
                FullStages: [],
                CurrentActors: request.CurrentActors.map((c) => ({
                    ...c,
                    ActorTags: [],
                })),
            }, comment, recipient ?? undefined);
            // console.log(response);
            const data = response;
            if (data) {
                this.state.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async passBack(action, request, comment, recipient) {
        try {
            this.state.setUpdating(true);
            const response = await this.service.passOn(
            // Alternate from and to stage o.
            action.ToStage, action.FromStage, {
                ...request,
                FullStages: [],
                CurrentActors: request.CurrentActors.map((c) => ({
                    ...c,
                    ActorTags: [],
                })),
            }, comment, recipient ?? undefined);
            // console.log(response);
            const data = response;
            if (data) {
                this.state.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async skipTo(action, request, comment, recipient) {
        try {
            this.state.setUpdating(true);
            const response = await this.service.passOn(action.FromStage, action.ToStage, {
                ...request,
                FullStages: [],
                CurrentActors: request.CurrentActors.map((c) => ({
                    ...c,
                    ActorTags: [],
                })),
            }, comment, recipient ?? undefined);
            // console.log(response);
            const data = response;
            if (data) {
                this.state.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async pickTask(action, request, comment, recipient) {
        try {
            this.state.setUpdating(true);
            const response = await this.service.passOn(action.FromStage, action.ToStage, {
                ...request,
                FullStages: [],
                CurrentActors: request.CurrentActors.map((c) => ({
                    ...c,
                    ActorTags: [],
                })),
            }, comment, recipient ?? undefined);
            // console.log(response);
            const data = response;
            if (data) {
                this.state.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async reAssign(request, comment) {
        try {
            this.state.setUpdating(true);
            const response = await this.service.reAssign({
                ...request,
                FullStages: [],
                CurrentActors: request.CurrentActors.map((c) => ({
                    ...c,
                    ActorTags: [],
                })),
            }, comment);
            // console.log(response);
            const data = response;
            if (data) {
                this.state.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    async fillForm(form, taskCode) {
        try {
            this.state.setUpdating(true);
            const filledForm = await this.service.fillForm(form, taskCode);
            return filledForm;
        }
        catch (error) {
            console.error('Failed to fill form:', error);
            throw error;
        }
        finally {
            this.state.setUpdating(false);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueFacade, deps: [{ token: MyQueueService }, { token: MyQueueState }, { token: UtilService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueFacade, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueFacade, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: MyQueueService }, { type: MyQueueState }, { type: UtilService }] });

class MyQueueComponent extends BaseDataViewComponent {
    cdr;
    facade;
    isGeneral = input(false);
    user;
    config = {
        dataSource: [], // Populate from service
        columns: columns$3, // Your existing column definitions
        cardDataMapper: (task) => ({
            selected: false,
            title: task.Name,
            data: task,
            body: [
                { title: 'Name', value: task.Name },
                { title: 'Status', value: task.Status },
            ],
            children: [],
        }),
        onDetailView: (task) => {
            // Custom detail view logic
        },
    };
    selectedTaskCode = null;
    activeActionType = null;
    comment = '';
    isModalVisible = false;
    tableRowActions = [
        { label: 'Pick Task', action: (data) => { }, divider: false },
        { label: 'Release Task', action: (data) => { }, divider: false },
        { label: 'Follow Task', action: (data) => { }, divider: true },
        {
            label: 'Pass On',
            action: (data) => {
                // console.log(data);
                this.activeActionType = ActionType.PassOn;
                this.selectedTaskCode = data.Code;
                this.facade.loadNextActions(data.Code).then((actions) => {
                    if (actions.length === 1) {
                        this.selectedAction = actions[0];
                        this.facade
                            .loadNextActors(data.Code, this.selectedAction?.Code)
                            .then((actors) => { });
                    }
                });
                this.facade.loadTaskForms(data.Code).then((forms) => { });
                // console.log(this.selectedTaskCode);
            },
            divider: false,
        },
        {
            label: 'Pass Back',
            action: (data) => {
                this.activeActionType = ActionType.PassBack;
                this.selectedTaskCode = data.Code;
                this.facade.loadPreviousActions(data.Code).then((actions) => { });
            },
            divider: false,
        },
        {
            label: 'Skip To',
            action: (data) => {
                this.activeActionType = ActionType.SkipTo;
                this.selectedTaskCode = data.Code;
                this.facade.loadAllPreviousActions(data.Code).then((actions) => { });
            },
            divider: false,
        },
        {
            label: 'Re-Assign',
            action: (data) => {
                this.activeActionType = ActionType.ReAssign;
                this.selectedTaskCode = data.Code;
            },
            divider: true,
        },
        { label: 'View Operation', action: (data) => { }, divider: false },
    ];
    nextActions = [];
    nextActors = [];
    stageForm = null;
    active = 0;
    dataType = DataType.Text;
    recipientCode = null;
    selectedAction = null;
    currentTask = null;
    constructor(cdr, facade) {
        super();
        this.cdr = cdr;
        this.facade = facade;
    }
    loadInitialData() {
        this.facade.updateQueryParams({ user: this.user });
        this.facade.getRequests$().subscribe((data) => {
            this.data.set(data);
        });
        this.facade.getNextActions$().subscribe((data) => {
            this.nextActions = data;
        });
        this.facade.getNextActors$().subscribe((data) => {
            this.nextActors = data;
        });
        this.facade.getTaskForms$().subscribe((data) => {
            this.stageForm = data?.[0] || null;
        });
        // this.data.set(generateTasks(5));
        try {
            this.facade.loadRequests().then(() => { });
            // this.userAccessRequestFacade.loadRoles();
        }
        catch (error) {
            // Handle error
        }
    }
    getCardDataByIdentifier(mailAddress) {
        return this.cardData().find(({ data }) => data.MailAddress === mailAddress);
    }
    loadMore() {
        // this.cardData = this.cardData.concat(this.cardData);
    }
    groupByWorkflowCode(task) {
        return `Workflow: ${task.WorkflowCode}`;
    }
    handlePopupClose(event) {
        if (event) {
            this.selectedTaskCode = null;
        }
    }
    checkForFormThenPassOn(task) {
        this.currentTask = task;
        // if (this.stageForm) {
        //   this.isModalVisible = true;
        // } else {
        //   this.passOn();
        // }
        this.passOn();
    }
    handleAction(task) {
        const action = this.activeActionType;
        switch (action) {
            case ActionType.PassOn:
                this.checkForFormThenPassOn(task);
                break;
            case ActionType.ReAssign:
                this.facade.reAssign(task, this.comment).then(() => {
                    this.comment = '';
                    this.nextActions = [];
                    this.recipientCode = null;
                    this.selectedAction = null;
                });
                break;
            case ActionType.PassBack:
                if (this.selectedAction) {
                    this.facade
                        .passBack(this.selectedAction, task, this.comment, this.recipientCode)
                        .then(() => {
                        this.comment = '';
                        this.nextActions = [];
                        this.recipientCode = null;
                        this.selectedAction = null;
                    });
                }
                break;
            case ActionType.SkipTo:
                if (this.selectedAction) {
                    this.facade
                        .skipTo(this.selectedAction, task, this.comment, this.recipientCode)
                        .then(() => {
                        this.comment = '';
                        this.nextActions = [];
                        this.recipientCode = null;
                        this.selectedAction = null;
                    });
                }
                break;
            default:
                break;
        }
    }
    submitForm() {
        const form = this.stageForm;
        if (form && this.currentTask) {
            this.facade
                .fillForm(form, this.currentTask.Code)
                .then((filledForm) => {
                this.stageForm = null;
                this.isModalVisible = false;
                this.passOn();
            })
                .catch((error) => {
                console.error('Error filling form:', error);
                // Handle error (e.g., show a notification)
            });
        }
    }
    passOn() {
        const nextAction = this.nextActions[0];
        console.log(JSON.stringify(this.currentTask, null, 2));
        if (this.selectedAction && this.currentTask) {
            this.facade
                .passOn(this.selectedAction, this.currentTask, this.comment, this.recipientCode)
                .then(() => {
                this.comment = '';
                this.nextActions = [];
                this.recipientCode = null;
                this.selectedAction = null;
            });
        }
    }
    areRequiredPropertiesFilled() {
        const properties = this.stageForm?.Entities[this.active].Properties || [];
        // Check if all required properties have valid values
        // return properties.every((property: any) => {
        //   console.log(property);
        //   return (
        //     !property.isRequired ||
        //     (property.Value !== undefined &&
        //       property.Value !== null &&
        //       property.Value !== '')
        //   );
        // });
        return true;
    }
    onActionDropDownChange(event) {
        const selectedAction = event;
        if (selectedAction) {
            this.selectedAction = selectedAction;
            // this.facade
            //   .loadNextActors(this.selectedTaskCode!, selectedAction.Code)
            //   .then((actors) => {});
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: MyQueueFacade }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: MyQueueComponent, selector: "lib-my-queue", inputs: { isGeneral: { classPropertyName: "isGeneral", publicName: "isGeneral", isSignal: true, isRequired: false, transformFunction: null }, user: { classPropertyName: "user", publicName: "user", isSignal: false, isRequired: false, transformFunction: null } }, usesInheritance: true, ngImport: i0, template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: false,\n      isToggle: true,\n    }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div table-content>\n      <lib-data-table\n        [data]=\"data()\"\n        [columns]=\"config.columns\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n        [groupBy]=\"groupByWorkflowCode\"\n      >\n        <ng-container libColumn=\"history\">\n          <ng-template #cell let-value let-deleteRow>\n            <a\n              [routerLink]=\"['/workflow/task-history', value.Code]\"\n              routerLinkActive=\"router-link-active\"\n              class=\"underline text-[#0000FF]\"\n              >view history</a\n            >\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-row=\"row\">\n            <verben-pop-Up\n              #popup\n              [customStyles]=\"{ 'z-index': '99' }\"\n              [enableMouseLeave]=\"false\"\n              [customStyles]=\"{\n                border: '1px solid #d4a10780',\n                borderRadius: '5px',\n                backgroundColor: 'white'\n              }\"\n              (dropdownOpenChange)=\"handlePopupClose($event)\"\n            >\n              <verben-svg\n                dropdown-trigger\n                icon=\"dots\"\n                [width]=\"2\"\n                [height]=\"12\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n              <div class=\"bg-white rounded-sm\" dropdown-content>\n                @if (selectedTaskCode) {\n                <div class=\"min-w-96\">\n                  <div\n                    class=\"flex items-center gap-4 justify-between h-12 px-2\"\n                  >\n                    <svg\n                      width=\"16\"\n                      height=\"16\"\n                      viewBox=\"0 0 16 16\"\n                      fill=\"none\"\n                      xmlns=\"http://www.w3.org/2000/svg\"\n                    >\n                      <g opacity=\"0.6\">\n                        <path\n                          d=\"M6.74649 8.00338C6.91483 8.1347 7.0252 8.20455 7.11531 8.29396C7.98846 9.16222 8.85742 10.0347 9.72917 10.905C9.87167 11.0475 9.99391 11.1921 9.99321 11.4129C9.99251 11.6462 9.89472 11.8152 9.69564 11.9256C9.49307 12.038 9.2926 12.0206 9.10469 11.8899C9.03833 11.8438 8.98175 11.7845 8.92378 11.7272C7.85574 10.6592 6.79678 9.58203 5.71477 8.52867C5.3711 8.19407 5.38437 7.79173 5.70779 7.47599C6.7884 6.42123 7.84875 5.34551 8.91539 4.27607C9.11377 4.07769 9.32054 3.92262 9.623 4.04137C9.97924 4.18107 10.112 4.58901 9.89472 4.90335C9.82976 4.99765 9.74174 5.07728 9.66002 5.1597C8.80642 6.01469 7.95283 6.86968 7.09645 7.72257C7.01472 7.8043 6.91553 7.86856 6.74579 8.00408L6.74649 8.00338Z\"\n                          fill=\"black\"\n                        />\n                      </g>\n                    </svg>\n\n                    <h3 class=\"text-sm\">Select Assignee</h3>\n\n                    <button\n                      (click)=\"handleAction(row)\"\n                      class=\"text-[#3479E9] text-xs font-medium\"\n                    >\n                      {{ activeActionType }}\n                    </button>\n                  </div>\n\n                  <div class=\"space-y-1 max-h-96 overflow-y-auto p-2\">\n                    <verben-drop-down\n                      label=\"Action\"\n                      styleClass=\"w-full\"\n                      width=\"100%\"\n                      [multiselect]=\"false\"\n                      [filter]=\"true\"\n                      [showClear]=\"true\"\n                      placeholder=\"Search\"\n                      [(options)]=\"nextActions\"\n                      id=\"actions\"\n                      optionLabel=\"Name\"\n                      [(ngModel)]=\"selectedAction\"\n                      (onChange)=\"onActionDropDownChange($event)\"\n                      class=\"form-control\"\n                    >\n                    </verben-drop-down>\n\n                    <verben-drop-down\n                      label=\"Actors\"\n                      styleClass=\"w-full\"\n                      width=\"100%\"\n                      [multiselect]=\"false\"\n                      [filter]=\"true\"\n                      [showClear]=\"true\"\n                      placeholder=\"Search\"\n                      [(options)]=\"nextActors\"\n                      id=\"actors\"\n                      optionLabel=\"Name\"\n                      optionValue=\"Code\"\n                      [(ngModel)]=\"recipientCode\"\n                      class=\"form-control\"\n                    >\n                    </verben-drop-down>\n\n                    <textarea\n                      [(ngModel)]=\"comment\"\n                      placeholder=\"Enter Comment\"\n                      class=\"w-full p-1 text-xs border border-primary rounded-md h-52\"\n                      [cols]=\"8\"\n                    ></textarea>\n                  </div>\n                </div>\n                } @else { @for (item of tableRowActions; track item.label) {\n                <div\n                  (click)=\"item.action(row)\"\n                  class=\"cursor-pointer py-2 px-2.5 hover:bg-primary\"\n                >\n                  {{ item.label }}\n                </div>\n                @if (item.divider) {\n                <hr class=\"bg-[#FFE681] h-1 rounded-xl border-0\" />\n                } } }\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #header>\n            <strong>Actions</strong>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        (loadMoreClick)=\"loadMore()\"\n        #vdcv\n        dataId=\"Id\"\n        border=\"5px\"\n        [cardDataList]=\"cardData()\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"20px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"Id\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData()\"\n          >\n            <ng-template #card let-item>\n              <div (click)=\"currentData = vdcv.onItemClick(item)\" class=\"flex\">\n                <div\n                  (click)=\"currentData = vdcv.onItemClick(item)\"\n                  class=\"flex cursor-pointer w-full bg-secondary rounded-xl\"\n                >\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"flex flex-col py-2 px-4 w-full\">\n                    <div class=\"flex items-center gap-4 justify-between\">\n                      <div class=\"grid gap-y-2\">\n                        <span class=\"font-semibold text-[#404040]\">{{\n                          item.title\n                        }}</span>\n                        <p class=\"flex items-center\">\n                          <label for=\"phone\" class=\"text-[10px] font-light\"\n                            >Status:</label\n                          >\n                          <span id=\"phone\" class=\"text-sm\">{{\n                            item.data.Status\n                          }}</span>\n                        </p>\n                      </div>\n\n                      <div class=\"grid gap-y-2\">\n                        <span for=\"role\" class=\"font-light\">{{\n                          item.data.WorkflowCode\n                        }}</span>\n                        <a\n                          [routerLink]=\"[\n                            '/workflow/task-history',\n                            item.data.Code\n                          ]\"\n                          routerLinkActive=\"router-link-active\"\n                          class=\"underline text-[#0000FF] text-xs\"\n                          >view history</a\n                        >\n                      </div>\n                    </div>\n\n                    <!-- <div class=\"flex\">\n                      <span class=\"font-normal text-sm\">{{ item.title }}</span>\n                    </div>\n                    @for (ciItem of item.body; track ciItem.value) {\n                    <div class=\"\">\n                      <span class=\"text-muted font-light text-xs\"\n                        >{{ ciItem.title }}:</span\n                      >\n                      <span class=\"text-black\">{{ ciItem.value }}</span>\n                    </div>\n                    } -->\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <!-- <lib-user-request-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onApproval)=\"onApprove($event)\"\n            ></lib-user-request-form> -->\n          </ng-template>\n        </verben-right-card-data-view>\n\n        <verben-card-data-view-footer class=\"float-right\">\n          <div class=\"flex gap-2\">\n            <!-- <span class=\"paginator-text\"\n              >{{ data().length }} records loaded</span\n            > -->\n            <span></span>\n            <button (click)=\"loadMore()\" class=\"load-more\">Load more</button>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <lib-data-columns\n        [columns]=\"config.columns\"\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n      ></lib-data-columns>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <lib-data-sort\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (sortApplied)=\"onSortUpdated($event)\"\n      ></lib-data-sort>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data()\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n</div>\n\n<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [mode]=\"'drawer'\"\n  [padding]=\"'0px'\"\n  [drawerWidth]=\"'400px'\"\n  [disableFooter]=\"false\"\n  [isVisible]=\"isModalVisible\"\n  [modalData]=\"stageForm\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [showCloseIcon]=\"false\"\n>\n</verben-dialogue>\n<ng-template #headerTemplate>\n  <div class=\"bg-[#FFE681] px-6 py-4 flex justify-between items-center\">\n    <h1>Form</h1>\n    <verben-svg\n      class=\"cursor-pointer\"\n      [icon]=\"'close-circle'\"\n      (click)=\"isModalVisible = false\"\n      [width]=\"15\"\n      [height]=\"15\"\n      [stroke]=\"'#fff'\"\n    ></verben-svg>\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div>\n    <div *ngIf=\"stageForm?.Entities?.[active]; else emptyState\" class=\"mt-4\">\n      <form-control\n        [dataType]=\"dataType\"\n        [formProperties]=\"stageForm?.Entities?.[active]?.Properties ?? []\"\n      ></form-control>\n\n      <div class=\"flex gap-3 justify-end\">\n        <verbena-button\n          class=\"verben-primary-button\"\n          (click)=\"submitForm()\"\n          [disable]=\"!areRequiredPropertiesFilled()\"\n          text=\"Save\"\n        ></verbena-button>\n      </div>\n    </div>\n\n    <!-- Empty state template -->\n    <ng-template #emptyState>\n      <p class=\"mt-4 p-4 text-gray-600 text-center\">\n        No entries available for the selected form group.\n      </p>\n    </ng-template>\n  </div>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.VerbenDialogueComponent, selector: "verben-dialogue", inputs: ["dialogueWidth", "headerTemplate", "bodyTemplate", "footerTemplate", "showCloseIcon", "dismissOutsideClick", "closeOnEscape", "isVisible", "size", "backdropColor", "customClass", "disableFooter", "margin", "padding", "borderRadius", "dialogueBgColor", "width", "closeIconClass", "boxShadow", "enableTransition", "modalData", "mode", "position", "drawerWidth"], outputs: ["openModal", "closeModal"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: i8.DataColumnsComponent, selector: "lib-data-columns", inputs: ["columns", "enableDragAndDrop", "maxVisibleItems"], outputs: ["columnsUpdated"] }, { kind: "component", type: i8.DataSortComponent, selector: "lib-data-sort", inputs: ["columns", "data", "enableDragAndDrop"], outputs: ["sortApplied", "resetFilter"] }, { kind: "directive", type: i5.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "component", type: FormControlComponent, selector: "form-control", inputs: ["dataType", "value", "boolInputType", "formProperties"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-my-queue', template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: false,\n      isToggle: true,\n    }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div table-content>\n      <lib-data-table\n        [data]=\"data()\"\n        [columns]=\"config.columns\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n        [groupBy]=\"groupByWorkflowCode\"\n      >\n        <ng-container libColumn=\"history\">\n          <ng-template #cell let-value let-deleteRow>\n            <a\n              [routerLink]=\"['/workflow/task-history', value.Code]\"\n              routerLinkActive=\"router-link-active\"\n              class=\"underline text-[#0000FF]\"\n              >view history</a\n            >\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-row=\"row\">\n            <verben-pop-Up\n              #popup\n              [customStyles]=\"{ 'z-index': '99' }\"\n              [enableMouseLeave]=\"false\"\n              [customStyles]=\"{\n                border: '1px solid #d4a10780',\n                borderRadius: '5px',\n                backgroundColor: 'white'\n              }\"\n              (dropdownOpenChange)=\"handlePopupClose($event)\"\n            >\n              <verben-svg\n                dropdown-trigger\n                icon=\"dots\"\n                [width]=\"2\"\n                [height]=\"12\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n              <div class=\"bg-white rounded-sm\" dropdown-content>\n                @if (selectedTaskCode) {\n                <div class=\"min-w-96\">\n                  <div\n                    class=\"flex items-center gap-4 justify-between h-12 px-2\"\n                  >\n                    <svg\n                      width=\"16\"\n                      height=\"16\"\n                      viewBox=\"0 0 16 16\"\n                      fill=\"none\"\n                      xmlns=\"http://www.w3.org/2000/svg\"\n                    >\n                      <g opacity=\"0.6\">\n                        <path\n                          d=\"M6.74649 8.00338C6.91483 8.1347 7.0252 8.20455 7.11531 8.29396C7.98846 9.16222 8.85742 10.0347 9.72917 10.905C9.87167 11.0475 9.99391 11.1921 9.99321 11.4129C9.99251 11.6462 9.89472 11.8152 9.69564 11.9256C9.49307 12.038 9.2926 12.0206 9.10469 11.8899C9.03833 11.8438 8.98175 11.7845 8.92378 11.7272C7.85574 10.6592 6.79678 9.58203 5.71477 8.52867C5.3711 8.19407 5.38437 7.79173 5.70779 7.47599C6.7884 6.42123 7.84875 5.34551 8.91539 4.27607C9.11377 4.07769 9.32054 3.92262 9.623 4.04137C9.97924 4.18107 10.112 4.58901 9.89472 4.90335C9.82976 4.99765 9.74174 5.07728 9.66002 5.1597C8.80642 6.01469 7.95283 6.86968 7.09645 7.72257C7.01472 7.8043 6.91553 7.86856 6.74579 8.00408L6.74649 8.00338Z\"\n                          fill=\"black\"\n                        />\n                      </g>\n                    </svg>\n\n                    <h3 class=\"text-sm\">Select Assignee</h3>\n\n                    <button\n                      (click)=\"handleAction(row)\"\n                      class=\"text-[#3479E9] text-xs font-medium\"\n                    >\n                      {{ activeActionType }}\n                    </button>\n                  </div>\n\n                  <div class=\"space-y-1 max-h-96 overflow-y-auto p-2\">\n                    <verben-drop-down\n                      label=\"Action\"\n                      styleClass=\"w-full\"\n                      width=\"100%\"\n                      [multiselect]=\"false\"\n                      [filter]=\"true\"\n                      [showClear]=\"true\"\n                      placeholder=\"Search\"\n                      [(options)]=\"nextActions\"\n                      id=\"actions\"\n                      optionLabel=\"Name\"\n                      [(ngModel)]=\"selectedAction\"\n                      (onChange)=\"onActionDropDownChange($event)\"\n                      class=\"form-control\"\n                    >\n                    </verben-drop-down>\n\n                    <verben-drop-down\n                      label=\"Actors\"\n                      styleClass=\"w-full\"\n                      width=\"100%\"\n                      [multiselect]=\"false\"\n                      [filter]=\"true\"\n                      [showClear]=\"true\"\n                      placeholder=\"Search\"\n                      [(options)]=\"nextActors\"\n                      id=\"actors\"\n                      optionLabel=\"Name\"\n                      optionValue=\"Code\"\n                      [(ngModel)]=\"recipientCode\"\n                      class=\"form-control\"\n                    >\n                    </verben-drop-down>\n\n                    <textarea\n                      [(ngModel)]=\"comment\"\n                      placeholder=\"Enter Comment\"\n                      class=\"w-full p-1 text-xs border border-primary rounded-md h-52\"\n                      [cols]=\"8\"\n                    ></textarea>\n                  </div>\n                </div>\n                } @else { @for (item of tableRowActions; track item.label) {\n                <div\n                  (click)=\"item.action(row)\"\n                  class=\"cursor-pointer py-2 px-2.5 hover:bg-primary\"\n                >\n                  {{ item.label }}\n                </div>\n                @if (item.divider) {\n                <hr class=\"bg-[#FFE681] h-1 rounded-xl border-0\" />\n                } } }\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #header>\n            <strong>Actions</strong>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        (loadMoreClick)=\"loadMore()\"\n        #vdcv\n        dataId=\"Id\"\n        border=\"5px\"\n        [cardDataList]=\"cardData()\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"20px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"Id\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData()\"\n          >\n            <ng-template #card let-item>\n              <div (click)=\"currentData = vdcv.onItemClick(item)\" class=\"flex\">\n                <div\n                  (click)=\"currentData = vdcv.onItemClick(item)\"\n                  class=\"flex cursor-pointer w-full bg-secondary rounded-xl\"\n                >\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"flex flex-col py-2 px-4 w-full\">\n                    <div class=\"flex items-center gap-4 justify-between\">\n                      <div class=\"grid gap-y-2\">\n                        <span class=\"font-semibold text-[#404040]\">{{\n                          item.title\n                        }}</span>\n                        <p class=\"flex items-center\">\n                          <label for=\"phone\" class=\"text-[10px] font-light\"\n                            >Status:</label\n                          >\n                          <span id=\"phone\" class=\"text-sm\">{{\n                            item.data.Status\n                          }}</span>\n                        </p>\n                      </div>\n\n                      <div class=\"grid gap-y-2\">\n                        <span for=\"role\" class=\"font-light\">{{\n                          item.data.WorkflowCode\n                        }}</span>\n                        <a\n                          [routerLink]=\"[\n                            '/workflow/task-history',\n                            item.data.Code\n                          ]\"\n                          routerLinkActive=\"router-link-active\"\n                          class=\"underline text-[#0000FF] text-xs\"\n                          >view history</a\n                        >\n                      </div>\n                    </div>\n\n                    <!-- <div class=\"flex\">\n                      <span class=\"font-normal text-sm\">{{ item.title }}</span>\n                    </div>\n                    @for (ciItem of item.body; track ciItem.value) {\n                    <div class=\"\">\n                      <span class=\"text-muted font-light text-xs\"\n                        >{{ ciItem.title }}:</span\n                      >\n                      <span class=\"text-black\">{{ ciItem.value }}</span>\n                    </div>\n                    } -->\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <!-- <lib-user-request-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onApproval)=\"onApprove($event)\"\n            ></lib-user-request-form> -->\n          </ng-template>\n        </verben-right-card-data-view>\n\n        <verben-card-data-view-footer class=\"float-right\">\n          <div class=\"flex gap-2\">\n            <!-- <span class=\"paginator-text\"\n              >{{ data().length }} records loaded</span\n            > -->\n            <span></span>\n            <button (click)=\"loadMore()\" class=\"load-more\">Load more</button>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <lib-data-columns\n        [columns]=\"config.columns\"\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n      ></lib-data-columns>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <lib-data-sort\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (sortApplied)=\"onSortUpdated($event)\"\n      ></lib-data-sort>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data()\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n</div>\n\n<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [mode]=\"'drawer'\"\n  [padding]=\"'0px'\"\n  [drawerWidth]=\"'400px'\"\n  [disableFooter]=\"false\"\n  [isVisible]=\"isModalVisible\"\n  [modalData]=\"stageForm\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [showCloseIcon]=\"false\"\n>\n</verben-dialogue>\n<ng-template #headerTemplate>\n  <div class=\"bg-[#FFE681] px-6 py-4 flex justify-between items-center\">\n    <h1>Form</h1>\n    <verben-svg\n      class=\"cursor-pointer\"\n      [icon]=\"'close-circle'\"\n      (click)=\"isModalVisible = false\"\n      [width]=\"15\"\n      [height]=\"15\"\n      [stroke]=\"'#fff'\"\n    ></verben-svg>\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div>\n    <div *ngIf=\"stageForm?.Entities?.[active]; else emptyState\" class=\"mt-4\">\n      <form-control\n        [dataType]=\"dataType\"\n        [formProperties]=\"stageForm?.Entities?.[active]?.Properties ?? []\"\n      ></form-control>\n\n      <div class=\"flex gap-3 justify-end\">\n        <verbena-button\n          class=\"verben-primary-button\"\n          (click)=\"submitForm()\"\n          [disable]=\"!areRequiredPropertiesFilled()\"\n          text=\"Save\"\n        ></verbena-button>\n      </div>\n    </div>\n\n    <!-- Empty state template -->\n    <ng-template #emptyState>\n      <p class=\"mt-4 p-4 text-gray-600 text-center\">\n        No entries available for the selected form group.\n      </p>\n    </ng-template>\n  </div>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: MyQueueFacade }], propDecorators: { user: [{
                type: Input
            }] } });
var ActionType;
(function (ActionType) {
    ActionType["PickTask"] = "PickTask";
    ActionType["UnPickTask"] = "UnPickTask";
    ActionType["ReAssign"] = "ReAssign";
    ActionType["PassOn"] = "PassOn";
    ActionType["PassBack"] = "PassBack";
    ActionType["FollowTask"] = "FollowTask";
    ActionType["UnfollowTask"] = "UnfollowTask";
    ActionType["SkipTo"] = "SkipTo";
})(ActionType || (ActionType = {}));

class MyQueueModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: MyQueueModule, declarations: [MyQueueComponent], imports: [CommonModule,
            SharedModule,
            RouterLink,
            FormControlerModule,
            FormTimerModule], exports: [MyQueueComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueModule, providers: [MyQueueService], imports: [CommonModule,
            SharedModule,
            FormControlerModule,
            FormTimerModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: MyQueueModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MyQueueComponent],
                    imports: [
                        CommonModule,
                        SharedModule,
                        RouterLink,
                        FormControlerModule,
                        FormTimerModule,
                    ],
                    providers: [MyQueueService],
                    exports: [MyQueueComponent],
                }]
        }] });

const columns$2 = [
    {
        id: 'name',
        header: 'Name',
        accessorKey: 'Name',
    },
    {
        id: 'description',
        header: 'Description',
        accessorKey: 'Description',
    },
    {
        id: 'assignment-type',
        header: 'Assignment Type',
        accessorKey: 'AssignmentType',
    },
    {
        id: 'operation',
        header: 'Operation',
        accessorKey: 'Operation',
    },
    {
        id: 'stage-entry-rule',
        header: 'StageEntryRule',
        accessorKey: 'StageEntryRule',
    },
    {
        id: 'status',
        header: 'Status',
        accessorKey: 'Status',
    },
    { id: 'actions', header: 'Actions', accessorKey: 'Code' },
];

var TaskAssignmentType;
(function (TaskAssignmentType) {
    TaskAssignmentType["Queue"] = "Queue";
    TaskAssignmentType["AutoRoute"] = "AutoRoute";
})(TaskAssignmentType || (TaskAssignmentType = {}));

var SearchPropertyValueType;
(function (SearchPropertyValueType) {
    SearchPropertyValueType["Int"] = "Int";
    SearchPropertyValueType["Float"] = "Float";
    SearchPropertyValueType["Decimal"] = "Decimal";
    SearchPropertyValueType["Double"] = "Double";
    SearchPropertyValueType["String"] = "String";
    SearchPropertyValueType["Bool"] = "Bool";
    SearchPropertyValueType["Date"] = "Date";
})(SearchPropertyValueType || (SearchPropertyValueType = {}));

function convertDataFilterTypeToSearchPropertyValueType(type) {
    switch (type) {
        case DataFilterType.String:
            return SearchPropertyValueType.String;
        case DataFilterType.Integer:
            return SearchPropertyValueType.Int;
        case DataFilterType.Decimal:
            return SearchPropertyValueType.Decimal;
        case DataFilterType.Credit:
            return SearchPropertyValueType.Float;
        case DataFilterType.Date:
            return SearchPropertyValueType.Date;
        case DataFilterType.Bool:
            return SearchPropertyValueType.Bool;
        case DataFilterType.Number:
            return SearchPropertyValueType.Int;
    }
}

class WorkflowsService {
    httpService;
    envSvc;
    BASE_URL = 'Workflow';
    constructor(httpService, envSvc) {
        this.httpService = httpService;
        this.envSvc = envSvc;
    }
    /**
     * Get user access requests with pagination and sorting
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the user access requests
     */
    getWorkflows(skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetWorkflows/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get user access requests with additional parameter, pagination and sorting
     * @param param Search parameter
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the filtered user access requests
     */
    getWorkflowWithParam(param, skip = 0, limit = 1, sortParam = 'CreatedAt', sortOrder = 'Asc') {
        const url = `${this.BASE_URL}/GetWorkflowsWithParam/${param}/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get user access requests with additional parameter, pagination and sorting
     * @param params Filter parameters
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the filtered user access requests
     */
    getWorkflowByFilterParams(params, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/SearchWorkflow/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.post(url, params);
    }
    /**
     * Save multiple user access requests
     * @param requests Array of user access requests to save
     * @returns Promise containing the save operation result
     */
    saveWorkflows(requests) {
        const url = `${this.BASE_URL}/SaveWorkflows`;
        // const payload = requests.map((wf) => {
        //   delete wf["Id"];
        //   wf.Actions = wf.Actions.map((ac) => {
        //     delete ac["Id"];
        //     return ac;
        //   })
        //   return wf;
        // })
        return this.httpService.post(url, requests);
    }
    /**
     * Approve or reject multiple user access requests
     * @param requests Array of user access requests to save
     * @param isApproval True for approval, false for decline
     * @returns Promise containing the save operation result
     */
    processWorkflows(requests, isApproval) {
        const url = `${this.BASE_URL}/WorkflowAction/${isApproval}`;
        return this.httpService.post(url, requests);
    }
    /**
     * Delete multiple user access requests
     * @param requestIds Array of request IDs to delete
     * @returns Observable containing the delete operation result
     */
    deleteWorkflows(requestIds) {
        const url = `${this.BASE_URL}/DeleteWorkflows`;
        return this.httpService.delete(`${url}?data=${requestIds.join(',')}`);
    }
    /**
     * Get user access requests with pagination and sorting
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the user access requests
     */
    getForms(skip, limit, sortParam, sortOrder) {
        const url = `Form/GetFormEntities/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get user access requests with pagination and sorting
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the user access requests
     */
    getTags(skip, limit, sortParam, sortOrder) {
        const url = `User/GetTags/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url, this.envSvc.environment.AuthAPI);
    }
    getWorkflowOperations(skip, limit, sortParam, sortOrder) {
        const url = `Workflow/GetWorkflowOperations/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsService, deps: [{ token: HttpWebRequestService }, { token: EnvironmentService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: HttpWebRequestService }, { type: EnvironmentService }] });

class WorkflowsState {
    updating$ = new BehaviorSubject(false);
    requests$ = new BehaviorSubject([]);
    searchTerm$ = new BehaviorSubject('');
    queryParams$ = new BehaviorSubject({
        skip: 0,
        limit: 20,
        sortParam: 'CreatedAt',
        sortOrder: SortDirection.Desc,
    });
    filterParams$ = new BehaviorSubject([]);
    operations$ = new BehaviorSubject([]);
    isUpdating$() {
        return this.updating$.asObservable();
    }
    setUpdating(isUpdating) {
        this.updating$.next(isUpdating);
    }
    getRequests$() {
        return this.requests$.asObservable();
    }
    setRequests(requests) {
        this.requests$.next(requests);
    }
    setOperations(operations) {
        this.operations$.next(operations);
    }
    getOperations$() {
        return this.operations$.asObservable();
    }
    getFilterParams$() {
        return this.filterParams$.asObservable();
    }
    setFilterParams(params) {
        this.filterParams$.next(params);
    }
    appendRequests(newRequests) {
        const currentRequests = this.requests$.getValue();
        this.requests$.next([...currentRequests, ...newRequests]);
    }
    getSearchTerm$() {
        return this.searchTerm$.asObservable();
    }
    getSearchTermValue() {
        return this.searchTerm$.getValue();
    }
    setSearchTerm(term) {
        this.searchTerm$.next(term);
    }
    getQueryParams$() {
        return this.queryParams$.asObservable();
    }
    getQueryParamsValue() {
        return this.queryParams$.getValue();
    }
    updateQueryParams(params) {
        this.queryParams$.next({ ...this.queryParams$.getValue(), ...params });
    }
    resetPagination() {
        const currentParams = this.queryParams$.getValue();
        this.queryParams$.next({ ...currentParams, skip: 0 });
    }
    addRequest(request) {
        const currentValue = this.requests$.getValue();
        this.requests$.next([request, ...currentValue]);
    }
    updateRequest(updatedRequest) {
        const requests = this.requests$.getValue();
        const index = requests.findIndex((r) => r.Code === updatedRequest.Code);
        if (index !== -1) {
            requests[index] = updatedRequest;
            this.requests$.next([...requests]);
        }
    }
    removeRequest(requestId) {
        const currentValue = this.requests$.getValue();
        this.requests$.next(currentValue.filter((r) => r.Code !== requestId));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsState, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsState, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsState, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class WorkflowFacade {
    workflowService;
    workflowState;
    utilService;
    searchSubject = new Subject();
    destroy$ = new Subject();
    constructor(workflowService, workflowState, utilService) {
        this.workflowService = workflowService;
        this.workflowState = workflowState;
        this.utilService = utilService;
        // Set up debounced search handling
        this.searchSubject
            .pipe(debounceTime(1000), distinctUntilChanged(), takeUntil(this.destroy$))
            .subscribe((searchTerm) => {
            this.handleSearch(searchTerm);
        });
        this.isUpdating$().subscribe((loading) => {
            this.utilService.sendBI(loading);
        });
        this.getFilterParams$().subscribe((params) => {
            if (params.length) {
            }
            else {
                this.loadRequests();
            }
        });
    }
    destroy() {
        this.destroy$.next();
        this.destroy$.complete();
    }
    isUpdating$() {
        return this.workflowState.isUpdating$();
    }
    getRequests$() {
        return this.workflowState.getRequests$();
    }
    getOperations$() {
        return this.workflowState.getOperations$();
    }
    getFilterParams$() {
        return this.workflowState.getFilterParams$();
    }
    getQueryParams$() {
        return this.workflowState.getQueryParams$();
    }
    getSearchTerm$() {
        return this.workflowState.getSearchTerm$();
    }
    // Search handling
    search(term) {
        this.searchSubject.next(term);
    }
    async handleSearch(searchTerm) {
        this.workflowState.setSearchTerm(searchTerm);
        this.workflowState.resetPagination();
        try {
            this.workflowState.setUpdating(true);
            if (searchTerm.trim()) {
                await this.loadRequestsWithParam(searchTerm);
            }
            else {
                await this.loadRequests();
            }
        }
        catch (error) {
            console.error('Search failed:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async filter(filterParams) {
        this.workflowState.resetPagination();
        this.workflowState.setFilterParams(filterParams);
    }
    // Load more handling
    async loadMore() {
        try {
            this.workflowState.setUpdating(true);
            const currentParams = this.workflowState.getQueryParamsValue();
            const searchTerm = this.workflowState.getSearchTermValue();
            // Update skip value
            const newSkip = currentParams.skip + currentParams.limit;
            this.workflowState.updateQueryParams({ skip: newSkip });
            // Load and append data
            const response = searchTerm
                ? await this.workflowService.getWorkflowWithParam(searchTerm, newSkip, currentParams.limit, currentParams.sortParam || 'createdDate', currentParams.sortOrder)
                : await this.workflowService.getWorkflows(newSkip, currentParams.limit, currentParams.sortParam || 'createdDate', currentParams.sortOrder);
            this.workflowState.appendRequests(response.Result);
        }
        catch (error) {
            console.error('Load more failed:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async loadRequests() {
        try {
            this.workflowState.setUpdating(true);
            const params = this.workflowState.getQueryParamsValue();
            const requests = await this.workflowService.getWorkflows(params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder);
            this.workflowState.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async loadOperations() {
        try {
            const response = await this.workflowService.getWorkflowOperations(0, 0, 'CreatedDate', SortDirection.Desc);
            this.workflowState.setOperations(response.Result);
        }
        catch (error) {
            console.error('Failed to load requests:', error);
            throw error;
        }
        finally {
        }
    }
    async loadRequestsWithParam(param) {
        try {
            this.workflowState.setUpdating(true);
            const params = this.workflowState.getQueryParamsValue();
            const requests = await this.workflowService.getWorkflowWithParam(param, params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder);
            this.workflowState.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async loadRequestsByFilterParams(filterParams) {
        try {
            this.workflowState.setUpdating(true);
            const params = this.workflowState.getQueryParamsValue();
            const requests = await this.workflowService.getWorkflowByFilterParams(filterParams.map((filter) => ({
                PropertyName: filter.name,
                EntityValue: filter.value,
                type: convertDataFilterTypeToSearchPropertyValueType(filter.type),
                Operator: SearchOperator.And,
                Sign: SearchPropertySign.EQ,
            })), params.skip, params.limit, params.sortParam || 'createdDate', params.sortOrder);
            this.workflowState.setRequests(requests.Result);
        }
        catch (error) {
            console.error('Failed to load requests with param:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    updateQueryParams(params) {
        this.workflowState.updateQueryParams(params);
        this.loadRequests();
    }
    async addRequest(request) {
        try {
            this.workflowState.setUpdating(true);
            const newRequest = { ...request };
            this.workflowState.addRequest(newRequest);
            newRequest.Id = '';
            newRequest.Code = '';
            await this.workflowService.saveWorkflows([newRequest]);
            await this.loadRequests(); // Reload to get server-side changes
        }
        catch (error) {
            console.error('Failed to add request:', error);
            this.workflowState.removeRequest(request.Code);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async updateRequest(request) {
        try {
            this.workflowState.setUpdating(true);
            await this.workflowService.saveWorkflows([request]);
            this.workflowState.updateRequest(request);
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async deleteRequest(requestId) {
        try {
            this.workflowState.setUpdating(true);
            await lastValueFrom(this.workflowService.deleteWorkflows([requestId]));
            this.workflowState.removeRequest(requestId);
        }
        catch (error) {
            console.error('Failed to delete request:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    async approveRequest(request) {
        try {
            this.workflowState.setUpdating(true);
            const response = await this.workflowService.processWorkflows([request], true);
            // console.log(response);
            const data = response?.[0];
            if (data) {
                this.workflowState.updateRequest(data);
            }
        }
        catch (error) {
            console.error('Failed to update request:', error);
            throw error;
        }
        finally {
            this.workflowState.setUpdating(false);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFacade, deps: [{ token: WorkflowsService }, { token: WorkflowsState }, { token: UtilService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFacade, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFacade, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: WorkflowsService }, { type: WorkflowsState }, { type: UtilService }] });
var DateFilterTypes;
(function (DateFilterTypes) {
    DateFilterTypes["Before"] = "LT";
    DateFilterTypes["On"] = "EQ";
    DateFilterTypes["After"] = "GT";
})(DateFilterTypes || (DateFilterTypes = {}));

class WorkflowFormComponent {
    fb;
    operations = [];
    get currentData() {
        return this._currentData;
    }
    set currentData(value) {
        this._currentData = value;
        console.log(value?.data);
        if (value?.data) {
            this.form.patchValue({
                Name: value.data.Name || '',
                Description: value.data.Description || '',
                AssignmentType: value.data.AssignmentType || '',
                Service: value.data.Service || '',
                Operation: value.data.Operation || '',
                Status: value.data.Status || '',
            });
        }
        else {
            this.form.reset();
        }
    }
    _currentData = null;
    switchView = new EventEmitter();
    onSave = new EventEmitter();
    form;
    assignmentTypes = Object.values(TaskAssignmentType);
    statuses = Object.values(Status);
    // roles: WritableSignal<Role[]> = signal([]);
    constructor(fb) {
        this.fb = fb;
        this.form = this.fb.group({
            Name: ['', { validators: [Validators.required] }],
            Description: ['', { validators: [Validators.required] }],
            AssignmentType: ['', { validators: [Validators.required] }],
            Service: [''],
            Operation: [''],
            Status: ['', { validators: [Validators.required] }],
        });
    }
    ngOnInit() {
        // this.userAccessRequestFacade.getRoles$().subscribe((data) => {
        //   this.roles.set(data);
        // });
        // try {
        //   this.userAccessRequestFacade.loadRoles();
        // } catch (error) {
        //   // Handle error
        // }
        console.log(this.currentData?.data);
    }
    handleSubmit() {
        if (this.form.valid) {
            // Emit save event with form value
            console.log('Form saved:', this.form.value);
            this.onSave.emit(this.form.value);
        }
    }
    onDelete() {
        // Emit delete event
        console.log('Delete requested');
    }
    disableProcessing() {
        return !this.form.valid;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFormComponent, deps: [{ token: i1$2.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WorkflowFormComponent, selector: "lib-workflow-form", inputs: { operations: "operations", currentData: "currentData" }, outputs: { switchView: "switchView", onSave: "onSave" }, ngImport: i0, template: "<form\n  [formGroup]=\"form\"\n  class=\"flex flex-col px-3 pb-3 rounded-xl h-full w-full relative space-y-4\"\n  (ngSubmit)=\"handleSubmit()\"\n>\n  <verbena-input\n    name=\"Name\"\n    label=\"Name\"\n    formControlName=\"Name\"\n    placeHolder=\"Enter Name\"\n  />\n  <verbena-input\n    name=\"Description\"\n    label=\"Description\"\n    formControlName=\"Description\"\n    placeHolder=\"Enter Description\"\n  />\n\n  <div class=\"space-y-1\">\n    <label for=\"assignment\">Assignment</label>\n\n    <verben-drop-down\n      label=\"Assignment\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      placeholder=\"Select\"\n      [options]=\"assignmentTypes\"\n      id=\"assignment\"\n      formControlName=\"AssignmentType\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <div class=\"space-y-1\">\n    <label for=\"operation\">Operation</label>\n\n    <verben-drop-down\n      label=\"Operation\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      placeholder=\"Select\"\n      [options]=\"operations\"\n      optionLabel=\"Description\"\n      optionValue=\"Description\"\n      id=\"operation\"\n      formControlName=\"Operation\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <!-- <div class=\"space-y-1\">\n    <label for=\"object\">Object</label>\n\n    <verbena-input\n      id=\"object\"\n      formControlName=\"Operation\"\n      placeHolder=\"Enter Object\"\n    />\n  </div> -->\n\n  <div class=\"space-y-1\">\n    <label for=\"status\">Status</label>\n\n    <verben-drop-down\n      label=\"Status\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      [showClear]=\"true\"\n      placeholder=\"Null\"\n      [(options)]=\"statuses\"\n      id=\"status\"\n      formControlName=\"Status\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <!-- buttons -->\n  <div class=\"flex justify-between gap-4 my-2\">\n    <verbena-button\n      width=\"114px\"\n      height=\"39px\"\n      text=\"Delete\"\n      bgColor=\"#999999\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n    <a [routerLink]=\"['/designer', currentData?.data.Code]\" class=\"ml-auto\">\n      <verbena-button\n        (click)=\"switchView.emit()\"\n        text=\"Designer\"\n        styleType=\"ylw-outline\"\n      ></verbena-button>\n    </a>\n    <verbena-button\n      (click)=\"switchView.emit()\"\n      text=\"Switch To Table\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n    <verbena-button\n      type=\"submit\"\n      text=\"Save\"\n      bgColor=\"#FFE681\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      pd=\"10px 20px\"\n      width=\"114px\"\n      height=\"39px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n  </div>\n</form>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1$2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1$2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "directive", type: i5.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFormComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-workflow-form', template: "<form\n  [formGroup]=\"form\"\n  class=\"flex flex-col px-3 pb-3 rounded-xl h-full w-full relative space-y-4\"\n  (ngSubmit)=\"handleSubmit()\"\n>\n  <verbena-input\n    name=\"Name\"\n    label=\"Name\"\n    formControlName=\"Name\"\n    placeHolder=\"Enter Name\"\n  />\n  <verbena-input\n    name=\"Description\"\n    label=\"Description\"\n    formControlName=\"Description\"\n    placeHolder=\"Enter Description\"\n  />\n\n  <div class=\"space-y-1\">\n    <label for=\"assignment\">Assignment</label>\n\n    <verben-drop-down\n      label=\"Assignment\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      placeholder=\"Select\"\n      [options]=\"assignmentTypes\"\n      id=\"assignment\"\n      formControlName=\"AssignmentType\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <div class=\"space-y-1\">\n    <label for=\"operation\">Operation</label>\n\n    <verben-drop-down\n      label=\"Operation\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      placeholder=\"Select\"\n      [options]=\"operations\"\n      optionLabel=\"Description\"\n      optionValue=\"Description\"\n      id=\"operation\"\n      formControlName=\"Operation\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <!-- <div class=\"space-y-1\">\n    <label for=\"object\">Object</label>\n\n    <verbena-input\n      id=\"object\"\n      formControlName=\"Operation\"\n      placeHolder=\"Enter Object\"\n    />\n  </div> -->\n\n  <div class=\"space-y-1\">\n    <label for=\"status\">Status</label>\n\n    <verben-drop-down\n      label=\"Status\"\n      styleClass=\"w-full\"\n      width=\"100%\"\n      [multiselect]=\"false\"\n      [showClear]=\"true\"\n      placeholder=\"Null\"\n      [(options)]=\"statuses\"\n      id=\"status\"\n      formControlName=\"Status\"\n      class=\"form-control\"\n    >\n    </verben-drop-down>\n  </div>\n\n  <!-- buttons -->\n  <div class=\"flex justify-between gap-4 my-2\">\n    <verbena-button\n      width=\"114px\"\n      height=\"39px\"\n      text=\"Delete\"\n      bgColor=\"#999999\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n    <a [routerLink]=\"['/designer', currentData?.data.Code]\" class=\"ml-auto\">\n      <verbena-button\n        (click)=\"switchView.emit()\"\n        text=\"Designer\"\n        styleType=\"ylw-outline\"\n      ></verbena-button>\n    </a>\n    <verbena-button\n      (click)=\"switchView.emit()\"\n      text=\"Switch To Table\"\n      styleType=\"ylw-outline\"\n      class=\"ml-auto\"\n    ></verbena-button>\n    <verbena-button\n      type=\"submit\"\n      text=\"Save\"\n      bgColor=\"#FFE681\"\n      textColor=\"#404040\"\n      borderRadius=\"10px\"\n      pd=\"10px 20px\"\n      width=\"114px\"\n      height=\"39px\"\n      [disable]=\"disableProcessing()\"\n    ></verbena-button>\n  </div>\n</form>\n" }]
        }], ctorParameters: () => [{ type: i1$2.FormBuilder }], propDecorators: { operations: [{
                type: Input
            }], currentData: [{
                type: Input
            }], switchView: [{
                type: Output
            }], onSave: [{
                type: Output
            }] } });

class WorkflowsComponent extends BaseDataViewComponent {
    cdr;
    facade;
    fb;
    designerUrl = input('');
    config = {
        dataSource: [], // Populate from service
        columns: columns$2, // Your existing column definitions
        cardDataMapper: (task) => ({
            selected: false,
            title: task.Name,
            data: task,
            body: [
                { title: 'Name', value: task.Name },
                { title: 'Status', value: task.Status },
                { title: 'AssignmentType', value: task.AssignmentType },
            ],
            children: [],
        }),
        onDetailView: (task) => {
            // Custom detail view logic
        },
    };
    editForms = new Map();
    assignmentTypes = Object.values(TaskAssignmentType);
    statuses = Object.values(Status);
    operations = signal([]);
    constructor(cdr, facade, fb) {
        super();
        this.cdr = cdr;
        this.facade = facade;
        this.fb = fb;
    }
    generateFormGroup(data) {
        console.log(data);
        const form = this.fb.group({
            // Name: [data?.Name ?? '', { validators: [Validators.required] }],
            Name: new FormControl(data?.Name ?? '', [Validators.required]),
            Description: new FormControl(data?.Description ?? '', [
                Validators.required,
            ]),
            AssignmentType: new FormControl(data?.AssignmentType ?? '', [
                Validators.required,
            ]),
            // Service: [data?.Service ?? ''],
            Operation: [data?.Operation ?? ''],
            Status: new FormControl(data?.Status ?? '', [Validators.required]),
        });
        // console.log(form.value);
        return form;
    }
    getFormControl(index, field) {
        const control = this.editForms.get(index)?.get(field);
        console.log(control);
        return control;
    }
    isRowValid(index) {
        return this.editForms.get(index)?.valid || false;
    }
    loadInitialData() {
        // this.userService.getRequests().subscribe(
        //   tasks => this.data.set(tasks)
        // );
        // this.data.set(generateWorkflows(5));
        super.loadInitialData();
        // this.data = this.service.getMockUserRequests();
        this.facade.getRequests$().subscribe((data) => {
            this.data.set(data);
        });
        this.facade.getOperations$().subscribe((data) => {
            this.operations.set(data);
        });
        // this.userAccessRequestFacade.getRoles$().subscribe((data) => {
        //   this.roles.set(data);
        // });
        try {
            this.facade.loadRequests();
            this.facade.loadOperations();
            // this.userAccessRequestFacade.loadRoles();
        }
        catch (error) {
            // Handle error
        }
    }
    getCardDataByIdentifier(code) {
        return this.cardData().find(({ data }) => data.data.Code === code);
    }
    loadMore() {
        // this.cardData = this.cardData.concat(this.cardData);
    }
    async onSave(data) {
        const payload = {
            ...this.currentData?.data,
            ...data,
        };
        if (payload.DataState === ObjectState.New) {
            console.log('Payload in new', payload);
            await this.facade.addRequest(payload);
        }
        else {
            console.log('Payload in update', payload);
            await this.facade.updateRequest({
                ...payload,
                DataState: ObjectState.Changed,
            });
        }
    }
    async commitRowChange(rowIndex, row, postCommit) {
        const data = this.editForms.get(rowIndex)?.value;
        if (data) {
            const datum = {
                ...row,
                ...data,
            };
            if (data.DataState === ObjectState.New) {
                this.facade.addRequest(datum).then(() => { });
            }
            else {
                this.facade.updateRequest(datum).then(() => { });
            }
        }
    }
    onFilterSet(event) { }
    handleSearch(event) { }
    onStateChange(event) {
        console.log(`State changed for ${event.key}:`, event.value);
        switch (event.key) {
            case 'create':
                const timestamp = new Date();
                var newForm = {
                    Name: '',
                    Description: '',
                    StageEntryRule: '',
                    AssignmentType: TaskAssignmentType.AutoRoute,
                    TenantId: '',
                    ServiceName: '',
                    id: crypto.randomUUID(),
                    Id: '',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                    Code: '',
                    Status: Status.Active,
                    Actions: [],
                    Lanes: [],
                    Stages: [],
                };
                this.data.update((prev) => [newForm, ...prev]);
                console.log(newForm);
                break;
            default:
                break;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: WorkflowFacade }, { token: i1$2.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "18.2.13", type: WorkflowsComponent, selector: "lib-workflows", inputs: { designerUrl: { classPropertyName: "designerUrl", publicName: "designerUrl", isSignal: true, isRequired: false, transformFunction: null } }, usesInheritance: true, ngImport: i0, template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: true,\n      isToggle: true,\n    }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n    (onSearchChange)=\"handleSearch($event)\"\n  >\n    <div table-content>\n      <lib-data-table\n        [data]=\"data()\"\n        [columns]=\"config.columns\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n      >\n        <ng-container libColumn=\"name\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <div class=\"width-max\">\n              <verbena-input\n                [formControl]=\"getFormControl(rowIndex, 'Name')\"\n              ></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"description\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <div class=\"width-max\">\n              <verbena-input\n                [formControl]=\"getFormControl(rowIndex, 'Description')\"\n              ></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"name\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <div class=\"width-max\">\n              <verbena-input\n                [formControl]=\"getFormControl(rowIndex, 'Name')\"\n              ></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"description\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verbena-input\n              [formControl]=\"getFormControl(rowIndex, 'Description')\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"assignment-type\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verben-drop-down\n              styleClass=\"w-full\"\n              width=\"100%\"\n              [multiselect]=\"false\"\n              placeholder=\"Select\"\n              [options]=\"assignmentTypes\"\n              [formControl]=\"getFormControl(rowIndex, 'AssignmentType')\"\n              class=\"form-control\"\n            >\n            </verben-drop-down>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"operation\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verbena-input\n              [formControl]=\"getFormControl(rowIndex, 'Operation')\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"status\">\n          <ng-template #cell let-value>\n            <verbena-badge\n              borderRadius=\"9px\"\n              [bgColor]=\"value == 'Active' ? '#CAE1CC' : '#FFDFDF'\"\n              [textColor]=\"value == 'Active' ? '#4ABB54' : '#EB5757'\"\n              fontSize=\"12px\"\n              [text]=\"value\"\n              [pd]=\"'2px 6px'\"\n            ></verbena-badge>\n          </ng-template>\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verben-drop-down\n              styleClass=\"w-full\"\n              width=\"100%\"\n              [multiselect]=\"false\"\n              placeholder=\"Null\"\n              [options]=\"statuses\"\n              [formControl]=\"getFormControl(rowIndex, 'Status')\"\n              class=\"form-control\"\n            >\n            </verben-drop-down>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <!-- <ng-template\n            #cell\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-rowIndex=\"rowIndex\"\n          >\n            <button\n              (click)=\"\n                editForms.set(rowIndex, generateFormGroup(row)); toggleRowEdit()\n              \"\n              [disabled]=\"isEditing ? !isRowValid(rowIndex) : false\"\n            >\n              {{ isEditing ? \"Save\" : \"Edit\" }}\n            </button>\n          </ng-template> -->\n\n          <ng-template\n            #cell\n            let-value\n            let-deleteRow=\"deleteRow\"\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-rowIndex=\"rowIndex\"\n          >\n            <div class=\"flex gap-6\">\n              <verben-svg\n                (click)=\"\n                  editForms.set(rowIndex, generateFormGroup(row));\n                  toggleRowEdit()\n                \"\n                icon=\"edit\"\n                [width]=\"15\"\n                [height]=\"15\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <verben-svg\n                icon=\"delete\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"deleteRow()\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <a [routerLink]=\"[designerUrl(), value]\">\n                <verben-svg\n                  icon=\"designer\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                  class=\"cursor-pointer\"\n                ></verben-svg>\n              </a>\n            </div>\n          </ng-template>\n\n          <ng-template\n            #cellEdit\n            let-value\n            let-deleteRow\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-rowIndex=\"rowIndex\"\n          >\n            <div class=\"flex gap-6\">\n              <verben-svg\n                (click)=\"commitRowChange(rowIndex, row)\"\n                icon=\"tick\"\n                [width]=\"15\"\n                [height]=\"15\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <verben-svg\n                icon=\"delete\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"toggleRowEdit()\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <a [routerLink]=\"[value]\">\n                <verben-svg\n                  icon=\"cardViewAlt\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                  class=\"cursor-pointer\"\n                ></verben-svg>\n              </a>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        (loadMoreClick)=\"loadMore()\"\n        #vdcv\n        dataId=\"Code\"\n        border=\"5px\"\n        [cardDataList]=\"cardData()\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"20px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"Code\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData()\"\n          >\n            <ng-template #card let-item>\n              <div (click)=\"currentData = vdcv.onItemClick(item)\" class=\"flex\">\n                <div\n                  (click)=\"currentData = vdcv.onItemClick(item)\"\n                  class=\"flex cursor-pointer w-full bg-secondary rounded-xl\"\n                >\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"flex-1 flex items-end gap-y-2 gap-x-4 p-4\">\n                    <div class=\"flex-1 space-y-2\">\n                      <span\n                        class=\"font-semibold text-[#404040] flex-1 truncate\"\n                        >{{ item.title }}</span\n                      >\n\n                      <p class=\"flex items-center my-1\">\n                        <label for=\"phone\" class=\"text-[10px] font-light\"\n                          >Assignment:</label\n                        >\n                        <span id=\"phone\" class=\"text-sm truncate\">{{\n                          item.data.AssignmentType\n                        }}</span>\n                      </p>\n                    </div>\n\n                    <div class=\"grid gap-y-1\">\n                      <p class=\"grid\">\n                        <label\n                          for=\"role\"\n                          class=\"text-[10px] font-light text-[#404040]\"\n                          >Object</label\n                        >\n                        <span id=\"role\" class=\"text-sm font-medium\">{{\n                          item.data?.Operation\n                        }}</span>\n                      </p>\n\n                      <verbena-badge\n                        borderRadius=\"9px\"\n                        [bgColor]=\"\n                          item.data.Status == 'Active' ? '#CAE1CC' : '#FFDFDF'\n                        \"\n                        [textColor]=\"\n                          item.data.Status == 'Active' ? '#4ABB54' : '#EB5757'\n                        \"\n                        fontSize=\"12px\"\n                        [text]=\"item.data.Status\"\n                        [pd]=\"'2px 6px'\"\n                      ></verbena-badge>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <lib-workflow-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onSave)=\"onSave($event)\"\n              [operations]=\"operations()\"\n            ></lib-workflow-form>\n          </ng-template>\n        </verben-right-card-data-view>\n\n        <verben-card-data-view-footer class=\"w-full\">\n          <div\n            [ngClass]=\"{\n              'flex gap-2 items-center': true,\n              'justify-between': true,\n              'justify-end': vdcv.hasCurrentItem()\n            }\"\n          >\n            <verbena-button\n              *ngIf=\"!vdcv.hasCurrentItem()\"\n              [fontWeight]=\"'bold'\"\n              [bgColor]=\"'#8E8D87'\"\n              [borderRadius]=\"'4px'\"\n              [textColor]=\"'#fff'\"\n              [pd]=\"'9.79px 37.28px'\"\n              [text]=\"'Delete'\"\n            >\n            </verbena-button>\n            <div\n              class=\"flex {{\n                vdcv.hasCurrentItem() ? 'flex-1' : ''\n              }} justify-end items-center gap-5\"\n            >\n              <span class=\"paginator-text\"\n                >{{ cardData().length }} records loaded</span\n              >\n              <button\n                (click)=\"loadMore()\"\n                class=\"load-more view-links text-[#3479E9] underline\"\n              >\n                Load more\n              </button>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n\n    <div column-content>\n      <!-- <verben-visible-column\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"\n      ></verben-visible-column> -->\n\n      <lib-data-columns\n        [columns]=\"config.columns\"\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n      ></lib-data-columns>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        (filtersApplied)=\"onFilterSet($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <!-- <verben-sort-table\n        (selectedOptions)=\"onSortUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"\n      ></verben-sort-table> -->\n      <lib-data-sort\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (sortApplied)=\"onSortUpdated($event)\"\n      ></lib-data-sort>\n    </div>\n    <div export-content>\n      <lib-data-xport\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (exportDataEvent)=\"handleExport($event)\"\n      >\n      </lib-data-xport>\n    </div>\n  </verben-data-view>\n\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button\n        [fontWeight]=\"'bold'\"\n        [bgColor]=\"'#8E8D87'\"\n        [borderRadius]=\"'4px'\"\n        [textColor]=\"'#fff'\"\n        [pd]=\"'9.79px 37.28px'\"\n        [text]=\"'Delete'\"\n      >\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData().length }} records loaded</span>\n      <button\n        (click)=\"loadMore()\"\n        class=\"load-more view-links text-[#3479E9] underline\"\n      >\n        Load more\n      </button>\n    </div>\n  </div>\n</div>\n", styles: [".view-links{color:#3479e9;cursor:pointer}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.VerbenaBadgeComponent, selector: "verbena-badge", inputs: ["text", "bgColor", "textColor", "borderRadius", "pd", "fontSize", "width", "height"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.DataColumnsComponent, selector: "lib-data-columns", inputs: ["columns", "enableDragAndDrop", "maxVisibleItems"], outputs: ["columnsUpdated"] }, { kind: "component", type: i8.DataXportComponent, selector: "lib-data-xport", inputs: ["data", "columns"], outputs: ["exportDataEvent"] }, { kind: "component", type: i8.DataSortComponent, selector: "lib-data-sort", inputs: ["columns", "data", "enableDragAndDrop"], outputs: ["sortApplied", "resetFilter"] }, { kind: "directive", type: i5.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "component", type: WorkflowFormComponent, selector: "lib-workflow-form", inputs: ["operations", "currentData"], outputs: ["switchView", "onSave"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-workflows', template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: true,\n      isToggle: true,\n    }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n    (onSearchChange)=\"handleSearch($event)\"\n  >\n    <div table-content>\n      <lib-data-table\n        [data]=\"data()\"\n        [columns]=\"config.columns\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n      >\n        <ng-container libColumn=\"name\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <div class=\"width-max\">\n              <verbena-input\n                [formControl]=\"getFormControl(rowIndex, 'Name')\"\n              ></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"description\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <div class=\"width-max\">\n              <verbena-input\n                [formControl]=\"getFormControl(rowIndex, 'Description')\"\n              ></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"name\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <div class=\"width-max\">\n              <verbena-input\n                [formControl]=\"getFormControl(rowIndex, 'Name')\"\n              ></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"description\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verbena-input\n              [formControl]=\"getFormControl(rowIndex, 'Description')\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"assignment-type\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verben-drop-down\n              styleClass=\"w-full\"\n              width=\"100%\"\n              [multiselect]=\"false\"\n              placeholder=\"Select\"\n              [options]=\"assignmentTypes\"\n              [formControl]=\"getFormControl(rowIndex, 'AssignmentType')\"\n              class=\"form-control\"\n            >\n            </verben-drop-down>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"operation\">\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verbena-input\n              [formControl]=\"getFormControl(rowIndex, 'Operation')\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"status\">\n          <ng-template #cell let-value>\n            <verbena-badge\n              borderRadius=\"9px\"\n              [bgColor]=\"value == 'Active' ? '#CAE1CC' : '#FFDFDF'\"\n              [textColor]=\"value == 'Active' ? '#4ABB54' : '#EB5757'\"\n              fontSize=\"12px\"\n              [text]=\"value\"\n              [pd]=\"'2px 6px'\"\n            ></verbena-badge>\n          </ng-template>\n          <ng-template #cellEdit let-rowIndex=\"rowIndex\">\n            <verben-drop-down\n              styleClass=\"w-full\"\n              width=\"100%\"\n              [multiselect]=\"false\"\n              placeholder=\"Null\"\n              [options]=\"statuses\"\n              [formControl]=\"getFormControl(rowIndex, 'Status')\"\n              class=\"form-control\"\n            >\n            </verben-drop-down>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <!-- <ng-template\n            #cell\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-rowIndex=\"rowIndex\"\n          >\n            <button\n              (click)=\"\n                editForms.set(rowIndex, generateFormGroup(row)); toggleRowEdit()\n              \"\n              [disabled]=\"isEditing ? !isRowValid(rowIndex) : false\"\n            >\n              {{ isEditing ? \"Save\" : \"Edit\" }}\n            </button>\n          </ng-template> -->\n\n          <ng-template\n            #cell\n            let-value\n            let-deleteRow=\"deleteRow\"\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-rowIndex=\"rowIndex\"\n          >\n            <div class=\"flex gap-6\">\n              <verben-svg\n                (click)=\"\n                  editForms.set(rowIndex, generateFormGroup(row));\n                  toggleRowEdit()\n                \"\n                icon=\"edit\"\n                [width]=\"15\"\n                [height]=\"15\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <verben-svg\n                icon=\"delete\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"deleteRow()\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <a [routerLink]=\"[designerUrl(), value]\">\n                <verben-svg\n                  icon=\"designer\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                  class=\"cursor-pointer\"\n                ></verben-svg>\n              </a>\n            </div>\n          </ng-template>\n\n          <ng-template\n            #cellEdit\n            let-value\n            let-deleteRow\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-rowIndex=\"rowIndex\"\n          >\n            <div class=\"flex gap-6\">\n              <verben-svg\n                (click)=\"commitRowChange(rowIndex, row)\"\n                icon=\"tick\"\n                [width]=\"15\"\n                [height]=\"15\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <verben-svg\n                icon=\"delete\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"toggleRowEdit()\"\n                class=\"cursor-pointer\"\n              ></verben-svg>\n\n              <a [routerLink]=\"[value]\">\n                <verben-svg\n                  icon=\"cardViewAlt\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                  class=\"cursor-pointer\"\n                ></verben-svg>\n              </a>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        (loadMoreClick)=\"loadMore()\"\n        #vdcv\n        dataId=\"Code\"\n        border=\"5px\"\n        [cardDataList]=\"cardData()\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"20px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"Code\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData()\"\n          >\n            <ng-template #card let-item>\n              <div (click)=\"currentData = vdcv.onItemClick(item)\" class=\"flex\">\n                <div\n                  (click)=\"currentData = vdcv.onItemClick(item)\"\n                  class=\"flex cursor-pointer w-full bg-secondary rounded-xl\"\n                >\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"flex-1 flex items-end gap-y-2 gap-x-4 p-4\">\n                    <div class=\"flex-1 space-y-2\">\n                      <span\n                        class=\"font-semibold text-[#404040] flex-1 truncate\"\n                        >{{ item.title }}</span\n                      >\n\n                      <p class=\"flex items-center my-1\">\n                        <label for=\"phone\" class=\"text-[10px] font-light\"\n                          >Assignment:</label\n                        >\n                        <span id=\"phone\" class=\"text-sm truncate\">{{\n                          item.data.AssignmentType\n                        }}</span>\n                      </p>\n                    </div>\n\n                    <div class=\"grid gap-y-1\">\n                      <p class=\"grid\">\n                        <label\n                          for=\"role\"\n                          class=\"text-[10px] font-light text-[#404040]\"\n                          >Object</label\n                        >\n                        <span id=\"role\" class=\"text-sm font-medium\">{{\n                          item.data?.Operation\n                        }}</span>\n                      </p>\n\n                      <verbena-badge\n                        borderRadius=\"9px\"\n                        [bgColor]=\"\n                          item.data.Status == 'Active' ? '#CAE1CC' : '#FFDFDF'\n                        \"\n                        [textColor]=\"\n                          item.data.Status == 'Active' ? '#4ABB54' : '#EB5757'\n                        \"\n                        fontSize=\"12px\"\n                        [text]=\"item.data.Status\"\n                        [pd]=\"'2px 6px'\"\n                      ></verbena-badge>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <lib-workflow-form\n              [currentData]=\"currentData\"\n              (switchView)=\"vdv.toggleView()\"\n              (onSave)=\"onSave($event)\"\n              [operations]=\"operations()\"\n            ></lib-workflow-form>\n          </ng-template>\n        </verben-right-card-data-view>\n\n        <verben-card-data-view-footer class=\"w-full\">\n          <div\n            [ngClass]=\"{\n              'flex gap-2 items-center': true,\n              'justify-between': true,\n              'justify-end': vdcv.hasCurrentItem()\n            }\"\n          >\n            <verbena-button\n              *ngIf=\"!vdcv.hasCurrentItem()\"\n              [fontWeight]=\"'bold'\"\n              [bgColor]=\"'#8E8D87'\"\n              [borderRadius]=\"'4px'\"\n              [textColor]=\"'#fff'\"\n              [pd]=\"'9.79px 37.28px'\"\n              [text]=\"'Delete'\"\n            >\n            </verbena-button>\n            <div\n              class=\"flex {{\n                vdcv.hasCurrentItem() ? 'flex-1' : ''\n              }} justify-end items-center gap-5\"\n            >\n              <span class=\"paginator-text\"\n                >{{ cardData().length }} records loaded</span\n              >\n              <button\n                (click)=\"loadMore()\"\n                class=\"load-more view-links text-[#3479E9] underline\"\n              >\n                Load more\n              </button>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n\n    <div column-content>\n      <!-- <verben-visible-column\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"\n      ></verben-visible-column> -->\n\n      <lib-data-columns\n        [columns]=\"config.columns\"\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n      ></lib-data-columns>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        (filtersApplied)=\"onFilterSet($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <!-- <verben-sort-table\n        (selectedOptions)=\"onSortUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"\n      ></verben-sort-table> -->\n      <lib-data-sort\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (sortApplied)=\"onSortUpdated($event)\"\n      ></lib-data-sort>\n    </div>\n    <div export-content>\n      <lib-data-xport\n        [columns]=\"config.columns\"\n        [data]=\"data()\"\n        (exportDataEvent)=\"handleExport($event)\"\n      >\n      </lib-data-xport>\n    </div>\n  </verben-data-view>\n\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button\n        [fontWeight]=\"'bold'\"\n        [bgColor]=\"'#8E8D87'\"\n        [borderRadius]=\"'4px'\"\n        [textColor]=\"'#fff'\"\n        [pd]=\"'9.79px 37.28px'\"\n        [text]=\"'Delete'\"\n      >\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData().length }} records loaded</span>\n      <button\n        (click)=\"loadMore()\"\n        class=\"load-more view-links text-[#3479E9] underline\"\n      >\n        Load more\n      </button>\n    </div>\n  </div>\n</div>\n", styles: [".view-links{color:#3479e9;cursor:pointer}\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: WorkflowFacade }, { type: i1$2.FormBuilder }] });

class WorkflowsModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsModule, declarations: [WorkflowsComponent, WorkflowFormComponent], imports: [CommonModule, SharedModule, RouterLink], exports: [WorkflowsComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsModule, providers: [WorkflowsService], imports: [CommonModule, SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [WorkflowsComponent, WorkflowFormComponent],
                    imports: [CommonModule, SharedModule, RouterLink],
                    providers: [WorkflowsService],
                    exports: [WorkflowsComponent],
                }]
        }] });

const columns$1 = [
    {
        id: 'name',
        header: 'Name',
        accessorKey: 'Name',
    },
    {
        id: 'description',
        header: 'Description',
        accessorKey: 'Description',
    },
    {
        id: 'assignmentType',
        header: 'Assignment Type',
        accessorKey: 'AssignmentType',
    },
    {
        id: 'service',
        header: 'Service',
        accessorKey: 'StageEntryRule',
    },
    {
        id: 'operation',
        header: 'Operation',
        accessorKey: 'Operation',
    },
    {
        id: 'status',
        header: 'Status',
        accessorKey: 'Status',
    },
    {
        id: 'action',
        header: 'Actions',
        // accessorKey: 'Actions',
    },
];

let mockNames = [
    'Jecil',
    'Akintunde',
    'Babatunde',
    'Busayo',
    'Jibola',
    'Temiloluwa',
];
let mockOperations = ['Queve', 'Assign'];
const mockData = new Array(10).fill(1).map((id, i) => ({
    Status: randomEnum(Status),
    Operation: randomOperation(),
    Description: 'Sign in flow',
    Name: randomName(),
    StageEntryRule: 'Design',
    AssignmentType: TaskAssignmentType.Queue,
    Actions: [],
    Id: id + i,
    id: (id + i).toString(),
    Tenants: [],
    ServiceName: '',
    Code: '',
    TenantId: '',
    CreatedAt: new Date(),
    UpdatedAt: new Date(),
    DataState: ObjectState.New,
    Tenant: `Tenant${id + i}`,
    Lanes: [],
    Stages: [],
}));
function randomEnum(anEnum) {
    const enumValues = Object.values(anEnum);
    const randomIndex = Math.floor(Math.random() * enumValues.length);
    return enumValues[randomIndex];
}
function randomOperation() {
    const randomIndex = Math.floor(Math.random() * mockOperations.length);
    return mockOperations[randomIndex];
}
function randomName() {
    const randomIndex = Math.floor(Math.random() * mockNames.length);
    return mockNames[randomIndex];
}

const baseStyle$3 = {
    width: '100%',
    fontFamily: '"Fraunces", serif',
    fontSize: '125%',
    whiteSpace: 'nowrap',
    margin: '0',
    border: '1px solid #D4A007',
    borderRadius: '16px',
    borderCollapse: 'separate',
    borderSpacing: '0',
    tableLayout: 'fixed',
    overflow: 'hidden',
    rows: {
        even: {
            backgroundColor: '#FDFDFD',
        },
        odd: {
            backgroundColor: '#F1F4FB',
        },
        height: '68px',
    },
    cells: {
        padding: '0.5rem 1rem',
    },
    header: {
        // stickyTop: true,
        // zIndex: 2,
        backgroundColor: '#EFF2FB',
        fontWeight: 'bold',
        textAlign: 'left',
        padding: '12px 16px',
        height: '40px',
    },
    footer: {
        // stickyBottom: true,
        // zIndex: 2,
        padding: '3px',
    },
    //   body: {
    //     background: '#fff',
    //     padding: '4px 5px',
    //     textAlign: 'center',
    //   },
    // firstColumn: {
    //   stickyLeft: true,
    //   zIndex: 1,
    // },
    lastColumn: {
    // stickyRight: true,
    // zIndex: 1,
    },
};

class WorkflowComponent {
    cardDataView;
    dataView;
    itemClicked = new EventEmitter();
    data = mockData;
    styles = baseStyle$3;
    currentData = null;
    isGridView = true;
    selected = null;
    showSidebar = false;
    columns = columns$1;
    cardData = mockData.map(({ Operation, Description, Name }) => ({
        selected: false,
        title: Name,
        data: {
            Name,
            Operation,
            Description,
        },
        body: [],
        children: [],
    }));
    openDetailView(mailAddress) {
        const cardItem = this.getCardDataByMailAddress(mailAddress);
        if (cardItem && this.cardDataView) {
            this.dataView.toggleView();
            // First reset all selections
            this.cardData.forEach((item) => {
                item.selected = false;
                if (item.children) {
                    item.children.forEach((child) => (child.selected = false));
                }
            });
            // Set the selected item
            cardItem.selected = true;
            this.currentData = this.cardDataView.onItemClick(cardItem);
            // Force change detection if needed
            // this.changeDetectorRef.detectChanges();
        }
    }
    getCardDataByMailAddress(mailAddress) {
        return this.cardData.find(({ data }) => data.MailAddress === mailAddress);
    }
    onViewChange(isGridView) {
        this.isGridView = isGridView;
        // Reset selection when switching views
        if (this.currentData) {
            this.cardDataView?.clearData();
            this.currentData = null;
        }
        if (this.selected) {
            this.cardDataView.onItemClick(this.selected);
        }
    }
    openFormView(index) {
        const item = this.cardData[index];
    }
    handleExport(exportedData) {
        this.downloadCSV(exportedData);
    }
    handleClick(item) {
        this.itemClicked.emit(item.data);
    }
    handleConfig(item) {
        this.itemClicked.emit(item);
    }
    /**
     *
     * @param data Simple csv export for testing
     */
    downloadCSV(data) {
        const headers = Object.keys(data[0]);
        const csvContent = [
            headers.join(','),
            ...data.map((row) => headers.map((header) => row[header]).join(',')),
        ].join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'export.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
    onSelectionChange(selectedRows) {
        console.log('Selection changed:', selectedRows);
        // Handle the selection change
    }
    /**
     * Copied over from card view doc until I understand usage
     */
    selectedColumnCount = 0;
    selectedFilterTableCount = 0;
    isOPen = true;
    selectedSortCount = 0;
    showColumn = false;
    showSort = false;
    selectedAll = false;
    nestedbgcolor = '';
    visibleColumns = columns$1.map((col) => ({
        checked: true,
        name: typeof col.header === 'string' ? col.header : col.id,
        type: DataFilterType.Bool,
    }));
    filterArray = [
        {
            name: 'Name',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'MailAddress',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'PhoneNumber',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'CreatedAt',
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    sortOptions = [
        {
            name: 'Name',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'MailAddress',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'PhoneNumber',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'CreatedAt',
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    clearData() {
        this.currentData = {};
    }
    loadMore() {
        this.cardData = this.cardData.concat(this.cardData);
    }
    onColumnChange(event) {
        this.showColumn = event;
    }
    onSortChange(event) {
        this.showSort = event;
        console.log(event);
    }
    onColumnsUpdated(updatedColumns) {
        console.log(updatedColumns);
        this.onColumnChange(false);
        this.selectedColumnCount = updatedColumns.length;
    }
    onSortUpdated(updatedSorts) {
        this.onSortChange(false);
        this.selectedSortCount = updatedSorts.length;
        console.log(updatedSorts);
    }
    onStateChange(event) {
        console.log(`State changed for ${event.key}:`, event.value);
    }
    getRowStatus(type) {
        console.log('data is here', type);
        switch (type) {
            // case WorkflowStatus.Pending:
            //   return 'bg-[#FEF2E5] text-[#CD6200]';
            case Status.Active:
                return 'bg-[#EBF9F1] text-[#1F9254]';
            case Status.InActive:
                return 'bg-[#FBE7E8] text-[#A30D11]';
            default:
                return '';
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WorkflowComponent, selector: "verben-workflow", outputs: { itemClicked: "itemClicked" }, viewQueries: [{ propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }], ngImport: i0, template: "<div class=\"space-y-8\">\n    <verben-data-view\n      #vdv\n      [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true\n      }\"\n      [buttonClass]=\"'my-custom-button-class'\"\n      [iconClass]=\"'my-icon-class'\"\n      [tableIcon]=\"'table-view'\"\n      [cardIcon]=\"'list-view'\"\n      [activeIconClass]=\"'my-active-icon-class'\"\n      [selectedColumnCount]=\"0\"\n      [selectedSortCount]=\"0\"\n      [selectedFilterTableCount]=\"0\"\n      (viewChange)=\"onViewChange($event)\"\n      (stateChange)=\"onStateChange($event)\"\n    >\n      <div table-content>\n        <lib-data-table\n          [data]=\"data\"\n          [columns]=\"columns\"\n          [styleConfig]=\"styles\"\n          (selectionChange)=\"onSelectionChange($event)\"\n        >\n        <ng-container libColumn=\"select\">\n          <ng-template\n            #cell\n            let-value\n            let-isSelected=\"isSelected\"\n            let-toggleRowSelection=\"toggleRowSelection\"\n          >\n            <input\n              type=\"checkbox\"\n              [checked]=\"isSelected\"\n              class=\"cursor-pointer\"\n            />\n          </ng-template>\n          <ng-template\n          #header\n          let-allRowsSelected=\"allRowsSelected\"\n          let-someRowsSelected=\"someRowsSelected\"\n          let-toggleAllRows=\"toggleAllRows\"\n        >\n          <input\n            type=\"checkbox\"\n            [checked]=\"allRowsSelected()\"\n            [indeterminate]=\"someRowsSelected()\"\n            (change)=\"toggleAllRows()\"\n          />\n        </ng-template>\n        </ng-container>\n          <ng-container libColumn=\"status\">\n            <ng-template #cell let-value>\n              <div [class]=\"getRowStatus(value)\" class=\"rounded-[22px] flex items-center justify-center w-[84px] h-[31px] font-medium text-xs leading-[14.63px]\"> \n                {{value}}\n              </div>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"action\">\n            <ng-template \n            #cell let-value \n            let-row=\"row\">\n            <div class=\"flex items-center gap-4\">\n              <span class=\"cursor-pointer\">\n                <verben-svg\n                  icon=\"edit\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                ></verben-svg>\n              </span>\n              <span class=\"cursor-pointer\">\n                <verben-svg\n                  icon=\"delete\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                ></verben-svg>\n              </span>\n              <span class=\"cursor-pointer\">\n                <verben-svg\n                  icon=\"draw\"\n                  [width]=\"18\"\n                  [height]=\"18\"\n                ></verben-svg>\n              </span>\n            </div>\n            </ng-template>\n          </ng-container>\n        </lib-data-table>\n      </div>\n      <div card-content>\n        <verben-card-data-view\n          borderRadius=\"12px\"\n          (loadMoreClick)=\"loadMore()\"\n          #vdcv\n          dataId=\"MailAddress\"\n          border=\"5px\"\n          [cardDataList]=\"cardData\"\n          rbgColor=\"#f5f6f9\"\n          mg=\"0px\"\n        >\n          <verben-left-card-data-view class=\"\">\n            <verben-left-card-data\n              #vlcd\n              [parent]=\"vdcv\"\n              dataId=\"MailAddress\"\n              class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n              [cardDataList]=\"cardData\"\n            >\n              <ng-template #card let-item>\n                <div class=\"flex h-[88px]\">\n                  <div\n                    class=\"flex  w-full bg-secondary rounded-xl\"\n                  >\n                    <div\n                      class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                      [ngClass]=\"\n                        item.selected ? 'bg-primary' : 'bg-secondary-200'\n                      \"\n                    ></div>\n                    <div class=\"py-3 px-4 w-full h-[100%]\">\n                      <div class=\"flex items-start justify-between h-[100%]\">\n                        <div class=\"flex flex-col justify-between h-[100%]\">\n                          <h3 class=\"my-0 font-semibold text-[#404040] leading-[19.5px]\">{{\n                            item.title\n                          }}</h3>\n                          <p class=\"flex items-center\">\n                            <label  class=\"!text-[10px] font-light text-[#404040] leading-[12.1px]\"\n                              >Config count:</label\n                            >\n                            <span class=\"text-[13px] leading-[15.85px] font-medium ml-1 text-black\">{{\n                              item.data.Count\n                            }}</span>\n                          </p>\n                        </div>\n  \n                        <div class=\"flex items-end h-[100%]\">\n                            <p\n                            (click)=\"handleClick(item)\" \n                            class=\"my-0 underline text-[#3479E9] text-[11px] leading-[16.6px] cursor-pointer font-medium\"\n                            >View configs</p>\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </ng-template>\n            </verben-left-card-data>\n          </verben-left-card-data-view>\n          <!-- <verben-right-card-data-view> \n            yeshhhhhh\n          </verben-right-card-data-view> -->\n  \n          <verben-card-data-view-footer class=\"float-right\">\n            <div class=\"flex gap-2\">\n              <span class=\"paginator-text\"\n                >{{ cardData.length }} records loaded</span\n              >\n              <button (click)=\"loadMore()\" class=\"load-more\">Load more</button>\n            </div>\n          </verben-card-data-view-footer>\n        </verben-card-data-view>\n      </div>\n      <div column-content>\n        <verben-visible-column\n          (columnsUpdated)=\"onColumnsUpdated($event)\"\n          [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\"\n          boxShadow=\"2px 2px 2px 0px silver\"\n          bgColor=\"white\"\n          width=\"400px\"\n          textColor=\"black\"\n          pd=\"1rem\"\n          primaryColor=\"#FFE681\"\n          secondaryColor=\"#3479E9\"\n          [columns]=\"visibleColumns\"\n          [displayedColumns]=\"5\"\n        ></verben-visible-column>\n      </div>\n      <div filter-content>\n        <verben-table-filter\n          [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\"\n          boxShadow=\"2px 2px 2px 0px silver\"\n          bgColor=\"white\"\n          width=\"420px\"\n          textColor=\"black\"\n          pd=\"1rem\"\n          primaryColor=\"#FFE681\"\n          secondaryColor=\"#3479E9\"\n          tertiaryColor=\"#404040\"\n          [filterOptions]=\"filterArray\"\n          [maxFilterLength]=\"3\"\n        ></verben-table-filter>\n      </div>\n      <div sort-content>\n        <verben-sort-table\n          (selectedOptions)=\"onSortUpdated($event)\"\n          [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\"\n          boxShadow=\"2px 2px 2px 0px silver\"\n          bgColor=\"white\"\n          width=\"400px\"\n          textColor=\"black\"\n          pd=\"1rem\"\n          primaryColor=\"#FFE681\"\n          secondaryColor=\"#3479E9\"\n          tertiaryColor=\"#404040\"\n          [enableDragAndDrop]=\"true\"\n          [sortOptions]=\"sortOptions\"\n        ></verben-sort-table>\n      </div>\n      <div export-content>\n        <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n        </lib-data-export>\n      </div>\n    </verben-data-view>\n  </div>\n  \n  ", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.SortTableComponent, selector: "verben-sort-table", inputs: ["enableDragAndDrop", "sortOptions", "resetText", "displayedOptions", "propertyText", "showMoreText", "sortButtonText", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "containerHeight"], outputs: ["selectedOptions", "resetSortData"] }, { kind: "component", type: i8.VisibleColumnComponent, selector: "verben-visible-column", inputs: ["columns", "items", "enableDragAndDrop", "displayedColumns", "showMore", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "closeColumn"], outputs: ["columnsUpdated", "resetFilter"] }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowComponent, decorators: [{
            type: Component,
            args: [{ selector: 'verben-workflow', template: "<div class=\"space-y-8\">\n    <verben-data-view\n      #vdv\n      [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true\n      }\"\n      [buttonClass]=\"'my-custom-button-class'\"\n      [iconClass]=\"'my-icon-class'\"\n      [tableIcon]=\"'table-view'\"\n      [cardIcon]=\"'list-view'\"\n      [activeIconClass]=\"'my-active-icon-class'\"\n      [selectedColumnCount]=\"0\"\n      [selectedSortCount]=\"0\"\n      [selectedFilterTableCount]=\"0\"\n      (viewChange)=\"onViewChange($event)\"\n      (stateChange)=\"onStateChange($event)\"\n    >\n      <div table-content>\n        <lib-data-table\n          [data]=\"data\"\n          [columns]=\"columns\"\n          [styleConfig]=\"styles\"\n          (selectionChange)=\"onSelectionChange($event)\"\n        >\n        <ng-container libColumn=\"select\">\n          <ng-template\n            #cell\n            let-value\n            let-isSelected=\"isSelected\"\n            let-toggleRowSelection=\"toggleRowSelection\"\n          >\n            <input\n              type=\"checkbox\"\n              [checked]=\"isSelected\"\n              class=\"cursor-pointer\"\n            />\n          </ng-template>\n          <ng-template\n          #header\n          let-allRowsSelected=\"allRowsSelected\"\n          let-someRowsSelected=\"someRowsSelected\"\n          let-toggleAllRows=\"toggleAllRows\"\n        >\n          <input\n            type=\"checkbox\"\n            [checked]=\"allRowsSelected()\"\n            [indeterminate]=\"someRowsSelected()\"\n            (change)=\"toggleAllRows()\"\n          />\n        </ng-template>\n        </ng-container>\n          <ng-container libColumn=\"status\">\n            <ng-template #cell let-value>\n              <div [class]=\"getRowStatus(value)\" class=\"rounded-[22px] flex items-center justify-center w-[84px] h-[31px] font-medium text-xs leading-[14.63px]\"> \n                {{value}}\n              </div>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"action\">\n            <ng-template \n            #cell let-value \n            let-row=\"row\">\n            <div class=\"flex items-center gap-4\">\n              <span class=\"cursor-pointer\">\n                <verben-svg\n                  icon=\"edit\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                ></verben-svg>\n              </span>\n              <span class=\"cursor-pointer\">\n                <verben-svg\n                  icon=\"delete\"\n                  [width]=\"15\"\n                  [height]=\"15\"\n                ></verben-svg>\n              </span>\n              <span class=\"cursor-pointer\">\n                <verben-svg\n                  icon=\"draw\"\n                  [width]=\"18\"\n                  [height]=\"18\"\n                ></verben-svg>\n              </span>\n            </div>\n            </ng-template>\n          </ng-container>\n        </lib-data-table>\n      </div>\n      <div card-content>\n        <verben-card-data-view\n          borderRadius=\"12px\"\n          (loadMoreClick)=\"loadMore()\"\n          #vdcv\n          dataId=\"MailAddress\"\n          border=\"5px\"\n          [cardDataList]=\"cardData\"\n          rbgColor=\"#f5f6f9\"\n          mg=\"0px\"\n        >\n          <verben-left-card-data-view class=\"\">\n            <verben-left-card-data\n              #vlcd\n              [parent]=\"vdcv\"\n              dataId=\"MailAddress\"\n              class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n              [cardDataList]=\"cardData\"\n            >\n              <ng-template #card let-item>\n                <div class=\"flex h-[88px]\">\n                  <div\n                    class=\"flex  w-full bg-secondary rounded-xl\"\n                  >\n                    <div\n                      class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                      [ngClass]=\"\n                        item.selected ? 'bg-primary' : 'bg-secondary-200'\n                      \"\n                    ></div>\n                    <div class=\"py-3 px-4 w-full h-[100%]\">\n                      <div class=\"flex items-start justify-between h-[100%]\">\n                        <div class=\"flex flex-col justify-between h-[100%]\">\n                          <h3 class=\"my-0 font-semibold text-[#404040] leading-[19.5px]\">{{\n                            item.title\n                          }}</h3>\n                          <p class=\"flex items-center\">\n                            <label  class=\"!text-[10px] font-light text-[#404040] leading-[12.1px]\"\n                              >Config count:</label\n                            >\n                            <span class=\"text-[13px] leading-[15.85px] font-medium ml-1 text-black\">{{\n                              item.data.Count\n                            }}</span>\n                          </p>\n                        </div>\n  \n                        <div class=\"flex items-end h-[100%]\">\n                            <p\n                            (click)=\"handleClick(item)\" \n                            class=\"my-0 underline text-[#3479E9] text-[11px] leading-[16.6px] cursor-pointer font-medium\"\n                            >View configs</p>\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </ng-template>\n            </verben-left-card-data>\n          </verben-left-card-data-view>\n          <!-- <verben-right-card-data-view> \n            yeshhhhhh\n          </verben-right-card-data-view> -->\n  \n          <verben-card-data-view-footer class=\"float-right\">\n            <div class=\"flex gap-2\">\n              <span class=\"paginator-text\"\n                >{{ cardData.length }} records loaded</span\n              >\n              <button (click)=\"loadMore()\" class=\"load-more\">Load more</button>\n            </div>\n          </verben-card-data-view-footer>\n        </verben-card-data-view>\n      </div>\n      <div column-content>\n        <verben-visible-column\n          (columnsUpdated)=\"onColumnsUpdated($event)\"\n          [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\"\n          boxShadow=\"2px 2px 2px 0px silver\"\n          bgColor=\"white\"\n          width=\"400px\"\n          textColor=\"black\"\n          pd=\"1rem\"\n          primaryColor=\"#FFE681\"\n          secondaryColor=\"#3479E9\"\n          [columns]=\"visibleColumns\"\n          [displayedColumns]=\"5\"\n        ></verben-visible-column>\n      </div>\n      <div filter-content>\n        <verben-table-filter\n          [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\"\n          boxShadow=\"2px 2px 2px 0px silver\"\n          bgColor=\"white\"\n          width=\"420px\"\n          textColor=\"black\"\n          pd=\"1rem\"\n          primaryColor=\"#FFE681\"\n          secondaryColor=\"#3479E9\"\n          tertiaryColor=\"#404040\"\n          [filterOptions]=\"filterArray\"\n          [maxFilterLength]=\"3\"\n        ></verben-table-filter>\n      </div>\n      <div sort-content>\n        <verben-sort-table\n          (selectedOptions)=\"onSortUpdated($event)\"\n          [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\"\n          boxShadow=\"2px 2px 2px 0px silver\"\n          bgColor=\"white\"\n          width=\"400px\"\n          textColor=\"black\"\n          pd=\"1rem\"\n          primaryColor=\"#FFE681\"\n          secondaryColor=\"#3479E9\"\n          tertiaryColor=\"#404040\"\n          [enableDragAndDrop]=\"true\"\n          [sortOptions]=\"sortOptions\"\n        ></verben-sort-table>\n      </div>\n      <div export-content>\n        <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n        </lib-data-export>\n      </div>\n    </verben-data-view>\n  </div>\n  \n  " }]
        }], propDecorators: { cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }], itemClicked: [{
                type: Output
            }] } });

class WorkflowModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: WorkflowModule, declarations: [WorkflowComponent], imports: [CommonModule, SharedModule], exports: [WorkflowComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowModule, imports: [CommonModule, SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [WorkflowComponent],
                    imports: [CommonModule, SharedModule],
                    exports: [WorkflowComponent]
                }]
        }] });

const columns = [
    {
        id: 'name',
        header: 'Name',
        accessorKey: 'Name',
    },
    {
        id: 'description',
        header: 'Description',
        accessorKey: 'Description',
    },
    {
        id: 'assignment-type',
        header: 'Assignment Type',
        accessorKey: 'AssignmentType',
    },
    {
        id: 'operation',
        header: 'Operation',
        accessorKey: 'Operation',
    },
    {
        id: 'stage-entry-rule',
        header: 'StageEntryRule',
        accessorKey: 'StageEntryRule',
    },
    {
        id: 'status',
        header: 'Status',
        accessorKey: 'Status',
    },
    { id: 'actions', header: 'Actions', accessorKey: 'Code' },
];

class WfComponent extends BaseDataViewComponent {
    config = {
        dataSource: [], // Populate from service
        columns: columns, // Your existing column definitions
        cardDataMapper: (task) => ({
            selected: false,
            title: task.Name,
            data: task,
            body: [
                { title: 'Name', value: task.Name },
                { title: 'Status', value: task.Status },
                { title: 'AssignmentType', value: task.AssignmentType },
            ],
            children: [],
        }),
        onDetailView: (task) => {
            // Custom detail view logic
        },
    };
    getCardDataByIdentifier(code) {
        return this.cardData().find(({ data }) => data.data.Code === code);
    }
    // Event handlers
    onViewChange(isGridView) { }
    onStateChange(event) {
        console.log(`State changed for ${event.key}:`, event.value);
        switch (event.key) {
            case 'create':
                const timestamp = new Date();
                var newForm = {
                    Name: '',
                    Description: '',
                    StageEntryRule: '',
                    AssignmentType: TaskAssignmentType.Queue,
                    TenantId: '',
                    ServiceName: '',
                    id: timestamp.toString(),
                    Id: timestamp.toString(),
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                    Code: timestamp.toString(),
                    Status: Status.Active,
                    Actions: [],
                    Lanes: [],
                    Stages: [],
                };
                this.data.update((prev) => [newForm, ...prev]);
                break;
            default:
                break;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WfComponent, selector: "lib-wf", usesInheritance: true, ngImport: i0, template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle: true,\n      }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div table-content></div>\n\n    <div card-content></div>\n\n    <div column-content></div>\n\n    <div filter-content></div>\n\n    <div sort-content></div>\n\n    <div export-content></div>\n  </verben-data-view>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-wf', template: "<div class=\"space-y-8\">\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle: true,\n      }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div table-content></div>\n\n    <div card-content></div>\n\n    <div column-content></div>\n\n    <div filter-content></div>\n\n    <div sort-content></div>\n\n    <div export-content></div>\n  </verben-data-view>\n</div>\n" }]
        }] });

class WfService {
    httpService;
    BASE_URL = 'Workflow';
    constructor(httpService) {
        this.httpService = httpService;
    }
    /**
     * Get user access requests with pagination and sorting
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the user access requests
     */
    getWorkflows(skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/GetWorkflows/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get user access requests with additional parameter, pagination and sorting
     * @param param Search parameter
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the filtered user access requests
     */
    getWorkflowWithParam(param, skip = 0, limit = 1, sortParam = 'CreatedAt', sortOrder = 'Asc') {
        const url = `${this.BASE_URL}/GetWorkflowsWithParam/${param}/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    /**
     * Get user access requests with additional parameter, pagination and sorting
     * @param params Filter parameters
     * @param skip Number of records to skip
     * @param limit Number of records to take
     * @param sortParam Sort parameter
     * @param sortOrder Sort order ('asc' or 'desc')
     * @returns Promise containing the filtered user access requests
     */
    getWorkflowByFilterParams(params, skip, limit, sortParam, sortOrder) {
        const url = `${this.BASE_URL}/SearchWorkflow/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.post(url, params);
    }
    /**
     * Save multiple user access requests
     * @param requests Array of user access requests to save
     * @returns Promise containing the save operation result
     */
    saveWorkflows(requests) {
        const url = `${this.BASE_URL}/SaveWorkflows`;
        // const payload = requests.map((wf) => {
        //   delete wf["Id"];
        //   wf.Actions = wf.Actions.map((ac) => {
        //     delete ac["Id"];
        //     return ac;
        //   })
        //   return wf;
        // })
        return this.httpService.post(url, requests);
    }
    /**
     * Delete multiple user access requests
     * @param requestIds Array of request IDs to delete
     * @returns Observable containing the delete operation result
     */
    deleteWorkflows(requestIds) {
        const url = `${this.BASE_URL}/DeleteWorkflows`;
        return this.httpService.delete(`${url}?data=${requestIds.join(',')}`);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfService, deps: [{ token: HttpWebRequestService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: HttpWebRequestService }] });

class WfModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: WfModule, declarations: [WfComponent], imports: [CommonModule, SharedModule, RouterLink], exports: [WfComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfModule, providers: [WfService], imports: [CommonModule, SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WfModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [WfComponent],
                    imports: [CommonModule, SharedModule, RouterLink],
                    providers: [WfService],
                    exports: [WfComponent],
                }]
        }] });

var StageActorRule;
(function (StageActorRule) {
    StageActorRule["None"] = "None";
    StageActorRule["Any"] = "Any";
    StageActorRule["All"] = "All";
    StageActorRule["MinimumNumber"] = "MinimumNumber";
})(StageActorRule || (StageActorRule = {}));

class WorkflowDesignerState {
    swimlanes = [];
    startNodeId = null; // Track the ID of the first/start node
    connections = [];
    draggingConnectionData = {};
    workflowFormId = null;
    workflowFormName = null;
    workflowId = null;
    workflow = null;
    swimlaneRecord = {};
    stageRecord = {};
    actionRecord = {};
    setWorkflowId(id) {
        this.workflowId = id;
    }
    laneIdToIndexMap = new Map();
    connectionRules = {
        stage: ['stage', 'decision', 'subflow', 'form'],
        decision: ['stage'], // Decisions can only connect to Stages
        // 'action': ['stage', 'form', 'decision'],
        form: [],
        subflow: ['stage', 'decision'],
    };
    setWorkflowForm(formId, formName) {
        this.workflowFormId = formId;
        this.workflowFormName = formName;
        console.log(this.workflowFormId, this.workflowFormName);
    }
    addSwimlane(name, tags) {
        // Generate a unique key for this swimlane
        const swimlaneKey = `lane-${Date.now()}-${Math.floor(Math.random() * 1000)}`;
        this.swimlanes = this.swimlanes.concat([
            {
                order: this.swimlanes.length,
                label: name,
                tags,
                nodes: [],
                id: swimlaneKey, // Store the generated key as id for frontend reference
            },
        ]);
    }
    registerLaneMapping(laneId, swimlaneIndex) {
        this.laneIdToIndexMap.set(laneId, swimlaneIndex);
    }
    // Add this method to generate connection points for a node
    generateConnectionPoints(node) {
        const points = [];
        const spacing = 50; // Space between connection points
        if (node.type === 'stage') {
            // Rectangular shapes - add points around the rectangle
            // Top edge points
            for (let x = spacing; x < node.width; x += spacing) {
                points.push({
                    id: `${node.id}-top-${x}`,
                    nodeId: node.id,
                    x: x,
                    y: 0,
                    type: 'top',
                });
            }
            // Right edge points
            for (let y = spacing; y < node.height; y += spacing) {
                points.push({
                    id: `${node.id}-right-${y}`,
                    nodeId: node.id,
                    x: node.width,
                    y: y,
                    type: 'right',
                });
            }
            // Bottom edge points
            for (let x = spacing; x < node.width; x += spacing) {
                points.push({
                    id: `${node.id}-bottom-${x}`,
                    nodeId: node.id,
                    x: x,
                    y: node.height,
                    type: 'bottom',
                });
            }
            // Left edge points
            for (let y = spacing; y < node.height; y += spacing) {
                points.push({
                    id: `${node.id}-left-${y}`,
                    nodeId: node.id,
                    x: 0,
                    y: y,
                    type: 'left',
                });
            }
        }
        else if (node.type === 'decision') {
            // Diamond shape - add points at the four corners
            points.push({
                id: `${node.id}-top-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: 0,
                type: 'top',
            });
            points.push({
                id: `${node.id}-right-0`,
                nodeId: node.id,
                x: node.width,
                y: node.height / 2,
                type: 'right',
            });
            points.push({
                id: `${node.id}-bottom-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: node.height,
                type: 'bottom',
            });
            points.push({
                id: `${node.id}-left-0`,
                nodeId: node.id,
                x: 0,
                y: node.height / 2,
                type: 'left',
            });
        }
        else if (node.type === 'form') {
            // Form only has input connection points, no output points
            // Left edge points (for input connections)
            for (let y = spacing; y < node.height; y += spacing) {
                points.push({
                    id: `${node.id}-left-${y}`,
                    nodeId: node.id,
                    x: 0,
                    y: y,
                    type: 'left',
                });
            }
        }
        else if (node.type === 'subflow') {
            // Hexagon shape - add points at the six corners
            points.push({
                id: `${node.id}-top-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: 0,
                type: 'top',
            });
            points.push({
                id: `${node.id}-right-top`,
                nodeId: node.id,
                x: node.width,
                y: node.height / 4,
                type: 'right',
            });
            points.push({
                id: `${node.id}-right-bottom`,
                nodeId: node.id,
                x: node.width,
                y: (node.height * 3) / 4,
                type: 'right',
            });
            points.push({
                id: `${node.id}-bottom-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: node.height,
                type: 'bottom',
            });
            points.push({
                id: `${node.id}-left-bottom`,
                nodeId: node.id,
                x: 0,
                y: (node.height * 3) / 4,
                type: 'left',
            });
            points.push({
                id: `${node.id}-left-top`,
                nodeId: node.id,
                x: 0,
                y: node.height / 4,
                type: 'left',
            });
        }
        return points;
    }
    addNode(swimlaneIndex, type, x, y, stageData, workflowData, useExistingId = false) {
        if (!this.swimlanes[swimlaneIndex] ||
            !type ||
            (type !== 'stage' &&
                type !== 'decision' &&
                type !== 'form' &&
                type !== 'subflow')) {
            return null;
        }
        // Adjust position relative to swimlane
        const adjustedY = y - swimlaneIndex * 263; // Subtracting header height
        // Generate a unique ID or use existing
        const id = useExistingId && stageData?.Code
            ? stageData.Code
            : `${type}-${Date.now()}-${Math.floor(Math.random() * 1000)}`;
        // Create node with dimensions based on type
        const node = {
            id,
            type,
            x,
            y: adjustedY,
            width: type === 'subflow' ? 150 : 169, // Width from SVG
            height: 100, // Height from SVG
            isStartNode: false, // Default to false
            stageData: stageData || {}, // Store stage data
            workflowData: workflowData || null,
        };
        // If this is the first node in the entire workflow, mark it as the start node
        if (this.getNodeCount() === 0) {
            node.isStartNode = true;
            this.startNodeId = id;
        }
        // Generate connection points for the node
        node.connectionPoints = this.generateConnectionPoints(node);
        // Add node to the swimlane
        if (!this.swimlanes[swimlaneIndex].nodes) {
            this.swimlanes[swimlaneIndex].nodes = [];
        }
        this.swimlanes[swimlaneIndex].nodes.push(node);
        return node;
    }
    // Helper to get total node count across all swimlanes
    getNodeCount() {
        return this.swimlanes.reduce((count, swimlane) => count + (swimlane.nodes?.length || 0), 0);
    }
    // Find a node by ID (useful for later operations)
    findNodeById(id) {
        for (let i = 0; i < this.swimlanes.length; i++) {
            const swimlane = this.swimlanes[i];
            const node = swimlane.nodes?.find((n) => n.id === id);
            if (node) {
                return { node, swimlaneIndex: i };
            }
        }
        return null;
    }
    startConnectionDrag(point, swimlaneIndex, globalX, globalY) {
        this.draggingConnectionData = {
            sourcePoint: point,
            sourceSwimlaneIndex: swimlaneIndex,
            startX: globalX,
            startY: globalY,
            currentX: globalX,
            currentY: globalY,
        };
    }
    updateConnectionDrag(currentX, currentY) {
        if (this.draggingConnectionData.sourcePoint) {
            this.draggingConnectionData.currentX = currentX;
            this.draggingConnectionData.currentY = currentY;
        }
    }
    endConnectionDrag() {
        console.log('Ending connection drag, clearing data');
        // Clear dragging data
        this.draggingConnectionData = {};
    }
    isConnectionDragging() {
        return !!this.draggingConnectionData.sourcePoint;
    }
    getConnectionPathData() {
        if (!this.draggingConnectionData.sourcePoint)
            return null;
        const { sourcePoint, sourceSwimlaneIndex, currentX, currentY } = this.draggingConnectionData;
        const node = this.findNodeById(sourcePoint.nodeId)?.node;
        if (!node || sourceSwimlaneIndex === undefined)
            return null;
        // Calculate start point in global coordinates
        const startX = node.x + sourcePoint.x;
        const startY = node.y + sourcePoint.y + sourceSwimlaneIndex * 263; // Add swimlane offset
        return {
            startX,
            startY,
            endX: currentX ?? startX,
            endY: currentY ?? startY,
            sourceSwimlaneIndex,
        };
    }
    createConnection(targetNodeId, targetPointId, targetSwimlaneIndex) {
        const { sourcePoint, sourceSwimlaneIndex } = this.draggingConnectionData;
        if (!sourcePoint || sourceSwimlaneIndex === undefined) {
            console.error('Missing source data for connection');
            return null;
        }
        const connection = {
            id: `conn-${Date.now()}-${Math.floor(Math.random() * 1000)}`,
            sourceNodeId: sourcePoint.nodeId,
            targetNodeId: targetNodeId,
            sourcePointId: sourcePoint.id,
            targetPointId: targetPointId,
            sourceSwimlaneIndex: sourceSwimlaneIndex,
            targetSwimlaneIndex: targetSwimlaneIndex,
            label: '',
        };
        this.connections.push(connection);
        console.log('Created connection:', connection);
        console.log('Connections array now has', this.connections.length, 'connections');
        return connection;
    }
    // Add a method to get connection data for rendering
    getConnectionData(connection) {
        const sourceNodeInfo = this.findNodeById(connection.sourceNodeId);
        const targetNodeInfo = this.findNodeById(connection.targetNodeId);
        if (!sourceNodeInfo || !targetNodeInfo) {
            return null;
        }
        const sourceNode = sourceNodeInfo.node;
        const targetNode = targetNodeInfo.node;
        // Find connection points
        const sourcePoint = sourceNode.connectionPoints?.find((p) => p.id === connection.sourcePointId);
        const targetPoint = targetNode.connectionPoints?.find((p) => p.id === connection.targetPointId);
        if (!sourcePoint || !targetPoint) {
            return null;
        }
        // Calculate global coordinates
        const startX = sourceNode.x + sourcePoint.x;
        const startY = sourceNode.y + sourcePoint.y + connection.sourceSwimlaneIndex * 263;
        const endX = targetNode.x + targetPoint.x;
        const endY = targetNode.y + targetPoint.y + connection.targetSwimlaneIndex * 263;
        return {
            startX,
            startY,
            endX,
            endY,
            sourceSwimlaneIndex: connection.sourceSwimlaneIndex,
            targetSwimlaneIndex: connection.targetSwimlaneIndex,
        };
    }
    // Add a method to check if a connection is allowed based on node types
    canConnect(sourceNodeType, targetNodeType) {
        return (this.connectionRules[sourceNodeType]?.includes(targetNodeType) || false);
    }
    // Add a method to get allowed node types for the current dragging connection
    getAllowedTargetNodeTypes() {
        if (!this.draggingConnectionData.sourcePoint) {
            return [];
        }
        const sourceNodeInfo = this.findNodeById(this.draggingConnectionData.sourcePoint.nodeId);
        if (!sourceNodeInfo) {
            return [];
        }
        const sourceNodeType = sourceNodeInfo.node.type;
        return this.connectionRules[sourceNodeType] || [];
    }
    updateSwimlane(index, name, tags) {
        console.log('State: Updating swimlane at index', index, 'with name', name, 'and tags', tags);
        if (index >= 0 && index < this.swimlanes.length) {
            this.swimlanes[index] = {
                ...this.swimlanes[index],
                label: name,
                tags: tags,
            };
            console.log('Swimlane updated:', this.swimlanes[index]);
        }
        else {
            console.error('Invalid swimlane index:', index);
        }
    }
    transformToWorkflowModel() {
        // Use stored workflow if available, otherwise create a new one
        const workflow = this.workflow
            ? { ...this.workflow, DataState: ObjectState.Changed }
            : {
                // BaseModel properties
                Id: '',
                Code: '',
                TenantId: '',
                id: '',
                ServiceName: '',
                CreatedAt: new Date(),
                UpdatedAt: new Date(),
                DataState: this.wasLoadedFromApi(this.workflowId || '')
                    ? ObjectState.Changed
                    : ObjectState.New,
                // Workflow specific properties
                Name: 'New Workflow',
                Description: '',
                StageEntryRule: '',
                Form: this.workflowFormId || undefined,
                AssignmentType: TaskAssignmentType.AutoRoute,
                Operation: '',
                Status: Status.Active,
                Actions: [],
                Lanes: [],
                Stages: [],
            };
        // Update workflow form if changed
        if (this.workflowFormId !== this.workflow?.Form) {
            workflow.Form = this.workflowFormId || workflow.Form;
        }
        // Transform swimlanes to SwimLane[]
        workflow.Lanes = this.swimlanes.map((swimlane) => {
            // Check if this is an existing swimlane
            if (swimlane.id && this.swimlaneRecord[swimlane.id]) {
                // Update existing lane with changed values
                const existingLane = this.swimlaneRecord[swimlane.id];
                return {
                    ...existingLane,
                    Tags: swimlane.tags,
                    Position: swimlane.order,
                    Coordinates: { X: 0, Y: swimlane.order * 263 },
                    DataState: ObjectState.Changed,
                    UpdatedAt: new Date(),
                };
            }
            else {
                // Generate a new ID for new swimlanes if not already set
                const laneId = swimlane.id ||
                    `lane-${Date.now()}-${Math.floor(Math.random() * 1000)}`;
                // Create new lane
                return {
                    Code: '',
                    Id: '',
                    TenantId: '',
                    // id: laneId,
                    id: '',
                    ServiceName: '',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                    Workflow: workflow.Code,
                    Tags: swimlane.tags || [],
                    Position: swimlane.order,
                    Coordinates: { X: 0, Y: swimlane.order * 263 },
                    Size: { Width: 3000, Height: 263 },
                    Key: swimlane.id,
                };
            }
        });
        // Transform nodes to WorkflowStage[]
        const stages = [];
        this.swimlanes.forEach((swimlane, swimlaneIndex) => {
            swimlane.nodes?.forEach((node) => {
                if (node.type === 'stage' || node.type === 'subflow') {
                    // Check if this is an existing stage
                    if (this.stageRecord[node.id]) {
                        // Update existing stage with changed values
                        const existingStage = this.stageRecord[node.id];
                        // Create a new object with updated properties
                        const updatedStage = {
                            ...existingStage,
                            DataState: ObjectState.Changed,
                            UpdatedAt: new Date(),
                        };
                        // Update properties that may have changed
                        if (node.stageData?.Name !== undefined)
                            updatedStage.Name = node.stageData.Name;
                        if (node.stageData?.Description !== undefined)
                            updatedStage.Description = node.stageData.Description;
                        if (node.stageData?.Duration !== undefined)
                            updatedStage.Duration = node.stageData.Duration;
                        if (node.stageData?.PassOnRule !== undefined)
                            updatedStage.PassOnRule = node.stageData.PassOnRule;
                        if (node.stageData?.ActorRule !== undefined)
                            updatedStage.ActorRule = node.stageData.ActorRule;
                        if (node.stageData?.AssignmentType !== undefined)
                            updatedStage.AssignmentType = node.stageData.AssignmentType;
                        if (node.stageData?.MinNoOfActor !== undefined)
                            updatedStage.MinNoOfActor = node.stageData.MinNoOfActor;
                        if (node.stageData?.IsParallel !== undefined)
                            updatedStage.IsParallel = node.stageData.IsParallel;
                        if (node.stageData?.Tags)
                            updatedStage.Tags = node.stageData.Tags;
                        // Always update these properties
                        updatedStage.IsEntryPoint = node.isStartNode;
                        updatedStage.IsExitPoint = node.stageData?.IsExitPoint || false;
                        updatedStage.Form = node.stageData?.formId || '';
                        updatedStage.Coordinates = { X: node.x, Y: node.y };
                        updatedStage.SwimLane = this.swimlanes[swimlaneIndex].id || '';
                        // Handle subflow stage
                        if (node.type === 'subflow') {
                            updatedStage.IsSubProcess = true;
                            updatedStage.SubWorkFlow = node.workflowData?.id || '';
                            updatedStage.Name = node.workflowData?.name || '';
                        }
                        // Add to stages
                        stages.push(updatedStage);
                    }
                    else {
                        // Create a new stage
                        stages.push({
                            Id: '',
                            Code: '',
                            TenantId: '',
                            // id: node.id,
                            id: '',
                            ServiceName: '',
                            CreatedAt: new Date(),
                            UpdatedAt: new Date(),
                            DataState: ObjectState.New,
                            Workflow: workflow.Code,
                            Name: node.stageData?.Name || 'Unnamed Stage',
                            Description: node.stageData?.Description || '',
                            Duration: node.stageData?.Duration || 0,
                            PassOnRule: node.stageData?.PassOnRule || '',
                            ActorRule: node.stageData?.ActorRule || StageActorRule.None,
                            MinNoOfActor: node.stageData?.MinNoOfActor || 0,
                            IsParallel: node.stageData?.IsParallel || false,
                            IsEntryPoint: node.isStartNode,
                            IsExitPoint: node.stageData?.IsExitPoint || false, // Will be updated below
                            Tags: node.stageData?.Tags || [],
                            Form: node.stageData?.formId ?? '',
                            AllowMultiSubProcess: false,
                            AssignmentType: node.stageData?.AssignmentType ||
                                this.workflow?.AssignmentType ||
                                TaskAssignmentType.AutoRoute,
                            SubWorkFlow: '',
                            SwimLane: this.swimlanes[swimlaneIndex].id || '',
                            Coordinates: { X: node.x, Y: node.y },
                            IsSubProcess: false,
                            Key: node.stageData?.Key || node.id,
                        });
                    }
                }
            });
        });
        // // Determine which stages are exit points (no outgoing connections)
        // stages.forEach((stage) => {
        //   const hasOutgoingConnections = this.connections.some(
        //     (conn) =>
        //       conn.sourceNodeId === stage.Code || conn.sourceNodeId === stage.id
        //   );
        //   if (!hasOutgoingConnections) {
        //     stage.IsExitPoint = true;
        //   }
        // });
        // Transform connections to WorkflowAction[]
        const actions = [];
        this.connections.forEach((conn) => {
            const sourceNode = this.findNodeById(conn.sourceNodeId)?.node;
            const targetNode = this.findNodeById(conn.targetNodeId)?.node;
            // Check if this is an existing action
            if (this.actionRecord[conn.id]) {
                // Update existing action with changed values
                const existingAction = this.actionRecord[conn.id];
                // Create updated action with changed properties
                const updatedAction = {
                    ...existingAction,
                    DataState: ObjectState.Changed,
                    UpdatedAt: new Date(),
                };
                // Update properties that may have changed
                updatedAction.Name =
                    conn.label ??
                        `Action from ${sourceNode?.stageData?.Name || 'Unknown'} to ${targetNode?.stageData?.Name || 'Unknown'}`;
                updatedAction.IsParallel = targetNode?.stageData?.IsParallel || false;
                updatedAction.PassOnRule = conn.condition || '';
                actions.push(updatedAction);
            }
            else {
                // Create a new action
                actions.push({
                    Id: '',
                    Code: '',
                    TenantId: '',
                    // id: conn.id,
                    id: '',
                    ServiceName: '',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                    Workflow: workflow.Code,
                    Name: conn.label ??
                        `Action from ${sourceNode?.stageData?.Name || 'Unknown'} to ${targetNode?.stageData?.Name || 'Unknown'}`,
                    FromStage: conn.sourceNodeId,
                    ToStage: conn.targetNodeId,
                    IsParallel: sourceNode?.stageData?.IsParallel || false,
                    PassOnRule: conn.condition || '',
                    SourcePointType: this.getConnectionPointType(conn.sourcePointId),
                    TargetPointType: this.getConnectionPointType(conn.targetPointId),
                });
            }
        });
        // Add deleted objects with Removed state
        Object.keys(this.stageRecord).forEach((stageId) => {
            const exists = stages.some((stage) => stage.Code === stageId || stage.id === stageId);
            if (!exists) {
                const stage = this.stageRecord[stageId];
                stages.push({
                    ...stage,
                    DataState: ObjectState.Removed,
                    UpdatedAt: new Date(),
                });
            }
        });
        Object.keys(this.actionRecord).forEach((actionId) => {
            const exists = actions.some((action) => action.Code === actionId || action.id === actionId);
            if (!exists) {
                const action = this.actionRecord[actionId];
                actions.push({
                    ...action,
                    DataState: ObjectState.Removed,
                    UpdatedAt: new Date(),
                });
            }
        });
        // Handle deleted swimlanes
        Object.keys(this.swimlaneRecord).forEach((laneId) => {
            const exists = workflow.Lanes.some((lane) => lane.Code === laneId || lane.id === laneId);
            if (!exists) {
                const lane = this.swimlaneRecord[laneId];
                workflow.Lanes.push({
                    ...lane,
                    DataState: ObjectState.Removed,
                    UpdatedAt: new Date(),
                });
            }
        });
        workflow.Stages = stages;
        workflow.Actions = actions;
        return workflow;
    }
    getConnectionPointType(pointId) {
        // Extract the type from the connection point ID format
        // which is usually something like "node-id-top-50"
        const parts = pointId.split('-');
        const typeIndex = parts.findIndex((part) => part === 'top' ||
            part === 'right' ||
            part === 'bottom' ||
            part === 'left');
        if (typeIndex >= 0) {
            return parts[typeIndex];
        }
        return undefined;
    }
    // Add a new property to track loaded objects
    loadedObjectIds = {}; // Format: { id: code }
    // Add a method to register loaded objects
    registerLoadedObject(id, code) {
        this.loadedObjectIds[id] = code;
    }
    // Method to check if an object was loaded from API
    wasLoadedFromApi(id) {
        return id in this.loadedObjectIds;
    }
    // Method to get the code for a loaded object
    getCodeForObject(id) {
        return this.loadedObjectIds[id] || '';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerState, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerState, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerState, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class WorkflowDataService {
    httpService;
    envSvc;
    WORKFLOW_MODEL_BASE_PATH = 'Workflow';
    AUTH_MODEL_BASE_PATH = 'User';
    FORM_MODEL_BASE_PATH = 'Form';
    constructor(httpService, envSvc) {
        this.httpService = httpService;
        this.envSvc = envSvc;
    }
    getWorkflowWithParam(param, skip = 0, limit = 1, sortParam = 'CreatedAt', sortOrder = 'Asc') {
        const url = `${this.WORKFLOW_MODEL_BASE_PATH}/GetWorkflowsWithParam/${param}/${skip}/${limit}/${sortParam}/${sortOrder}`;
        return this.httpService.get(url);
    }
    getWorkflows(skip = 0, limit = 0) {
        const url = `${this.WORKFLOW_MODEL_BASE_PATH}/GetWorkflows/${skip}/${limit}`;
        return this.httpService.get(url, this.envSvc.environment.WorkFlowAPI);
    }
    getForms(skip = 0, limit = 0) {
        const url = `${this.FORM_MODEL_BASE_PATH}/GetForms/${skip}/${limit}`;
        return this.httpService.get(url, this.envSvc.environment.WorkFlowAPI);
    }
    getTags(skip = 0, limit = 0) {
        const url = `${this.AUTH_MODEL_BASE_PATH}/GetTags/${skip}/${limit}`;
        return this.httpService.get(url, this.envSvc.environment.AuthAPI);
    }
    saveWorkflows(requests) {
        const url = `${this.WORKFLOW_MODEL_BASE_PATH}/SaveWorkflows`;
        // console.log('Saving workflows', requests);
        return this.httpService.post(url, requests, this.envSvc.environment.WorkFlowAPI);
    }
    // Helper to create a mock workflow (just for demo)
    createMockWorkflow(code) {
        // Return a simple workflow with one lane and one stage
        const workflow = {
            Id: 'workflow-123',
            Code: code,
            TenantId: 'tenant-1',
            id: 'workflow-123',
            ServiceName: 'workflow-service',
            CreatedAt: new Date(),
            UpdatedAt: new Date(),
            DataState: ObjectState.Unchanged,
            Name: 'Sample Workflow',
            Description: 'A sample workflow loaded from API',
            StageEntryRule: '',
            AssignmentType: TaskAssignmentType.AutoRoute,
            Status: Status.Active,
            Actions: [],
            Lanes: [
                {
                    Id: 'lane-0',
                    Code: 'lane-0',
                    TenantId: 'tenant-1',
                    id: 'lane-0',
                    ServiceName: 'workflow-service',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.Unchanged,
                    Workflow: 'workflow-123',
                    Tags: [],
                    Position: 0,
                    Coordinates: { X: 0, Y: 0 },
                    Size: { Width: 3000, Height: 263 },
                },
            ],
            Stages: [
                {
                    Id: 'stage-123',
                    Code: 'stage-123',
                    TenantId: 'tenant-1',
                    id: 'stage-123',
                    ServiceName: 'workflow-service',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.Unchanged,
                    Workflow: 'workflow-123',
                    Name: 'Initial Stage',
                    Description: 'Starting point',
                    Duration: 24,
                    PassOnRule: '',
                    ActorRule: StageActorRule.None,
                    MinNoOfActor: 1,
                    IsParallel: false,
                    IsEntryPoint: true,
                    IsExitPoint: false,
                    Tags: [],
                    Form: '',
                    AllowMultiSubProcess: false,
                    AssignmentType: TaskAssignmentType.AutoRoute,
                    SubWorkFlow: '',
                    SwimLane: 'lane-0',
                    Coordinates: { X: 100, Y: 50 },
                    IsSubProcess: false,
                },
            ],
        };
        return workflow;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDataService, deps: [{ token: HttpWebRequestService }, { token: EnvironmentService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDataService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDataService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: HttpWebRequestService }, { type: EnvironmentService }] });

class NodeManagementService {
    state;
    constructor(state) {
        this.state = state;
    }
    /**
     * Adds a new node to the specified swimlane
     */
    addNode(swimlaneIndex, type, x, y, stageData, workflowData) {
        if (!this.state.swimlanes[swimlaneIndex] ||
            !type ||
            (type !== 'stage' &&
                type !== 'decision' &&
                type !== 'form' &&
                type !== 'subflow')) {
            return null;
        }
        // Adjust position relative to swimlane
        const adjustedY = y - swimlaneIndex * 263 - 40; // Subtracting header height
        // Generate a unique ID
        const id = `${type}-${Date.now()}-${Math.floor(Math.random() * 1000)}`;
        // Create node with dimensions based on type
        const node = {
            id,
            type,
            x,
            y: adjustedY,
            width: type === 'subflow' ? 150 : 169, // Width from SVG
            height: 100, // Height from SVG
            isStartNode: false, // Default to false
            stageData: stageData || {}, // Store stage data
            workflowData: workflowData || null,
        };
        // If this is the first node in the entire workflow, mark it as the start node
        if (this.getNodeCount() === 0) {
            node.isStartNode = true;
            this.state.startNodeId = id;
        }
        // Generate connection points for the node
        node.connectionPoints = this.generateConnectionPoints(node);
        // Add node to the swimlane
        if (!this.state.swimlanes[swimlaneIndex].nodes) {
            this.state.swimlanes[swimlaneIndex].nodes = [];
        }
        this.state.swimlanes[swimlaneIndex].nodes.push(node);
        return node;
    }
    /**
     * Gets the total count of nodes across all swimlanes
     */
    getNodeCount() {
        return this.state.swimlanes.reduce((count, swimlane) => count + (swimlane.nodes?.length || 0), 0);
    }
    /**
     * Find a node by ID
     */
    findNodeById(id) {
        for (let i = 0; i < this.state.swimlanes.length; i++) {
            const swimlane = this.state.swimlanes[i];
            const node = swimlane.nodes?.find((n) => n.id === id);
            if (node) {
                return { node, swimlaneIndex: i };
            }
        }
        return null;
    }
    /**
     * Generate connection points for a node
     */
    generateConnectionPoints(node) {
        const points = [];
        const spacing = 50; // Space between connection points
        if (node.type === 'stage') {
            // Rectangular shapes - add points around the rectangle
            // Top edge points
            for (let x = spacing; x < node.width; x += spacing) {
                points.push({
                    id: `${node.id}-top-${x}`,
                    nodeId: node.id,
                    x: x,
                    y: 0,
                    type: 'top',
                });
            }
            // Right edge points
            for (let y = spacing; y < node.height; y += spacing) {
                points.push({
                    id: `${node.id}-right-${y}`,
                    nodeId: node.id,
                    x: node.width,
                    y: y,
                    type: 'right',
                });
            }
            // Bottom edge points
            for (let x = spacing; x < node.width; x += spacing) {
                points.push({
                    id: `${node.id}-bottom-${x}`,
                    nodeId: node.id,
                    x: x,
                    y: node.height,
                    type: 'bottom',
                });
            }
            // Left edge points
            for (let y = spacing; y < node.height; y += spacing) {
                points.push({
                    id: `${node.id}-left-${y}`,
                    nodeId: node.id,
                    x: 0,
                    y: y,
                    type: 'left',
                });
            }
        }
        else if (node.type === 'decision') {
            // Diamond shape - add points at the four corners
            points.push({
                id: `${node.id}-top-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: 0,
                type: 'top',
            });
            points.push({
                id: `${node.id}-right-0`,
                nodeId: node.id,
                x: node.width,
                y: node.height / 2,
                type: 'right',
            });
            points.push({
                id: `${node.id}-bottom-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: node.height,
                type: 'bottom',
            });
            points.push({
                id: `${node.id}-left-0`,
                nodeId: node.id,
                x: 0,
                y: node.height / 2,
                type: 'left',
            });
        }
        else if (node.type === 'form') {
            // Form only has input connection points, no output points
            // Left edge points (for input connections)
            for (let y = spacing; y < node.height; y += spacing) {
                points.push({
                    id: `${node.id}-left-${y}`,
                    nodeId: node.id,
                    x: 0,
                    y: y,
                    type: 'left',
                });
            }
        }
        else if (node.type === 'subflow') {
            // Hexagon shape - add points at the six corners
            points.push({
                id: `${node.id}-top-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: 0,
                type: 'top',
            });
            points.push({
                id: `${node.id}-right-top`,
                nodeId: node.id,
                x: node.width,
                y: node.height / 4,
                type: 'right',
            });
            points.push({
                id: `${node.id}-right-bottom`,
                nodeId: node.id,
                x: node.width,
                y: (node.height * 3) / 4,
                type: 'right',
            });
            points.push({
                id: `${node.id}-bottom-0`,
                nodeId: node.id,
                x: node.width / 2,
                y: node.height,
                type: 'bottom',
            });
            points.push({
                id: `${node.id}-left-bottom`,
                nodeId: node.id,
                x: 0,
                y: (node.height * 3) / 4,
                type: 'left',
            });
            points.push({
                id: `${node.id}-left-top`,
                nodeId: node.id,
                x: 0,
                y: node.height / 4,
                type: 'left',
            });
        }
        return points;
    }
    /**
     * Update node properties
     */
    updateNodeProperties(nodeId, properties) {
        const nodeInfo = this.findNodeById(nodeId);
        if (!nodeInfo)
            return false;
        const { node, swimlaneIndex } = nodeInfo;
        // Update the node with new properties
        Object.assign(node, properties);
        return true;
    }
    /**
     * Update stage data for a node
     */
    updateStageData(nodeId, stageData) {
        const nodeInfo = this.findNodeById(nodeId);
        if (!nodeInfo)
            return false;
        const { node } = nodeInfo;
        // Update the stage data
        node.stageData = {
            ...node.stageData,
            ...stageData,
        };
        return true;
    }
    /**
     * Set a node as a start node
     */
    setAsStartNode(nodeId) {
        // First, clear any existing start nodes
        this.state.swimlanes.forEach((swimlane) => {
            swimlane.nodes?.forEach((node) => {
                if (node.isStartNode) {
                    node.isStartNode = false;
                }
            });
        });
        // Then set the new start node
        const nodeInfo = this.findNodeById(nodeId);
        if (!nodeInfo)
            return false;
        nodeInfo.node.isStartNode = true;
        this.state.startNodeId = nodeId;
        return true;
    }
    /**
     * Delete a node
     */
    deleteNode(nodeId) {
        const nodeInfo = this.findNodeById(nodeId);
        if (!nodeInfo)
            return false;
        const { swimlaneIndex } = nodeInfo;
        // Find the node index in the swimlane
        const nodeIndex = this.state.swimlanes[swimlaneIndex].nodes?.findIndex((n) => n.id === nodeId);
        if (nodeIndex === undefined || nodeIndex === -1)
            return false;
        // Remove the node
        this.state.swimlanes[swimlaneIndex].nodes?.splice(nodeIndex, 1);
        return true;
    }
    /**
     * Check if a node has outgoing connections
     */
    hasOutgoingConnections(nodeId) {
        return this.state.connections.some((conn) => conn.sourceNodeId === nodeId);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeManagementService, deps: [{ token: WorkflowDesignerState }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeManagementService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeManagementService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }] });

class SwimlaneService {
    state;
    swimlaneHeight = 263;
    constructor(state) {
        this.state = state;
    }
    /**
     * Add a new swimlane
     */
    addSwimlane(name, tags) {
        const newSwimlane = {
            order: this.state.swimlanes.length,
            label: name,
            tags,
            nodes: [],
        };
        this.state.swimlanes.push(newSwimlane);
        return newSwimlane;
    }
    /**
     * Update an existing swimlane
     */
    updateSwimlane(index, name, tags) {
        if (index < 0 || index >= this.state.swimlanes.length) {
            console.error('Invalid swimlane index:', index);
            return false;
        }
        this.state.swimlanes[index] = {
            ...this.state.swimlanes[index],
            label: name,
            tags: tags,
        };
        return true;
    }
    /**
     * Reorder swimlanes (move a swimlane up or down in the list)
     */
    reorderSwimlane(fromIndex, toIndex) {
        if (fromIndex < 0 ||
            fromIndex >= this.state.swimlanes.length ||
            toIndex < 0 ||
            toIndex >= this.state.swimlanes.length) {
            return false;
        }
        // Remove the swimlane from its current position
        const [swimlane] = this.state.swimlanes.splice(fromIndex, 1);
        // Insert it at the new position
        this.state.swimlanes.splice(toIndex, 0, swimlane);
        // Update order properties for all swimlanes
        this.state.swimlanes.forEach((lane, idx) => {
            lane.order = idx;
        });
        return true;
    }
    /**
     * Delete a swimlane by index
     */
    deleteSwimlane(index) {
        if (index < 0 || index >= this.state.swimlanes.length) {
            return false;
        }
        // Check if the swimlane has nodes
        if (this.state.swimlanes[index].nodes?.length) {
            console.error('Cannot delete swimlane with nodes');
            return false;
        }
        // Remove the swimlane
        this.state.swimlanes.splice(index, 1);
        // Update order properties for all swimlanes
        this.state.swimlanes.forEach((lane, idx) => {
            lane.order = idx;
        });
        return true;
    }
    /**
     * Get all swimlanes
     */
    getSwimlanes() {
        return this.state.swimlanes;
    }
    /**
     * Get swimlane by index
     */
    getSwimlane(index) {
        if (index < 0 || index >= this.state.swimlanes.length) {
            return null;
        }
        return this.state.swimlanes[index];
    }
    /**
     * Calculate total canvas height needed for all swimlanes
     */
    calculateCanvasHeight(minHeight = 2000) {
        const requiredHeight = (this.state.swimlanes.length + 1) * this.swimlaneHeight;
        return Math.max(minHeight, requiredHeight);
    }
    /**
     * Check if a Y position is within any swimlane
     */
    isPositionInsideSwimlane(y) {
        // Check if y position is within any swimlane
        const swimlaneCount = this.state.swimlanes.length;
        if (swimlaneCount === 0)
            return false;
        // Each swimlane has a height of 263px
        const totalSwimlaneHeight = swimlaneCount * this.swimlaneHeight;
        // Check if y is within the total height of all swimlanes
        return y >= 0 && y < totalSwimlaneHeight;
    }
    /**
     * Calculate swimlane index from Y position
     */
    getSwimlaneIndexFromPosition(y) {
        if (!this.isPositionInsideSwimlane(y))
            return -1;
        return Math.floor(y / this.swimlaneHeight);
    }
    /**
     * Find swimlane index by Lane ID
     */
    findSwimlaneIndexByLaneId(laneId) {
        // In a real implementation, you would maintain a mapping between API lane IDs and UI swimlane indices
        // For now we'll just return the index based on position
        const parts = laneId.split('-');
        if (parts.length > 1) {
            const index = parseInt(parts[1]);
            if (!isNaN(index) && index < this.state.swimlanes.length) {
                return index;
            }
        }
        return -1;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneService, deps: [{ token: WorkflowDesignerState }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }] });

class DesignerToolbarComponent {
    nodeService;
    swimlaneService;
    selectedTool = null;
    isSaving = false;
    toolSelected = new EventEmitter();
    saveWorkflow = new EventEmitter();
    // Simple array of toolbar items
    toolbarItems = [
        { id: 'swimlane', label: 'Swimlane' },
        { id: 'stage', label: 'Stage' },
        // { id: 'action', label: 'Action' },
        // { id: 'form', label: 'Form' },
        { id: 'decision', label: 'Decision' },
        // { id: 'subflow', label: 'Subflow' },
    ];
    constructor(nodeService, swimlaneService) {
        this.nodeService = nodeService;
        this.swimlaneService = swimlaneService;
    }
    /**
     * Handle tool button click
     */
    onToolClick(tool) {
        this.toolSelected.emit(tool);
    }
    /**
     * Check if a tool should be enabled
     */
    isEnabled(type) {
        switch (type) {
            case 'swimlane':
                return true; // Always enabled
            case 'stage':
            case 'decision':
                // Enabled if there are swimlanes available
                return this.swimlaneService.getSwimlanes().length > 0;
            case 'form':
            case 'action':
            case 'subflow':
                // Only enabled if there are nodes in the workflow
                return this.nodeService.getNodeCount() > 0;
            default:
                return false;
        }
    }
    /**
     * Handle save button click
     */
    onSaveClick() {
        this.saveWorkflow.emit();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DesignerToolbarComponent, deps: [{ token: NodeManagementService }, { token: SwimlaneService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: DesignerToolbarComponent, selector: "lib-designer-toolbar", inputs: { selectedTool: "selectedTool", isSaving: "isSaving" }, outputs: { toolSelected: "toolSelected", saveWorkflow: "saveWorkflow" }, ngImport: i0, template: "<div class=\"designer-toolbar\">\n  <div class=\"toolbar-container\">\n    <button\n      *ngFor=\"let item of toolbarItems\"\n      class=\"tool-button\"\n      [class.active]=\"selectedTool === item.id\"\n      [class.disabled]=\"!isEnabled(item.id)\"\n      (click)=\"onToolClick(item.id)\"\n      [title]=\"item.label\"\n      [disabled]=\"!isEnabled(item.id)\"\n      style=\"width: 60px; height: auto\"\n    >\n      <!-- {{ item.label }} -->\n      <img\n        [src]=\"'icons/' + item.id + '.svg'\"\n        [alt]=\"item.label\"\n        class=\"tool-icon\"\n      />\n    </button>\n  </div>\n\n  <!-- <button class=\"save-button\" (click)=\"onSaveClick()\" [disabled]=\"isSaving\">\n    {{ isSaving ? \"Saving...\" : \"Save Workflow\" }}\n  </button> -->\n\n  <verbena-button\n    buttonClass=\"save-button\"\n    (click)=\"onSaveClick()\"\n    [isLoading]=\"isSaving\"\n    type=\"submit\"\n    text=\"Save\"\n    bgColor=\"#FFE681\"\n    textColor=\"#404040\"\n    borderRadius=\"10px\"\n    pd=\"10px 20px\"\n    width=\"114px\"\n    height=\"39px\"\n  ></verbena-button>\n</div>\n", styles: [".designer-toolbar{padding:.5rem;background-color:#fff;border-bottom:1px solid #e2e8f0;display:flex;justify-content:space-between;align-items:center}.toolbar-container{display:flex;gap:.5rem;background-color:#fff;border:1px solid #d8b4fe;border-radius:.5rem;padding:.5rem;box-shadow:0 2px 4px #0000001a;max-width:fit-content}.tool-button{padding:.5rem 1rem;background-color:#fff;border:1px solid #e2e8f0;border-radius:.25rem;cursor:pointer;font-size:.875rem;transition:all .2s}.tool-button:hover{background-color:#f9fafb}.tool-button.active{background-color:#f3e8ff;border-color:#d8b4fe;color:#7e22ce}.tool-button.active{opacity:.75}.save-button{padding:.5rem 1rem;background-color:#f3e8ff;border:1px solid #d8b4fe;border-radius:.25rem;color:#7e22ce;font-size:.875rem;cursor:pointer;transition:all .2s}.save-button:hover{background-color:#e9d5ff}.save-button:disabled{opacity:.5;cursor:not-allowed}\n"], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DesignerToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-designer-toolbar', template: "<div class=\"designer-toolbar\">\n  <div class=\"toolbar-container\">\n    <button\n      *ngFor=\"let item of toolbarItems\"\n      class=\"tool-button\"\n      [class.active]=\"selectedTool === item.id\"\n      [class.disabled]=\"!isEnabled(item.id)\"\n      (click)=\"onToolClick(item.id)\"\n      [title]=\"item.label\"\n      [disabled]=\"!isEnabled(item.id)\"\n      style=\"width: 60px; height: auto\"\n    >\n      <!-- {{ item.label }} -->\n      <img\n        [src]=\"'icons/' + item.id + '.svg'\"\n        [alt]=\"item.label\"\n        class=\"tool-icon\"\n      />\n    </button>\n  </div>\n\n  <!-- <button class=\"save-button\" (click)=\"onSaveClick()\" [disabled]=\"isSaving\">\n    {{ isSaving ? \"Saving...\" : \"Save Workflow\" }}\n  </button> -->\n\n  <verbena-button\n    buttonClass=\"save-button\"\n    (click)=\"onSaveClick()\"\n    [isLoading]=\"isSaving\"\n    type=\"submit\"\n    text=\"Save\"\n    bgColor=\"#FFE681\"\n    textColor=\"#404040\"\n    borderRadius=\"10px\"\n    pd=\"10px 20px\"\n    width=\"114px\"\n    height=\"39px\"\n  ></verbena-button>\n</div>\n", styles: [".designer-toolbar{padding:.5rem;background-color:#fff;border-bottom:1px solid #e2e8f0;display:flex;justify-content:space-between;align-items:center}.toolbar-container{display:flex;gap:.5rem;background-color:#fff;border:1px solid #d8b4fe;border-radius:.5rem;padding:.5rem;box-shadow:0 2px 4px #0000001a;max-width:fit-content}.tool-button{padding:.5rem 1rem;background-color:#fff;border:1px solid #e2e8f0;border-radius:.25rem;cursor:pointer;font-size:.875rem;transition:all .2s}.tool-button:hover{background-color:#f9fafb}.tool-button.active{background-color:#f3e8ff;border-color:#d8b4fe;color:#7e22ce}.tool-button.active{opacity:.75}.save-button{padding:.5rem 1rem;background-color:#f3e8ff;border:1px solid #d8b4fe;border-radius:.25rem;color:#7e22ce;font-size:.875rem;cursor:pointer;transition:all .2s}.save-button:hover{background-color:#e9d5ff}.save-button:disabled{opacity:.5;cursor:not-allowed}\n"] }]
        }], ctorParameters: () => [{ type: NodeManagementService }, { type: SwimlaneService }], propDecorators: { selectedTool: [{
                type: Input
            }], isSaving: [{
                type: Input
            }], toolSelected: [{
                type: Output
            }], saveWorkflow: [{
                type: Output
            }] } });

// components/label-editor.component.ts
class LabelEditorComponent {
    label = '';
    x = 0;
    y = 0;
    isConnection = false;
    isSwimlane = false;
    labelChange = new EventEmitter();
    labelInput;
    isEditing = false;
    Math = Math;
    getEditorPosition() {
        const offsetX = this.isConnection ? -25 : -25; // Center the label
        const offsetY = -10; // Slight upward offset to center vertically
        return `translate(${this.x + offsetX}px, ${this.y + offsetY}px)`;
    }
    getLabelStyle() {
        if (this.isEditing)
            return {};
        return {
            'text-anchor': 'middle',
            'dominant-baseline': 'middle',
            'pointer-events': 'all',
        };
    }
    startEditing() {
        this.isEditing = true;
        setTimeout(() => {
            if (this.labelInput) {
                this.labelInput.nativeElement.focus();
                this.labelInput.nativeElement.select();
            }
        });
    }
    finishEditing() {
        if (this.isEditing) {
            const newValue = this.labelInput.nativeElement.value.trim();
            if (newValue && newValue !== this.label) {
                this.labelChange.emit(newValue);
            }
            this.isEditing = false;
        }
    }
    cancelEditing() {
        this.isEditing = false;
    }
    onEscapePress() {
        this.cancelEditing();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelEditorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: LabelEditorComponent, isStandalone: true, selector: "wf-label-editor", inputs: { label: "label", x: "x", y: "y", isConnection: "isConnection", isSwimlane: "isSwimlane" }, outputs: { labelChange: "labelChange" }, host: { listeners: { "document:keydown.escape": "onEscapePress()" } }, viewQueries: [{ propertyName: "labelInput", first: true, predicate: ["labelInput"], descendants: true }], ngImport: i0, template: `
    <div
      class="label-container"
      [class.editing]="isEditing"
      [class.swimlane-label]="isSwimlane"
      [style.transform]="getEditorPosition()"
      [style.position]="isEditing ? 'absolute' : 'static'"
    >
      @if (isEditing) {
      <input
        #labelInput
        type="text"
        [value]="label"
        (blur)="finishEditing()"
        (keyup.enter)="finishEditing()"
        (keyup.escape)="cancelEditing()"
        class="label-input"
        [class.swimlane-input]="isSwimlane"
        [style.width.px]="Math.max(100, label.length * 8)"
      />
      } @else {
      <span
        (dblclick)="startEditing()"
        class="label-text"
        [class.connection-label]="isConnection"
        [class.swimlane-text]="isSwimlane"
      >
        {{ label }}
      </span>
      }
    </div>
  `, isInline: true, styles: [":host{display:block;width:100%;height:100%}.label-container{display:inline-block;min-width:50px;z-index:1000}.label-container.editing{background:#fff;padding:2px;border-radius:4px;box-shadow:0 2px 4px #0000001a}.label-input{padding:2px 4px;border:1px solid #d36cff;border-radius:2px;font-size:12px;font-family:inherit;outline:none}.label-input.swimlane-input{font-size:14px;font-weight:500;min-width:150px}.label-text{cursor:text;-webkit-user-select:none;user-select:none;font-size:12px;pointer-events:all;display:inline-block;min-width:20px;min-height:14px}.connection-label{background:#fff;padding:2px 4px;border:1px solid #e5e7eb;border-radius:2px}.swimlane-text{font-size:14px;font-weight:500;color:#64748b}.swimlane-label{position:absolute;left:20px}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'wf-label-editor', standalone: true, imports: [CommonModule], template: `
    <div
      class="label-container"
      [class.editing]="isEditing"
      [class.swimlane-label]="isSwimlane"
      [style.transform]="getEditorPosition()"
      [style.position]="isEditing ? 'absolute' : 'static'"
    >
      @if (isEditing) {
      <input
        #labelInput
        type="text"
        [value]="label"
        (blur)="finishEditing()"
        (keyup.enter)="finishEditing()"
        (keyup.escape)="cancelEditing()"
        class="label-input"
        [class.swimlane-input]="isSwimlane"
        [style.width.px]="Math.max(100, label.length * 8)"
      />
      } @else {
      <span
        (dblclick)="startEditing()"
        class="label-text"
        [class.connection-label]="isConnection"
        [class.swimlane-text]="isSwimlane"
      >
        {{ label }}
      </span>
      }
    </div>
  `, styles: [":host{display:block;width:100%;height:100%}.label-container{display:inline-block;min-width:50px;z-index:1000}.label-container.editing{background:#fff;padding:2px;border-radius:4px;box-shadow:0 2px 4px #0000001a}.label-input{padding:2px 4px;border:1px solid #d36cff;border-radius:2px;font-size:12px;font-family:inherit;outline:none}.label-input.swimlane-input{font-size:14px;font-weight:500;min-width:150px}.label-text{cursor:text;-webkit-user-select:none;user-select:none;font-size:12px;pointer-events:all;display:inline-block;min-width:20px;min-height:14px}.connection-label{background:#fff;padding:2px 4px;border:1px solid #e5e7eb;border-radius:2px}.swimlane-text{font-size:14px;font-weight:500;color:#64748b}.swimlane-label{position:absolute;left:20px}\n"] }]
        }], propDecorators: { label: [{
                type: Input
            }], x: [{
                type: Input
            }], y: [{
                type: Input
            }], isConnection: [{
                type: Input
            }], isSwimlane: [{
                type: Input
            }], labelChange: [{
                type: Output
            }], labelInput: [{
                type: ViewChild,
                args: ['labelInput']
            }], onEscapePress: [{
                type: HostListener,
                args: ['document:keydown.escape']
            }] } });

class StageNodeComponent {
    state;
    dataService;
    node;
    isStartNode = false;
    stageData = {};
    stagePropertiesUpdated = new EventEmitter();
    parallelExecutionToggled = new EventEmitter();
    showShieldDialog = new EventEmitter();
    // Properties for icon click events
    showFormPopup = false;
    showTimerPopup = false;
    showActionPopupLeft = false;
    showActionPopupRight = false;
    showCodePopup = false;
    formsList = [];
    isLoadingForms = false;
    formPopupX = 0;
    formPopupY = 0;
    constructor(state, dataService) {
        this.state = state;
        this.dataService = dataService;
    }
    ngOnInit() {
        console.log('Stage node initialized with:', this.node);
        this.updateConnectedStagesInfo();
    }
    // Method to check if this stage has multiple outgoing connections to other stages
    updateConnectedStagesInfo() {
        // Count the number of outgoing connections that connect to stages
        const outgoingConnections = this.state.connections.filter((conn) => conn.sourceNodeId === this.node.id);
        // Check if the target nodes are stages
        const connectedStageNodes = outgoingConnections
            .map((conn) => this.state.findNodeById(conn.targetNodeId))
            .filter((nodeInfo) => nodeInfo && nodeInfo.node.type === 'stage');
        this.node.hasMultipleConnectedStages = connectedStageNodes.length > 1;
        this.node.hasParallelStages = connectedStageNodes.every((nd) => nd?.node.stageData?.IsParallel);
    }
    get hasMultipleConnectedStages() {
        return this.node.hasMultipleConnectedStages === true;
    }
    get isParallelExecution() {
        return this.node.hasParallelStages === true;
    }
    selectForm(form) {
        // If form is null, we're clearing the selection
        if (!this.node.stageData) {
            this.node.stageData = {};
        }
        if (form) {
            this.node.stageData.formId = form.Code;
            this.node.stageData.formName = form.Name;
        }
        else {
            // Clear form selection
            delete this.node.stageData.formId;
            delete this.node.stageData.formName;
        }
        // Close the popup
        this.showFormPopup = false;
        // Emit an event to update the stage data
        this.stagePropertiesUpdated.emit({
            nodeId: this.node.id,
            stageData: this.node.stageData,
        });
    }
    toggleFormPopup(event) {
        if (event) {
            event.preventDefault();
            event.stopPropagation();
            // Calculate absolute position for the popup
            const rect = event.target.getBoundingClientRect();
            this.formPopupX = rect.left + window.scrollX;
            this.formPopupY = rect.top + window.scrollY;
        }
        // If we're opening the popup, load forms
        if (!this.showFormPopup) {
            this.isLoadingForms = true;
            this.dataService
                .getForms()
                .then((response) => {
                this.formsList = response.Result;
                this.isLoadingForms = false;
            })
                .catch((error) => {
                console.error('Error loading forms:', error);
                this.isLoadingForms = false;
            });
        }
        this.showFormPopup = !this.showFormPopup;
    }
    toggleShieldPopup(event) {
        if (event) {
            event.preventDefault();
            event.stopPropagation();
        }
        console.log('Shield icon clicked for node:', this.node.id);
        this.showShieldDialog.emit(this.node.id);
    }
    toggleTimerPopup(event) {
        if (event) {
            event.preventDefault();
            event.stopPropagation();
        }
        this.showTimerPopup = !this.showTimerPopup;
    }
    toggleActionPopup(side, event) {
        if (event) {
            event.preventDefault();
            event.stopPropagation();
        }
        if (side === 'left') {
            this.showActionPopupLeft = !this.showActionPopupLeft;
        }
        else {
            this.showActionPopupRight = !this.showActionPopupRight;
        }
    }
    toggleCodePopup(event) {
        if (event) {
            event.preventDefault();
            event.stopPropagation();
        }
        // Toggle parallel execution state
        const newParallelState = !this.isParallelExecution;
        // Update this node's stage data
        if (!this.node.stageData) {
            this.node.stageData = {};
        }
        this.node.hasParallelStages = newParallelState;
        const outgoingConnections = this.state.connections.filter((conn) => conn.sourceNodeId === this.node.id);
        // Check if the target nodes are stages
        const connectedStageNodes = outgoingConnections
            .map((conn) => this.state.findNodeById(conn.targetNodeId))
            .filter((nodeInfo) => nodeInfo && nodeInfo.node.type === 'stage');
        this.state.swimlanes = this.state.swimlanes.map((sw, i) => {
            sw.nodes = sw?.nodes?.map((swNode) => {
                const foundNode = connectedStageNodes
                    .map((connected) => connected?.node)
                    .find((nde) => nde?.id === swNode.id);
                if (foundNode?.stageData) {
                    foundNode.stageData.IsParallel = newParallelState;
                }
                return swNode;
            });
            return sw;
        });
        console.log(`Parallel execution ${newParallelState ? 'enabled' : 'disabled'} for node:`, this.node.id);
    }
    // This method should be called whenever connections change
    refreshState() {
        this.updateConnectedStagesInfo();
    }
    onStagePropertiesSaved(stageData) {
        // Emit the event to the parent component with the node id and updated data
        this.stagePropertiesUpdated.emit({
            nodeId: this.node.id,
            stageData: stageData,
        });
        console.log('Stage properties updated:', stageData);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageNodeComponent, deps: [{ token: WorkflowDesignerState }, { token: WorkflowDataService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: StageNodeComponent, selector: "svg:g[lib-stage-node]", inputs: { node: "node", isStartNode: "isStartNode", stageData: "stageData" }, outputs: { stagePropertiesUpdated: "stagePropertiesUpdated", parallelExecutionToggled: "parallelExecutionToggled", showShieldDialog: "showShieldDialog" }, ngImport: i0, template: "<svg:g>\n  <!-- Stage node -->\n  <svg:rect\n    x=\"0\"\n    y=\"0\"\n    [attr.width]=\"node.width\"\n    [attr.height]=\"node.height\"\n    fill=\"none\"\n    stroke=\"#D36CFF\"\n    stroke-width=\"1\"\n  ></svg:rect>\n\n  <!-- Top-left icon: Stage form -->\n  <svg:g\n    (click)=\"toggleFormPopup($event)\"\n    class=\"stage-icon\"\n    transform=\"translate(6, 6)\"\n  >\n    <!-- Transparent rectangle to capture clicks -->\n    <svg:rect\n      x=\"-2\"\n      y=\"-2\"\n      width=\"24\"\n      height=\"24\"\n      fill=\"transparent\"\n      style=\"cursor: pointer\"\n    />\n\n    <svg:path\n      d=\"M16.5 20.475V17.475H13.5V16.475H16.5V13.475H17.5V16.475H20.5V17.475H17.5V20.475H16.5ZM3.5 17.5V16.5H4.5V17.5H3.5ZM6.5 17.5V16.5H11.517C11.5057 16.6767 11.5043 16.845 11.513 17.005C11.521 17.165 11.531 17.33 11.543 17.5H6.5ZM3.5 13.5V12.5H4.5V13.5H3.5ZM6.5 13.5V12.5H13.804C13.6127 12.6387 13.4333 12.7913 13.266 12.958C13.0993 13.1247 12.9377 13.3053 12.781 13.5H6.5ZM3.5 9.5V8.5H4.5V9.5H3.5ZM6.5 9.5V8.5H18.5V9.5H6.5ZM3.5 5.5V4.5H4.5V5.5H3.5ZM6.5 5.5V4.5H18.5V5.5H6.5Z\"\n      [attr.fill]=\"node.stageData?.formId ? '#D36CFF' : 'black'\"\n    />\n  </svg:g>\n\n  <!-- Top-right icon: Shield -->\n  <svg:g\n    (click)=\"toggleShieldPopup($event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"'translate(' + (node.width - 30) + ', 6)'\"\n  >\n    <!-- Transparent rectangle to capture clicks -->\n    <svg:rect\n      x=\"-2\"\n      y=\"-2\"\n      width=\"24\"\n      height=\"24\"\n      fill=\"transparent\"\n      style=\"cursor: pointer\"\n    />\n\n    <svg:path\n      d=\"M7.5 12H16.5V13.5H7.5V12ZM7.5 7.5H16.5V9H7.5V7.5Z\"\n      fill=\"black\"\n    />\n    <svg:path\n      d=\"M12 22.5L7.36801 20.0303C6.0474 19.3279 4.94303 18.2791 4.17348 16.9964C3.40393 15.7138 2.99825 14.2458 3.00001 12.75V3C3.00001 2.60218 3.15804 2.22064 3.43935 1.93934C3.72065 1.65804 4.10218 1.5 4.50001 1.5H19.5C19.8978 1.5 20.2794 1.65804 20.5607 1.93934C20.842 2.22064 21 2.60218 21 3V12.75C21.0018 14.2458 20.5961 15.7138 19.8265 16.9964C19.057 18.2791 17.9526 19.3279 16.632 20.0303L12 22.5ZM4.50001 3V12.75C4.49917 13.9738 4.83141 15.1747 5.46111 16.224C6.09082 17.2733 6.99423 18.1315 8.07451 18.7065L12 20.7997L15.9255 18.7073C17.0059 18.1322 17.9094 17.2739 18.5391 16.2244C19.1688 15.175 19.501 13.9739 19.5 12.75V3H4.50001Z\"\n      fill=\"black\"\n    />\n  </svg:g>\n\n  <!-- Left-center icon: Thunderbolt -->\n  <svg:g\n    (click)=\"toggleActionPopup('left', $event)\"\n    class=\"stage-icon\"\n    transform=\"translate(6, 38)\"\n  >\n    <svg:path d=\"M11 15H6L13 1V9H18L11 23V15Z\" fill=\"black\" />\n  </svg:g>\n\n  <!-- Right-center icon: Thunderbolt -->\n  <svg:g\n    (click)=\"toggleActionPopup('right', $event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"'translate(' + (node.width - 30) + ', 38)'\"\n  >\n    <svg:path d=\"M11 15H6L13 1V9H18L11 23V15Z\" fill=\"black\" />\n  </svg:g>\n\n  <!-- Bottom-left icon: Double slash text -->\n  <svg:g\n    *ngIf=\"hasMultipleConnectedStages\"\n    (click)=\"toggleCodePopup($event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"'translate(6, ' + (node.height - 16) + ')'\"\n  >\n    <svg:text\n      font-family=\"'Plus Jakarta Sans', sans-serif\"\n      font-weight=\"500\"\n      font-size=\"16px\"\n      dominant-baseline=\"middle\"\n      [attr.fill]=\"isParallelExecution ? '#D36CFF' : 'black'\"\n    >\n      //\n    </svg:text>\n  </svg:g>\n\n  <!-- Bottom-right icon: Timer -->\n  <svg:g\n    (click)=\"toggleTimerPopup($event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"\n      'translate(' + (node.width - 30) + ', ' + (node.height - 30) + ')'\n    \"\n  >\n    <svg:path\n      d=\"M11.5 3C14.0196 3 16.4359 4.00089 18.2175 5.78249C19.9991 7.56408 21 9.98044 21 12.5C21 15.0196 19.9991 17.4359 18.2175 19.2175C16.4359 20.9991 14.0196 22 11.5 22C8.98044 22 6.56408 20.9991 4.78249 19.2175C3.00089 17.4359 2 15.0196 2 12.5C2 9.98044 3.00089 7.56408 4.78249 5.78249C6.56408 4.00089 8.98044 3 11.5 3ZM11.5 4C9.24566 4 7.08365 4.89553 5.48959 6.48959C3.89553 8.08365 3 10.2457 3 12.5C3 14.7543 3.89553 16.9163 5.48959 18.5104C7.08365 20.1045 9.24566 21 11.5 21C12.6162 21 13.7215 20.7801 14.7528 20.353C15.7841 19.9258 16.7211 19.2997 17.5104 18.5104C18.2997 17.7211 18.9258 16.7841 19.353 15.7528C19.7801 14.7215 20 13.6162 20 12.5C20 10.2457 19.1045 8.08365 17.5104 6.48959C15.9163 4.89553 13.7543 4 11.5 4ZM11 7H12V12.42L16.7 15.13L16.2 16L11 13V7Z\"\n      fill=\"black\"\n    />\n  </svg:g>\n\n  <!-- Label in the center -->\n  <svg:text\n    [attr.x]=\"node.width / 2\"\n    [attr.y]=\"node.height / 2\"\n    text-anchor=\"middle\"\n    dominant-baseline=\"middle\"\n    font-size=\"14\"\n    fill=\"#000000\"\n  >\n    {{\n      (node.stageData?.Name || \"Stage\").length > 12\n        ? node.stageData?.Name?.substring(0, 10) + \"...\"\n        : node.stageData?.Name || \"Stage\"\n    }}\n  </svg:text>\n</svg:g>\n\n<!-- <lib-stage-dialog\n  [visible]=\"showShieldPopup()\"\n  [stageData]=\"node.stageData || {}\"\n  (closed)=\"showShieldPopup.set(false)\"\n  (saved)=\"onStagePropertiesSaved($event)\"\n></lib-stage-dialog> -->\n\n<div\n  *ngIf=\"showFormPopup\"\n  [style.position]=\"'fixed'\"\n  [style.left.px]=\"formPopupX\"\n  [style.top.px]=\"formPopupY\"\n  [style.background-color]=\"'white'\"\n>\n  <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n    <div dropdown-trigger style=\"display: none\">\n      <!-- Hidden trigger element -->\n    </div>\n    <div\n      class=\"p-3 bg-white border border-gray-200 rounded shadow-md w-64\"\n      dropdown-content\n      style=\"background-color: white; z-index: 1000\"\n    >\n      <h4 class=\"mb-2 font-medium\">Select Form</h4>\n      <div *ngIf=\"isLoadingForms\" class=\"text-center py-2\">\n        Loading forms...\n      </div>\n      <div *ngIf=\"!isLoadingForms\" class=\"max-h-48 overflow-y-auto\">\n        <div class=\"mb-2\">\n          <button\n            class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n            (click)=\"selectForm(null)\"\n          >\n            Clear form selection\n          </button>\n        </div>\n        <div *ngFor=\"let form of formsList\" class=\"mb-1\">\n          <button\n            class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n            (click)=\"selectForm(form)\"\n          >\n            {{ form.Name }}\n          </button>\n        </div>\n        <div\n          *ngIf=\"formsList.length === 0\"\n          class=\"text-center py-2 text-gray-500\"\n        >\n          No forms available\n        </div>\n      </div>\n    </div>\n  </verben-pop-Up>\n</div>\n", styles: [".stage-icon{cursor:pointer}.stage-icon:hover path{fill:#d36cff}\n"], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageNodeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'svg:g[lib-stage-node]', template: "<svg:g>\n  <!-- Stage node -->\n  <svg:rect\n    x=\"0\"\n    y=\"0\"\n    [attr.width]=\"node.width\"\n    [attr.height]=\"node.height\"\n    fill=\"none\"\n    stroke=\"#D36CFF\"\n    stroke-width=\"1\"\n  ></svg:rect>\n\n  <!-- Top-left icon: Stage form -->\n  <svg:g\n    (click)=\"toggleFormPopup($event)\"\n    class=\"stage-icon\"\n    transform=\"translate(6, 6)\"\n  >\n    <!-- Transparent rectangle to capture clicks -->\n    <svg:rect\n      x=\"-2\"\n      y=\"-2\"\n      width=\"24\"\n      height=\"24\"\n      fill=\"transparent\"\n      style=\"cursor: pointer\"\n    />\n\n    <svg:path\n      d=\"M16.5 20.475V17.475H13.5V16.475H16.5V13.475H17.5V16.475H20.5V17.475H17.5V20.475H16.5ZM3.5 17.5V16.5H4.5V17.5H3.5ZM6.5 17.5V16.5H11.517C11.5057 16.6767 11.5043 16.845 11.513 17.005C11.521 17.165 11.531 17.33 11.543 17.5H6.5ZM3.5 13.5V12.5H4.5V13.5H3.5ZM6.5 13.5V12.5H13.804C13.6127 12.6387 13.4333 12.7913 13.266 12.958C13.0993 13.1247 12.9377 13.3053 12.781 13.5H6.5ZM3.5 9.5V8.5H4.5V9.5H3.5ZM6.5 9.5V8.5H18.5V9.5H6.5ZM3.5 5.5V4.5H4.5V5.5H3.5ZM6.5 5.5V4.5H18.5V5.5H6.5Z\"\n      [attr.fill]=\"node.stageData?.formId ? '#D36CFF' : 'black'\"\n    />\n  </svg:g>\n\n  <!-- Top-right icon: Shield -->\n  <svg:g\n    (click)=\"toggleShieldPopup($event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"'translate(' + (node.width - 30) + ', 6)'\"\n  >\n    <!-- Transparent rectangle to capture clicks -->\n    <svg:rect\n      x=\"-2\"\n      y=\"-2\"\n      width=\"24\"\n      height=\"24\"\n      fill=\"transparent\"\n      style=\"cursor: pointer\"\n    />\n\n    <svg:path\n      d=\"M7.5 12H16.5V13.5H7.5V12ZM7.5 7.5H16.5V9H7.5V7.5Z\"\n      fill=\"black\"\n    />\n    <svg:path\n      d=\"M12 22.5L7.36801 20.0303C6.0474 19.3279 4.94303 18.2791 4.17348 16.9964C3.40393 15.7138 2.99825 14.2458 3.00001 12.75V3C3.00001 2.60218 3.15804 2.22064 3.43935 1.93934C3.72065 1.65804 4.10218 1.5 4.50001 1.5H19.5C19.8978 1.5 20.2794 1.65804 20.5607 1.93934C20.842 2.22064 21 2.60218 21 3V12.75C21.0018 14.2458 20.5961 15.7138 19.8265 16.9964C19.057 18.2791 17.9526 19.3279 16.632 20.0303L12 22.5ZM4.50001 3V12.75C4.49917 13.9738 4.83141 15.1747 5.46111 16.224C6.09082 17.2733 6.99423 18.1315 8.07451 18.7065L12 20.7997L15.9255 18.7073C17.0059 18.1322 17.9094 17.2739 18.5391 16.2244C19.1688 15.175 19.501 13.9739 19.5 12.75V3H4.50001Z\"\n      fill=\"black\"\n    />\n  </svg:g>\n\n  <!-- Left-center icon: Thunderbolt -->\n  <svg:g\n    (click)=\"toggleActionPopup('left', $event)\"\n    class=\"stage-icon\"\n    transform=\"translate(6, 38)\"\n  >\n    <svg:path d=\"M11 15H6L13 1V9H18L11 23V15Z\" fill=\"black\" />\n  </svg:g>\n\n  <!-- Right-center icon: Thunderbolt -->\n  <svg:g\n    (click)=\"toggleActionPopup('right', $event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"'translate(' + (node.width - 30) + ', 38)'\"\n  >\n    <svg:path d=\"M11 15H6L13 1V9H18L11 23V15Z\" fill=\"black\" />\n  </svg:g>\n\n  <!-- Bottom-left icon: Double slash text -->\n  <svg:g\n    *ngIf=\"hasMultipleConnectedStages\"\n    (click)=\"toggleCodePopup($event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"'translate(6, ' + (node.height - 16) + ')'\"\n  >\n    <svg:text\n      font-family=\"'Plus Jakarta Sans', sans-serif\"\n      font-weight=\"500\"\n      font-size=\"16px\"\n      dominant-baseline=\"middle\"\n      [attr.fill]=\"isParallelExecution ? '#D36CFF' : 'black'\"\n    >\n      //\n    </svg:text>\n  </svg:g>\n\n  <!-- Bottom-right icon: Timer -->\n  <svg:g\n    (click)=\"toggleTimerPopup($event)\"\n    class=\"stage-icon\"\n    [attr.transform]=\"\n      'translate(' + (node.width - 30) + ', ' + (node.height - 30) + ')'\n    \"\n  >\n    <svg:path\n      d=\"M11.5 3C14.0196 3 16.4359 4.00089 18.2175 5.78249C19.9991 7.56408 21 9.98044 21 12.5C21 15.0196 19.9991 17.4359 18.2175 19.2175C16.4359 20.9991 14.0196 22 11.5 22C8.98044 22 6.56408 20.9991 4.78249 19.2175C3.00089 17.4359 2 15.0196 2 12.5C2 9.98044 3.00089 7.56408 4.78249 5.78249C6.56408 4.00089 8.98044 3 11.5 3ZM11.5 4C9.24566 4 7.08365 4.89553 5.48959 6.48959C3.89553 8.08365 3 10.2457 3 12.5C3 14.7543 3.89553 16.9163 5.48959 18.5104C7.08365 20.1045 9.24566 21 11.5 21C12.6162 21 13.7215 20.7801 14.7528 20.353C15.7841 19.9258 16.7211 19.2997 17.5104 18.5104C18.2997 17.7211 18.9258 16.7841 19.353 15.7528C19.7801 14.7215 20 13.6162 20 12.5C20 10.2457 19.1045 8.08365 17.5104 6.48959C15.9163 4.89553 13.7543 4 11.5 4ZM11 7H12V12.42L16.7 15.13L16.2 16L11 13V7Z\"\n      fill=\"black\"\n    />\n  </svg:g>\n\n  <!-- Label in the center -->\n  <svg:text\n    [attr.x]=\"node.width / 2\"\n    [attr.y]=\"node.height / 2\"\n    text-anchor=\"middle\"\n    dominant-baseline=\"middle\"\n    font-size=\"14\"\n    fill=\"#000000\"\n  >\n    {{\n      (node.stageData?.Name || \"Stage\").length > 12\n        ? node.stageData?.Name?.substring(0, 10) + \"...\"\n        : node.stageData?.Name || \"Stage\"\n    }}\n  </svg:text>\n</svg:g>\n\n<!-- <lib-stage-dialog\n  [visible]=\"showShieldPopup()\"\n  [stageData]=\"node.stageData || {}\"\n  (closed)=\"showShieldPopup.set(false)\"\n  (saved)=\"onStagePropertiesSaved($event)\"\n></lib-stage-dialog> -->\n\n<div\n  *ngIf=\"showFormPopup\"\n  [style.position]=\"'fixed'\"\n  [style.left.px]=\"formPopupX\"\n  [style.top.px]=\"formPopupY\"\n  [style.background-color]=\"'white'\"\n>\n  <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n    <div dropdown-trigger style=\"display: none\">\n      <!-- Hidden trigger element -->\n    </div>\n    <div\n      class=\"p-3 bg-white border border-gray-200 rounded shadow-md w-64\"\n      dropdown-content\n      style=\"background-color: white; z-index: 1000\"\n    >\n      <h4 class=\"mb-2 font-medium\">Select Form</h4>\n      <div *ngIf=\"isLoadingForms\" class=\"text-center py-2\">\n        Loading forms...\n      </div>\n      <div *ngIf=\"!isLoadingForms\" class=\"max-h-48 overflow-y-auto\">\n        <div class=\"mb-2\">\n          <button\n            class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n            (click)=\"selectForm(null)\"\n          >\n            Clear form selection\n          </button>\n        </div>\n        <div *ngFor=\"let form of formsList\" class=\"mb-1\">\n          <button\n            class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n            (click)=\"selectForm(form)\"\n          >\n            {{ form.Name }}\n          </button>\n        </div>\n        <div\n          *ngIf=\"formsList.length === 0\"\n          class=\"text-center py-2 text-gray-500\"\n        >\n          No forms available\n        </div>\n      </div>\n    </div>\n  </verben-pop-Up>\n</div>\n", styles: [".stage-icon{cursor:pointer}.stage-icon:hover path{fill:#d36cff}\n"] }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }, { type: WorkflowDataService }], propDecorators: { node: [{
                type: Input
            }], isStartNode: [{
                type: Input
            }], stageData: [{
                type: Input
            }], stagePropertiesUpdated: [{
                type: Output
            }], parallelExecutionToggled: [{
                type: Output
            }], showShieldDialog: [{
                type: Output
            }] } });

/**
 * Service for managing various popups in the workflow designer
 */
class PopupService {
    dataService;
    // Connection creation popup
    _connectionPopupVisible = new BehaviorSubject(false);
    _connectionPopupPosition = new BehaviorSubject({ x: 0, y: 0 });
    _allowedNodeTypes = new BehaviorSubject([]);
    // Form selection popup for stages
    _formPopupVisible = new BehaviorSubject(false);
    _formPopupPosition = new BehaviorSubject({
        x: 0,
        y: 0,
    });
    _formsList = new BehaviorSubject([]);
    _isLoadingForms = new BehaviorSubject(false);
    _selectedNodeForForm = new BehaviorSubject(null);
    // Workflow form selection popup for start node
    _startNodeFormPopupVisible = new BehaviorSubject(false);
    _startNodeFormPopupPosition = new BehaviorSubject({ x: 0, y: 0 });
    // Subflow selection popup
    _subflowPopupVisible = new BehaviorSubject(false);
    _subflowPopupPosition = new BehaviorSubject({ x: 0, y: 0 });
    _workflowsList = new BehaviorSubject([]);
    _isLoadingWorkflows = new BehaviorSubject(false);
    _pendingSubflowPosition = new BehaviorSubject(null);
    // Connection data for popups
    _pendingConnectionSourcePoint = new BehaviorSubject(null);
    _pendingConnectionSourceSwimlaneIndex = new BehaviorSubject(null);
    constructor(dataService) {
        this.dataService = dataService;
    }
    // Connection popup observables
    get connectionPopupVisible() {
        return this._connectionPopupVisible.asObservable();
    }
    get connectionPopupPosition() {
        return this._connectionPopupPosition.asObservable();
    }
    get allowedNodeTypes() {
        return this._allowedNodeTypes.asObservable();
    }
    // Form popup observables
    get formPopupVisible() {
        return this._formPopupVisible.asObservable();
    }
    get formPopupPosition() {
        return this._formPopupPosition.asObservable();
    }
    get formsList() {
        return this._formsList.asObservable();
    }
    get isLoadingForms() {
        return this._isLoadingForms.asObservable();
    }
    get selectedNodeForForm() {
        return this._selectedNodeForForm.asObservable();
    }
    // Start node form popup observables
    get startNodeFormPopupVisible() {
        return this._startNodeFormPopupVisible.asObservable();
    }
    get startNodeFormPopupPosition() {
        return this._startNodeFormPopupPosition.asObservable();
    }
    // Subflow popup observables
    get subflowPopupVisible() {
        return this._subflowPopupVisible.asObservable();
    }
    get subflowPopupPosition() {
        return this._subflowPopupPosition.asObservable();
    }
    get workflowsList() {
        return this._workflowsList.asObservable();
    }
    get isLoadingWorkflows() {
        return this._isLoadingWorkflows.asObservable();
    }
    get pendingSubflowPosition() {
        return this._pendingSubflowPosition.asObservable();
    }
    // Connection data observables
    get pendingConnectionSourcePoint() {
        return this._pendingConnectionSourcePoint.asObservable();
    }
    get pendingConnectionSourceSwimlaneIndex() {
        return this._pendingConnectionSourceSwimlaneIndex.asObservable();
    }
    /**
     * Show connection creation popup
     */
    showConnectionPopup(x, y, allowedNodeTypes) {
        this._connectionPopupPosition.next({ x, y });
        this._allowedNodeTypes.next(allowedNodeTypes);
        this._connectionPopupVisible.next(true);
    }
    /**
     * Hide connection creation popup
     */
    hideConnectionPopup() {
        this._connectionPopupVisible.next(false);
    }
    /**
     * Store connection source data for use in other popups
     */
    storeConnectionSourceData(point, swimlaneIndex) {
        this._pendingConnectionSourcePoint.next(point);
        this._pendingConnectionSourceSwimlaneIndex.next(swimlaneIndex);
    }
    /**
     * Clear connection source data
     */
    clearConnectionSourceData() {
        this._pendingConnectionSourcePoint.next(null);
        this._pendingConnectionSourceSwimlaneIndex.next(null);
    }
    /**
     * Show form selection popup for a stage
     */
    async showFormPopup(x, y, nodeId) {
        this._formPopupPosition.next({ x, y });
        this._selectedNodeForForm.next(nodeId);
        this._formPopupVisible.next(true);
        // Load forms
        this._isLoadingForms.next(true);
        try {
            const response = await this.dataService.getForms();
            this._formsList.next(response.Result);
        }
        catch (error) {
            console.error('Error loading forms:', error);
            this._formsList.next([]);
        }
        finally {
            this._isLoadingForms.next(false);
        }
    }
    /**
     * Hide form selection popup
     */
    hideFormPopup() {
        this._formPopupVisible.next(false);
        this._selectedNodeForForm.next(null);
    }
    /**
     * Show workflow form selection popup for start node
     */
    async showStartNodeFormPopup(x, y) {
        this._startNodeFormPopupPosition.next({ x, y });
        this._startNodeFormPopupVisible.next(true);
        // Load forms
        this._isLoadingForms.next(true);
        try {
            const response = await this.dataService.getForms();
            this._formsList.next(response.Result);
        }
        catch (error) {
            console.error('Error loading forms:', error);
            this._formsList.next([]);
        }
        finally {
            this._isLoadingForms.next(false);
        }
    }
    /**
     * Hide workflow form selection popup
     */
    hideStartNodeFormPopup() {
        this._startNodeFormPopupVisible.next(false);
    }
    /**
     * Show subflow selection popup
     */
    async showSubflowPopup(x, y, swimlaneIndex) {
        this._subflowPopupPosition.next({ x, y });
        this._pendingSubflowPosition.next({ swimlaneIndex, x, y });
        this._subflowPopupVisible.next(true);
        // Load workflows
        this._isLoadingWorkflows.next(true);
        try {
            const response = await this.dataService.getWorkflows();
            this._workflowsList.next(response.Result);
        }
        catch (error) {
            console.error('Error loading workflows:', error);
            this._workflowsList.next([]);
        }
        finally {
            this._isLoadingWorkflows.next(false);
        }
    }
    /**
     * Hide subflow selection popup
     */
    hideSubflowPopup() {
        this._subflowPopupVisible.next(false);
        this._pendingSubflowPosition.next(null);
    }
    // Current values for internal use
    getCurrentValues() {
        return {
            connectionPopupVisible: this._connectionPopupVisible.getValue(),
            connectionPopupPosition: this._connectionPopupPosition.getValue(),
            allowedNodeTypes: this._allowedNodeTypes.getValue(),
            formPopupVisible: this._formPopupVisible.getValue(),
            formPopupPosition: this._formPopupPosition.getValue(),
            formsList: this._formsList.getValue(),
            isLoadingForms: this._isLoadingForms.getValue(),
            selectedNodeForForm: this._selectedNodeForForm.getValue(),
            startNodeFormPopupVisible: this._startNodeFormPopupVisible.getValue(),
            startNodeFormPopupPosition: this._startNodeFormPopupPosition.getValue(),
            subflowPopupVisible: this._subflowPopupVisible.getValue(),
            subflowPopupPosition: this._subflowPopupPosition.getValue(),
            workflowsList: this._workflowsList.getValue(),
            isLoadingWorkflows: this._isLoadingWorkflows.getValue(),
            pendingSubflowPosition: this._pendingSubflowPosition.getValue(),
            pendingConnectionSourcePoint: this._pendingConnectionSourcePoint.getValue(),
            pendingConnectionSourceSwimlaneIndex: this._pendingConnectionSourceSwimlaneIndex.getValue(),
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PopupService, deps: [{ token: WorkflowDataService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PopupService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PopupService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: WorkflowDataService }] });

class StageDialogComponent {
    fb;
    dataService;
    nodeService;
    popupService;
    // Use Angular's signal-based input
    visible = input(false);
    stageData = {}; // For editing existing stages
    closed = new EventEmitter();
    saved = new EventEmitter();
    stageForm;
    tags = [];
    actorRules = Object.values(StageActorRule);
    assignmentTypes = Object.values(TaskAssignmentType);
    selectedTagIds = [];
    hasOutgoingConnections = false;
    constructor(fb, dataService, nodeService, popupService) {
        this.fb = fb;
        this.dataService = dataService;
        this.nodeService = nodeService;
        this.popupService = popupService;
        this.stageForm = this.fb.group({
            Name: ['', Validators.required],
            Description: [''],
            MinNoOfActor: [0],
            Duration: [0],
            PassOnRule: [''],
            ActorRule: [StageActorRule.None],
            AssignmentType: [TaskAssignmentType.AutoRoute],
            IsExitPoint: [false],
            Tags: [[]],
        });
    }
    ngOnInit() {
        // Load tags
        this.loadTags();
        // If editing an existing stage, populate form
        this.initFormWithStageData();
    }
    ngOnChanges(changes) {
        // If stageData changes, update the form
        if (changes['stageData'] && this.stageData) {
            this.stageForm.patchValue({
                Name: this.stageData.Name || '',
                Description: this.stageData.Description || '',
                MinNoOfActor: this.stageData.MinNoOfActor || 0,
                Duration: this.stageData.Duration || 0,
                PassOnRule: this.stageData.PassOnRule || '',
                ActorRule: this.stageData.ActorRule || StageActorRule.None,
                AssignmentType: this.stageData.AssignmentType || TaskAssignmentType.AutoRoute,
                IsExitPoint: this.stageData.IsExitPoint || false,
            });
            // Update selected tags
            if (this.stageData.Tags && this.stageData.Tags.length > 0) {
                this.selectedTagIds = this.stageData.Tags.map((tag) => tag.Code);
            }
            else {
                this.selectedTagIds = [];
            }
        }
    }
    /**
     * Load tags from data service
     */
    loadTags() {
        this.dataService.getTags().then((data) => {
            this.tags = data.Result;
            // If we have stage data with tags, update selectedTagIds after tags are loaded
            if (this.stageData &&
                this.stageData.Tags &&
                this.stageData.Tags.length > 0) {
                this.selectedTagIds = this.stageData.Tags.map((tag) => tag.Code);
            }
        });
    }
    /**
     * Initialize form with stage data if provided
     */
    initFormWithStageData() {
        if (this.stageData) {
            console.log('Initializing form with stage data:', this.stageData);
            this.stageForm.patchValue({
                Name: this.stageData.Name || '',
                Description: this.stageData.Description || '',
                MinNoOfActor: this.stageData.MinNoOfActor || 0,
                Duration: this.stageData.Duration || 0,
                PassOnRule: this.stageData.PassOnRule || '',
                ActorRule: this.stageData.ActorRule || StageActorRule.None,
                IsExitPoint: this.stageData.IsExitPoint || false,
            });
        }
    }
    checkOutgoingConnections() {
        if (this.stageData && this.stageData.Code) {
            // Check if there are outgoing connections from this stage
            this.hasOutgoingConnections = this.nodeService.hasOutgoingConnections(this.stageData.Code);
            // If there are outgoing connections, disable IsExitPoint
            if (this.hasOutgoingConnections) {
                this.stageForm.get('IsExitPoint')?.disable();
            }
            else {
                this.stageForm.get('IsExitPoint')?.enable();
            }
        }
    }
    onDialogClose(event) {
        this.closed.emit();
    }
    saveStage() {
        if (this.stageForm.valid) {
            const selectedTags = this.tags.filter((tag) => this.selectedTagIds.includes(tag.Code));
            const stageData = {
                ...this.stageForm.value,
                Tags: selectedTags,
            };
            // Reset form after saving
            this.stageForm.reset();
            // Emit the saved data to the parent component
            this.saved.emit(stageData);
        }
    }
    toggleTagSelection(tagId) {
        const index = this.selectedTagIds.indexOf(tagId);
        if (index > -1) {
            this.selectedTagIds.splice(index, 1);
        }
        else {
            this.selectedTagIds.push(tagId);
        }
    }
    isTagSelected(tagId) {
        return this.selectedTagIds.includes(tagId);
    }
    onDialogOpen(event) {
        console.log('Dialog opened:', event);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDialogComponent, deps: [{ token: i1$2.FormBuilder }, { token: WorkflowDataService }, { token: NodeManagementService }, { token: PopupService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "18.2.13", type: StageDialogComponent, selector: "lib-stage-dialog", inputs: { visible: { classPropertyName: "visible", publicName: "visible", isSignal: true, isRequired: false, transformFunction: null }, stageData: { classPropertyName: "stageData", publicName: "stageData", isSignal: false, isRequired: false, transformFunction: null } }, outputs: { closed: "closed", saved: "saved" }, usesOnChanges: true, ngImport: i0, template: "<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [size]=\"'medium'\"\n  [mode]=\"'drawer'\"\n  [disableFooter]=\"false\"\n  [isVisible]=\"visible()\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [footerTemplate]=\"footerTemplate\"\n  (openModal)=\"onDialogOpen($event)\"\n  (closeModal)=\"onDialogClose($event)\"\n>\n</verben-dialogue>\n\n<ng-template #headerTemplate>\n  <div class=\"p-4 border-b border-gray-200\">\n    <h2 class=\"text-xl font-medium m-0\">Stage Properties</h2>\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div class=\"p-4\">\n    <form [formGroup]=\"stageForm\" class=\"space-y-4\">\n      <!-- Stage Name -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Stage Name</label>\n        <input\n          type=\"text\"\n          formControlName=\"Name\"\n          placeholder=\"Enter Stage Name\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Description -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Description</label>\n        <textarea\n          formControlName=\"Description\"\n          placeholder=\"Enter Description\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n          rows=\"3\"\n        ></textarea>\n      </div>\n\n      <!-- Recipient Count -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Recipient Count</label>\n        <input\n          type=\"number\"\n          formControlName=\"MinNoOfActor\"\n          placeholder=\"Enter Count\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Pass On Rule -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Pass On Rule</label>\n        <input\n          type=\"text\"\n          formControlName=\"PassOnRule\"\n          placeholder=\"Select Rule\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Duration -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Duration</label>\n        <input\n          type=\"number\"\n          formControlName=\"Duration\"\n          placeholder=\"Set Duration\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Actor Rule -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Actor Rule</label>\n        <select\n          formControlName=\"ActorRule\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        >\n          <option *ngFor=\"let rule of actorRules\" [value]=\"rule\">\n            {{ rule }}\n          </option>\n        </select>\n      </div>\n\n      <!-- Assignment Type -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Assignment Type</label>\n\n        <verben-drop-down\n          label=\"Assignment\"\n          styleClass=\"w-full\"\n          width=\"100%\"\n          [multiselect]=\"false\"\n          placeholder=\"Select\"\n          [options]=\"assignmentTypes\"\n          id=\"assignment\"\n          formControlName=\"AssignmentType\"\n          class=\"form-control\"\n        >\n        </verben-drop-down>\n      </div>\n\n      <!-- Is Exit Point -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Exit Point</label>\n        <div class=\"flex items-center\">\n          <input\n            type=\"checkbox\"\n            formControlName=\"IsExitPoint\"\n            [disabled]=\"hasOutgoingConnections\"\n            class=\"mr-2 h-4 w-4\"\n          />\n          <span class=\"text-sm text-gray-600\">Mark as workflow end point</span>\n        </div>\n      </div>\n\n      <!-- Tags -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Tags</label>\n        <div\n          class=\"border border-gray-200 rounded p-2 max-h-40 overflow-y-auto\"\n        >\n          <div *ngFor=\"let tag of tags\" class=\"py-1\">\n            <label class=\"flex items-center\">\n              <input\n                type=\"checkbox\"\n                [checked]=\"isTagSelected(tag.Code)\"\n                (change)=\"toggleTagSelection(tag.Code)\"\n                class=\"mr-2\"\n              />\n              <span>{{ tag.Name }}</span>\n            </label>\n          </div>\n        </div>\n      </div>\n    </form>\n  </div>\n</ng-template>\n\n<ng-template #footerTemplate>\n  <div class=\"flex justify-end p-4 border-t border-gray-200\">\n    <button\n      class=\"px-4 py-2 mr-2 bg-white border border-gray-200 rounded text-sm font-medium\"\n      (click)=\"onDialogClose($event)\"\n    >\n      Cancel\n    </button>\n    <button\n      class=\"px-4 py-2 bg-yellow-300 text-black rounded text-sm font-medium\"\n      (click)=\"saveStage()\"\n      [disabled]=\"stageForm.invalid\"\n    >\n      Save\n    </button>\n  </div>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: i8.VerbenDialogueComponent, selector: "verben-dialogue", inputs: ["dialogueWidth", "headerTemplate", "bodyTemplate", "footerTemplate", "showCloseIcon", "dismissOutsideClick", "closeOnEscape", "isVisible", "size", "backdropColor", "customClass", "disableFooter", "margin", "padding", "borderRadius", "dialogueBgColor", "width", "closeIconClass", "boxShadow", "enableTransition", "modalData", "mode", "position", "drawerWidth"], outputs: ["openModal", "closeModal"] }, { kind: "directive", type: i1$2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1$2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i1$2.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i1$2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1$2.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1$2.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-stage-dialog', template: "<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [size]=\"'medium'\"\n  [mode]=\"'drawer'\"\n  [disableFooter]=\"false\"\n  [isVisible]=\"visible()\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [footerTemplate]=\"footerTemplate\"\n  (openModal)=\"onDialogOpen($event)\"\n  (closeModal)=\"onDialogClose($event)\"\n>\n</verben-dialogue>\n\n<ng-template #headerTemplate>\n  <div class=\"p-4 border-b border-gray-200\">\n    <h2 class=\"text-xl font-medium m-0\">Stage Properties</h2>\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div class=\"p-4\">\n    <form [formGroup]=\"stageForm\" class=\"space-y-4\">\n      <!-- Stage Name -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Stage Name</label>\n        <input\n          type=\"text\"\n          formControlName=\"Name\"\n          placeholder=\"Enter Stage Name\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Description -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Description</label>\n        <textarea\n          formControlName=\"Description\"\n          placeholder=\"Enter Description\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n          rows=\"3\"\n        ></textarea>\n      </div>\n\n      <!-- Recipient Count -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Recipient Count</label>\n        <input\n          type=\"number\"\n          formControlName=\"MinNoOfActor\"\n          placeholder=\"Enter Count\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Pass On Rule -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Pass On Rule</label>\n        <input\n          type=\"text\"\n          formControlName=\"PassOnRule\"\n          placeholder=\"Select Rule\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Duration -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Duration</label>\n        <input\n          type=\"number\"\n          formControlName=\"Duration\"\n          placeholder=\"Set Duration\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        />\n      </div>\n\n      <!-- Actor Rule -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Actor Rule</label>\n        <select\n          formControlName=\"ActorRule\"\n          class=\"w-full px-4 py-2 rounded border border-gray-200\"\n        >\n          <option *ngFor=\"let rule of actorRules\" [value]=\"rule\">\n            {{ rule }}\n          </option>\n        </select>\n      </div>\n\n      <!-- Assignment Type -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Assignment Type</label>\n\n        <verben-drop-down\n          label=\"Assignment\"\n          styleClass=\"w-full\"\n          width=\"100%\"\n          [multiselect]=\"false\"\n          placeholder=\"Select\"\n          [options]=\"assignmentTypes\"\n          id=\"assignment\"\n          formControlName=\"AssignmentType\"\n          class=\"form-control\"\n        >\n        </verben-drop-down>\n      </div>\n\n      <!-- Is Exit Point -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Exit Point</label>\n        <div class=\"flex items-center\">\n          <input\n            type=\"checkbox\"\n            formControlName=\"IsExitPoint\"\n            [disabled]=\"hasOutgoingConnections\"\n            class=\"mr-2 h-4 w-4\"\n          />\n          <span class=\"text-sm text-gray-600\">Mark as workflow end point</span>\n        </div>\n      </div>\n\n      <!-- Tags -->\n      <div>\n        <label class=\"block text-sm font-medium mb-1\">Tags</label>\n        <div\n          class=\"border border-gray-200 rounded p-2 max-h-40 overflow-y-auto\"\n        >\n          <div *ngFor=\"let tag of tags\" class=\"py-1\">\n            <label class=\"flex items-center\">\n              <input\n                type=\"checkbox\"\n                [checked]=\"isTagSelected(tag.Code)\"\n                (change)=\"toggleTagSelection(tag.Code)\"\n                class=\"mr-2\"\n              />\n              <span>{{ tag.Name }}</span>\n            </label>\n          </div>\n        </div>\n      </div>\n    </form>\n  </div>\n</ng-template>\n\n<ng-template #footerTemplate>\n  <div class=\"flex justify-end p-4 border-t border-gray-200\">\n    <button\n      class=\"px-4 py-2 mr-2 bg-white border border-gray-200 rounded text-sm font-medium\"\n      (click)=\"onDialogClose($event)\"\n    >\n      Cancel\n    </button>\n    <button\n      class=\"px-4 py-2 bg-yellow-300 text-black rounded text-sm font-medium\"\n      (click)=\"saveStage()\"\n      [disabled]=\"stageForm.invalid\"\n    >\n      Save\n    </button>\n  </div>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i1$2.FormBuilder }, { type: WorkflowDataService }, { type: NodeManagementService }, { type: PopupService }], propDecorators: { stageData: [{
                type: Input
            }], closed: [{
                type: Output
            }], saved: [{
                type: Output
            }] } });

class ConditionsPopupComponent {
    state;
    visible = false;
    decisionNodeId = '';
    newConnectionId = '';
    popupX = 0;
    popupY = 0;
    closed = new EventEmitter();
    saved = new EventEmitter();
    connectionConditions = [];
    currentCondition = '';
    constructor(state) {
        this.state = state;
    }
    ngOnInit() {
        this.loadConnectionConditions();
    }
    loadConnectionConditions() {
        if (!this.decisionNodeId)
            return;
        // Get all connections from this decision node
        const connections = this.state.connections.filter((conn) => conn.sourceNodeId === this.decisionNodeId);
        this.connectionConditions = connections.map((conn) => {
            const targetNode = this.state.findNodeById(conn.targetNodeId)?.node;
            return {
                connectionId: conn.id,
                sourceNodeId: conn.sourceNodeId,
                targetNodeId: conn.targetNodeId,
                targetNodeName: targetNode?.stageData?.Name || 'Unknown Stage',
                condition: conn.condition || '',
                isActive: conn.id === this.newConnectionId,
            };
        });
        // Find the current connection being edited
        const activeCondition = this.connectionConditions.find((c) => c.isActive);
        if (activeCondition) {
            this.currentCondition = activeCondition.condition;
        }
    }
    saveCondition() {
        this.saved.emit({
            connectionId: this.newConnectionId,
            condition: this.currentCondition,
        });
    }
    onClose() {
        this.closed.emit();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConditionsPopupComponent, deps: [{ token: WorkflowDesignerState }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: ConditionsPopupComponent, selector: "lib-conditions-popup", inputs: { visible: "visible", decisionNodeId: "decisionNodeId", newConnectionId: "newConnectionId", popupX: "popupX", popupY: "popupY" }, outputs: { closed: "closed", saved: "saved" }, ngImport: i0, template: "<div\n  *ngIf=\"visible\"\n  [style.position]=\"'fixed'\"\n  [style.left.px]=\"popupX\"\n  [style.top.px]=\"popupY\"\n>\n  <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n    <div dropdown-trigger style=\"display: none\">\n      <!-- Hidden trigger element -->\n    </div>\n    <div\n      class=\"p-4 bg-white border border-purple-300 rounded shadow-md w-80\"\n      dropdown-content\n    >\n      <div class=\"flex justify-between items-center mb-3\">\n        <h3 class=\"text-lg font-medium\">Decision Conditions</h3>\n        <button class=\"text-gray-500 hover:text-gray-700\" (click)=\"onClose()\">\n          <svg\n            xmlns=\"http://www.w3.org/2000/svg\"\n            width=\"18\"\n            height=\"18\"\n            viewBox=\"0 0 24 24\"\n            fill=\"none\"\n            stroke=\"currentColor\"\n            stroke-width=\"2\"\n            stroke-linecap=\"round\"\n            stroke-linejoin=\"round\"\n          >\n            <line x1=\"18\" y1=\"6\" x2=\"6\" y2=\"18\"></line>\n            <line x1=\"6\" y1=\"6\" x2=\"18\" y2=\"18\"></line>\n          </svg>\n        </button>\n      </div>\n\n      <div class=\"mb-3\">\n        <p class=\"text-sm text-gray-600\">Define a condition for this branch.</p>\n      </div>\n\n      <div class=\"mb-4\">\n        <label class=\"block text-sm font-medium mb-1\">Condition</label>\n        <input\n          type=\"text\"\n          [(ngModel)]=\"currentCondition\"\n          placeholder=\"e.g., order.amount > 500,000\"\n          class=\"w-full px-3 py-2 rounded border border-gray-200 text-sm\"\n        />\n      </div>\n\n      <div\n        class=\"space-y-3 max-h-60 overflow-y-auto\"\n        *ngIf=\"connectionConditions.length > 1\"\n      >\n        <h4 class=\"text-sm font-medium\">Existing Conditions:</h4>\n        @for (conn of connectionConditions; track conn.connectionId) { @if\n        (!conn.isActive) {\n        <div class=\"border rounded p-3\">\n          <div class=\"mb-2\">\n            <span class=\"font-medium\">{{ conn.targetNodeName }}</span>\n          </div>\n          <div>\n            <input\n              type=\"text\"\n              [value]=\"conn.condition\"\n              placeholder=\"No condition\"\n              class=\"w-full px-3 py-2 rounded border border-gray-200 bg-gray-50 text-sm\"\n              readonly\n            />\n          </div>\n        </div>\n        } }\n      </div>\n\n      <div class=\"flex justify-end mt-4 pt-3 border-t border-gray-200\">\n        <button\n          class=\"px-4 py-2 mr-2 bg-white border border-gray-200 rounded text-sm font-medium\"\n          (click)=\"onClose()\"\n        >\n          Cancel\n        </button>\n        <button\n          class=\"px-4 py-2 bg-yellow-300 text-black rounded text-sm font-medium\"\n          (click)=\"saveCondition()\"\n        >\n          Save\n        </button>\n      </div>\n    </div>\n  </verben-pop-Up>\n</div>\n", styles: [".border-purple-400{border-color:#d36cff}.bg-purple-50{background-color:#f9f5ff}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConditionsPopupComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-conditions-popup', template: "<div\n  *ngIf=\"visible\"\n  [style.position]=\"'fixed'\"\n  [style.left.px]=\"popupX\"\n  [style.top.px]=\"popupY\"\n>\n  <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n    <div dropdown-trigger style=\"display: none\">\n      <!-- Hidden trigger element -->\n    </div>\n    <div\n      class=\"p-4 bg-white border border-purple-300 rounded shadow-md w-80\"\n      dropdown-content\n    >\n      <div class=\"flex justify-between items-center mb-3\">\n        <h3 class=\"text-lg font-medium\">Decision Conditions</h3>\n        <button class=\"text-gray-500 hover:text-gray-700\" (click)=\"onClose()\">\n          <svg\n            xmlns=\"http://www.w3.org/2000/svg\"\n            width=\"18\"\n            height=\"18\"\n            viewBox=\"0 0 24 24\"\n            fill=\"none\"\n            stroke=\"currentColor\"\n            stroke-width=\"2\"\n            stroke-linecap=\"round\"\n            stroke-linejoin=\"round\"\n          >\n            <line x1=\"18\" y1=\"6\" x2=\"6\" y2=\"18\"></line>\n            <line x1=\"6\" y1=\"6\" x2=\"18\" y2=\"18\"></line>\n          </svg>\n        </button>\n      </div>\n\n      <div class=\"mb-3\">\n        <p class=\"text-sm text-gray-600\">Define a condition for this branch.</p>\n      </div>\n\n      <div class=\"mb-4\">\n        <label class=\"block text-sm font-medium mb-1\">Condition</label>\n        <input\n          type=\"text\"\n          [(ngModel)]=\"currentCondition\"\n          placeholder=\"e.g., order.amount > 500,000\"\n          class=\"w-full px-3 py-2 rounded border border-gray-200 text-sm\"\n        />\n      </div>\n\n      <div\n        class=\"space-y-3 max-h-60 overflow-y-auto\"\n        *ngIf=\"connectionConditions.length > 1\"\n      >\n        <h4 class=\"text-sm font-medium\">Existing Conditions:</h4>\n        @for (conn of connectionConditions; track conn.connectionId) { @if\n        (!conn.isActive) {\n        <div class=\"border rounded p-3\">\n          <div class=\"mb-2\">\n            <span class=\"font-medium\">{{ conn.targetNodeName }}</span>\n          </div>\n          <div>\n            <input\n              type=\"text\"\n              [value]=\"conn.condition\"\n              placeholder=\"No condition\"\n              class=\"w-full px-3 py-2 rounded border border-gray-200 bg-gray-50 text-sm\"\n              readonly\n            />\n          </div>\n        </div>\n        } }\n      </div>\n\n      <div class=\"flex justify-end mt-4 pt-3 border-t border-gray-200\">\n        <button\n          class=\"px-4 py-2 mr-2 bg-white border border-gray-200 rounded text-sm font-medium\"\n          (click)=\"onClose()\"\n        >\n          Cancel\n        </button>\n        <button\n          class=\"px-4 py-2 bg-yellow-300 text-black rounded text-sm font-medium\"\n          (click)=\"saveCondition()\"\n        >\n          Save\n        </button>\n      </div>\n    </div>\n  </verben-pop-Up>\n</div>\n", styles: [".border-purple-400{border-color:#d36cff}.bg-purple-50{background-color:#f9f5ff}\n"] }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }], propDecorators: { visible: [{
                type: Input
            }], decisionNodeId: [{
                type: Input
            }], newConnectionId: [{
                type: Input
            }], popupX: [{
                type: Input
            }], popupY: [{
                type: Input
            }], closed: [{
                type: Output
            }], saved: [{
                type: Output
            }] } });

class DesignerCanvasComponent {
    state;
    dataService;
    selectedTool = null;
    clickedPosition = new EventEmitter();
    subflowSelected = new EventEmitter();
    pendingStagePosition = null;
    showStageDialog = new EventEmitter();
    stagePropertiesUpdated = new EventEmitter();
    // Reference to the SVG element
    canvasRef;
    onWindowMouseUp(event) {
        // If we have a popup open but the mouse is released outside, clean up
        if (!this.showSubflowPopup &&
            !this.showStartNodeFormPopup &&
            !this.popupVisible && // Only end drag if no popup is visible
            this.state.isConnectionDragging()) {
            console.log('External mouseup detected - cleaning up connection drag');
            this.state.endConnectionDrag();
        }
    }
    // Canvas dimensions
    canvasWidth = 3000;
    canvasHeight = 2000;
    // Grid size
    gridSize = 20;
    swimlaneHeight = 263;
    visibleConnectionPointsNodeId = null;
    popupVisible = false;
    popupX = 0;
    popupY = 0;
    allowedNodeTypes = [];
    showStartNodeFormPopup = false;
    startNodeFormsList = [];
    isLoadingStartNodeForms = false;
    startNodeFormPopupX = 0;
    startNodeFormPopupY = 0;
    showSubflowPopup = false;
    workflowsList = [];
    isLoadingWorkflows = false;
    subflowPopupX = 0;
    subflowPopupY = 0;
    pendingSubflowPosition = null;
    pendingDecisionConnection = null;
    pendingConnectionSourcePoint = null;
    pendingConnectionSourceSwimlaneIndex = null;
    showDecisionConditionDialog = false;
    showConditionsDialog = false;
    activeDecisionNodeId = '';
    activeConnectionId = '';
    decisionConditionPopupX = 0;
    decisionConditionPopupY = 0;
    isCreatingStageFromDecision = false;
    pendingDecisionCondition = '';
    activeStageId = null;
    showStageDialogLocal = false;
    activeStageData = {};
    potentialTargetPointId = null;
    constructor(state, dataService) {
        this.state = state;
        this.dataService = dataService;
    }
    ngOnInit() {
        this.updateCanvasSize();
    }
    // Handle mouse click on canvas
    onCanvasClick(event) {
        // Only process canvas clicks if a tool is selected
        if (!this.selectedTool) {
            return;
        }
        // Get the position where the click occurred
        const position = this.getMousePosition(event);
        console.log('Canvas clicked at:', position, 'with tool:', this.selectedTool);
        // Calculate the swimlane index based on position
        // const swimlaneIndex = Math.floor(position.y / this.swimlaneHeight);
        // Only emit the position if we have a tool selected and it's a valid click area
        if (this.selectedTool) {
            this.clickedPosition.emit({
                x: position.x,
                y: position.y,
            });
        }
    }
    onShowShieldDialog(stageId) {
        // Find the node
        const nodeInfo = this.state.findNodeById(stageId);
        if (nodeInfo) {
            this.activeStageId = stageId;
            this.activeStageData = nodeInfo.node.stageData || {};
            this.showStageDialogLocal = true;
        }
    }
    // Add this method to handle dialog closure
    onStageDialogClosed() {
        this.showStageDialogLocal = false;
        this.activeStageId = null;
        this.activeStageData = {};
    }
    // Add this method to handle saving stage data
    onStageDialogSaved(stageData) {
        if (this.activeStageId) {
            // Editing an existing stage
            const nodeInfo = this.state.findNodeById(this.activeStageId);
            if (nodeInfo) {
                // Update the stage data
                nodeInfo.node.stageData = {
                    ...nodeInfo.node.stageData,
                    ...stageData,
                };
                console.log('Updated stage data:', nodeInfo.node.stageData);
                // Emit event for parent component to know about the update
                this.stagePropertiesUpdated.emit({
                    nodeId: this.activeStageId,
                    stageData: nodeInfo.node.stageData,
                });
            }
        }
        // Close the dialog
        this.onStageDialogClosed();
    }
    updateCanvasSize() {
        const requiredHeight = (this.state.swimlanes.length + 1) * this.swimlaneHeight;
        this.canvasHeight = Math.max(2000, requiredHeight); // Ensure we have at least our default height
        // Update all the swimlane clip paths when size changes
        setTimeout(() => {
            this.state.swimlanes.forEach((swimlane, index) => {
                const clipPathId = `swimlane-clip-${index}`;
                const clipPathElement = document.getElementById(clipPathId);
                if (clipPathElement) {
                    const rectElement = clipPathElement.querySelector('rect');
                    if (rectElement) {
                        rectElement.setAttribute('width', this.canvasWidth.toString());
                    }
                }
            });
        }, 0);
    }
    // Helper method to get the mouse position relative to the SVG canvas
    getMousePosition(event) {
        // Use clientX/Y and getBoundingClientRect() for cross-browser compatibility
        const rect = this.canvasRef.nativeElement.getBoundingClientRect();
        return {
            x: event.clientX - rect.left,
            y: event.clientY - rect.top,
        };
    }
    showConnectionPoints(nodeId, swimlaneIndex) {
        this.visibleConnectionPointsNodeId = nodeId;
    }
    isMouseOverNode(event, node, swimlaneIndex) {
        const position = this.getMousePosition(event);
        const nodeBounds = this.getNodeBoundsWithPadding(node, swimlaneIndex);
        return (position.x >= nodeBounds.x &&
            position.x <= nodeBounds.x + nodeBounds.width &&
            position.y >= nodeBounds.y &&
            position.y <= nodeBounds.y + nodeBounds.height);
    }
    // helper method to calculate node bounds with padding
    getNodeBoundsWithPadding(node, swimlaneIndex) {
        const padding = 10; // Add 10px padding around nodes for easier hover detection
        // Calculate the absolute Y position including swimlane offset
        const absoluteY = node.y + swimlaneIndex * 263;
        return {
            x: node.x - padding,
            y: absoluteY - padding,
            width: node.width + padding * 2,
            height: node.height + padding * 2,
        };
    }
    hideConnectionPoints(nodeId) {
        if (this.visibleConnectionPointsNodeId === nodeId &&
            !this.state.isConnectionDragging()) {
            this.visibleConnectionPointsNodeId = null;
        }
    }
    isConnectionPointVisible(nodeId) {
        return this.visibleConnectionPointsNodeId === nodeId;
    }
    startConnectionDrag(event, point, swimlaneIndex) {
        event.preventDefault();
        event.stopPropagation();
        // Check if this is an exit point node
        const nodeInfo = this.state.findNodeById(point.nodeId);
        if (nodeInfo &&
            nodeInfo.node.type === 'stage' &&
            nodeInfo.node.stageData?.IsExitPoint) {
            // Don't allow connections from exit points
            console.log('Cannot create connections from exit points');
            return;
        }
        const position = this.getMousePosition(event);
        this.state.startConnectionDrag(point, swimlaneIndex, position.x, position.y);
        // Add mouse move and mouse up event listeners to the document
        document.addEventListener('mousemove', this.onMouseMove);
        document.addEventListener('mouseup', this.onMouseUp);
    }
    highlightPotentialTargets(event) {
        if (!this.state.isConnectionDragging())
            return;
        const position = this.getMousePosition(event);
        const targetPointInfo = this.findConnectionPointAtPosition(position.x, position.y);
        if (targetPointInfo &&
            targetPointInfo.point.id !== this.potentialTargetPointId) {
            // We have a new target point
            this.potentialTargetPointId = targetPointInfo.point.id;
        }
        else if (!targetPointInfo && this.potentialTargetPointId) {
            // We're no longer over a target point
            this.potentialTargetPointId = null;
        }
    }
    // Use arrow functions to preserve 'this' context
    onMouseMove = (event) => {
        const position = this.getMousePosition(event);
        this.updateConnectionDrag(position.x, position.y);
        this.highlightPotentialTargets(event);
    };
    updateConnectionDrag(currentX, currentY) {
        if (this.state.draggingConnectionData.sourcePoint) {
            this.state.draggingConnectionData.currentX = currentX;
            this.state.draggingConnectionData.currentY = currentY;
            // Calculate which swimlane the cursor is over
            const swimlaneIndex = Math.floor(currentY / this.swimlaneHeight);
            if (swimlaneIndex >= 0 && swimlaneIndex < this.state.swimlanes.length) {
                // Ensure the target swimlane is fully visible
                this.ensureSwimlaneInView(swimlaneIndex);
            }
        }
    }
    onMouseUp = (event) => {
        document.removeEventListener('mousemove', this.onMouseMove);
        document.removeEventListener('mouseup', this.onMouseUp);
        const position = this.getMousePosition(event);
        console.log('Mouse up at position:', position);
        console.log('Is connection dragging:', this.state.isConnectionDragging());
        // Only proceed if we are dragging a connection
        if (!this.state.isConnectionDragging()) {
            return;
        }
        // Check if we're dropping onto a connection point
        const targetPointInfo = this.findConnectionPointAtPosition(position.x, position.y);
        if (targetPointInfo) {
            // We found a target connection point
            console.log('Found target connection point:', targetPointInfo);
            // Get the source point and swimlane index
            const sourcePoint = this.state.draggingConnectionData.sourcePoint;
            const sourceSwimlaneIndex = this.state.draggingConnectionData.sourceSwimlaneIndex;
            if (sourcePoint && sourceSwimlaneIndex !== undefined) {
                // Prevent connecting a node to itself
                if (sourcePoint.nodeId !== targetPointInfo.nodeId) {
                    // Get source and target node types to check if connection is allowed
                    const sourceNodeInfo = this.state.findNodeById(sourcePoint.nodeId);
                    const targetNodeInfo = this.state.findNodeById(targetPointInfo.nodeId);
                    if (sourceNodeInfo &&
                        targetNodeInfo &&
                        this.state.canConnect(sourceNodeInfo.node.type, targetNodeInfo.node.type)) {
                        // Create the connection
                        const connection = {
                            id: `conn-${Date.now()}-${Math.floor(Math.random() * 1000)}`,
                            sourceNodeId: sourcePoint.nodeId,
                            targetNodeId: targetPointInfo.nodeId,
                            sourcePointId: sourcePoint.id,
                            targetPointId: targetPointInfo.point.id,
                            sourceSwimlaneIndex: sourceSwimlaneIndex,
                            targetSwimlaneIndex: targetPointInfo.swimlaneIndex,
                            label: '',
                        };
                        // Add to connections array
                        this.state.connections.push(connection);
                        console.log('Created direct connection between nodes:', connection);
                        // Notify about connection creation
                        this.onConnectionCreated(connection);
                    }
                    else {
                        console.log('Cannot connect these node types:', sourceNodeInfo?.node.type, '->', targetNodeInfo?.node.type);
                    }
                }
                else {
                    console.log('Cannot connect a node to itself');
                }
            }
            // End the connection drag
            this.state.endConnectionDrag();
            return;
        }
        // Check if the position is within any swimlane
        const isInsideSwimlane = this.isPositionInsideSwimlane(position.y);
        console.log('Is inside swimlane:', isInsideSwimlane);
        // Only show popup if within a swimlane
        if (isInsideSwimlane && this.state.isConnectionDragging()) {
            console.log('Showing connection popup');
            this.showConnectionPopup(position.x, position.y);
        }
        else {
            // End the connection drag if outside a swimlane
            console.log('Ending connection drag without showing popup');
            this.state.endConnectionDrag();
        }
    };
    findConnectionPointAtPosition(x, y, tolerance = 10) {
        // Iterate through all swimlanes and nodes to find connection points
        for (let swimlaneIndex = 0; swimlaneIndex < this.state.swimlanes.length; swimlaneIndex++) {
            const swimlane = this.state.swimlanes[swimlaneIndex];
            if (!swimlane.nodes)
                continue;
            for (const node of swimlane.nodes) {
                if (!node.connectionPoints)
                    continue;
                // Calculate the absolute position of the node (including swimlane offset)
                const absoluteNodeX = node.x;
                const absoluteNodeY = node.y + swimlaneIndex * this.swimlaneHeight;
                for (const point of node.connectionPoints) {
                    // Calculate absolute position of the connection point
                    const pointX = absoluteNodeX + point.x;
                    const pointY = absoluteNodeY + point.y;
                    // Check if the given position is within tolerance of this point
                    if (Math.abs(x - pointX) <= tolerance &&
                        Math.abs(y - pointY) <= tolerance) {
                        return {
                            point: point,
                            nodeId: node.id,
                            swimlaneIndex: swimlaneIndex,
                        };
                    }
                }
            }
        }
        return null;
    }
    isPositionInsideSwimlane(y) {
        // Check if y position is within any swimlane
        const swimlaneCount = this.state.swimlanes.length;
        if (swimlaneCount === 0)
            return false;
        // Each swimlane has a height of 263px
        const totalSwimlaneHeight = swimlaneCount * this.swimlaneHeight;
        // Check if y is within the total height of all swimlanes
        return y >= 0 && y < totalSwimlaneHeight;
    }
    showConnectionPopup(x, y) {
        console.log('Showing connection popup at:', x, y);
        this.popupX = x;
        this.popupY = y;
        // Get allowed node types based on the source node type
        this.allowedNodeTypes = this.state.getAllowedTargetNodeTypes();
        console.log('Allowed node types:', this.allowedNodeTypes);
        // Only show the popup if we have allowed node types
        if (this.allowedNodeTypes.length > 0) {
            this.popupVisible = true;
            console.log('Popup visibility set to true');
            // Force the popup to be visible in the next tick
            setTimeout(() => {
                console.log('Is popup visible in next tick:', this.popupVisible);
            }, 0);
        }
        else {
            // No allowed node types, just end the drag
            console.log('No allowed node types, ending drag');
            this.state.endConnectionDrag();
        }
    }
    hideConnectionPopup() {
        this.popupVisible = false;
        this.state.endConnectionDrag();
    }
    // Add this handler to close the popup when clicking outside
    onDocumentClick(event) {
        if (this.popupVisible) {
            const popupElement = document.querySelector('verben-pop-Up');
            if (popupElement && !popupElement.contains(event.target)) {
                this.hideConnectionPopup();
            }
        }
    }
    createNodeConnection(nodeType) {
        const pathData = this.state.getConnectionPathData();
        if (!pathData) {
            this.hideConnectionPopup();
            return;
        }
        // Check if this node type is allowed to be created
        const allowedTypes = this.state.getAllowedTargetNodeTypes();
        if (!allowedTypes.includes(nodeType)) {
            console.error(`Cannot create connection to ${nodeType} from current node type`);
            this.hideConnectionPopup();
            return;
        }
        const { endX, endY, sourceSwimlaneIndex } = pathData;
        // Get source node info
        const sourcePoint = this.state.draggingConnectionData.sourcePoint;
        if (!sourcePoint) {
            this.hideConnectionPopup();
            return;
        }
        const sourceNodeInfo = this.state.findNodeById(sourcePoint.nodeId);
        if (!sourceNodeInfo) {
            this.hideConnectionPopup();
            return;
        }
        // If connecting from a decision to a stage, show condition popup first
        if (sourceNodeInfo.node.type === 'decision' && nodeType === 'stage') {
            // Store information for later stage creation
            this.pendingDecisionConnection = {
                decisionNodeId: sourceNodeInfo.node.id,
                swimlaneIndex: sourceSwimlaneIndex,
                x: endX,
                y: endY,
            };
            // Calculate popup position - position it near the decision node
            const swimlaneOffsetY = sourceSwimlaneIndex * 263;
            // Center the popup over the connection endpoint
            this.decisionConditionPopupX = endX;
            this.decisionConditionPopupY = endY - 150; // Position above the endpoint
            // Set decision node ID
            this.activeDecisionNodeId = sourceNodeInfo.node.id;
            this.showDecisionConditionDialog = true;
            // End the connection drag
            this.hideConnectionPopup();
            return;
        }
        // Calculate swimlane-relative position
        const swimlaneOffsetY = sourceSwimlaneIndex * 263;
        const relativeY = endY - swimlaneOffsetY;
        // Handle preconditions based on node type
        if (nodeType === 'stage') {
            // Create the stage directly with default properties
            const newNode = this.state.addNode(sourceSwimlaneIndex, 'stage', endX, relativeY, { Name: 'New Stage' } // Add default properties
            );
            if (newNode &&
                newNode.connectionPoints &&
                newNode.connectionPoints.length > 0 &&
                sourcePoint) {
                // Handle connection creation
                const opposingType = {
                    right: 'left',
                    left: 'right',
                    top: 'bottom',
                    bottom: 'top',
                }[sourcePoint.type];
                const targetPoint = newNode.connectionPoints.find((p) => p.type === opposingType);
                if (targetPoint) {
                    // Create the connection
                    const connection = this.state.createConnection(newNode.id, targetPoint.id, sourceSwimlaneIndex);
                    if (connection) {
                        this.onConnectionCreated(connection);
                    }
                }
            }
            this.hideConnectionPopup();
            return;
        }
        else if (nodeType === 'subflow') {
            console.log('Creating subflow from connection at:', endX, endY, 'swimlane:', sourceSwimlaneIndex);
            // Show workflow selection popup and store connection data for later use
            this.showSubflowSelectionPopup(endX, endY, sourceSwimlaneIndex);
            this.hideConnectionPopup();
            return;
        }
        // For other nodes Create the new node at the end position of the connection
        const newNode = this.state.addNode(sourceSwimlaneIndex, nodeType, endX, relativeY);
        if (newNode &&
            newNode.connectionPoints &&
            newNode.connectionPoints.length > 0) {
            // Find the most appropriate connection point (closest to the source)
            if (sourcePoint) {
                // For simplicity, use the first connection point of opposing type
                // In a real implementation, you'd find the closest or most appropriate point
                let targetPoint;
                // If source is on right, target should be on left, etc.
                const opposingType = {
                    right: 'left',
                    left: 'right',
                    top: 'bottom',
                    bottom: 'top',
                }[sourcePoint.type];
                targetPoint = newNode.connectionPoints.find((p) => p.type === opposingType);
                if (targetPoint) {
                    // Create the connection
                    const connection = this.state.createConnection(newNode.id, targetPoint.id, sourceSwimlaneIndex);
                    if (connection) {
                        this.onConnectionCreated(connection);
                    }
                }
            }
        }
        if (sourceNodeInfo) {
            this.updateNodeConnections(sourceNodeInfo.node);
        }
        // End the connection drag
        this.hideConnectionPopup();
    }
    // Method to handle saving the condition
    onDecisionConditionSaved(event) {
        if (!this.pendingDecisionConnection) {
            this.showDecisionConditionDialog = false;
            return;
        }
        const { decisionNodeId, swimlaneIndex, x, y } = this.pendingDecisionConnection;
        // Create the stage directly with default properties
        const node = this.state.addNode(swimlaneIndex, 'stage', x, y, { Name: 'New Stage' } // Add default properties
        );
        if (node) {
            const decisionNodeInfo = this.state.findNodeById(decisionNodeId);
            if (decisionNodeInfo &&
                node.connectionPoints &&
                node.connectionPoints.length > 0) {
                // Find a suitable connection point from the decision node
                const decisionNode = decisionNodeInfo.node;
                const decisionNodePoints = decisionNode.connectionPoints || [];
                const sourcePoint = decisionNodePoints.find((p) => p.type === 'right' || p.type === 'bottom');
                if (sourcePoint) {
                    // Find opposing type connection point on the new stage
                    const opposingType = {
                        right: 'left',
                        bottom: 'top',
                        left: 'right',
                        top: 'bottom',
                    }[sourcePoint.type];
                    const targetPoint = node.connectionPoints.find((p) => p.type === opposingType);
                    if (targetPoint) {
                        // Create connection with condition
                        const connection = {
                            id: `conn-${Date.now()}-${Math.floor(Math.random() * 1000)}`,
                            sourceNodeId: decisionNode.id,
                            targetNodeId: node.id,
                            sourcePointId: sourcePoint.id,
                            targetPointId: targetPoint.id,
                            sourceSwimlaneIndex: decisionNodeInfo.swimlaneIndex,
                            targetSwimlaneIndex: swimlaneIndex,
                            condition: event.condition,
                            label: '',
                        };
                        // Add connection to the state
                        this.state.connections.push(connection);
                        console.log('Created decision connection with condition:', connection);
                    }
                }
            }
        }
        // Clear pending data
        this.pendingDecisionConnection = null;
        this.pendingDecisionCondition = '';
        // Hide the condition popup
        this.showDecisionConditionDialog = false;
    }
    onDecisionConditionCancelled() {
        this.showDecisionConditionDialog = false;
        // Don't create the stage or connection
    }
    getConnectionPath() {
        const pathData = this.state.getConnectionPathData();
        if (!pathData)
            return '';
        const { startX, startY, endX, endY } = pathData;
        const sourcePoint = this.state.draggingConnectionData.sourcePoint;
        if (!sourcePoint)
            return '';
        return this.getOrthogonalPath(startX, startY, endX, endY, sourcePoint.type);
    }
    getConnectionPathForSavedConnection(connection) {
        try {
            const pathData = this.state.getConnectionData(connection);
            if (!pathData) {
                console.error('No path data for connection:', connection);
                return '';
            }
            const { startX, startY, endX, endY } = pathData;
            const sourceNodeInfo = this.state.findNodeById(connection.sourceNodeId);
            if (!sourceNodeInfo) {
                console.error('Source node not found for connection:', connection);
                return '';
            }
            const sourceNode = sourceNodeInfo.node;
            const sourcePoint = sourceNode.connectionPoints?.find((p) => p.id === connection.sourcePointId);
            if (!sourcePoint) {
                console.error('Source point not found for connection:', connection);
                return '';
            }
            return this.getOrthogonalPath(startX, startY, endX, endY, sourcePoint.type);
        }
        catch (error) {
            console.error('Error generating path for connection:', connection, error);
            return '';
        }
    }
    getOrthogonalPath(startX, startY, endX, endY, pointType) {
        // Determine initial direction based on connection point type
        let path = '';
        // For side points (left/right), start with horizontal line
        if (pointType === 'left' || pointType === 'right') {
            // Calculate horizontal distance
            const horizontalDist = endX - startX;
            // If the end point is very close horizontally, use a simple 3-segment path
            if (Math.abs(horizontalDist) < 30) {
                const midY = (startY + endY) / 2;
                path = `M ${startX} ${startY} H ${endX} V ${midY} V ${endY}`;
            }
            // Otherwise, create a path with horizontal segment first, then vertical, then horizontal
            else {
                path = `M ${startX} ${startY} H ${startX + horizontalDist / 2} V ${endY} H ${endX}`;
            }
        }
        // For top/bottom points, start with vertical line
        else if (pointType === 'top' || pointType === 'bottom') {
            // Calculate vertical distance
            const verticalDist = endY - startY;
            // If the end point is very close vertically, use a simple 3-segment path
            if (Math.abs(verticalDist) < 30) {
                const midX = (startX + endX) / 2;
                path = `M ${startX} ${startY} V ${endY} H ${midX} H ${endX}`;
            }
            // Otherwise, create a path with vertical segment first, then horizontal, then vertical
            else {
                path = `M ${startX} ${startY} V ${startY + verticalDist / 2} H ${endX} V ${endY}`;
            }
        }
        return path;
    }
    onStagePropertiesUpdated(event) {
        // Find the node in the swimlanes
        for (let i = 0; i < this.state.swimlanes.length; i++) {
            const swimlane = this.state.swimlanes[i];
            const nodeIndex = swimlane.nodes?.findIndex((n) => n.id === event.nodeId);
            if (nodeIndex !== undefined && nodeIndex >= 0) {
                // Update the stage data
                if (swimlane.nodes) {
                    swimlane.nodes[nodeIndex].stageData = {
                        ...swimlane.nodes[nodeIndex].stageData,
                        ...event.stageData,
                    };
                    console.log('Updated stage data in swimlane:', i, 'node:', nodeIndex, 'data:', swimlane.nodes[nodeIndex].stageData);
                }
                break;
            }
        }
    }
    onConnectionCreated(connection) {
        // After a connection is created, refresh the source node to update its state
        const sourceNodeInfo = this.state.findNodeById(connection.sourceNodeId);
        if (sourceNodeInfo && sourceNodeInfo.node.type === 'stage') {
            // Refresh node state
            this.updateNodeConnections(sourceNodeInfo.node);
        }
    }
    // Helper method to update node's connection status
    updateNodeConnections(node) {
        // Count the number of outgoing connections that connect to stages
        const outgoingConnections = this.state.connections.filter((conn) => conn.sourceNodeId === node.id);
        // Check if the target nodes are stages
        const connectedStageNodes = outgoingConnections
            .map((conn) => this.state.findNodeById(conn.targetNodeId))
            .filter((nodeInfo) => nodeInfo && nodeInfo.node.type === 'stage');
        node.hasMultipleConnectedStages = connectedStageNodes.length > 1;
        node.hasParallelStages = connectedStageNodes.every((nd) => nd?.node.stageData?.IsParallel);
    }
    onEditSwimlane(event, swimlane, swimlaneIndex) {
        event.stopPropagation(); // Prevent the canvas click event from firing
        event.preventDefault();
        console.log('Edit swimlane button clicked for swimlane:', swimlaneIndex);
        // Emit a special event for editing a swimlane
        this.clickedPosition.emit({
            x: -1, // Special value to indicate edit mode
            y: swimlaneIndex,
        });
    }
    // showStartNodeFormPopup(event: MouseEvent): void {
    //   event.preventDefault();
    //   event.stopPropagation();
    //   // Implementation will be similar to the stage form popup
    //   // We'll need to add UI elements for this
    //   console.log('Start node form popup requested');
    //   // For now, this is a placeholder
    //   // The actual implementation would load forms and add them to the workflow
    // }
    toggleStartNodeFormPopup(event, nodeX, nodeY, swimlaneIndex) {
        event.preventDefault();
        event.stopPropagation();
        // Set popup position
        const swimlaneOffset = swimlaneIndex * 263;
        this.startNodeFormPopupX = nodeX - 30; // Position near the start node
        this.startNodeFormPopupY = nodeY + swimlaneOffset;
        // If we're opening the popup, load forms
        if (!this.showStartNodeFormPopup) {
            this.isLoadingStartNodeForms = true;
            this.dataService
                .getForms()
                .then((response) => {
                this.startNodeFormsList = response.Result;
                this.isLoadingStartNodeForms = false;
            })
                .catch((error) => {
                console.error('Error loading forms:', error);
                this.isLoadingStartNodeForms = false;
            });
        }
        this.showStartNodeFormPopup = !this.showStartNodeFormPopup;
    }
    selectStartNodeForm(form) {
        console.log(form);
        if (form) {
            this.state.setWorkflowForm(form.Code, form.Name);
        }
        else {
            this.state.setWorkflowForm(null, null);
        }
        // Close the popup
        this.showStartNodeFormPopup = false;
    }
    showSubflowSelectionPopup(x, y, swimlaneIndex) {
        this.subflowPopupX = x;
        this.subflowPopupY = y;
        this.pendingSubflowPosition = { swimlaneIndex, x, y };
        // Store connection data if we're creating from a connection
        if (this.state.isConnectionDragging()) {
            // Store the source connection data
            this.pendingConnectionSourcePoint =
                this.state.draggingConnectionData.sourcePoint ?? null;
            this.pendingConnectionSourceSwimlaneIndex =
                this.state.draggingConnectionData.sourceSwimlaneIndex ?? null;
            console.log('Stored connection data for subflow:', {
                sourcePoint: this.pendingConnectionSourcePoint,
                sourceSwimlaneIndex: this.pendingConnectionSourceSwimlaneIndex,
            });
        }
        // Load workflows
        this.isLoadingWorkflows = true;
        this.dataService
            .getWorkflows()
            .then((response) => {
            this.workflowsList = response.Result;
            this.isLoadingWorkflows = false;
        })
            .catch((error) => {
            console.error('Error loading workflows:', error);
            this.isLoadingWorkflows = false;
        });
        this.showSubflowPopup = true;
    }
    selectSubflowWorkflow(workflow) {
        console.log('Selecting workflow for subflow:', workflow.Name);
        console.log('Pending connection data:', {
            sourcePoint: this.pendingConnectionSourcePoint,
            sourceSwimlaneIndex: this.pendingConnectionSourceSwimlaneIndex,
            position: this.pendingSubflowPosition,
        });
        if (this.pendingSubflowPosition) {
            const { swimlaneIndex, x, y } = this.pendingSubflowPosition;
            // Create the subflow node with the selected workflow data
            const node = this.state.addNode(swimlaneIndex, 'subflow', x, y, undefined, // No stage data
            { id: workflow.Code, name: workflow.Name });
            console.log('Created subflow node:', node);
            // If this was created from a connection, create the connection
            if (node && this.pendingConnectionSourcePoint) {
                console.log('Creating connection to new subflow node');
                // Find a suitable connection point on the new node
                if (node.connectionPoints && node.connectionPoints.length > 0) {
                    const sourcePoint = this.pendingConnectionSourcePoint;
                    // Find opposing type connection point
                    const opposingType = {
                        right: 'left',
                        left: 'right',
                        top: 'bottom',
                        bottom: 'top',
                    }[sourcePoint.type];
                    const targetPoint = node.connectionPoints.find((p) => p.type === opposingType);
                    if (targetPoint) {
                        // Create connection
                        const connection = {
                            id: `conn-${Date.now()}-${Math.floor(Math.random() * 1000)}`,
                            sourceNodeId: sourcePoint.nodeId,
                            targetNodeId: node.id,
                            sourcePointId: sourcePoint.id,
                            targetPointId: targetPoint.id,
                            sourceSwimlaneIndex: this.pendingConnectionSourceSwimlaneIndex,
                            targetSwimlaneIndex: swimlaneIndex,
                            label: '',
                        };
                        // Add connection directly to the state's connections array
                        this.state.connections.push(connection);
                        console.log('Added connection to state:', connection);
                        console.log('Connections after adding:', this.state.connections);
                        this.onConnectionCreated(connection);
                    }
                }
                this.state.endConnectionDrag();
            }
            // Reset selection tool in parent component
            this.subflowSelected.emit();
        }
        // Clean up
        this.showSubflowPopup = false;
        this.pendingSubflowPosition = null;
        this.pendingConnectionSourcePoint = null;
        this.pendingConnectionSourceSwimlaneIndex = null;
    }
    showDecisionConditionsPopup(event, node, swimlaneIndex) {
        event.preventDefault();
        event.stopPropagation();
        // Get the position for the popup
        const position = this.getMousePosition(event);
        const globalX = position.x;
        const globalY = position.y;
        // Find all connections from this decision node
        const connections = this.state.connections.filter((conn) => conn.sourceNodeId === node.id);
        if (connections.length === 0) {
            // No connections to show
            return;
        }
        // Show the decision conditions popup
        this.activeDecisionNodeId = node.id;
        this.decisionConditionPopupX = globalX;
        this.decisionConditionPopupY = globalY;
        // Set the correct popup visibility flag - this is likely the issue
        this.showDecisionConditionDialog = true;
        console.log('Showing decision popup:', {
            x: globalX,
            y: globalY,
            nodeId: node.id,
            isVisible: this.showDecisionConditionDialog,
        });
    }
    ensureSwimlaneInView(swimlaneIndex) {
        // Ensure we have enough swimlanes visible
        const requiredHeight = (swimlaneIndex + 1) * this.swimlaneHeight;
        if (this.canvasHeight < requiredHeight) {
            this.canvasHeight = requiredHeight;
        }
    }
    getLabelPosition(connection) {
        try {
            const pathData = this.state.getConnectionData(connection);
            if (!pathData) {
                console.error('No path data for connection:', connection);
                return { x: 0, y: 0 };
            }
            const { startX, startY, endX, endY } = pathData;
            const sourceNodeInfo = this.state.findNodeById(connection.sourceNodeId);
            if (!sourceNodeInfo) {
                console.error('Source node not found for connection:', connection);
                return { x: 0, y: 0 };
            }
            const sourceNode = sourceNodeInfo.node;
            const sourcePoint = sourceNode.connectionPoints?.find((p) => p.id === connection.sourcePointId);
            if (!sourcePoint) {
                console.error('Source point not found for connection:', connection);
                return { x: 0, y: 0 };
            }
            // Calculate midpoint based on the connection point type
            if (sourcePoint.type === 'left' || sourcePoint.type === 'right') {
                const horizontalDist = endX - startX;
                if (Math.abs(horizontalDist) < 30) {
                    // For short horizontal connections
                    const midY = (startY + endY) / 2;
                    return {
                        x: startX + (endX - startX) / 2,
                        y: midY,
                    };
                }
                else {
                    // For regular connections starting horizontally
                    const midX = startX + horizontalDist / 2;
                    const midY = endY;
                    return {
                        x: midX,
                        y: (startY + endY) / 2,
                    };
                }
            }
            else {
                // 'top' or 'bottom'
                const verticalDist = endY - startY;
                if (Math.abs(verticalDist) < 30) {
                    // For short vertical connections
                    const midX = (startX + endX) / 2;
                    return {
                        x: midX,
                        y: startY + (endY - startY) / 2,
                    };
                }
                else {
                    // For regular connections starting vertically
                    const midX = endX;
                    const midY = startY + verticalDist / 2;
                    return {
                        x: (startX + endX) / 2,
                        y: midY,
                    };
                }
            }
        }
        catch (error) {
            console.error('Error calculating label position for connection:', connection, error);
            return { x: 0, y: 0 };
        }
    }
    saveConnectionLabel(connection, label) {
        // Update the connection label in the state
        this.state.connections = this.state.connections.map((conn) => {
            if (conn.id === connection.id) {
                return {
                    ...conn,
                    label: label,
                };
            }
            return conn;
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DesignerCanvasComponent, deps: [{ token: WorkflowDesignerState }, { token: WorkflowDataService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: DesignerCanvasComponent, selector: "lib-designer-canvas", inputs: { selectedTool: "selectedTool" }, outputs: { clickedPosition: "clickedPosition", subflowSelected: "subflowSelected", showStageDialog: "showStageDialog", stagePropertiesUpdated: "stagePropertiesUpdated" }, host: { listeners: { "window:mouseup": "onWindowMouseUp($event)", "document:click": "onDocumentClick($event)" } }, viewQueries: [{ propertyName: "canvasRef", first: true, predicate: ["canvas"], descendants: true, static: true }], ngImport: i0, template: "<div class=\"canvas-container\">\n  <svg\n    #canvas\n    [attr.width]=\"canvasWidth\"\n    [attr.height]=\"canvasHeight\"\n    class=\"designer-canvas\"\n    (click)=\"onCanvasClick($event)\"\n  >\n    <defs>\n      <!-- Grid pattern definition -->\n\n      <pattern\n        id=\"grid\"\n        [attr.width]=\"gridSize\"\n        [attr.height]=\"gridSize\"\n        patternUnits=\"userSpaceOnUse\"\n      >\n        <path\n          d=\"M 20 0 L 0 0 0 20\"\n          fill=\"none\"\n          stroke=\"#e2e8f0\"\n          stroke-width=\"0.5\"\n        />\n      </pattern>\n\n      <!-- Arrow head marker definition -->\n      <marker\n        id=\"arrowhead\"\n        markerWidth=\"10\"\n        markerHeight=\"7\"\n        refX=\"9\"\n        refY=\"3.5\"\n        orient=\"auto\"\n      >\n        <polygon points=\"0 0, 10 3.5, 0 7\" fill=\"#D36CFF\" />\n      </marker>\n\n      <!-- Connection point styles -->\n      <circle\n        id=\"connection-point-template\"\n        r=\"5\"\n        fill=\"#D36CFF\"\n        stroke=\"#FFFFFF\"\n        stroke-width=\"1\"\n      />\n\n      <!-- Dashed line style for connection preview -->\n      <pattern\n        id=\"dashed-line\"\n        width=\"10\"\n        height=\"10\"\n        patternUnits=\"userSpaceOnUse\"\n      >\n        <line\n          x1=\"0\"\n          y1=\"5\"\n          x2=\"10\"\n          y2=\"5\"\n          stroke=\"#D36CFF\"\n          stroke-width=\"2\"\n          stroke-dasharray=\"5,5\"\n        />\n      </pattern>\n\n      @for (swimlane of state.swimlanes; track swimlane.order) {\n      <clipPath [attr.id]=\"'swimlane-clip-' + swimlane.order\">\n        <rect x=\"0\" y=\"0\" [attr.width]=\"canvasWidth\" height=\"263\" />\n      </clipPath>\n      }\n    </defs>\n\n    <!-- Background grid -->\n    <rect width=\"100%\" height=\"100%\" fill=\"url(#grid)\" />\n\n    <!-- Display a message when no swimlanes exist -->\n    @if (state.swimlanes.length === 0) {\n    <text\n      x=\"50%\"\n      y=\"50%\"\n      font-family=\"sans-serif\"\n      font-size=\"16\"\n      fill=\"#94a3b8\"\n      text-anchor=\"middle\"\n    >\n      Select the Swimlane tool and click on the canvas to add a swimlane\n    </text>\n    }\n\n    <!-- This is where workflow elements will be added later -->\n    @for (swimlane of state.swimlanes; track swimlane.order) {\n    <!-- <g\n      [attr.transform]=\"'translate(0,' + swimlane.order * 263 + ')'\"\n      [attr.clip-path]=\"'url(#swimlane-clip-' + swimlane.order + ')'\"\n    >\n      <rect\n        x=\"0\"\n        y=\"0\"\n        [attr.width]=\"canvasWidth\"\n        [attr.height]=\"263\"\n        fill=\"#ffffff\"\n        stroke=\"#e2e8f0\"\n        stroke-width=\"1\"\n      ></rect>\n\n      <rect\n        x=\"0\"\n        y=\"0\"\n        [attr.width]=\"canvasWidth\"\n        height=\"40\"\n        fill=\"#f8fafc\"\n        stroke=\"#e2e8f0\"\n        stroke-width=\"1\"\n      ></rect>\n\n      <text\n        x=\"20\"\n        y=\"25\"\n        font-family=\"sans-serif\"\n        font-size=\"14\"\n        fill=\"#333333\"\n        font-weight=\"bold\"\n      >\n        {{ swimlane.label }}\n      </text>\n\n      <g\n        class=\"edit-swimlane-button\"\n        [attr.transform]=\"'translate(100, 20)'\"\n        (click)=\"\n          onEditSwimlane($event, swimlane, swimlane.order);\n          $event.stopPropagation()\n        \"\n      >\n        <rect\n          x=\"-5\"\n          y=\"-15\"\n          width=\"40\"\n          height=\"20\"\n          fill=\"#f3e8ff\"\n          rx=\"3\"\n          ry=\"3\"\n          stroke=\"#d8b4fe\"\n          stroke-width=\"1\"\n        ></rect>\n        <text\n          x=\"15\"\n          y=\"0\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"#7e22ce\"\n          text-anchor=\"middle\"\n        >\n          Edit\n        </text>\n      </g>\n\n      <g [attr.transform]=\"'translate(200, 20)'\">\n        @for (tag of swimlane.tags.slice(0, 3); track tag.Name; let i = $index)\n        {\n        <text\n          [attr.x]=\"i * 100\"\n          y=\"5\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"#666666\"\n        >\n          {{ tag.Name }}\n        </text>\n        } @if (swimlane.tags.length > 3) {\n        <text\n          [attr.x]=\"3 * 100 + 10\"\n          y=\"5\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"#666666\"\n        >\n          +{{ swimlane.tags.length - 3 }} more\n        </text>\n        }\n      </g>\n    </g> -->\n\n    <g [attr.transform]=\"'translate(0,' + swimlane.order * 263 + ')'\">\n      <!-- Swimlane container - remove stroke to make it purely background -->\n      <rect\n        x=\"0\"\n        y=\"0\"\n        [attr.width]=\"canvasWidth\"\n        [attr.height]=\"263\"\n        [attr.fill]=\"swimlane.order % 2 === 0 ? '#FCF3FF' : '#ECFFF5'\"\n        stroke=\"none\"\n      ></rect>\n\n      <!-- Vertical swimlane label on the left -->\n      <g class=\"swimlane-label\">\n        <!-- Purple background for the label -->\n        <rect\n          x=\"0.5\"\n          y=\"0.5\"\n          width=\"43\"\n          height=\"215\"\n          rx=\"10.5\"\n          fill=\"white\"\n          stroke=\"#D36CFF\"\n        ></rect>\n\n        <!-- Plus button at the top -->\n        <path\n          d=\"M22.52 12.174V17.08H27.47V18.51H22.52V23.394H21.2V18.51H16.25V17.08H21.2V12.174H22.52Z\"\n          fill=\"#0000FF\"\n          class=\"plus-icon\"\n          (click)=\"\n            onEditSwimlane($event, swimlane, swimlane.order);\n            $event.stopPropagation()\n          \"\n          style=\"cursor: pointer\"\n        ></path>\n\n        <!-- Swimlane label -->\n        <text\n          x=\"22\"\n          y=\"106\"\n          font-family=\"sans-serif\"\n          font-size=\"14\"\n          fill=\"#333333\"\n          text-anchor=\"middle\"\n          transform=\"rotate(-90, 22, 100)\"\n        >\n          {{\n            swimlane.label.length > 12\n              ? swimlane.label.substring(0, 10) + \"...\"\n              : swimlane.label\n          }}\n        </text>\n\n        <!-- Tag count indicator at the bottom -->\n        <rect\n          x=\"11.5\"\n          y=\"187\"\n          width=\"21\"\n          height=\"19\"\n          rx=\"9.5\"\n          fill=\"#9E9E9E\"\n        ></rect>\n        <text\n          x=\"24\"\n          y=\"206\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"black\"\n          text-anchor=\"middle\"\n          transform=\"rotate(-90, 22, 200)\"\n        >\n          {{ swimlane.tags.length }}\n        </text>\n      </g>\n    </g>\n\n    }\n\n    <!-- Nodes -->\n    @for (swimlane of state.swimlanes; track swimlane.order) {\n    <!-- Render nodes in this swimlane -->\n    @for (node of swimlane.nodes; track node.id) {\n    <g\n      class=\"node-element\"\n      [attr.transform]=\"\n        'translate(' + node.x + ',' + (node.y - swimlane.order * 263) + ')'\n      \"\n      (mouseenter)=\"showConnectionPoints(node.id, swimlane.order)\"\n      (mouseleave)=\"hideConnectionPoints(node.id)\"\n    >\n      <!-- Start node indicator (circle and arrow) for the first node -->\n      @if (node.isStartNode) {\n      <!-- Circle -->\n      <circle\n        cx=\"-50\"\n        cy=\"50\"\n        r=\"30\"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n      ></circle>\n      <!-- Form icon for start node -->\n      <svg:g\n        (click)=\"\n          toggleStartNodeFormPopup($event, node.x, node.y, swimlane.order)\n        \"\n        class=\"stage-icon\"\n        transform=\"translate(-45, 42)\"\n        style=\"cursor: pointer; pointer-events: all\"\n      >\n        <!-- Transparent rectangle to capture clicks -->\n        <svg:rect\n          x=\"-2\"\n          y=\"-2\"\n          width=\"24\"\n          height=\"24\"\n          fill=\"transparent\"\n          style=\"cursor: pointer\"\n        />\n        <svg:path\n          d=\"M16.5 20.475V17.475H13.5V16.475H16.5V13.475H17.5V16.475H20.5V17.475H17.5V20.475H16.5ZM3.5 17.5V16.5H4.5V17.5H3.5ZM6.5 17.5V16.5H11.517C11.5057 16.6767 11.5043 16.845 11.513 17.005C11.521 17.165 11.531 17.33 11.543 17.5H6.5ZM3.5 13.5V12.5H4.5V13.5H3.5ZM6.5 13.5V12.5H13.804C13.6127 12.6387 13.4333 12.7913 13.266 12.958C13.0993 13.1247 12.9377 13.3053 12.781 13.5H6.5ZM3.5 9.5V8.5H4.5V9.5H3.5ZM6.5 9.5V8.5H18.5V9.5H6.5ZM3.5 5.5V4.5H4.5V5.5H3.5ZM6.5 5.5V4.5H18.5V5.5H6.5Z\"\n          [attr.fill]=\"state.workflowFormId ? '#D36CFF' : 'black'\"\n          transform=\"scale(0.7)\"\n        />\n      </svg:g>\n      <!-- Arrow from circle to node -->\n      <path\n        d=\"M -20 50 L 0 50\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n        marker-end=\"url(#arrowhead)\"\n      ></path>\n      }\n\n      <!-- Exit point indicator (circle and arrow) -->\n      @if (node.stageData?.IsExitPoint) {\n      <!-- Arrow from node to circle -->\n      <path\n        [attr.d]=\"'M ' + node.width + ' 50 L ' + (node.width + 20) + ' 50'\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n        marker-end=\"url(#arrowhead)\"\n      ></path>\n      <!-- Circle -->\n      <circle\n        [attr.cx]=\"node.width + 50\"\n        cy=\"50\"\n        r=\"30\"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"2\"\n      ></circle>\n      }\n\n      <!-- Stage node -->\n      @if (node.type === 'stage') {\n      <!-- <rect\n                  x=\"0\"\n                  y=\"0\"\n                  [attr.width]=\"node.width\"\n                  [attr.height]=\"node.height\"\n                  fill=\"none\"\n                  stroke=\"#D36CFF\"\n                  stroke-width=\"1\"\n                ></rect> -->\n      <svg:g\n        lib-stage-node\n        [node]=\"node\"\n        [isStartNode]=\"node.isStartNode\"\n        (stagePropertiesUpdated)=\"onStagePropertiesUpdated($event)\"\n        (showShieldDialog)=\"onShowShieldDialog($event)\"\n      ></svg:g>\n      }\n\n      <!-- Decision node -->\n      @if (node.type === 'decision') {\n      <path\n        [attr.d]=\"\n          'M 0 ' +\n          node.height / 2 +\n          ' L ' +\n          node.width / 2 +\n          ' 0' +\n          ' L ' +\n          node.width +\n          ' ' +\n          node.height / 2 +\n          ' L ' +\n          node.width / 2 +\n          ' ' +\n          node.height +\n          ' Z'\n        \"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n      ></path>\n\n      <!-- Decision node condition indicator icon -->\n      <svg:g\n        (click)=\"showDecisionConditionsPopup($event, node, swimlane.order)\"\n        class=\"decision-condition-icon\"\n        [attr.transform]=\"\n          'translate(' +\n          (node.width / 2 - 10) +\n          ',' +\n          (node.height / 2 - 10) +\n          ')'\n        \"\n      >\n        <svg:rect\n          x=\"-5\"\n          y=\"-5\"\n          width=\"30\"\n          height=\"30\"\n          fill=\"transparent\"\n          style=\"cursor: pointer\"\n        />\n        <svg:path\n          d=\"M10 0H20V2H10V0ZM10 8H20V10H10V8ZM10 4H20V6H10V4ZM0 0H8V2H0V0ZM0 8H8V10H0V8ZM0 4H8V6H0V4Z\"\n          fill=\"#D36CFF\"\n        />\n      </svg:g>\n      }\n\n      <!-- Form node -->\n      @if (node.type === 'form') {\n      <path\n        d=\"M95.0625 50.5591V95.0625C95.0625 97.9716 93.9069 100.762 91.8498 102.819C89.7928 104.876 87.0028 106.031 84.0938 106.031H32.9062C29.9972 106.031 27.2072 104.876 25.1502 102.819C23.0931 100.762 21.9375 97.9716 21.9375 95.0625V21.9375C21.9375 19.0284 23.0931 16.2385 25.1502 14.1814C27.2072 12.1244 29.9972 10.9688 32.9062 10.9688H55.4722C57.4109 10.969 59.2701 11.7392 60.6412 13.1099L92.9213 45.3901C94.292 46.7611 95.0622 48.6204 95.0625 50.5591Z\"\n        transform=\"scale(0.7)\"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-linejoin=\"round\"\n      />\n      <path\n        d=\"M58.5 12.7969V40.2188C58.5 42.1581 59.2704 44.0181 60.6418 45.3895C62.0131 46.7608 63.8731 47.5312 65.8125 47.5312H93.2344\"\n        transform=\"scale(0.7)\"\n        stroke=\"#D36CFF\"\n        stroke-linecap=\"round\"\n        stroke-linejoin=\"round\"\n      />\n      <text\n        x=\"50%\"\n        y=\"50%\"\n        text-anchor=\"middle\"\n        dominant-baseline=\"middle\"\n        font-family=\"sans-serif\"\n        font-size=\"14\"\n        fill=\"#D36CFF\"\n      >\n        Form\n      </text>\n      }\n\n      <!-- Subflow node -->\n      @if (node.type === 'subflow') {\n      <path\n        [attr.d]=\"\n          'M 1 ' +\n          node.height / 4 +\n          ' L ' +\n          node.width / 2 +\n          ' 1 L ' +\n          (node.width - 1) +\n          ' ' +\n          node.height / 4 +\n          ' V ' +\n          (node.height * 3) / 4 +\n          ' L ' +\n          node.width / 2 +\n          ' ' +\n          (node.height - 1) +\n          ' L 1 ' +\n          (node.height * 3) / 4 +\n          ' Z'\n        \"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n      ></path>\n      <text\n        [attr.x]=\"node.width / 2\"\n        [attr.y]=\"node.height / 2\"\n        text-anchor=\"middle\"\n        alignment-baseline=\"middle\"\n        font-family=\"sans-serif\"\n        font-size=\"10\"\n        fill=\"#000000\"\n      >\n        <!-- Limit text length -->\n        {{\n          (node.workflowData?.name || \"Subflow\").length > 12\n            ? (node.workflowData?.name || \"Subflow\").substring(0, 10) + \"...\"\n            : node.workflowData?.name || \"Subflow\"\n        }}\n      </text>\n      }\n\n      <!-- Connection points for this node -->\n      @for (point of node.connectionPoints || []; track point.id) { @if\n      (isConnectionPointVisible(node.id)) {\n      <use\n        [attr.href]=\"'#connection-point-template'\"\n        [attr.x]=\"point.x\"\n        [attr.y]=\"point.y\"\n        [attr.id]=\"point.id\"\n        (mousedown)=\"startConnectionDrag($event, point, swimlane.order)\"\n      />\n      } }\n    </g>\n    <!-- A transparent hover area for improved hover detection -->\n    <rect\n      [attr.x]=\"node.x - 10\"\n      [attr.y]=\"node.y + 40 - 10\"\n      [attr.width]=\"node.width + 20\"\n      [attr.height]=\"node.height + 20\"\n      fill=\"transparent\"\n      (mouseover)=\"showConnectionPoints(node.id, swimlane.order)\"\n      (mouseout)=\"hideConnectionPoints(node.id)\"\n      style=\"pointer-events: none\"\n    />\n    } }\n\n    <!-- Connections -->\n    @for (connection of state.connections; track connection.id) {\n    <g class=\"connection-element\">\n      <path\n        [attr.d]=\"getConnectionPathForSavedConnection(connection)\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"2\"\n        fill=\"none\"\n        marker-end=\"url(#arrowhead)\"\n      ></path>\n\n      <!-- Connection Label -->\n      @if (connection.sourceNodeId && connection.targetNodeId) {\n      <foreignObject\n        [attr.x]=\"getLabelPosition(connection).x\"\n        [attr.y]=\"getLabelPosition(connection).y\"\n        width=\"150\"\n        height=\"40\"\n        style=\"overflow: visible; pointer-events: all\"\n        [attr.transform]=\"'translate(-10, -10)'\"\n      >\n        <wf-label-editor\n          [label]=\"connection.label || 'New Action'\"\n          [x]=\"0\"\n          [y]=\"0\"\n          [isConnection]=\"true\"\n          (labelChange)=\"saveConnectionLabel(connection, $event)\"\n        />\n      </foreignObject>\n      }\n    </g>\n    }\n\n    <!-- Connection preview line -->\n    @if (state.isConnectionDragging()) {\n    <g>\n      <path\n        [attr.d]=\"getConnectionPath()\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"2\"\n        stroke-dasharray=\"5,5\"\n        fill=\"none\"\n      ></path>\n    </g>\n    }\n  </svg>\n\n  <div\n    *ngIf=\"popupVisible\"\n    [style.position]=\"'absolute'\"\n    [style.left.px]=\"popupX\"\n    [style.top.px]=\"popupY\"\n  >\n    <verben-pop-Up\n      [dropdownOpen]=\"true\"\n      [customStyles]=\"{ 'z-index': '99' }\"\n      [enableMouseLeave]=\"false\"\n    >\n      <div dropdown-trigger style=\"display: none\">\n        <!-- Hidden trigger element -->\n      </div>\n      <div\n        class=\"p-3 bg-white border border-gray-200 rounded shadow-md\"\n        dropdown-content\n      >\n        <h4 class=\"mb-2 font-medium\">Create Connection</h4>\n        <div class=\"flex flex-col gap-2\">\n          <ng-container *ngFor=\"let type of allowedNodeTypes\">\n            <button\n              class=\"px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50\"\n              (click)=\"createNodeConnection(type)\"\n            >\n              Create {{ type | titlecase }}\n            </button>\n          </ng-container>\n          <button\n            class=\"px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50\"\n            (click)=\"hideConnectionPopup()\"\n          >\n            Cancel\n          </button>\n        </div>\n      </div>\n    </verben-pop-Up>\n  </div>\n\n  <div\n    *ngIf=\"showStartNodeFormPopup\"\n    [style.position]=\"'absolute'\"\n    [style.left.px]=\"startNodeFormPopupX\"\n    [style.top.px]=\"startNodeFormPopupY\"\n  >\n    <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n      <div dropdown-trigger style=\"display: none\">\n        <!-- Hidden trigger element -->\n      </div>\n      <div\n        class=\"p-3 bg-white border border-gray-200 rounded shadow-md w-64\"\n        dropdown-content\n        style=\"background-color: white; z-index: 1000\"\n      >\n        <h4 class=\"mb-2 font-medium\">Select Workflow Form</h4>\n        <div *ngIf=\"isLoadingStartNodeForms\" class=\"text-center py-2\">\n          Loading forms...\n        </div>\n        <div *ngIf=\"!isLoadingStartNodeForms\" class=\"max-h-48 overflow-y-auto\">\n          <div class=\"mb-2\">\n            <button\n              class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n              (click)=\"selectStartNodeForm(null)\"\n            >\n              Clear form selection\n            </button>\n          </div>\n          <div *ngFor=\"let form of startNodeFormsList\" class=\"mb-1\">\n            <button\n              class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n              (click)=\"selectStartNodeForm(form)\"\n            >\n              {{ form.Name }}\n            </button>\n          </div>\n          <div\n            *ngIf=\"startNodeFormsList.length === 0\"\n            class=\"text-center py-2 text-gray-500\"\n          >\n            No forms available\n          </div>\n        </div>\n      </div>\n    </verben-pop-Up>\n  </div>\n\n  <div\n    *ngIf=\"showSubflowPopup\"\n    [style.position]=\"'absolute'\"\n    [style.left.px]=\"subflowPopupX\"\n    [style.top.px]=\"subflowPopupY\"\n  >\n    <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n      <div dropdown-trigger style=\"display: none\">\n        <!-- Hidden trigger element -->\n      </div>\n      <div\n        class=\"p-3 bg-white border border-gray-200 rounded shadow-md w-64\"\n        dropdown-content\n        style=\"background-color: white; z-index: 1000\"\n      >\n        <h4 class=\"mb-2 font-medium\">Select Workflow</h4>\n        <div *ngIf=\"isLoadingWorkflows\" class=\"text-center py-2\">\n          Loading workflows...\n        </div>\n        <div *ngIf=\"!isLoadingWorkflows\" class=\"max-h-48 overflow-y-auto\">\n          <div *ngFor=\"let workflow of workflowsList\" class=\"mb-1\">\n            <button\n              class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n              (click)=\"selectSubflowWorkflow(workflow)\"\n            >\n              {{ workflow.Name }}\n            </button>\n          </div>\n          <div\n            *ngIf=\"workflowsList.length === 0\"\n            class=\"text-center py-2 text-gray-500\"\n          >\n            No workflows available\n          </div>\n        </div>\n      </div>\n    </verben-pop-Up>\n  </div>\n\n  <lib-conditions-popup\n    [visible]=\"showDecisionConditionDialog\"\n    [decisionNodeId]=\"activeDecisionNodeId\"\n    [newConnectionId]=\"activeConnectionId\"\n    [popupX]=\"decisionConditionPopupX\"\n    [popupY]=\"decisionConditionPopupY\"\n    (closed)=\"onDecisionConditionCancelled()\"\n    (saved)=\"onDecisionConditionSaved($event)\"\n  ></lib-conditions-popup>\n\n  <!-- <lib-decision-popup\n    [visible]=\"showConditionsDialog\"\n    [decisionNodeId]=\"activeDecisionNodeId\"\n    [popupX]=\"decisionConditionPopupX\"\n    [popupY]=\"decisionConditionPopupY\"\n    (closed)=\"onDecisionConditionCancelled()\"\n  ></lib-decision-popup> -->\n\n  <lib-stage-dialog\n    [visible]=\"showStageDialogLocal\"\n    [stageData]=\"activeStageData || {}\"\n    (closed)=\"onStageDialogClosed()\"\n    (saved)=\"onStageDialogSaved($event)\"\n  ></lib-stage-dialog>\n</div>\n", styles: [".canvas-container{flex:1;overflow:auto;background-color:#fff}.designer-canvas{min-width:100%;min-height:100%;cursor:default}.designer-canvas:focus{outline:none}.edit-swimlane-button{cursor:pointer}.edit-swimlane-button:hover rect{fill:#ddd6fe}.decision-condition-icon{cursor:pointer}.decision-condition-icon:hover path{fill:#c084fc}.swimlane-label{z-index:10;cursor:default}.plus-icon:hover{fill:#d36cff}.swimlane-container{pointer-events:none}.swimlane-container>*{pointer-events:auto}.node-element{z-index:10}.connection-element{z-index:5}\n"], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: LabelEditorComponent, selector: "wf-label-editor", inputs: ["label", "x", "y", "isConnection", "isSwimlane"], outputs: ["labelChange"] }, { kind: "component", type: StageNodeComponent, selector: "svg:g[lib-stage-node]", inputs: ["node", "isStartNode", "stageData"], outputs: ["stagePropertiesUpdated", "parallelExecutionToggled", "showShieldDialog"] }, { kind: "component", type: StageDialogComponent, selector: "lib-stage-dialog", inputs: ["visible", "stageData"], outputs: ["closed", "saved"] }, { kind: "component", type: ConditionsPopupComponent, selector: "lib-conditions-popup", inputs: ["visible", "decisionNodeId", "newConnectionId", "popupX", "popupY"], outputs: ["closed", "saved"] }, { kind: "pipe", type: i1$1.TitleCasePipe, name: "titlecase" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DesignerCanvasComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-designer-canvas', template: "<div class=\"canvas-container\">\n  <svg\n    #canvas\n    [attr.width]=\"canvasWidth\"\n    [attr.height]=\"canvasHeight\"\n    class=\"designer-canvas\"\n    (click)=\"onCanvasClick($event)\"\n  >\n    <defs>\n      <!-- Grid pattern definition -->\n\n      <pattern\n        id=\"grid\"\n        [attr.width]=\"gridSize\"\n        [attr.height]=\"gridSize\"\n        patternUnits=\"userSpaceOnUse\"\n      >\n        <path\n          d=\"M 20 0 L 0 0 0 20\"\n          fill=\"none\"\n          stroke=\"#e2e8f0\"\n          stroke-width=\"0.5\"\n        />\n      </pattern>\n\n      <!-- Arrow head marker definition -->\n      <marker\n        id=\"arrowhead\"\n        markerWidth=\"10\"\n        markerHeight=\"7\"\n        refX=\"9\"\n        refY=\"3.5\"\n        orient=\"auto\"\n      >\n        <polygon points=\"0 0, 10 3.5, 0 7\" fill=\"#D36CFF\" />\n      </marker>\n\n      <!-- Connection point styles -->\n      <circle\n        id=\"connection-point-template\"\n        r=\"5\"\n        fill=\"#D36CFF\"\n        stroke=\"#FFFFFF\"\n        stroke-width=\"1\"\n      />\n\n      <!-- Dashed line style for connection preview -->\n      <pattern\n        id=\"dashed-line\"\n        width=\"10\"\n        height=\"10\"\n        patternUnits=\"userSpaceOnUse\"\n      >\n        <line\n          x1=\"0\"\n          y1=\"5\"\n          x2=\"10\"\n          y2=\"5\"\n          stroke=\"#D36CFF\"\n          stroke-width=\"2\"\n          stroke-dasharray=\"5,5\"\n        />\n      </pattern>\n\n      @for (swimlane of state.swimlanes; track swimlane.order) {\n      <clipPath [attr.id]=\"'swimlane-clip-' + swimlane.order\">\n        <rect x=\"0\" y=\"0\" [attr.width]=\"canvasWidth\" height=\"263\" />\n      </clipPath>\n      }\n    </defs>\n\n    <!-- Background grid -->\n    <rect width=\"100%\" height=\"100%\" fill=\"url(#grid)\" />\n\n    <!-- Display a message when no swimlanes exist -->\n    @if (state.swimlanes.length === 0) {\n    <text\n      x=\"50%\"\n      y=\"50%\"\n      font-family=\"sans-serif\"\n      font-size=\"16\"\n      fill=\"#94a3b8\"\n      text-anchor=\"middle\"\n    >\n      Select the Swimlane tool and click on the canvas to add a swimlane\n    </text>\n    }\n\n    <!-- This is where workflow elements will be added later -->\n    @for (swimlane of state.swimlanes; track swimlane.order) {\n    <!-- <g\n      [attr.transform]=\"'translate(0,' + swimlane.order * 263 + ')'\"\n      [attr.clip-path]=\"'url(#swimlane-clip-' + swimlane.order + ')'\"\n    >\n      <rect\n        x=\"0\"\n        y=\"0\"\n        [attr.width]=\"canvasWidth\"\n        [attr.height]=\"263\"\n        fill=\"#ffffff\"\n        stroke=\"#e2e8f0\"\n        stroke-width=\"1\"\n      ></rect>\n\n      <rect\n        x=\"0\"\n        y=\"0\"\n        [attr.width]=\"canvasWidth\"\n        height=\"40\"\n        fill=\"#f8fafc\"\n        stroke=\"#e2e8f0\"\n        stroke-width=\"1\"\n      ></rect>\n\n      <text\n        x=\"20\"\n        y=\"25\"\n        font-family=\"sans-serif\"\n        font-size=\"14\"\n        fill=\"#333333\"\n        font-weight=\"bold\"\n      >\n        {{ swimlane.label }}\n      </text>\n\n      <g\n        class=\"edit-swimlane-button\"\n        [attr.transform]=\"'translate(100, 20)'\"\n        (click)=\"\n          onEditSwimlane($event, swimlane, swimlane.order);\n          $event.stopPropagation()\n        \"\n      >\n        <rect\n          x=\"-5\"\n          y=\"-15\"\n          width=\"40\"\n          height=\"20\"\n          fill=\"#f3e8ff\"\n          rx=\"3\"\n          ry=\"3\"\n          stroke=\"#d8b4fe\"\n          stroke-width=\"1\"\n        ></rect>\n        <text\n          x=\"15\"\n          y=\"0\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"#7e22ce\"\n          text-anchor=\"middle\"\n        >\n          Edit\n        </text>\n      </g>\n\n      <g [attr.transform]=\"'translate(200, 20)'\">\n        @for (tag of swimlane.tags.slice(0, 3); track tag.Name; let i = $index)\n        {\n        <text\n          [attr.x]=\"i * 100\"\n          y=\"5\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"#666666\"\n        >\n          {{ tag.Name }}\n        </text>\n        } @if (swimlane.tags.length > 3) {\n        <text\n          [attr.x]=\"3 * 100 + 10\"\n          y=\"5\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"#666666\"\n        >\n          +{{ swimlane.tags.length - 3 }} more\n        </text>\n        }\n      </g>\n    </g> -->\n\n    <g [attr.transform]=\"'translate(0,' + swimlane.order * 263 + ')'\">\n      <!-- Swimlane container - remove stroke to make it purely background -->\n      <rect\n        x=\"0\"\n        y=\"0\"\n        [attr.width]=\"canvasWidth\"\n        [attr.height]=\"263\"\n        [attr.fill]=\"swimlane.order % 2 === 0 ? '#FCF3FF' : '#ECFFF5'\"\n        stroke=\"none\"\n      ></rect>\n\n      <!-- Vertical swimlane label on the left -->\n      <g class=\"swimlane-label\">\n        <!-- Purple background for the label -->\n        <rect\n          x=\"0.5\"\n          y=\"0.5\"\n          width=\"43\"\n          height=\"215\"\n          rx=\"10.5\"\n          fill=\"white\"\n          stroke=\"#D36CFF\"\n        ></rect>\n\n        <!-- Plus button at the top -->\n        <path\n          d=\"M22.52 12.174V17.08H27.47V18.51H22.52V23.394H21.2V18.51H16.25V17.08H21.2V12.174H22.52Z\"\n          fill=\"#0000FF\"\n          class=\"plus-icon\"\n          (click)=\"\n            onEditSwimlane($event, swimlane, swimlane.order);\n            $event.stopPropagation()\n          \"\n          style=\"cursor: pointer\"\n        ></path>\n\n        <!-- Swimlane label -->\n        <text\n          x=\"22\"\n          y=\"106\"\n          font-family=\"sans-serif\"\n          font-size=\"14\"\n          fill=\"#333333\"\n          text-anchor=\"middle\"\n          transform=\"rotate(-90, 22, 100)\"\n        >\n          {{\n            swimlane.label.length > 12\n              ? swimlane.label.substring(0, 10) + \"...\"\n              : swimlane.label\n          }}\n        </text>\n\n        <!-- Tag count indicator at the bottom -->\n        <rect\n          x=\"11.5\"\n          y=\"187\"\n          width=\"21\"\n          height=\"19\"\n          rx=\"9.5\"\n          fill=\"#9E9E9E\"\n        ></rect>\n        <text\n          x=\"24\"\n          y=\"206\"\n          font-family=\"sans-serif\"\n          font-size=\"12\"\n          fill=\"black\"\n          text-anchor=\"middle\"\n          transform=\"rotate(-90, 22, 200)\"\n        >\n          {{ swimlane.tags.length }}\n        </text>\n      </g>\n    </g>\n\n    }\n\n    <!-- Nodes -->\n    @for (swimlane of state.swimlanes; track swimlane.order) {\n    <!-- Render nodes in this swimlane -->\n    @for (node of swimlane.nodes; track node.id) {\n    <g\n      class=\"node-element\"\n      [attr.transform]=\"\n        'translate(' + node.x + ',' + (node.y - swimlane.order * 263) + ')'\n      \"\n      (mouseenter)=\"showConnectionPoints(node.id, swimlane.order)\"\n      (mouseleave)=\"hideConnectionPoints(node.id)\"\n    >\n      <!-- Start node indicator (circle and arrow) for the first node -->\n      @if (node.isStartNode) {\n      <!-- Circle -->\n      <circle\n        cx=\"-50\"\n        cy=\"50\"\n        r=\"30\"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n      ></circle>\n      <!-- Form icon for start node -->\n      <svg:g\n        (click)=\"\n          toggleStartNodeFormPopup($event, node.x, node.y, swimlane.order)\n        \"\n        class=\"stage-icon\"\n        transform=\"translate(-45, 42)\"\n        style=\"cursor: pointer; pointer-events: all\"\n      >\n        <!-- Transparent rectangle to capture clicks -->\n        <svg:rect\n          x=\"-2\"\n          y=\"-2\"\n          width=\"24\"\n          height=\"24\"\n          fill=\"transparent\"\n          style=\"cursor: pointer\"\n        />\n        <svg:path\n          d=\"M16.5 20.475V17.475H13.5V16.475H16.5V13.475H17.5V16.475H20.5V17.475H17.5V20.475H16.5ZM3.5 17.5V16.5H4.5V17.5H3.5ZM6.5 17.5V16.5H11.517C11.5057 16.6767 11.5043 16.845 11.513 17.005C11.521 17.165 11.531 17.33 11.543 17.5H6.5ZM3.5 13.5V12.5H4.5V13.5H3.5ZM6.5 13.5V12.5H13.804C13.6127 12.6387 13.4333 12.7913 13.266 12.958C13.0993 13.1247 12.9377 13.3053 12.781 13.5H6.5ZM3.5 9.5V8.5H4.5V9.5H3.5ZM6.5 9.5V8.5H18.5V9.5H6.5ZM3.5 5.5V4.5H4.5V5.5H3.5ZM6.5 5.5V4.5H18.5V5.5H6.5Z\"\n          [attr.fill]=\"state.workflowFormId ? '#D36CFF' : 'black'\"\n          transform=\"scale(0.7)\"\n        />\n      </svg:g>\n      <!-- Arrow from circle to node -->\n      <path\n        d=\"M -20 50 L 0 50\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n        marker-end=\"url(#arrowhead)\"\n      ></path>\n      }\n\n      <!-- Exit point indicator (circle and arrow) -->\n      @if (node.stageData?.IsExitPoint) {\n      <!-- Arrow from node to circle -->\n      <path\n        [attr.d]=\"'M ' + node.width + ' 50 L ' + (node.width + 20) + ' 50'\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n        marker-end=\"url(#arrowhead)\"\n      ></path>\n      <!-- Circle -->\n      <circle\n        [attr.cx]=\"node.width + 50\"\n        cy=\"50\"\n        r=\"30\"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"2\"\n      ></circle>\n      }\n\n      <!-- Stage node -->\n      @if (node.type === 'stage') {\n      <!-- <rect\n                  x=\"0\"\n                  y=\"0\"\n                  [attr.width]=\"node.width\"\n                  [attr.height]=\"node.height\"\n                  fill=\"none\"\n                  stroke=\"#D36CFF\"\n                  stroke-width=\"1\"\n                ></rect> -->\n      <svg:g\n        lib-stage-node\n        [node]=\"node\"\n        [isStartNode]=\"node.isStartNode\"\n        (stagePropertiesUpdated)=\"onStagePropertiesUpdated($event)\"\n        (showShieldDialog)=\"onShowShieldDialog($event)\"\n      ></svg:g>\n      }\n\n      <!-- Decision node -->\n      @if (node.type === 'decision') {\n      <path\n        [attr.d]=\"\n          'M 0 ' +\n          node.height / 2 +\n          ' L ' +\n          node.width / 2 +\n          ' 0' +\n          ' L ' +\n          node.width +\n          ' ' +\n          node.height / 2 +\n          ' L ' +\n          node.width / 2 +\n          ' ' +\n          node.height +\n          ' Z'\n        \"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n      ></path>\n\n      <!-- Decision node condition indicator icon -->\n      <svg:g\n        (click)=\"showDecisionConditionsPopup($event, node, swimlane.order)\"\n        class=\"decision-condition-icon\"\n        [attr.transform]=\"\n          'translate(' +\n          (node.width / 2 - 10) +\n          ',' +\n          (node.height / 2 - 10) +\n          ')'\n        \"\n      >\n        <svg:rect\n          x=\"-5\"\n          y=\"-5\"\n          width=\"30\"\n          height=\"30\"\n          fill=\"transparent\"\n          style=\"cursor: pointer\"\n        />\n        <svg:path\n          d=\"M10 0H20V2H10V0ZM10 8H20V10H10V8ZM10 4H20V6H10V4ZM0 0H8V2H0V0ZM0 8H8V10H0V8ZM0 4H8V6H0V4Z\"\n          fill=\"#D36CFF\"\n        />\n      </svg:g>\n      }\n\n      <!-- Form node -->\n      @if (node.type === 'form') {\n      <path\n        d=\"M95.0625 50.5591V95.0625C95.0625 97.9716 93.9069 100.762 91.8498 102.819C89.7928 104.876 87.0028 106.031 84.0938 106.031H32.9062C29.9972 106.031 27.2072 104.876 25.1502 102.819C23.0931 100.762 21.9375 97.9716 21.9375 95.0625V21.9375C21.9375 19.0284 23.0931 16.2385 25.1502 14.1814C27.2072 12.1244 29.9972 10.9688 32.9062 10.9688H55.4722C57.4109 10.969 59.2701 11.7392 60.6412 13.1099L92.9213 45.3901C94.292 46.7611 95.0622 48.6204 95.0625 50.5591Z\"\n        transform=\"scale(0.7)\"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-linejoin=\"round\"\n      />\n      <path\n        d=\"M58.5 12.7969V40.2188C58.5 42.1581 59.2704 44.0181 60.6418 45.3895C62.0131 46.7608 63.8731 47.5312 65.8125 47.5312H93.2344\"\n        transform=\"scale(0.7)\"\n        stroke=\"#D36CFF\"\n        stroke-linecap=\"round\"\n        stroke-linejoin=\"round\"\n      />\n      <text\n        x=\"50%\"\n        y=\"50%\"\n        text-anchor=\"middle\"\n        dominant-baseline=\"middle\"\n        font-family=\"sans-serif\"\n        font-size=\"14\"\n        fill=\"#D36CFF\"\n      >\n        Form\n      </text>\n      }\n\n      <!-- Subflow node -->\n      @if (node.type === 'subflow') {\n      <path\n        [attr.d]=\"\n          'M 1 ' +\n          node.height / 4 +\n          ' L ' +\n          node.width / 2 +\n          ' 1 L ' +\n          (node.width - 1) +\n          ' ' +\n          node.height / 4 +\n          ' V ' +\n          (node.height * 3) / 4 +\n          ' L ' +\n          node.width / 2 +\n          ' ' +\n          (node.height - 1) +\n          ' L 1 ' +\n          (node.height * 3) / 4 +\n          ' Z'\n        \"\n        fill=\"none\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"1\"\n      ></path>\n      <text\n        [attr.x]=\"node.width / 2\"\n        [attr.y]=\"node.height / 2\"\n        text-anchor=\"middle\"\n        alignment-baseline=\"middle\"\n        font-family=\"sans-serif\"\n        font-size=\"10\"\n        fill=\"#000000\"\n      >\n        <!-- Limit text length -->\n        {{\n          (node.workflowData?.name || \"Subflow\").length > 12\n            ? (node.workflowData?.name || \"Subflow\").substring(0, 10) + \"...\"\n            : node.workflowData?.name || \"Subflow\"\n        }}\n      </text>\n      }\n\n      <!-- Connection points for this node -->\n      @for (point of node.connectionPoints || []; track point.id) { @if\n      (isConnectionPointVisible(node.id)) {\n      <use\n        [attr.href]=\"'#connection-point-template'\"\n        [attr.x]=\"point.x\"\n        [attr.y]=\"point.y\"\n        [attr.id]=\"point.id\"\n        (mousedown)=\"startConnectionDrag($event, point, swimlane.order)\"\n      />\n      } }\n    </g>\n    <!-- A transparent hover area for improved hover detection -->\n    <rect\n      [attr.x]=\"node.x - 10\"\n      [attr.y]=\"node.y + 40 - 10\"\n      [attr.width]=\"node.width + 20\"\n      [attr.height]=\"node.height + 20\"\n      fill=\"transparent\"\n      (mouseover)=\"showConnectionPoints(node.id, swimlane.order)\"\n      (mouseout)=\"hideConnectionPoints(node.id)\"\n      style=\"pointer-events: none\"\n    />\n    } }\n\n    <!-- Connections -->\n    @for (connection of state.connections; track connection.id) {\n    <g class=\"connection-element\">\n      <path\n        [attr.d]=\"getConnectionPathForSavedConnection(connection)\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"2\"\n        fill=\"none\"\n        marker-end=\"url(#arrowhead)\"\n      ></path>\n\n      <!-- Connection Label -->\n      @if (connection.sourceNodeId && connection.targetNodeId) {\n      <foreignObject\n        [attr.x]=\"getLabelPosition(connection).x\"\n        [attr.y]=\"getLabelPosition(connection).y\"\n        width=\"150\"\n        height=\"40\"\n        style=\"overflow: visible; pointer-events: all\"\n        [attr.transform]=\"'translate(-10, -10)'\"\n      >\n        <wf-label-editor\n          [label]=\"connection.label || 'New Action'\"\n          [x]=\"0\"\n          [y]=\"0\"\n          [isConnection]=\"true\"\n          (labelChange)=\"saveConnectionLabel(connection, $event)\"\n        />\n      </foreignObject>\n      }\n    </g>\n    }\n\n    <!-- Connection preview line -->\n    @if (state.isConnectionDragging()) {\n    <g>\n      <path\n        [attr.d]=\"getConnectionPath()\"\n        stroke=\"#D36CFF\"\n        stroke-width=\"2\"\n        stroke-dasharray=\"5,5\"\n        fill=\"none\"\n      ></path>\n    </g>\n    }\n  </svg>\n\n  <div\n    *ngIf=\"popupVisible\"\n    [style.position]=\"'absolute'\"\n    [style.left.px]=\"popupX\"\n    [style.top.px]=\"popupY\"\n  >\n    <verben-pop-Up\n      [dropdownOpen]=\"true\"\n      [customStyles]=\"{ 'z-index': '99' }\"\n      [enableMouseLeave]=\"false\"\n    >\n      <div dropdown-trigger style=\"display: none\">\n        <!-- Hidden trigger element -->\n      </div>\n      <div\n        class=\"p-3 bg-white border border-gray-200 rounded shadow-md\"\n        dropdown-content\n      >\n        <h4 class=\"mb-2 font-medium\">Create Connection</h4>\n        <div class=\"flex flex-col gap-2\">\n          <ng-container *ngFor=\"let type of allowedNodeTypes\">\n            <button\n              class=\"px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50\"\n              (click)=\"createNodeConnection(type)\"\n            >\n              Create {{ type | titlecase }}\n            </button>\n          </ng-container>\n          <button\n            class=\"px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50\"\n            (click)=\"hideConnectionPopup()\"\n          >\n            Cancel\n          </button>\n        </div>\n      </div>\n    </verben-pop-Up>\n  </div>\n\n  <div\n    *ngIf=\"showStartNodeFormPopup\"\n    [style.position]=\"'absolute'\"\n    [style.left.px]=\"startNodeFormPopupX\"\n    [style.top.px]=\"startNodeFormPopupY\"\n  >\n    <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n      <div dropdown-trigger style=\"display: none\">\n        <!-- Hidden trigger element -->\n      </div>\n      <div\n        class=\"p-3 bg-white border border-gray-200 rounded shadow-md w-64\"\n        dropdown-content\n        style=\"background-color: white; z-index: 1000\"\n      >\n        <h4 class=\"mb-2 font-medium\">Select Workflow Form</h4>\n        <div *ngIf=\"isLoadingStartNodeForms\" class=\"text-center py-2\">\n          Loading forms...\n        </div>\n        <div *ngIf=\"!isLoadingStartNodeForms\" class=\"max-h-48 overflow-y-auto\">\n          <div class=\"mb-2\">\n            <button\n              class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n              (click)=\"selectStartNodeForm(null)\"\n            >\n              Clear form selection\n            </button>\n          </div>\n          <div *ngFor=\"let form of startNodeFormsList\" class=\"mb-1\">\n            <button\n              class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n              (click)=\"selectStartNodeForm(form)\"\n            >\n              {{ form.Name }}\n            </button>\n          </div>\n          <div\n            *ngIf=\"startNodeFormsList.length === 0\"\n            class=\"text-center py-2 text-gray-500\"\n          >\n            No forms available\n          </div>\n        </div>\n      </div>\n    </verben-pop-Up>\n  </div>\n\n  <div\n    *ngIf=\"showSubflowPopup\"\n    [style.position]=\"'absolute'\"\n    [style.left.px]=\"subflowPopupX\"\n    [style.top.px]=\"subflowPopupY\"\n  >\n    <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n      <div dropdown-trigger style=\"display: none\">\n        <!-- Hidden trigger element -->\n      </div>\n      <div\n        class=\"p-3 bg-white border border-gray-200 rounded shadow-md w-64\"\n        dropdown-content\n        style=\"background-color: white; z-index: 1000\"\n      >\n        <h4 class=\"mb-2 font-medium\">Select Workflow</h4>\n        <div *ngIf=\"isLoadingWorkflows\" class=\"text-center py-2\">\n          Loading workflows...\n        </div>\n        <div *ngIf=\"!isLoadingWorkflows\" class=\"max-h-48 overflow-y-auto\">\n          <div *ngFor=\"let workflow of workflowsList\" class=\"mb-1\">\n            <button\n              class=\"w-full px-3 py-2 bg-white border border-gray-200 rounded text-sm hover:bg-gray-50 text-left\"\n              (click)=\"selectSubflowWorkflow(workflow)\"\n            >\n              {{ workflow.Name }}\n            </button>\n          </div>\n          <div\n            *ngIf=\"workflowsList.length === 0\"\n            class=\"text-center py-2 text-gray-500\"\n          >\n            No workflows available\n          </div>\n        </div>\n      </div>\n    </verben-pop-Up>\n  </div>\n\n  <lib-conditions-popup\n    [visible]=\"showDecisionConditionDialog\"\n    [decisionNodeId]=\"activeDecisionNodeId\"\n    [newConnectionId]=\"activeConnectionId\"\n    [popupX]=\"decisionConditionPopupX\"\n    [popupY]=\"decisionConditionPopupY\"\n    (closed)=\"onDecisionConditionCancelled()\"\n    (saved)=\"onDecisionConditionSaved($event)\"\n  ></lib-conditions-popup>\n\n  <!-- <lib-decision-popup\n    [visible]=\"showConditionsDialog\"\n    [decisionNodeId]=\"activeDecisionNodeId\"\n    [popupX]=\"decisionConditionPopupX\"\n    [popupY]=\"decisionConditionPopupY\"\n    (closed)=\"onDecisionConditionCancelled()\"\n  ></lib-decision-popup> -->\n\n  <lib-stage-dialog\n    [visible]=\"showStageDialogLocal\"\n    [stageData]=\"activeStageData || {}\"\n    (closed)=\"onStageDialogClosed()\"\n    (saved)=\"onStageDialogSaved($event)\"\n  ></lib-stage-dialog>\n</div>\n", styles: [".canvas-container{flex:1;overflow:auto;background-color:#fff}.designer-canvas{min-width:100%;min-height:100%;cursor:default}.designer-canvas:focus{outline:none}.edit-swimlane-button{cursor:pointer}.edit-swimlane-button:hover rect{fill:#ddd6fe}.decision-condition-icon{cursor:pointer}.decision-condition-icon:hover path{fill:#c084fc}.swimlane-label{z-index:10;cursor:default}.plus-icon:hover{fill:#d36cff}.swimlane-container{pointer-events:none}.swimlane-container>*{pointer-events:auto}.node-element{z-index:10}.connection-element{z-index:5}\n"] }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }, { type: WorkflowDataService }], propDecorators: { selectedTool: [{
                type: Input
            }], clickedPosition: [{
                type: Output
            }], subflowSelected: [{
                type: Output
            }], showStageDialog: [{
                type: Output
            }], stagePropertiesUpdated: [{
                type: Output
            }], canvasRef: [{
                type: ViewChild,
                args: ['canvas', { static: true }]
            }], onWindowMouseUp: [{
                type: HostListener,
                args: ['window:mouseup', ['$event']]
            }], onDocumentClick: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

class SwimlaneDialogComponent {
    dataService;
    swimlaneService;
    visible = false;
    swimlaneData = null;
    closed = new EventEmitter();
    created = new EventEmitter();
    searchQuery = '';
    workflowName = '';
    // Track selected tags in a separate array
    selectedTagNames = [];
    // Tags list
    tags = [];
    constructor(dataService, swimlaneService) {
        this.dataService = dataService;
        this.swimlaneService = swimlaneService;
    }
    ngOnInit() {
        console.log('Swimlane dialog initialized with data:', this.swimlaneData);
        // Reset form fields when dialog opens
        this.selectedTagNames = [];
        this.workflowName = '';
        this.searchQuery = '';
        // Load tags from the data service
        this.loadTags();
        // If editing an existing swimlane, populate the form
        if (this.swimlaneData) {
            this.workflowName = this.swimlaneData.name;
            // Set selected tags
            this.selectedTagNames = this.swimlaneData.tags.map((tag) => tag.Name);
        }
    }
    /**
     * Load tags from the data service
     */
    loadTags() {
        this.dataService.getTags().then((data) => {
            this.tags = data.Result;
        });
    }
    get allSelected() {
        return (this.tags.length > 0 && this.selectedTagNames.length === this.tags.length);
    }
    set allSelected(value) {
        if (value) {
            this.selectedTagNames = this.tags.map((tag) => tag.Name);
        }
        else {
            this.selectedTagNames = [];
        }
    }
    get filteredTags() {
        if (!this.searchQuery) {
            return this.tags;
        }
        return this.tags.filter((tag) => tag.Name.toLowerCase().includes(this.searchQuery.toLowerCase()));
    }
    isTagSelected(tagName) {
        return this.selectedTagNames.includes(tagName);
    }
    toggleTagSelection(tagName) {
        const index = this.selectedTagNames.indexOf(tagName);
        if (index > -1) {
            this.selectedTagNames.splice(index, 1);
        }
        else {
            this.selectedTagNames.push(tagName);
        }
    }
    onDialogClose(eventData) {
        console.log('Dialog closed, received data:', eventData);
        this.searchQuery = '';
        this.workflowName = '';
        this.selectedTagNames = [];
        this.closed.emit();
    }
    onDialogOpen(eventData) {
        console.log('Dialog opened, received data:', eventData);
    }
    applySelection() {
        // Validate name
        if (!this.workflowName || this.workflowName.trim() === '') {
            console.error('Swimlane name cannot be empty');
            return;
        }
        const selectedTags = this.tags.filter((tag) => this.selectedTagNames.includes(tag.Name));
        console.log('Submitting swimlane data:', {
            name: this.workflowName,
            tags: selectedTags,
        });
        this.created.emit({
            tags: selectedTags,
            name: this.workflowName,
        });
        // Reset form fields when dialog opens
        this.selectedTagNames = [];
        this.workflowName = '';
        this.searchQuery = '';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneDialogComponent, deps: [{ token: WorkflowDataService }, { token: SwimlaneService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: SwimlaneDialogComponent, selector: "lib-swimlane-dialog", inputs: { visible: "visible", swimlaneData: "swimlaneData" }, outputs: { closed: "closed", created: "created" }, ngImport: i0, template: "<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [size]=\"'medium'\"\n  [mode]=\"'drawer'\"\n  [disableFooter]=\"false\"\n  [isVisible]=\"visible\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [footerTemplate]=\"footerTemplate\"\n  (openModal)=\"onDialogOpen($event)\"\n  (closeModal)=\"onDialogClose($event)\"\n>\n</verben-dialogue>\n\n<ng-template #headerTemplate>\n  <div\n    class=\"flex items-center justify-between p-3 text-xs border-b-4 border-[#FFE681]\"\n  >\n    <button class=\"mr-4\" type=\"button\" (click)=\"onDialogClose($event)\">\n      <span\n        class=\"block w-2.5 h-2.5 border-t border-l border-[#3E3E3E]/70 transform -rotate-45\"\n      ></span>\n    </button>\n    <div class=\"text-center\">\n      <h2 class=\"text-sm font-medium\">Select Tags</h2>\n      <span class=\"text-xs text-[#3E3E3E]/70\"\n        >{{ this.selectedTagNames.length }}/{{ tags.length }}</span\n      >\n    </div>\n    <span\n      class=\"font-medium cursor-pointer text-[#3E3E3E]/70\"\n      (click)=\"applySelection()\"\n      >Create</span\n    >\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div class=\"p-3\">\n    <div class=\"mb-4 space-y-4\">\n      <input\n        type=\"text\"\n        placeholder=\"Enter Name\"\n        class=\"w-full px-4 py-2 rounded-lg border border-[#E7C10B] outline-none\"\n        [(ngModel)]=\"workflowName\"\n      />\n\n      <input\n        type=\"search\"\n        placeholder=\"Filter Tags\"\n        class=\"w-full px-4 py-2 rounded-lg border border-[#E7C10B] outline-none\"\n        [(ngModel)]=\"searchQuery\"\n      />\n    </div>\n\n    <div class=\"\">\n      <div class=\"py-3\">\n        <label class=\"flex items-center\">\n          <input type=\"checkbox\" class=\"mr-3\" [(ngModel)]=\"allSelected\" />\n          <span class=\"text-sm\">Select All</span>\n        </label>\n      </div>\n\n      <div *ngFor=\"let tag of filteredTags\" class=\"py-3\">\n        <label class=\"flex items-center\">\n          <input\n            type=\"checkbox\"\n            class=\"mr-3\"\n            [checked]=\"isTagSelected(tag.Name)\"\n            (change)=\"toggleTagSelection(tag.Name)\"\n          />\n          <span class=\"text-sm\">{{ tag.Name }}</span>\n          <span *ngIf=\"!tag.IsOptional\" class=\"ml-2 text-xs text-red-500\"\n            >(Required)</span\n          >\n        </label>\n      </div>\n    </div>\n  </div>\n</ng-template>\n\n<ng-template #footerTemplate>\n  <!-- <div class=\"flex justify-end p-3 border-t border-gray-200\">\n    <button\n      class=\"px-4 py-2 mr-2 bg-white border border-gray-200 rounded text-sm font-medium\"\n      (click)=\"onDialogClose($event)\"\n    >\n      Cancel\n    </button>\n    <button\n      class=\"px-4 py-2 bg-blue-600 text-white rounded text-sm font-medium\"\n      (click)=\"applySelection()\"\n    >\n      Apply\n    </button>\n  </div> -->\n</ng-template>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.VerbenDialogueComponent, selector: "verben-dialogue", inputs: ["dialogueWidth", "headerTemplate", "bodyTemplate", "footerTemplate", "showCloseIcon", "dismissOutsideClick", "closeOnEscape", "isVisible", "size", "backdropColor", "customClass", "disableFooter", "margin", "padding", "borderRadius", "dialogueBgColor", "width", "closeIconClass", "boxShadow", "enableTransition", "modalData", "mode", "position", "drawerWidth"], outputs: ["openModal", "closeModal"] }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-swimlane-dialog', template: "<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [size]=\"'medium'\"\n  [mode]=\"'drawer'\"\n  [disableFooter]=\"false\"\n  [isVisible]=\"visible\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [footerTemplate]=\"footerTemplate\"\n  (openModal)=\"onDialogOpen($event)\"\n  (closeModal)=\"onDialogClose($event)\"\n>\n</verben-dialogue>\n\n<ng-template #headerTemplate>\n  <div\n    class=\"flex items-center justify-between p-3 text-xs border-b-4 border-[#FFE681]\"\n  >\n    <button class=\"mr-4\" type=\"button\" (click)=\"onDialogClose($event)\">\n      <span\n        class=\"block w-2.5 h-2.5 border-t border-l border-[#3E3E3E]/70 transform -rotate-45\"\n      ></span>\n    </button>\n    <div class=\"text-center\">\n      <h2 class=\"text-sm font-medium\">Select Tags</h2>\n      <span class=\"text-xs text-[#3E3E3E]/70\"\n        >{{ this.selectedTagNames.length }}/{{ tags.length }}</span\n      >\n    </div>\n    <span\n      class=\"font-medium cursor-pointer text-[#3E3E3E]/70\"\n      (click)=\"applySelection()\"\n      >Create</span\n    >\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div class=\"p-3\">\n    <div class=\"mb-4 space-y-4\">\n      <input\n        type=\"text\"\n        placeholder=\"Enter Name\"\n        class=\"w-full px-4 py-2 rounded-lg border border-[#E7C10B] outline-none\"\n        [(ngModel)]=\"workflowName\"\n      />\n\n      <input\n        type=\"search\"\n        placeholder=\"Filter Tags\"\n        class=\"w-full px-4 py-2 rounded-lg border border-[#E7C10B] outline-none\"\n        [(ngModel)]=\"searchQuery\"\n      />\n    </div>\n\n    <div class=\"\">\n      <div class=\"py-3\">\n        <label class=\"flex items-center\">\n          <input type=\"checkbox\" class=\"mr-3\" [(ngModel)]=\"allSelected\" />\n          <span class=\"text-sm\">Select All</span>\n        </label>\n      </div>\n\n      <div *ngFor=\"let tag of filteredTags\" class=\"py-3\">\n        <label class=\"flex items-center\">\n          <input\n            type=\"checkbox\"\n            class=\"mr-3\"\n            [checked]=\"isTagSelected(tag.Name)\"\n            (change)=\"toggleTagSelection(tag.Name)\"\n          />\n          <span class=\"text-sm\">{{ tag.Name }}</span>\n          <span *ngIf=\"!tag.IsOptional\" class=\"ml-2 text-xs text-red-500\"\n            >(Required)</span\n          >\n        </label>\n      </div>\n    </div>\n  </div>\n</ng-template>\n\n<ng-template #footerTemplate>\n  <!-- <div class=\"flex justify-end p-3 border-t border-gray-200\">\n    <button\n      class=\"px-4 py-2 mr-2 bg-white border border-gray-200 rounded text-sm font-medium\"\n      (click)=\"onDialogClose($event)\"\n    >\n      Cancel\n    </button>\n    <button\n      class=\"px-4 py-2 bg-blue-600 text-white rounded text-sm font-medium\"\n      (click)=\"applySelection()\"\n    >\n      Apply\n    </button>\n  </div> -->\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: WorkflowDataService }, { type: SwimlaneService }], propDecorators: { visible: [{
                type: Input
            }], swimlaneData: [{
                type: Input
            }], closed: [{
                type: Output
            }], created: [{
                type: Output
            }] } });

class WorkflowDesignerComponent {
    state;
    dataService;
    canvasRef;
    workflowCode = null;
    // Currently selected toolWOR-N9H5CL
    selectedTool = null;
    showSwimlaneDialog = false;
    // New properties for stage dialog
    showStageDialog = false;
    pendingStagePosition = null;
    pendingStageData = {};
    editingSwimlaneIndex = null;
    isCreatingStageFromConnection = false;
    pendingConnectionSourcePoint = null;
    pendingConnectionSourceSwimlaneIndex = null;
    isLoading = false;
    isSaving = false;
    constructor(state, dataService) {
        this.state = state;
        this.dataService = dataService;
    }
    ngOnInit() {
        // Load workflow data if code is provided
        if (this.workflowCode) {
            this.loadWorkflow(this.workflowCode);
        }
    }
    saveWorkflow() {
        if (this.isSaving)
            return;
        this.isSaving = true;
        // Transform the UI model to the API model
        const workflowModel = this.state.transformToWorkflowModel();
        if (workflowModel) {
            // Save to the backend
            this.dataService
                .saveWorkflows([workflowModel])
                .then((response) => {
                console.log('Workflow saved successfully:', response);
                // If the API returns an updated workflow, we might want to reload it
                const updatedWorkflow = response[0];
                if (updatedWorkflow) {
                    this.state.setWorkflowId(updatedWorkflow.Code);
                    this.parseWorkflowData(updatedWorkflow);
                }
                this.isSaving = false;
            })
                .catch((error) => {
                console.error('Error saving workflow:', error);
                this.isSaving = false;
                // Handle error - show a notification, etc.
            });
        }
    }
    loadWorkflow(code) {
        this.isLoading = true;
        this.dataService
            .getWorkflowWithParam(code)
            .then((response) => {
            if (response && response.Result) {
                // Store the workflow ID
                const wf = response.Result[0];
                this.state.setWorkflowId(wf.Code);
                this.parseWorkflowData(wf);
            }
            this.isLoading = false;
        })
            .catch((error) => {
            console.error('Error loading workflow:', error);
            this.isLoading = false;
        });
    }
    // Method to parse workflow data from API and populate the designer
    parseWorkflowData(workflow) {
        // Store the complete workflow
        this.state.workflow = workflow;
        // Clear existing state
        this.state.swimlanes = [];
        this.state.connections = [];
        this.state.swimlaneRecord = {};
        this.state.stageRecord = {};
        this.state.actionRecord = {};
        // Set workflow form if exists
        if (workflow.Form) {
            this.state.setWorkflowForm(workflow.Form, workflow.FormName || 'Workflow Form');
        }
        // Store the workflow ID
        this.state.setWorkflowId(workflow.Code);
        // Process swimlanes first
        if (workflow.Lanes && workflow.Lanes.length) {
            workflow.Lanes.sort((a, b) => a.Position - b.Position).forEach((lane) => {
                // Store original lane in record
                this.state.swimlaneRecord[lane.Code] = lane;
                // Add swimlane to UI model with the original ID
                const swimlane = {
                    order: lane.Position,
                    label: lane.Name || `Lane ${lane.Position}`,
                    tags: lane.Tags || [],
                    nodes: [],
                    id: lane.Code, // Store the original ID
                };
                this.state.swimlanes.push(swimlane);
                // Register loaded object
                this.state.registerLoadedObject(lane.Id, lane.Code);
            });
        }
        // Process stages
        if (workflow.Stages && workflow.Stages.length) {
            workflow.Stages.forEach((stage) => {
                // Store original stage in record
                this.state.stageRecord[stage.Code] = stage;
                // Find swimlane index by SwimLane ID
                const swimlaneIndex = this.state.swimlanes.findIndex((lane) => lane.id === stage.SwimLane);
                if (swimlaneIndex !== -1) {
                    const x = stage.Coordinates?.X || 100;
                    const y = stage.Coordinates?.Y || 50;
                    // Create node with original ID
                    const node = {
                        id: stage.Code, // Use original ID
                        type: 'stage',
                        x: x,
                        y: y,
                        width: 169,
                        height: 100,
                        isStartNode: stage.IsEntryPoint,
                        stageData: {
                            Name: stage.Name,
                            Description: stage.Description,
                            Duration: stage.Duration,
                            PassOnRule: stage.PassOnRule,
                            ActorRule: stage.ActorRule,
                            MinNoOfActor: stage.MinNoOfActor,
                            Tags: stage.Tags || [],
                            IsParallel: stage.IsParallel,
                            IsEntryPoint: stage.IsEntryPoint,
                            IsExitPoint: stage.IsExitPoint,
                            Id: stage.Id, // Keep original ID
                            Code: stage.Code,
                            Form: stage.Form,
                            formId: stage.Form,
                        },
                        connectionPoints: [], // Initialize with empty array
                    };
                    // Generate connection points
                    node.connectionPoints = this.state.generateConnectionPoints(node);
                    // Add node to swimlane
                    this.state.swimlanes[swimlaneIndex].nodes =
                        this.state.swimlanes[swimlaneIndex].nodes || [];
                    this.state.swimlanes[swimlaneIndex].nodes.push(node);
                    // If this is a start node, update state
                    if (stage.IsEntryPoint) {
                        this.state.startNodeId = stage.Code;
                    }
                    // Register loaded stage
                    this.state.registerLoadedObject(stage.Id, stage.Code);
                }
            });
        }
        // Process connections/actions
        if (workflow.Actions && workflow.Actions.length) {
            workflow.Actions.forEach((action) => {
                // Store original action in record
                this.state.actionRecord[action.Code] = action;
                // Find source and target nodes
                const sourceNodeInfo = this.state.findNodeById(action.FromStage);
                const targetNodeInfo = this.state.findNodeById(action.ToStage);
                console.log(sourceNodeInfo, targetNodeInfo);
                if (sourceNodeInfo && targetNodeInfo) {
                    // Find suitable connection points
                    // const sourceNode = sourceNodeInfo.node;
                    // const targetNode = targetNodeInfo.node;
                    // const sourcePoint = sourceNode.connectionPoints?.find(
                    //   (p) => p.type === 'right' || p.type === 'bottom'
                    // );
                    // const targetPoint = targetNode.connectionPoints?.find(
                    //   (p) => p.type === 'left' || p.type === 'top'
                    // );
                    const sourceNode = sourceNodeInfo.node;
                    const targetNode = targetNodeInfo.node;
                    let sourcePointId, targetPointId;
                    console.log(action.SourcePointType, action.TargetPointType);
                    if (action.SourcePointType) {
                        // Find a point with matching type
                        const sourcePoint = sourceNode.connectionPoints?.find((p) => p.type === action.SourcePointType?.toLowerCase());
                        sourcePointId = sourcePoint?.id;
                    }
                    else {
                        // Fallback to finding a suitable point
                        const sourcePoint = sourceNode.connectionPoints?.find((p) => p.type === 'right' || p.type === 'bottom');
                        sourcePointId = sourcePoint?.id;
                    }
                    if (action.TargetPointType) {
                        // Find a point with matching type
                        const targetPoint = targetNode.connectionPoints?.find((p) => p.type === action.TargetPointType?.toLowerCase());
                        targetPointId = targetPoint?.id;
                    }
                    else {
                        // Fallback to finding a suitable point
                        const targetPoint = targetNode.connectionPoints?.find((p) => p.type === 'left' || p.type === 'top');
                        targetPointId = targetPoint?.id;
                    }
                    console.log('Source point:', sourcePointId);
                    console.log('Target point:', targetPointId);
                    if (sourcePointId && targetPointId) {
                        const connection = {
                            id: action.Code, // Use original ID
                            sourceNodeId: action.FromStage,
                            targetNodeId: action.ToStage,
                            sourcePointId: sourcePointId,
                            targetPointId: targetPointId,
                            sourceSwimlaneIndex: sourceNodeInfo.swimlaneIndex,
                            targetSwimlaneIndex: targetNodeInfo.swimlaneIndex,
                            condition: action.PassOnRule || '',
                            label: action.Name || '',
                        };
                        this.state.connections.push(connection);
                        // Register loaded action
                        this.state.registerLoadedObject(action.Id, action.Code);
                    }
                }
            });
        }
    }
    // Helper method to find swimlane index by Lane ID
    findSwimlaneIndexByLaneId(laneId) {
        // First check our mapping
        if (this.state.laneIdToIndexMap.has(laneId)) {
            return this.state.laneIdToIndexMap.get(laneId);
        }
        // Fallback to the original logic (for backward compatibility)
        const parts = laneId.split('-');
        if (parts.length > 1) {
            const index = parseInt(parts[1]);
            if (!isNaN(index) && index < this.state.swimlanes.length) {
                return index;
            }
        }
        return -1;
    }
    // Handle tool selection from toolbar
    onToolSelected(tool) {
        // Toggle selection if the same tool is clicked again
        this.selectedTool = this.selectedTool === tool ? null : tool;
        console.log('Selected tool:', this.selectedTool);
    }
    openSwimlaneDialog() {
        console.log(this.editingSwimlaneIndex);
        if (this.editingSwimlaneIndex !== null) {
            console.log(this.state.swimlanes[this.editingSwimlaneIndex]);
        }
        this.showSwimlaneDialog = true;
    }
    onShowStageDialog(event) {
        console.log('Received showStageDialog event:', event);
        this.pendingStagePosition = event.position;
        this.showStageDialog = true;
        // If this is from a connection creation, store that info
        this.isCreatingStageFromConnection = event.isFromConnection;
        // Store the source point data before it gets lost
        if (event.isFromConnection &&
            this.state.draggingConnectionData.sourcePoint) {
            this.pendingConnectionSourcePoint =
                this.state.draggingConnectionData.sourcePoint;
            this.pendingConnectionSourceSwimlaneIndex =
                this.state.draggingConnectionData.sourceSwimlaneIndex ?? null;
            console.log('Stored source point for connection:', this.pendingConnectionSourcePoint);
        }
        console.log('Stage dialog state:', {
            pendingPosition: this.pendingStagePosition,
            isVisible: this.showStageDialog,
        });
    }
    handleCanvasPositionClick(event) {
        console.log(event);
        // Check if this is an edit swimlane event
        if (event.x === -1 &&
            event.y >= 0 &&
            event.y < this.state.swimlanes.length) {
            console.log('Editing swimlane', event.y);
            this.editingSwimlaneIndex = event.y;
            this.openSwimlaneDialog();
            return;
        }
        // Normal canvas click handling
        const swimlaneIndex = Math.floor(event.y / 263);
        switch (this.selectedTool) {
            case 'swimlane':
                console.log('Opening swimlane dialog for new swimlane');
                this.editingSwimlaneIndex = null; // Set to null to indicate creating a new swimlane
                this.openSwimlaneDialog();
                this.selectedTool = null;
                break;
            case 'stage':
                if (swimlaneIndex >= 0 && swimlaneIndex < this.state.swimlanes.length) {
                    console.log(`Adding ${this.selectedTool} to swimlane ${swimlaneIndex}`);
                    // Create the stage directly with default properties
                    const node = this.state.addNode(swimlaneIndex, 'stage', event.x, event.y, { Name: 'New Stage' } // Add default properties
                    );
                    if (node) {
                        // Reset the selected tool after placing a node
                        this.selectedTool = null;
                    }
                }
                break;
            case 'decision':
            case 'form':
                if (swimlaneIndex >= 0 && swimlaneIndex < this.state.swimlanes.length) {
                    console.log(`Adding ${this.selectedTool} to swimlane ${swimlaneIndex}`);
                    const node = this.state.addNode(swimlaneIndex, this.selectedTool, event.x, event.y);
                    if (node) {
                        // Reset the selected tool after placing a node
                        this.selectedTool = null;
                    }
                }
                break;
            case 'subflow':
                if (swimlaneIndex >= 0 && swimlaneIndex < this.state.swimlanes.length) {
                    console.log(`Adding ${this.selectedTool} to swimlane ${swimlaneIndex}`);
                    // Show subflow workflow selection popup
                    this.canvasRef.showSubflowSelectionPopup(event.x, event.y, swimlaneIndex);
                }
                break;
            default:
                break;
        }
    }
    onSwimlaneDialogFilled(event) {
        console.log('Swimlane dialog filled:', event, 'Editing index:', this.editingSwimlaneIndex);
        // Validate that name is not empty
        if (!event.name || event.name.trim() === '') {
            console.error('Swimlane name cannot be empty');
            return;
        }
        if (this.editingSwimlaneIndex !== null) {
            // Update existing swimlane
            console.log('Updating existing swimlane at index:', this.editingSwimlaneIndex);
            this.state.updateSwimlane(this.editingSwimlaneIndex, event.name, event.tags);
        }
        else {
            // Create new swimlane
            console.log('Creating new swimlane');
            this.state.addSwimlane(event.name, event.tags);
        }
        this.showSwimlaneDialog = false;
        this.editingSwimlaneIndex = null;
    }
    onStageDialogSaved(stageData) {
        if (this.canvasRef.activeStageId) {
            // Editing an existing stage
            const nodeInfo = this.state.findNodeById(this.canvasRef.activeStageId);
            if (nodeInfo) {
                // Update the stage data
                nodeInfo.node.stageData = {
                    ...nodeInfo.node.stageData,
                    ...stageData,
                };
                console.log('Updated stage data:', nodeInfo.node.stageData);
            }
            this.canvasRef.activeStageId = null;
        }
        else if (this.pendingStagePosition) {
            if (this.canvasRef.activeStageId) {
                // Editing an existing stage
                const nodeInfo = this.state.findNodeById(this.canvasRef.activeStageId);
                if (nodeInfo) {
                    // Update the stage data
                    nodeInfo.node.stageData = {
                        ...nodeInfo.node.stageData,
                        ...stageData,
                    };
                    console.log('Updated stage data:', nodeInfo.node.stageData);
                }
                this.canvasRef.activeStageId = null;
            }
            else if (this.pendingStagePosition) {
                // Creating a new stage (keep existing logic for this case)
                // ...existing code...
            }
            this.showStageDialog = false;
        }
        this.showStageDialog = false;
    }
    onSubflowSelected() {
        // Reset the selected tool after placing a subflow node
        this.selectedTool = null;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerComponent, deps: [{ token: WorkflowDesignerState }, { token: WorkflowDataService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: WorkflowDesignerComponent, selector: "lib-workflow-designer", inputs: { workflowCode: "workflowCode" }, viewQueries: [{ propertyName: "canvasRef", first: true, predicate: ["canvasRef"], descendants: true }], ngImport: i0, template: "<div class=\"workflow-designer\">\n  <div class=\"workflow-header\">\n    <h1>{{ state.workflow?.Name }}</h1>\n  </div>\n\n  <!-- Toolbar Component -->\n  <lib-designer-toolbar\n    [selectedTool]=\"selectedTool\"\n    [isSaving]=\"isSaving\"\n    (toolSelected)=\"onToolSelected($event)\"\n    (saveWorkflow)=\"saveWorkflow()\"\n  >\n  </lib-designer-toolbar>\n\n  <!-- Show loading indicator if needed -->\n  <div *ngIf=\"isLoading\" class=\"loading-overlay\">\n    <div class=\"loading-spinner\"></div>\n    <div class=\"loading-text\">Loading workflow...</div>\n  </div>\n\n  <!-- Canvas Component -->\n  <lib-designer-canvas\n    [selectedTool]=\"selectedTool\"\n    (clickedPosition)=\"handleCanvasPositionClick($event)\"\n    (subflowSelected)=\"onSubflowSelected()\"\n    (showStageDialog)=\"onShowStageDialog($event)\"\n    #canvasRef\n  >\n  </lib-designer-canvas>\n\n  <lib-swimlane-dialog\n    [visible]=\"showSwimlaneDialog\"\n    [swimlaneData]=\"\n      editingSwimlaneIndex !== null\n        ? {\n            name: state.swimlanes[editingSwimlaneIndex].label,\n            tags: state.swimlanes[editingSwimlaneIndex].tags\n          }\n        : null\n    \"\n    (created)=\"onSwimlaneDialogFilled($event)\"\n    (closed)=\"showSwimlaneDialog = false\"\n  ></lib-swimlane-dialog>\n\n  <lib-stage-dialog\n    [visible]=\"showStageDialog\"\n    [stageData]=\"pendingStageData\"\n    (closed)=\"showStageDialog = false\"\n    (saved)=\"onStageDialogSaved($event)\"\n  ></lib-stage-dialog>\n</div>\n", styles: [".workflow-designer{display:flex;flex-direction:column;height:100vh;background-color:#f8fafc}.workflow-header{padding:1rem;background-color:#fff;border-bottom:1px solid #e2e8f0;text-align:center}.workflow-header h1{font-size:1.25rem;font-weight:600;color:#334155;margin:0}.loading-overlay{position:absolute;inset:0;background-color:#ffffffb3;display:flex;flex-direction:column;justify-content:center;align-items:center;z-index:1000}.loading-spinner{border:4px solid #f3f3f3;border-top:4px solid #d8b4fe;border-radius:50%;width:40px;height:40px;animation:spin 1s linear infinite}.loading-text{margin-top:1rem;font-size:1rem;color:#7e22ce}@keyframes spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: DesignerToolbarComponent, selector: "lib-designer-toolbar", inputs: ["selectedTool", "isSaving"], outputs: ["toolSelected", "saveWorkflow"] }, { kind: "component", type: DesignerCanvasComponent, selector: "lib-designer-canvas", inputs: ["selectedTool"], outputs: ["clickedPosition", "subflowSelected", "showStageDialog", "stagePropertiesUpdated"] }, { kind: "component", type: SwimlaneDialogComponent, selector: "lib-swimlane-dialog", inputs: ["visible", "swimlaneData"], outputs: ["closed", "created"] }, { kind: "component", type: StageDialogComponent, selector: "lib-stage-dialog", inputs: ["visible", "stageData"], outputs: ["closed", "saved"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-workflow-designer', template: "<div class=\"workflow-designer\">\n  <div class=\"workflow-header\">\n    <h1>{{ state.workflow?.Name }}</h1>\n  </div>\n\n  <!-- Toolbar Component -->\n  <lib-designer-toolbar\n    [selectedTool]=\"selectedTool\"\n    [isSaving]=\"isSaving\"\n    (toolSelected)=\"onToolSelected($event)\"\n    (saveWorkflow)=\"saveWorkflow()\"\n  >\n  </lib-designer-toolbar>\n\n  <!-- Show loading indicator if needed -->\n  <div *ngIf=\"isLoading\" class=\"loading-overlay\">\n    <div class=\"loading-spinner\"></div>\n    <div class=\"loading-text\">Loading workflow...</div>\n  </div>\n\n  <!-- Canvas Component -->\n  <lib-designer-canvas\n    [selectedTool]=\"selectedTool\"\n    (clickedPosition)=\"handleCanvasPositionClick($event)\"\n    (subflowSelected)=\"onSubflowSelected()\"\n    (showStageDialog)=\"onShowStageDialog($event)\"\n    #canvasRef\n  >\n  </lib-designer-canvas>\n\n  <lib-swimlane-dialog\n    [visible]=\"showSwimlaneDialog\"\n    [swimlaneData]=\"\n      editingSwimlaneIndex !== null\n        ? {\n            name: state.swimlanes[editingSwimlaneIndex].label,\n            tags: state.swimlanes[editingSwimlaneIndex].tags\n          }\n        : null\n    \"\n    (created)=\"onSwimlaneDialogFilled($event)\"\n    (closed)=\"showSwimlaneDialog = false\"\n  ></lib-swimlane-dialog>\n\n  <lib-stage-dialog\n    [visible]=\"showStageDialog\"\n    [stageData]=\"pendingStageData\"\n    (closed)=\"showStageDialog = false\"\n    (saved)=\"onStageDialogSaved($event)\"\n  ></lib-stage-dialog>\n</div>\n", styles: [".workflow-designer{display:flex;flex-direction:column;height:100vh;background-color:#f8fafc}.workflow-header{padding:1rem;background-color:#fff;border-bottom:1px solid #e2e8f0;text-align:center}.workflow-header h1{font-size:1.25rem;font-weight:600;color:#334155;margin:0}.loading-overlay{position:absolute;inset:0;background-color:#ffffffb3;display:flex;flex-direction:column;justify-content:center;align-items:center;z-index:1000}.loading-spinner{border:4px solid #f3f3f3;border-top:4px solid #d8b4fe;border-radius:50%;width:40px;height:40px;animation:spin 1s linear infinite}.loading-text{margin-top:1rem;font-size:1rem;color:#7e22ce}@keyframes spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }, { type: WorkflowDataService }], propDecorators: { canvasRef: [{
                type: ViewChild,
                args: ['canvasRef']
            }], workflowCode: [{
                type: Input
            }] } });

let ConnectionService$1 = class ConnectionService {
    state;
    nodeService;
    draggingConnectionData = {};
    // The rules defining which node types can connect to which other node types
    connectionRules = {
        stage: ['stage', 'decision', 'subflow', 'form'],
        decision: ['stage'], // Decisions can only connect to Stages
        form: [],
        subflow: ['stage', 'decision'],
    };
    constructor(state, nodeService) {
        this.state = state;
        this.nodeService = nodeService;
    }
    /**
     * Start a new connection drag operation
     */
    startConnectionDrag(point, swimlaneIndex, globalX, globalY) {
        this.draggingConnectionData = {
            sourcePoint: point,
            sourceSwimlaneIndex: swimlaneIndex,
            startX: globalX,
            startY: globalY,
            currentX: globalX,
            currentY: globalY,
        };
    }
    /**
     * Update the position of the dragging connection
     */
    updateConnectionDrag(currentX, currentY) {
        if (this.draggingConnectionData.sourcePoint) {
            this.draggingConnectionData.currentX = currentX;
            this.draggingConnectionData.currentY = currentY;
        }
    }
    /**
     * End the current connection drag operation
     */
    endConnectionDrag() {
        this.draggingConnectionData = {};
    }
    /**
     * Check if a connection drag is in progress
     */
    isConnectionDragging() {
        return !!this.draggingConnectionData.sourcePoint;
    }
    /**
     * Get the current connection path data for rendering
     */
    getConnectionPathData() {
        if (!this.draggingConnectionData.sourcePoint)
            return null;
        const { sourcePoint, sourceSwimlaneIndex, currentX, currentY } = this.draggingConnectionData;
        const nodeInfo = this.nodeService.findNodeById(sourcePoint.nodeId);
        if (!nodeInfo || sourceSwimlaneIndex === undefined)
            return null;
        const node = nodeInfo.node;
        // Calculate start point in global coordinates
        const startX = node.x + sourcePoint.x;
        const startY = node.y + sourcePoint.y + (sourceSwimlaneIndex * 263 + 40); // Add swimlane offset
        return {
            startX,
            startY,
            endX: currentX ?? startX,
            endY: currentY ?? startY,
            sourceSwimlaneIndex,
        };
    }
    /**
     * Create a new connection between nodes
     */
    createConnection(targetNodeId, targetPointId, targetSwimlaneIndex) {
        const { sourcePoint, sourceSwimlaneIndex } = this.draggingConnectionData;
        if (!sourcePoint || sourceSwimlaneIndex === undefined) {
            console.error('Missing source data for connection');
            return null;
        }
        const connection = {
            id: `conn-${Date.now()}-${Math.floor(Math.random() * 1000)}`,
            sourceNodeId: sourcePoint.nodeId,
            targetNodeId: targetNodeId,
            sourcePointId: sourcePoint.id,
            targetPointId: targetPointId,
            sourceSwimlaneIndex: sourceSwimlaneIndex,
            targetSwimlaneIndex: targetSwimlaneIndex,
            label: '', // Default label, can be set later
        };
        // Add the connection to the state
        this.state.connections.push(connection);
        return connection;
    }
    /**
     * Get the path data for rendering a saved connection
     */
    getConnectionData(connection) {
        const sourceNodeInfo = this.nodeService.findNodeById(connection.sourceNodeId);
        const targetNodeInfo = this.nodeService.findNodeById(connection.targetNodeId);
        if (!sourceNodeInfo || !targetNodeInfo) {
            return null;
        }
        const sourceNode = sourceNodeInfo.node;
        const targetNode = targetNodeInfo.node;
        // Find connection points
        const sourcePoint = sourceNode.connectionPoints?.find((p) => p.id === connection.sourcePointId);
        const targetPoint = targetNode.connectionPoints?.find((p) => p.id === connection.targetPointId);
        if (!sourcePoint || !targetPoint) {
            return null;
        }
        // Calculate global coordinates
        const startX = sourceNode.x + sourcePoint.x;
        const startY = sourceNode.y +
            sourcePoint.y +
            (connection.sourceSwimlaneIndex * 263 + 40);
        const endX = targetNode.x + targetPoint.x;
        const endY = targetNode.y +
            targetPoint.y +
            (connection.targetSwimlaneIndex * 263 + 40);
        return {
            startX,
            startY,
            endX,
            endY,
            sourceSwimlaneIndex: connection.sourceSwimlaneIndex,
            targetSwimlaneIndex: connection.targetSwimlaneIndex,
        };
    }
    /**
     * Calculate a path for orthogonal connection rendering
     */
    getOrthogonalPath(startX, startY, endX, endY, pointType) {
        // Determine initial direction based on connection point type
        let path = '';
        // For side points (left/right), start with horizontal line
        if (pointType === 'left' || pointType === 'right') {
            // Calculate horizontal distance
            const horizontalDist = endX - startX;
            // If the end point is very close horizontally, use a simple 3-segment path
            if (Math.abs(horizontalDist) < 30) {
                const midY = (startY + endY) / 2;
                path = `M ${startX} ${startY} H ${endX} V ${midY} V ${endY}`;
            }
            // Otherwise, create a path with horizontal segment first, then vertical, then horizontal
            else {
                path = `M ${startX} ${startY} H ${startX + horizontalDist / 2} V ${endY} H ${endX}`;
            }
        }
        // For top/bottom points, start with vertical line
        else if (pointType === 'top' || pointType === 'bottom') {
            // Calculate vertical distance
            const verticalDist = endY - startY;
            // If the end point is very close vertically, use a simple 3-segment path
            if (Math.abs(verticalDist) < 30) {
                const midX = (startX + endX) / 2;
                path = `M ${startX} ${startY} V ${endY} H ${midX} H ${endX}`;
            }
            // Otherwise, create a path with vertical segment first, then horizontal, then vertical
            else {
                path = `M ${startX} ${startY} V ${startY + verticalDist / 2} H ${endX} V ${endY}`;
            }
        }
        return path;
    }
    /**
     * Check if a connection is allowed between node types
     */
    canConnect(sourceNodeType, targetNodeType) {
        return (this.connectionRules[sourceNodeType]?.includes(targetNodeType) || false);
    }
    /**
     * Get allowed node types for the current dragging connection
     */
    getAllowedTargetNodeTypes() {
        if (!this.draggingConnectionData.sourcePoint) {
            return [];
        }
        const sourceNodeInfo = this.nodeService.findNodeById(this.draggingConnectionData.sourcePoint.nodeId);
        if (!sourceNodeInfo) {
            return [];
        }
        const sourceNodeType = sourceNodeInfo.node.type;
        return this.connectionRules[sourceNodeType] || [];
    }
    /**
     * Delete a connection by ID
     */
    deleteConnection(connectionId) {
        const index = this.state.connections.findIndex((conn) => conn.id === connectionId);
        if (index === -1)
            return false;
        this.state.connections.splice(index, 1);
        return true;
    }
    /**
     * Delete all connections associated with a node
     */
    deleteConnectionsForNode(nodeId) {
        this.state.connections = this.state.connections.filter((conn) => conn.sourceNodeId !== nodeId && conn.targetNodeId !== nodeId);
    }
    /**
     * Get the current connection drag data
     */
    getConnectionDragData() {
        return this.draggingConnectionData;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionService, deps: [{ token: WorkflowDesignerState }, { token: NodeManagementService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionService, providedIn: 'root' });
};
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionService$1, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }, { type: NodeManagementService }] });

class TransformerService {
    state;
    swimlaneService;
    nodeService;
    connectionService;
    // Map to track loaded objects
    loadedObjectIds = {}; // Format: { id: code }
    constructor(state, swimlaneService, nodeService, connectionService) {
        this.state = state;
        this.swimlaneService = swimlaneService;
        this.nodeService = nodeService;
        this.connectionService = connectionService;
    }
    /**
     * Transform the UI model to a Workflow API model
     */
    transformToWorkflowModel() {
        // Create base workflow object
        const workflow = {
            // BaseModel properties
            Id: this.wasLoadedFromApi(this.state.workflowId || '')
                ? this.state.workflowId || ''
                : '',
            Code: this.getCodeForObject(this.state.workflowId || ''),
            TenantId: '',
            id: this.wasLoadedFromApi(this.state.workflowId || '')
                ? this.state.workflowId || ''
                : '',
            ServiceName: '',
            CreatedAt: new Date(),
            UpdatedAt: new Date(),
            DataState: this.wasLoadedFromApi(this.state.workflowId || '')
                ? ObjectState.Changed
                : ObjectState.New,
            // Workflow specific properties
            Name: 'New Workflow', // Default name
            Description: '', // Default description
            StageEntryRule: '',
            Form: this.state.workflowFormId || undefined,
            AssignmentType: TaskAssignmentType.AutoRoute,
            Operation: '',
            Status: Status.Active,
            Actions: [],
            Lanes: [],
            Stages: [],
        };
        // Transform swimlanes to SwimLane[]
        workflow.Lanes = this.state.swimlanes.map((swimlane, index) => {
            const laneId = `lane-${index}`;
            return {
                // BaseModel properties
                Id: '',
                Code: '',
                TenantId: '',
                id: laneId,
                ServiceName: '',
                CreatedAt: new Date(),
                UpdatedAt: new Date(),
                DataState: ObjectState.New,
                // SwimLane specific properties
                Workflow: workflow.Id,
                Tags: swimlane.tags || [],
                Position: swimlane.order,
                Coordinates: { X: 0, Y: swimlane.order * 263 },
                Size: { Width: 3000, Height: 263 },
            };
        });
        // Transform nodes to WorkflowStage[]
        const stages = [];
        this.state.swimlanes.forEach((swimlane, swimlaneIndex) => {
            swimlane.nodes?.forEach((node) => {
                if (node.type === 'stage') {
                    // Create a stage from the node
                    const stage = {
                        // BaseModel properties
                        Id: node.id,
                        Code: this.getCodeForObject(node.id),
                        TenantId: '',
                        id: node.id,
                        ServiceName: '',
                        CreatedAt: new Date(),
                        UpdatedAt: new Date(),
                        DataState: this.wasLoadedFromApi(node.id)
                            ? ObjectState.Changed
                            : ObjectState.New,
                        // WorkflowStage specific properties
                        Workflow: workflow.Id,
                        Name: node.stageData?.Name || 'Unnamed Stage',
                        Description: node.stageData?.Description || '',
                        Duration: node.stageData?.Duration || 0,
                        PassOnRule: node.stageData?.PassOnRule || '',
                        ActorRule: node.stageData?.ActorRule || StageActorRule.None,
                        MinNoOfActor: node.stageData?.MinNoOfActor || 0,
                        IsParallel: node.stageData?.IsParallel || false,
                        IsEntryPoint: node.isStartNode,
                        IsExitPoint: false, // Will be updated below
                        Tags: node.stageData?.Tags || [],
                        Form: node.stageData?.formId ? node.stageData.formId : '',
                        AllowMultiSubProcess: false,
                        AssignmentType: TaskAssignmentType.AutoRoute,
                        SubWorkFlow: '',
                        SwimLane: workflow.Lanes[swimlaneIndex].Id,
                        Coordinates: { X: node.x, Y: node.y },
                        IsSubProcess: false,
                        Key: node.stageData?.Key || undefined,
                    };
                    stages.push(stage);
                }
            });
        });
        // Determine which stages are exit points (no outgoing connections)
        stages.forEach((stage) => {
            const hasOutgoingConnections = this.state.connections.some((conn) => conn.sourceNodeId === stage.Id);
            if (!hasOutgoingConnections) {
                stage.IsExitPoint = true;
            }
        });
        // Transform connections to WorkflowAction[]
        workflow.Actions = this.state.connections.map((conn) => {
            const sourceNode = this.nodeService.findNodeById(conn.sourceNodeId)?.node;
            const targetNode = this.nodeService.findNodeById(conn.targetNodeId)?.node;
            return {
                // BaseModel properties
                Id: conn.id,
                Code: this.getCodeForObject(conn.id),
                TenantId: '',
                id: conn.id,
                ServiceName: '',
                CreatedAt: new Date(),
                UpdatedAt: new Date(),
                DataState: this.wasLoadedFromApi(conn.id)
                    ? ObjectState.Changed
                    : ObjectState.New,
                // WorkflowAction specific properties
                Workflow: workflow.Id,
                Name: `Action from ${sourceNode?.stageData?.Name || 'Unknown'} to ${targetNode?.stageData?.Name || 'Unknown'}`,
                FromStage: conn.sourceNodeId,
                ToStage: conn.targetNodeId,
                IsParallel: sourceNode?.stageData?.IsParallel || false,
                PassOnRule: '', // Optional property
            };
        });
        workflow.Stages = stages;
        return workflow;
    }
    /**
     * Parse API workflow model and convert to UI model
     */
    parseWorkflowData(workflow) {
        // Clear existing state
        this.state.swimlanes = [];
        this.state.connections = [];
        // Set workflow form if exists
        if (workflow.Form) {
            this.state.setWorkflowForm(workflow.Form, workflow.FormName || 'Workflow Form');
        }
        // Store the workflow ID
        this.state.setWorkflowId(workflow.Id);
        // Register the workflow itself
        this.registerLoadedObject(workflow.Id, workflow.Code);
        // Process swimlanes first
        if (workflow.Lanes && workflow.Lanes.length) {
            workflow.Lanes.sort((a, b) => a.Position - b.Position).forEach((lane) => {
                this.swimlaneService.addSwimlane(lane.Name || `Lane ${lane.Position}`, lane.Tags || []);
                // Register loaded lane
                this.registerLoadedObject(lane.Id, lane.Code);
            });
        }
        // Process stages
        if (workflow.Stages && workflow.Stages.length) {
            workflow.Stages.forEach((stage) => {
                // Find swimlane index
                const swimlaneIndex = this.swimlaneService.findSwimlaneIndexByLaneId(stage.SwimLane);
                if (swimlaneIndex !== -1) {
                    const x = stage.Coordinates?.X || 100;
                    const y = stage.Coordinates?.Y || 50;
                    this.nodeService.addNode(swimlaneIndex, 'stage', x, y, {
                        Name: stage.Name,
                        Description: stage.Description,
                        Duration: stage.Duration,
                        PassOnRule: stage.PassOnRule,
                        ActorRule: stage.ActorRule,
                        MinNoOfActor: stage.MinNoOfActor,
                        Tags: stage.Tags || [],
                        IsParallel: stage.IsParallel,
                        IsEntryPoint: stage.IsEntryPoint,
                        IsExitPoint: stage.IsExitPoint,
                        Id: stage.Id,
                    });
                    // Register loaded stage
                    this.registerLoadedObject(stage.Id, stage.Code);
                }
            });
        }
        // Process connections/actions
        if (workflow.Actions && workflow.Actions.length) {
            workflow.Actions.forEach((action) => {
                // Find source and target nodes
                const sourceNodeInfo = this.nodeService.findNodeById(action.FromStage);
                const targetNodeInfo = this.nodeService.findNodeById(action.ToStage);
                if (sourceNodeInfo && targetNodeInfo) {
                    // Find suitable connection points
                    const sourcePoint = sourceNodeInfo.node.connectionPoints?.[0];
                    const targetPoint = targetNodeInfo.node.connectionPoints?.[0];
                    if (sourcePoint && targetPoint) {
                        const connection = {
                            id: action.Id,
                            sourceNodeId: action.FromStage,
                            targetNodeId: action.ToStage,
                            sourcePointId: sourcePoint.id,
                            targetPointId: targetPoint.id,
                            sourceSwimlaneIndex: sourceNodeInfo.swimlaneIndex,
                            targetSwimlaneIndex: targetNodeInfo.swimlaneIndex,
                            label: action.Name,
                        };
                        this.state.connections.push(connection);
                        // Register loaded action
                        this.registerLoadedObject(action.Id, action.Code);
                    }
                }
            });
        }
    }
    /**
     * Register a loaded object from the API
     */
    registerLoadedObject(id, code) {
        this.loadedObjectIds[id] = code;
    }
    /**
     * Check if an object was loaded from API
     */
    wasLoadedFromApi(id) {
        return id in this.loadedObjectIds;
    }
    /**
     * Get the code for a loaded object
     */
    getCodeForObject(id) {
        return this.loadedObjectIds[id] || '';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TransformerService, deps: [{ token: WorkflowDesignerState }, { token: SwimlaneService }, { token: NodeManagementService }, { token: ConnectionService$1 }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TransformerService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TransformerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }, { type: SwimlaneService }, { type: NodeManagementService }, { type: ConnectionService$1 }] });

class DecisionPopupComponent {
    state;
    visible = false;
    decisionNodeId = '';
    popupX = 0;
    popupY = 0;
    closed = new EventEmitter();
    showDuration = true;
    constructor(state) {
        this.state = state;
    }
    getConnectionConditions() {
        if (!this.decisionNodeId)
            return [];
        // Get all connections from this decision node
        return this.state.connections
            .filter((conn) => conn.sourceNodeId === this.decisionNodeId)
            .map((conn) => ({
            connectionId: conn.id,
            sourceNodeId: conn.sourceNodeId,
            targetNodeId: conn.targetNodeId,
            condition: conn.condition || 'order.amount > 500,000', // Default or actual condition
        }));
    }
    getTargetNodeName(nodeId) {
        const nodeInfo = this.state.findNodeById(nodeId);
        if (nodeInfo && nodeInfo.node) {
            return nodeInfo.node.stageData?.Name || 'Stage';
        }
        return 'Unknown Stage';
    }
    getDuration() {
        // Get duration from the decision node or default to 120 days
        const nodeInfo = this.state.findNodeById(this.decisionNodeId);
        if (nodeInfo && nodeInfo.node && nodeInfo.node.stageData) {
            return nodeInfo.node.stageData.Duration || 120;
        }
        return 120;
    }
    onClose() {
        this.closed.emit();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DecisionPopupComponent, deps: [{ token: WorkflowDesignerState }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: DecisionPopupComponent, selector: "lib-decision-popup", inputs: { visible: "visible", decisionNodeId: "decisionNodeId", popupX: "popupX", popupY: "popupY" }, outputs: { closed: "closed" }, ngImport: i0, template: "<div\n  *ngIf=\"visible\"\n  [style.position]=\"'absolute'\"\n  [style.left.px]=\"popupX\"\n  [style.top.px]=\"popupY\"\n  class=\"decision-conditions-popup\"\n>\n  <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n    <div dropdown-trigger style=\"display: none\">\n      <!-- Hidden trigger element -->\n    </div>\n    <div\n      class=\"p-4 bg-white border border-purple-300 rounded shadow-md w-80\"\n      dropdown-content\n    >\n      <div class=\"flex justify-between items-center mb-3\">\n        <h3 class=\"text-lg font-medium\">Decision Conditions</h3>\n        <button class=\"text-gray-500 hover:text-gray-700\" (click)=\"onClose()\">\n          <svg\n            xmlns=\"http://www.w3.org/2000/svg\"\n            width=\"18\"\n            height=\"18\"\n            viewBox=\"0 0 24 24\"\n            fill=\"none\"\n            stroke=\"currentColor\"\n            stroke-width=\"2\"\n            stroke-linecap=\"round\"\n            stroke-linejoin=\"round\"\n          >\n            <line x1=\"18\" y1=\"6\" x2=\"6\" y2=\"18\"></line>\n            <line x1=\"6\" y1=\"6\" x2=\"18\" y2=\"18\"></line>\n          </svg>\n        </button>\n      </div>\n\n      <div class=\"space-y-3\">\n        @for (condition of getConnectionConditions(); track\n        condition.connectionId) {\n        <div class=\"p-3 border rounded\">\n          <div class=\"mb-2\">\n            <span class=\"font-medium\">Action {{ $index + 1 }}:</span>\n          </div>\n          <div class=\"flex items-center\">\n            <input\n              type=\"text\"\n              [value]=\"condition.condition\"\n              readonly\n              class=\"w-full px-3 py-2 bg-gray-50 border rounded\"\n              placeholder=\"No condition\"\n            />\n            <span class=\"ml-2\">&gt;</span>\n          </div>\n          <div class=\"mt-1 text-xs text-gray-500\">\n            {{ getTargetNodeName(condition.targetNodeId) }}\n          </div>\n        </div>\n        }\n      </div>\n\n      @if (getConnectionConditions().length === 0) {\n      <div class=\"text-center py-3 text-gray-500\">\n        No conditions defined for this decision node\n      </div>\n      } @if (showDuration) {\n      <div class=\"mt-4 pt-3 border-t border-gray-200\">\n        <div class=\"flex items-center\">\n          <span class=\"font-medium\">Duration:</span>\n          <span class=\"ml-2\">{{ getDuration() }} days</span>\n        </div>\n      </div>\n      }\n    </div>\n  </verben-pop-Up>\n</div>\n", styles: [".decision-conditions-popup{z-index:1000}.border-purple-300{border-color:#d8b4fe}.bg-gray-50{background-color:#f9fafb}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: DecisionPopupComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-decision-popup', template: "<div\n  *ngIf=\"visible\"\n  [style.position]=\"'absolute'\"\n  [style.left.px]=\"popupX\"\n  [style.top.px]=\"popupY\"\n  class=\"decision-conditions-popup\"\n>\n  <verben-pop-Up [dropdownOpen]=\"true\" [customStyles]=\"{ 'z-index': '100' }\">\n    <div dropdown-trigger style=\"display: none\">\n      <!-- Hidden trigger element -->\n    </div>\n    <div\n      class=\"p-4 bg-white border border-purple-300 rounded shadow-md w-80\"\n      dropdown-content\n    >\n      <div class=\"flex justify-between items-center mb-3\">\n        <h3 class=\"text-lg font-medium\">Decision Conditions</h3>\n        <button class=\"text-gray-500 hover:text-gray-700\" (click)=\"onClose()\">\n          <svg\n            xmlns=\"http://www.w3.org/2000/svg\"\n            width=\"18\"\n            height=\"18\"\n            viewBox=\"0 0 24 24\"\n            fill=\"none\"\n            stroke=\"currentColor\"\n            stroke-width=\"2\"\n            stroke-linecap=\"round\"\n            stroke-linejoin=\"round\"\n          >\n            <line x1=\"18\" y1=\"6\" x2=\"6\" y2=\"18\"></line>\n            <line x1=\"6\" y1=\"6\" x2=\"18\" y2=\"18\"></line>\n          </svg>\n        </button>\n      </div>\n\n      <div class=\"space-y-3\">\n        @for (condition of getConnectionConditions(); track\n        condition.connectionId) {\n        <div class=\"p-3 border rounded\">\n          <div class=\"mb-2\">\n            <span class=\"font-medium\">Action {{ $index + 1 }}:</span>\n          </div>\n          <div class=\"flex items-center\">\n            <input\n              type=\"text\"\n              [value]=\"condition.condition\"\n              readonly\n              class=\"w-full px-3 py-2 bg-gray-50 border rounded\"\n              placeholder=\"No condition\"\n            />\n            <span class=\"ml-2\">&gt;</span>\n          </div>\n          <div class=\"mt-1 text-xs text-gray-500\">\n            {{ getTargetNodeName(condition.targetNodeId) }}\n          </div>\n        </div>\n        }\n      </div>\n\n      @if (getConnectionConditions().length === 0) {\n      <div class=\"text-center py-3 text-gray-500\">\n        No conditions defined for this decision node\n      </div>\n      } @if (showDuration) {\n      <div class=\"mt-4 pt-3 border-t border-gray-200\">\n        <div class=\"flex items-center\">\n          <span class=\"font-medium\">Duration:</span>\n          <span class=\"ml-2\">{{ getDuration() }} days</span>\n        </div>\n      </div>\n      }\n    </div>\n  </verben-pop-Up>\n</div>\n", styles: [".decision-conditions-popup{z-index:1000}.border-purple-300{border-color:#d8b4fe}.bg-gray-50{background-color:#f9fafb}\n"] }]
        }], ctorParameters: () => [{ type: WorkflowDesignerState }], propDecorators: { visible: [{
                type: Input
            }], decisionNodeId: [{
                type: Input
            }], popupX: [{
                type: Input
            }], popupY: [{
                type: Input
            }], closed: [{
                type: Output
            }] } });

class WorkflowDesignerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerModule, declarations: [WorkflowDesignerComponent,
            DesignerToolbarComponent,
            DesignerCanvasComponent,
            SwimlaneDialogComponent,
            StageNodeComponent,
            StageDialogComponent,
            ConditionsPopupComponent,
            DecisionPopupComponent], imports: [CommonModule,
            VerbenDialogueModule,
            FormsModule$1,
            ReactiveFormsModule,
            VerbenPopUpModule,
            VerbenaButtonModule,
            DropDownModule,
            LabelEditorComponent], exports: [WorkflowDesignerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerModule, providers: [
            NodeManagementService,
            ConnectionService$1,
            SwimlaneService,
            TransformerService,
            PopupService,
        ], imports: [CommonModule,
            VerbenDialogueModule,
            FormsModule$1,
            ReactiveFormsModule,
            VerbenPopUpModule,
            VerbenaButtonModule,
            DropDownModule,
            LabelEditorComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowDesignerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        WorkflowDesignerComponent,
                        DesignerToolbarComponent,
                        DesignerCanvasComponent,
                        SwimlaneDialogComponent,
                        StageNodeComponent,
                        StageDialogComponent,
                        ConditionsPopupComponent,
                        DecisionPopupComponent,
                    ],
                    imports: [
                        CommonModule,
                        VerbenDialogueModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        VerbenPopUpModule,
                        VerbenaButtonModule,
                        DropDownModule,
                        LabelEditorComponent,
                    ],
                    providers: [
                        NodeManagementService,
                        ConnectionService$1,
                        SwimlaneService,
                        TransformerService,
                        PopupService,
                    ],
                    exports: [WorkflowDesignerComponent],
                }]
        }] });

// components/workflow/toolbar/wf-toolbar.component.ts
class WFToolbarComponent {
    selectedTool = null;
    toolSelected = new EventEmitter();
    toolbarItems = [
        { id: 'swimlane', label: 'Swimlane', icon: 'icons/swimlane.svg' },
        { id: 'stage', label: 'Stage', icon: 'icons/stage.svg' },
        { id: 'action', label: 'Action', icon: 'icons/action.svg' },
        { id: 'form', label: 'Form', icon: 'icons/form.svg' },
        // { id: 'decision', label: 'Decision', icon: 'icons/decision.svg' },
        { id: 'decision', label: 'Decision', icon: 'icons/stage.svg' },
        { id: 'subflow', label: 'Subflow', icon: 'icons/subflow.svg' },
    ];
    onToolSelect(toolId) {
        // If same tool is selected, deselect it
        this.toolSelected.emit(this.selectedTool === toolId ? null : toolId);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WFToolbarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: WFToolbarComponent, isStandalone: true, selector: "wf-toolbar", inputs: { selectedTool: "selectedTool" }, outputs: { toolSelected: "toolSelected" }, ngImport: i0, template: `
    <div class="toolbar">
      @for (item of toolbarItems; track item.id) {
      <button
        class="tool-button"
        [class.active]="selectedTool === item.id"
        (click)="onToolSelect(item.id)"
      >
        <img [src]="item.icon" [alt]="item.label" class="tool-icon" />
      </button>
      }
    </div>
  `, isInline: true, styles: [".toolbar{display:flex;padding:.5rem;gap:.5rem;background:#fff;border:1px solid #aa00ff;border-radius:7px;box-shadow:4px 4px 4px 3px #00000040}.tool-button{display:flex;align-items:center;justify-content:center;border:1px solid #e5e7eb;border-radius:.375rem;background:#fff;cursor:pointer;transition:all .2s}.tool-button:hover{background:#f9fafb}.tool-button.active{background:#f3e8ff;border-color:#d8b4fe}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WFToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'wf-toolbar', standalone: true, imports: [CommonModule], template: `
    <div class="toolbar">
      @for (item of toolbarItems; track item.id) {
      <button
        class="tool-button"
        [class.active]="selectedTool === item.id"
        (click)="onToolSelect(item.id)"
      >
        <img [src]="item.icon" [alt]="item.label" class="tool-icon" />
      </button>
      }
    </div>
  `, styles: [".toolbar{display:flex;padding:.5rem;gap:.5rem;background:#fff;border:1px solid #aa00ff;border-radius:7px;box-shadow:4px 4px 4px 3px #00000040}.tool-button{display:flex;align-items:center;justify-content:center;border:1px solid #e5e7eb;border-radius:.375rem;background:#fff;cursor:pointer;transition:all .2s}.tool-button:hover{background:#f9fafb}.tool-button.active{background:#f3e8ff;border-color:#d8b4fe}\n"] }]
        }], propDecorators: { selectedTool: [{
                type: Input
            }], toolSelected: [{
                type: Output
            }] } });

// services/wf-state.service.ts
class WorkflowStateService {
    state = signal({
        objects: [],
        selectedObjectId: null,
        selectedTool: null,
    });
    // Computed signals for better reactivity
    objects = computed(() => this.state().objects);
    selectedObjectId = computed(() => this.state().selectedObjectId);
    selectedTool = computed(() => this.state().selectedTool);
    // private swimlaneManagement = inject(SwimlaneManagementService);
    // Computed signals for filtered objects
    nodes = computed(() => this.objects().filter((obj) => obj.type !== 'swimlane' && obj.type !== 'action'));
    swimlanes = computed(() => this.objects().filter((obj) => obj.type === 'swimlane'));
    connections = computed(() => this.objects().filter((obj) => obj.type === 'action'));
    addObject(object) {
        this.state.update((state) => ({
            ...state,
            objects: [...state.objects, object],
        }));
    }
    updateObject(id, changes) {
        this.state.update((state) => ({
            ...state,
            objects: state.objects.map((obj) => obj.id === id ? { ...obj, ...changes } : obj),
        }));
    }
    updateMultipleObjects(updates) {
        this.state.update((state) => ({
            ...state,
            objects: state.objects.map((obj) => {
                const update = updates.find((u) => u.id === obj.id);
                return update ? { ...obj, ...update.changes } : obj;
            }),
        }));
    }
    removeObject(id) {
        this.state.update((state) => ({
            ...state,
            objects: state.objects.filter((obj) => obj.id !== id),
        }));
    }
    setSelectedTool(tool) {
        this.state.update((state) => ({ ...state, selectedTool: tool }));
    }
    setSelectedObject(id) {
        this.state.update((state) => ({ ...state, selectedObjectId: id }));
    }
    getObjectById(id) {
        return this.objects().find((obj) => obj.id === id);
    }
    // Initialize workflow with default objects
    initializeWorkflow() {
        const swimlaneHeight = 260;
        const swimlane = {
            id: crypto.randomUUID(),
            type: 'swimlane',
            position: { x: 0, y: 0 },
            size: { width: 3000 - 40, height: swimlaneHeight },
            label: 'Default Swimlane',
        };
        // Position start node vertically centered in the swimlane
        const startNodeHeight = 46; // Height of start node
        const startY = (swimlaneHeight - startNodeHeight) / 2;
        const startNode = {
            id: crypto.randomUUID(),
            type: 'start',
            position: { x: 50, y: startY },
            size: { width: 58, height: startNodeHeight },
            label: 'Start',
        };
        const initialConnection = {
            id: crypto.randomUUID(),
            type: 'action',
            position: startNode.position,
            size: { width: 0, height: 0 },
            label: '',
            fromId: startNode.id,
            toId: '',
            points: [
                {
                    x: startNode.position.x + startNode.size.width,
                    y: startNode.position.y + startNode.size.height / 2,
                },
                {
                    x: startNode.position.x + startNode.size.width + 50,
                    y: startNode.position.y + startNode.size.height / 2,
                },
            ],
        };
        this.state.set({
            ...this.state(),
            objects: [swimlane, startNode, initialConnection],
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowStateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowStateService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowStateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/label-management.service.ts
class LabelManagementService {
    workflowState = inject(WorkflowStateService);
    updateLabel(objectId, newLabel) {
        this.workflowState.updateObject(objectId, { label: newLabel });
    }
    getLabelPosition(object) {
        if (object.type === 'action') {
            return this.getConnectionLabelPosition(object);
        }
        // // // For regular nodes, use SVG coordinates
        // if (object.type === 'swimlane') {
        //   return {
        //     x: 100, // Fixed position for swimlane labels
        //     y: object.position.y + 20,
        //   };
        // }
        // For regular nodes, use SVG coordinates
        // For swimlanes, position label at the left side
        if (object.type === 'swimlane') {
            return {
                x: object.position.x + 20, // Small indent from left edge
                y: object.position.y + object.size.height / 2, // Vertically centered
            };
        }
        return {
            x: object.position.x + object.size.width / 2,
            y: object.position.y + object.size.height / 2,
        };
    }
    getConnectionLabelPosition(connection) {
        if (!connection.points || connection.points.length < 2) {
            return { x: 0, y: 0 };
        }
        // Find the middle point of the connection
        const midIndex = Math.floor(connection.points.length / 2);
        const point1 = connection.points[midIndex - 1];
        const point2 = connection.points[midIndex];
        return {
            x: (point1.x + point2.x) / 2,
            y: (point1.y + point2.y) / 2 - 10, // Offset above the line
        };
    }
    getSVGTextPosition(object) {
        // Center the label for all node types
        const centerX = object.size.width / 2;
        let centerY = object.size.height / 2;
        // Adjust position for form type
        if (object.type === 'form') {
            centerY = object.size.height + 20; // Position below the form
        }
        return { x: centerX, y: centerY };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelManagementService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelManagementService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LabelManagementService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// components/workflow/swimlane-label.component.ts
class SwimlaneLabelComponent {
    label = '';
    count = 0;
    addClick = new EventEmitter();
    labelChange = new EventEmitter();
    onAddClick(event) {
        event.stopPropagation();
        this.addClick.emit(event);
    }
    onLabelChange(newLabel) {
        this.labelChange.emit(newLabel);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneLabelComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: SwimlaneLabelComponent, isStandalone: true, selector: "[wf-swimlane-label]", inputs: { label: "label", count: "count" }, outputs: { addClick: "addClick", labelChange: "labelChange" }, ngImport: i0, template: `
    <svg:g>
      <!-- Plus icon at top -->
      <svg:g
        transform="translate(0, 20)"
        class="cursor-pointer"
        (click)="onAddClick($event)"
      >
        <svg:circle r="10" fill="white" stroke="#D8B4FE" stroke-width="1" />
        <svg:path
          d="M-6 0h12 M0 -6v12"
          stroke="#9333EA"
          stroke-width="2"
          stroke-linecap="round"
        />
      </svg:g>

      <!-- Label in middle with edit support -->
      <svg:g transform="translate(0, 120)">
        <svg:foreignObject
          x="-60"
          y="-12"
          width="180"
          height="24"
          transform="rotate(-90)"
        >
          <xhtml:div
            xmlns="http://www.w3.org/1999/xhtml"
            style="width: 100%; height: 100%;"
          >
            <wf-label-editor
              [label]="label"
              [x]="0"
              [y]="0"
              (labelChange)="onLabelChange($event)"
            />
          </xhtml:div>
        </svg:foreignObject>
      </svg:g>

      <!-- Count badge at bottom -->
      <svg:g transform="translate(0, 200)">
        <svg:rect
          x="-15"
          y="-10"
          width="20"
          height="20"
          rx="20"
          fill="#F3E8FF"
          stroke="#D8B4FE"
        />
        <svg:text
          x="0"
          y="4"
          text-anchor="middle"
          font-size="12"
          fill="#7E22CE"
          font-weight="500"
          transform="rotate(-90)"
        >
          {{ count }}
        </svg:text>
      </svg:g>
    </svg:g>
  `, isInline: true, styles: [":host{display:block}circle:hover{fill:#f3e8ff}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "component", type: LabelEditorComponent, selector: "wf-label-editor", inputs: ["label", "x", "y", "isConnection", "isSwimlane"], outputs: ["labelChange"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneLabelComponent, decorators: [{
            type: Component,
            args: [{ selector: '[wf-swimlane-label]', standalone: true, imports: [CommonModule, LabelEditorComponent], template: `
    <svg:g>
      <!-- Plus icon at top -->
      <svg:g
        transform="translate(0, 20)"
        class="cursor-pointer"
        (click)="onAddClick($event)"
      >
        <svg:circle r="10" fill="white" stroke="#D8B4FE" stroke-width="1" />
        <svg:path
          d="M-6 0h12 M0 -6v12"
          stroke="#9333EA"
          stroke-width="2"
          stroke-linecap="round"
        />
      </svg:g>

      <!-- Label in middle with edit support -->
      <svg:g transform="translate(0, 120)">
        <svg:foreignObject
          x="-60"
          y="-12"
          width="180"
          height="24"
          transform="rotate(-90)"
        >
          <xhtml:div
            xmlns="http://www.w3.org/1999/xhtml"
            style="width: 100%; height: 100%;"
          >
            <wf-label-editor
              [label]="label"
              [x]="0"
              [y]="0"
              (labelChange)="onLabelChange($event)"
            />
          </xhtml:div>
        </svg:foreignObject>
      </svg:g>

      <!-- Count badge at bottom -->
      <svg:g transform="translate(0, 200)">
        <svg:rect
          x="-15"
          y="-10"
          width="20"
          height="20"
          rx="20"
          fill="#F3E8FF"
          stroke="#D8B4FE"
        />
        <svg:text
          x="0"
          y="4"
          text-anchor="middle"
          font-size="12"
          fill="#7E22CE"
          font-weight="500"
          transform="rotate(-90)"
        >
          {{ count }}
        </svg:text>
      </svg:g>
    </svg:g>
  `, styles: [":host{display:block}circle:hover{fill:#f3e8ff}\n"] }]
        }], propDecorators: { label: [{
                type: Input
            }], count: [{
                type: Input
            }], addClick: [{
                type: Output
            }], labelChange: [{
                type: Output
            }] } });

// components/workflow/swimlane-popup.component.ts
class SwimLanePopupComponent {
    position;
    close = new EventEmitter();
    actionSelected = new EventEmitter();
    actions = [
        { id: 'add-above', label: 'Add Swimlane Above' },
        { id: 'add-below', label: 'Add Swimlane Below' },
        { id: 'delete', label: 'Delete Swimlane' },
    ];
    onActionClick(action) {
        this.actionSelected.emit(action.id);
        this.close.emit();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimLanePopupComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: SwimLanePopupComponent, isStandalone: true, selector: "wf-swimlane-popup", inputs: { position: "position" }, outputs: { close: "close", actionSelected: "actionSelected" }, ngImport: i0, template: `
    <div 
      class="fixed bg-white rounded-lg shadow-lg border border-slate-200 p-4 min-w-[200px]"
      [style.left.px]="position.x"
      [style.top.px]="position.y"
    >
      <div class="flex justify-between items-center mb-4">
        <h3 class="text-sm font-medium text-slate-900">Swimlane Actions</h3>
        <button 
          class="text-slate-400 hover:text-slate-600"
          (click)="close.emit()"
        >×</button>
      </div>

      <div class="space-y-2">
        <button 
          *ngFor="let action of actions"
          class="w-full text-left px-3 py-2 text-sm text-slate-700 hover:bg-purple-50 rounded-md"
          (click)="onActionClick(action)"
        >
          {{ action.label }}
        </button>
      </div>
    </div>
  `, isInline: true, dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimLanePopupComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'wf-swimlane-popup',
                    standalone: true,
                    imports: [CommonModule],
                    template: `
    <div 
      class="fixed bg-white rounded-lg shadow-lg border border-slate-200 p-4 min-w-[200px]"
      [style.left.px]="position.x"
      [style.top.px]="position.y"
    >
      <div class="flex justify-between items-center mb-4">
        <h3 class="text-sm font-medium text-slate-900">Swimlane Actions</h3>
        <button 
          class="text-slate-400 hover:text-slate-600"
          (click)="close.emit()"
        >×</button>
      </div>

      <div class="space-y-2">
        <button 
          *ngFor="let action of actions"
          class="w-full text-left px-3 py-2 text-sm text-slate-700 hover:bg-purple-50 rounded-md"
          (click)="onActionClick(action)"
        >
          {{ action.label }}
        </button>
      </div>
    </div>
  `
                }]
        }], propDecorators: { position: [{
                type: Input
            }], close: [{
                type: Output
            }], actionSelected: [{
                type: Output
            }] } });

// services/swimlane-stats.service.ts
class SwimlaneStatsService {
    workflowState = inject(WorkflowStateService);
    popupState = signal({
        isOpen: false,
        position: { x: 0, y: 0 },
        swimlaneId: null,
    });
    popupStatus = this.popupState.asReadonly();
    getNodeCount(swimlaneId) {
        const nodes = this.workflowState.nodes();
        return nodes.filter((node) => this.isNodeInSwimlane(node, swimlaneId))
            .length;
    }
    isNodeInSwimlane(node, swimlaneId) {
        const swimlane = this.workflowState.getObjectById(swimlaneId);
        if (!swimlane)
            return false;
        return (node.position.y >= swimlane.position.y &&
            node.position.y <= swimlane.position.y + swimlane.size.height);
    }
    openPopup(position, swimlaneId) {
        this.popupState.set({
            isOpen: true,
            position,
            swimlaneId,
        });
    }
    closePopup() {
        this.popupState.update((state) => ({ ...state, isOpen: false }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneStatsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneStatsService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneStatsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/canvas-state.service.ts
class CanvasStateService {
    state = signal({
        width: 3000,
        height: 2000,
        gridSize: 20,
        isConnecting: false,
        isDragging: false,
        dragStartPosition: null,
        dragOffset: { x: 0, y: 0 },
        connectionPreview: null,
    });
    canvasState = this.state.asReadonly();
    setConnecting(isConnecting) {
        this.state.update((state) => ({ ...state, isConnecting }));
    }
    setDragging(isDragging) {
        this.state.update((state) => ({ ...state, isDragging }));
    }
    setDragStartPosition(position) {
        this.state.update((state) => ({ ...state, dragStartPosition: position }));
    }
    setDragOffset(offset) {
        this.state.update((state) => ({ ...state, dragOffset: offset }));
    }
    setConnectionPreview(points) {
        this.state.update((state) => ({ ...state, connectionPreview: points }));
    }
    resetInteractionState() {
        this.state.update((state) => ({
            ...state,
            isConnecting: false,
            isDragging: false,
            dragStartPosition: null,
            dragOffset: { x: 0, y: 0 },
            connectionPreview: null,
        }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CanvasStateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CanvasStateService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: CanvasStateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/node-finder.service.ts
class NodeFinderService {
    workflowState = inject(WorkflowStateService);
    findNodeAtPoint(point) {
        return (this.workflowState
            .nodes()
            .find((node) => this.isPointInNode(point, node)) || null);
    }
    isPointInNode(point, node) {
        return (point.x >= node.position.x &&
            point.x <= node.position.x + node.size.width &&
            point.y >= node.position.y &&
            point.y <= node.position.y + node.size.height);
    }
    isProtectedNode(node) {
        return ['start', 'swimlane'].includes(node.type);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeFinderService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeFinderService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeFinderService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class NodeSelectionService {
    workflowState = inject(WorkflowStateService);
    nodeFinder = inject(NodeFinderService);
    canvasState = inject(CanvasStateService);
    handleNodeClick(point) {
        // Clear any ongoing interactions first
        this.canvasState.resetInteractionState();
        const nodes = this.workflowState.nodes();
        const clickedNode = this.nodeFinder.findNodeAtPoint(point);
        if (clickedNode) {
            this.selectNode(clickedNode.id);
        }
        else {
            this.clearSelection();
        }
    }
    selectNode(nodeId) {
        // Don't reselect if already selected
        if (this.workflowState.selectedObjectId() === nodeId)
            return;
        this.workflowState.setSelectedObject(nodeId);
    }
    clearSelection() {
        this.workflowState.setSelectedObject(null);
    }
    isSelected(nodeId) {
        return this.workflowState.selectedObjectId() === nodeId;
    }
    getSelectedNode() {
        const selectedId = this.workflowState.selectedObjectId();
        if (!selectedId)
            return null;
        return this.workflowState.getObjectById(selectedId) || null;
    }
    canSelectNode(node) {
        // Add any rules for node selection here
        // For example, prevent selecting swimlanes
        return node.type !== 'swimlane';
    }
    handleToolSelection(nodeType) {
        // Clear selection when tool is selected
        if (nodeType) {
            this.clearSelection();
        }
    }
    handleKeyboardEvent(event) {
        // Handle keyboard shortcuts for selection
        // For example, 'Escape' to clear selection
        if (event.key === 'Escape') {
            this.clearSelection();
        }
    }
    handleClickOutside(event) {
        // Check if click is outside any node and clear selection
        const target = event.target;
        if (target.tagName === 'svg' ||
            target.classList.contains('canvas-container')) {
            this.clearSelection();
        }
    }
    deleteSelectedObject() {
        const selectedId = this.workflowState.selectedObjectId();
        if (!selectedId)
            return;
        const selectedObject = this.workflowState.getObjectById(selectedId);
        if (!selectedObject)
            return;
        // First, remove any connections to/from this object
        const connections = this.workflowState.connections();
        const relatedConnectionIds = connections
            .filter((conn) => conn.fromId === selectedId || conn.toId === selectedId)
            .map((conn) => conn.id);
        // Remove all related connections
        relatedConnectionIds.forEach((id) => {
            this.workflowState.removeObject(id);
        });
        // Remove the selected object
        this.workflowState.removeObject(selectedId);
        // Clear the selection
        this.clearSelection();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeSelectionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeSelectionService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeSelectionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/keyboard-handler.service.ts
class KeyboardHandlerService {
    workflowState = inject(WorkflowStateService);
    selection = inject(NodeSelectionService);
    handleKeyDown(event) {
        // Only handle keyboard events if an object is selected
        if (!this.workflowState.selectedObjectId())
            return;
        switch (event.key) {
            case 'Delete':
            case 'Backspace':
                this.handleDelete();
                break;
            // Add other keyboard shortcuts here
        }
    }
    handleDelete() {
        const selectedId = this.workflowState.selectedObjectId();
        if (!selectedId)
            return;
        const selectedObject = this.workflowState.getObjectById(selectedId);
        if (!selectedObject)
            return;
        // Don't delete protected nodes like start node or swimlanes
        if (['start', 'swimlane'].includes(selectedObject.type))
            return;
        // Remove the object and its connections
        this.selection.deleteSelectedObject();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: KeyboardHandlerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: KeyboardHandlerService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: KeyboardHandlerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/rendering.service.ts
class RenderingService {
    // Node path generation
    generateNodePath(object) {
        switch (object.type) {
            case 'start':
                return this.getStartNodePath(object.size.width, object.size.height);
            case 'decision':
                return this.getDecisionPath(object.size.width, object.size.height);
            case 'form':
                return this.getFormPath(object.size.width, object.size.height);
            case 'subflow':
                return this.getSubflowPath(object.size.width, object.size.height);
            default:
                return '';
        }
    }
    // Individual path generators
    getStartNodePath(width, height) {
        return `M${width} ${height / 2} 
              A${width / 2} ${height / 2} 0 0 0 
              0 ${height / 2}
              A${width / 2} ${height / 2} 0 0 0 
              ${width} ${height / 2}`;
    }
    getFormPath(width, height) {
        // Use exact path from design SVG
        return `M74.0625 40.5591V85.0625C74.0625 87.9716 72.9069 90.7615 70.8498 92.8186C68.7928 94.8756 66.0028 96.0312 63.0938 96.0312H11.9062C8.99716 96.0312 6.20721 94.8756 4.15017 92.8186C2.09313 90.7615 0.9375 87.9716 0.9375 85.0625V11.9375C0.9375 9.02841 2.09313 6.23846 4.15017 4.18142C6.20721 2.12438 8.99716 0.96875 11.9062 0.96875H34.4722C36.4109 0.969043 38.2701 1.73921 39.6412 3.10994L71.9213 35.3901C73.292 36.7611 74.0622 38.6204 74.0625 40.5591Z`;
    }
    getStartNodePaths() {
        return {
            circle: 'M57.5 23C57.5 35.3246 44.8544 45.5 29 45.5C13.1456 45.5 0.5 35.3246 0.5 23C0.5 10.6754 13.1456 0.5 29 0.5C44.8544 0.5 57.5 10.6754 57.5 23Z',
            arrow: 'M74 6L64 0.226497V11.7735L74 6ZM0 7H65V5H0V7Z',
        };
    }
    getNodeStyle(isSelected) {
        return {
            fill: 'white',
            stroke: '#D36CFF',
            strokeWidth: isSelected ? 2 : 1,
            strokeLinejoin: 'round',
        };
    }
    getConnectionStyle(isSelected) {
        return {
            stroke: '#D36CFF',
            strokeWidth: isSelected ? '2' : '1',
            fill: 'none',
        };
    }
    getConnectionPreviewStyle() {
        return {
            stroke: '#D36CFF',
            strokeWidth: '1',
            strokeDasharray: '4',
            fill: 'none',
        };
    }
    getSwimlaneStyle() {
        return {
            fill: '#f8fafc',
            stroke: '#e2e8f0',
            strokeWidth: '1',
        };
    }
    getNodeTransforms(node) {
        const baseTransform = `translate(${node.position.x}, ${node.position.y})`;
        switch (node.type) {
            case 'start':
                return {
                    node: baseTransform,
                    arrow: 'translate(57, 17)', // Position arrow relative to circle
                };
            case 'decision':
                return {
                    node: baseTransform,
                    indicator: `translate(${node.size.width + 10}, -10)`, // Position properties indicator
                };
            default:
                return { node: baseTransform };
        }
    }
    getDecisionNodePath(width, height) {
        return `M${width / 2} 0 L${width} ${height / 2} L${width / 2} ${height} L0 ${height / 2} Z`;
    }
    getPropertiesIndicator() {
        return {
            circle: {
                r: 8,
                style: {
                    fill: 'white',
                    stroke: '#D36CFF',
                    strokeWidth: 1,
                },
            },
            text: {
                content: 'i',
                style: {
                    fontSize: '12px',
                    textAnchor: 'middle',
                    alignmentBaseline: 'middle',
                    userSelect: 'none',
                    pointerEvents: 'none',
                },
            },
        };
    }
    getLabelStyle(nodeType) {
        const baseStyle = {
            fontSize: '12px',
            textAnchor: 'middle',
            dominantBaseline: 'middle',
            userSelect: 'none',
            pointerEvents: 'none',
        };
        switch (nodeType) {
            case 'swimlane':
                return {
                    ...baseStyle,
                    fontSize: '14px',
                    fontWeight: '500',
                    fill: '#64748b',
                    // writingMode: 'vertical-lr',
                };
            default:
                return baseStyle;
        }
    }
    getDefaultDimensions() {
        return {
            width: 3000,
            height: 2000,
            gridSize: 20,
        };
    }
    getGridPattern() {
        return {
            pattern: {
                width: 20,
                height: 20,
            },
            path: {
                d: 'M 20 0 L 0 0 0 20',
                style: {
                    fill: 'none',
                    stroke: '#e2e8f0',
                    strokeWidth: '0.5',
                },
            },
        };
    }
    // getConnectionPath(points: Position[]): string {
    //   if (!points || points.length < 2) return '';
    //   const [start, ...rest] = points;
    //   const end = rest[rest.length - 1];
    //   // Create the main path
    //   const mainPath =
    //     `M ${start.x} ${start.y} ` + rest.map((p) => `L ${p.x} ${p.y}`).join(' ');
    //   // Add arrowhead
    //   const arrowPath = this.createArrowhead(
    //     end,
    //     this.getEndPointAngle(points[points.length - 2], end)
    //   );
    //   return `${mainPath} ${arrowPath}`;
    // }
    /**
     * Gets the SVG path for a connection
     */
    getConnectionPath(points) {
        if (!points || points.length < 2)
            return '';
        // Create the main path
        const pathCommands = points.map((point, index) => {
            return index === 0
                ? `M ${point.x} ${point.y}`
                : `L ${point.x} ${point.y}`;
        });
        // Add arrowhead to the last segment
        const lastSegmentStart = points[points.length - 2];
        const lastSegmentEnd = points[points.length - 1];
        const arrowPath = this.createArrowhead(lastSegmentEnd, this.getEndPointAngle(lastSegmentStart, lastSegmentEnd));
        return `${pathCommands.join(' ')} ${arrowPath}`;
    }
    /**
     * Gets style for an individual connection segment
     */
    getConnectionSegmentStyle(isSelected, isHovered) {
        return {
            stroke: '#D36CFF',
            strokeWidth: isSelected ? '2' : isHovered ? '2' : '1',
            fill: 'none',
            transition: 'stroke-width 0.2s ease',
        };
    }
    createArrowhead(point, angle) {
        const arrowSize = 10;
        const arrowPoints = [
            {
                x: point.x - arrowSize * Math.cos(angle - Math.PI / 6),
                y: point.y - arrowSize * Math.sin(angle - Math.PI / 6),
            },
            point,
            {
                x: point.x - arrowSize * Math.cos(angle + Math.PI / 6),
                y: point.y - arrowSize * Math.sin(angle + Math.PI / 6),
            },
        ];
        return (`M ${arrowPoints[0].x} ${arrowPoints[0].y} ` +
            `L ${arrowPoints[1].x} ${arrowPoints[1].y} ` +
            `L ${arrowPoints[2].x} ${arrowPoints[2].y}`);
    }
    getEndPointAngle(p1, p2) {
        return Math.atan2(p2.y - p1.y, p2.x - p1.x);
    }
    getDecisionPath(width, height) {
        // Using the exact dimensions from your SVG
        const centerX = width / 2;
        const centerY = height / 2;
        return `M0.981845 ${centerY} L${centerX} 0.580976 L${width - 0.981845} ${centerY} L${centerX} ${height - 0.580976}Z`;
    }
    getSubflowPath(width, height) {
        // Using the exact dimensions from your SVG
        return `M1.19873 ${height * 0.252887}L${width / 2} 0.57735L${width - 1.19873} ${height * 0.252887}V${height * 0.747113}L${width / 2} ${height - 0.57735}L1.19873 ${height * 0.747113}V${height * 0.252887}`;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RenderingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RenderingService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: RenderingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/orthogonal-router.service.ts
class OrthogonalRouterService {
    /**
     * Finds the closest node side and point for a given mouse position
     */
    findConnectionPoint(node, mousePos) {
        const { position: pos, size } = node;
        // Calculate distances to each side
        const distToTop = Math.abs(mousePos.y - pos.y);
        const distToBottom = Math.abs(mousePos.y - (pos.y + size.height));
        const distToLeft = Math.abs(mousePos.x - pos.x);
        const distToRight = Math.abs(mousePos.x - (pos.x + size.width));
        // Find the minimum distance
        const minDist = Math.min(distToTop, distToBottom, distToLeft, distToRight);
        // Determine connection point based on closest side
        let side;
        let x;
        let y;
        if (minDist === distToTop) {
            side = 'top';
            x = Math.min(Math.max(mousePos.x, pos.x), pos.x + size.width);
            y = pos.y;
        }
        else if (minDist === distToBottom) {
            side = 'bottom';
            x = Math.min(Math.max(mousePos.x, pos.x), pos.x + size.width);
            y = pos.y + size.height;
        }
        else if (minDist === distToLeft) {
            side = 'left';
            x = pos.x;
            y = Math.min(Math.max(mousePos.y, pos.y), pos.y + size.height);
        }
        else {
            side = 'right';
            x = pos.x + size.width;
            y = Math.min(Math.max(mousePos.y, pos.y), pos.y + size.height);
        }
        return { x, y, side };
    }
    /**
     * Calculates the optimal orthogonal route between two points
     */
    calculateRoute(startNode, endNode, startPoint, endPoint) {
        // Convert connection points to routing points
        const start = { ...startPoint, type: 'start' };
        const end = { ...endPoint, type: 'end' };
        // If points are aligned vertically or horizontally, create direct route
        if (Math.abs(start.x - end.x) < 10) {
            return this.createVerticalRoute(start, end);
        }
        if (Math.abs(start.y - end.y) < 10) {
            return this.createHorizontalRoute(start, end);
        }
        // Create route based on connection sides
        return this.createRouteFromSides(start, end, startPoint.side, endPoint.side);
    }
    createRouteFromSides(start, end, startSide, endSide) {
        const points = [start];
        // Determine if we need to start horizontally or vertically based on the start side
        const startHorizontal = startSide === 'left' || startSide === 'right';
        const endHorizontal = endSide === 'left' || endSide === 'right';
        if (startHorizontal) {
            // Start with horizontal movement
            const midX = (start.x + end.x) / 2;
            if (start.y !== end.y) {
                points.push(this.createBendPoint(midX, start.y, true));
                points.push(this.createBendPoint(midX, end.y, false));
            }
        }
        else {
            // Start with vertical movement
            const midY = (start.y + end.y) / 2;
            if (start.x !== end.x) {
                points.push(this.createBendPoint(start.x, midY, false));
                points.push(this.createBendPoint(end.x, midY, true));
            }
        }
        points.push(end);
        return this.simplifyRoute(points);
    }
    createBendPoint(x, y, isHorizontal) {
        return { x, y, type: 'bend', isHorizontal };
    }
    createHorizontalRoute(start, end) {
        return [start, { ...end, type: 'end', isHorizontal: true }];
    }
    createVerticalRoute(start, end) {
        return [start, { ...end, type: 'end', isHorizontal: false }];
    }
    simplifyRoute(points) {
        // Remove unnecessary bends (where three points form a straight line)
        const simplified = points.filter((point, index) => {
            if (index === 0 || index === points.length - 1)
                return true;
            const prev = points[index - 1];
            const next = points[index + 1];
            // Keep point if it creates an actual bend
            return (!(prev.x === point.x && point.x === next.x) &&
                !(prev.y === point.y && point.y === next.y));
        });
        // Update point types and horizontal flags
        return simplified.map((point, index) => ({
            ...point,
            type: index === 0
                ? 'start'
                : index === simplified.length - 1
                    ? 'end'
                    : 'bend',
            isHorizontal: index < simplified.length - 1
                ? simplified[index + 1].y === point.y
                : point.y === simplified[index - 1].y,
        }));
    }
    /**
     * Updates a segment's position while maintaining orthogonal constraints
     */
    updateSegment(points, segmentIndex, newPosition) {
        const updatedPoints = [...points];
        const currentPoint = points[segmentIndex];
        const nextPoint = points[segmentIndex + 1];
        if (!currentPoint || !nextPoint)
            return points;
        // Determine if this is a horizontal or vertical segment
        const isHorizontal = currentPoint.y === nextPoint.y;
        if (isHorizontal) {
            // Moving a horizontal segment - adjust y coordinate
            updatedPoints[segmentIndex].y = newPosition.y;
            updatedPoints[segmentIndex + 1].y = newPosition.y;
        }
        else {
            // Moving a vertical segment - adjust x coordinate
            updatedPoints[segmentIndex].x = newPosition.x;
            updatedPoints[segmentIndex + 1].x = newPosition.x;
        }
        return this.simplifyRoute(updatedPoints);
    }
    /**
     * Determines if a point is near enough to a line segment for manipulation
     */
    isPointNearSegment(point, segmentStart, segmentEnd, threshold = 10) {
        // For horizontal segments
        if (segmentStart.y === segmentEnd.y) {
            return (Math.abs(point.y - segmentStart.y) <= threshold &&
                point.x >= Math.min(segmentStart.x, segmentEnd.x) &&
                point.x <= Math.max(segmentStart.x, segmentEnd.x));
        }
        // For vertical segments
        if (segmentStart.x === segmentEnd.x) {
            return (Math.abs(point.x - segmentStart.x) <= threshold &&
                point.y >= Math.min(segmentStart.y, segmentEnd.y) &&
                point.y <= Math.max(segmentStart.y, segmentEnd.y));
        }
        return false;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: OrthogonalRouterService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: OrthogonalRouterService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: OrthogonalRouterService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/connection-segment-interaction.service.ts
class ConnectionSegmentInteractionService {
    workflowState = inject(WorkflowStateService);
    orthogonalRouter = inject(OrthogonalRouterService);
    dragState = null;
    /**
     * Identifies if a point is near any connection segment
     */
    findSegmentAtPoint(point) {
        const connections = this.workflowState.connections();
        for (const connection of connections) {
            const points = connection.points;
            if (!points || points.length < 2)
                continue;
            // Check each segment
            for (let i = 0; i < points.length - 1; i++) {
                if (this.orthogonalRouter.isPointNearSegment(point, points[i], points[i + 1])) {
                    return {
                        connectionId: connection.id,
                        segmentIndex: i,
                    };
                }
            }
        }
        return null;
    }
    /**
     * Starts dragging a connection segment
     */
    startDragging(connectionId, segmentIndex, point) {
        this.dragState = {
            connectionId,
            segmentIndex,
            initialPosition: point,
        };
    }
    /**
     * Updates segment position during drag
     */
    updateDragging(point) {
        if (!this.dragState)
            return;
        const connection = this.workflowState.getObjectById(this.dragState.connectionId);
        if (!connection || !connection.points)
            return;
        // Convert Position[] to RoutingPoint[]
        const routingPoints = connection.points.map((p, index) => ({
            ...p,
            type: index === 0
                ? 'start'
                : index === connection.points.length - 1
                    ? 'end'
                    : 'bend',
            isHorizontal: index < connection.points.length - 1
                ? connection.points[index].y === connection.points[index + 1].y
                : false,
        }));
        const updatedPoints = this.orthogonalRouter.updateSegment(routingPoints, this.dragState.segmentIndex, point);
        // Convert back to Position[] for storage
        const positionPoints = updatedPoints.map((p) => ({
            x: p.x,
            y: p.y,
        }));
        this.workflowState.updateObject(connection.id, {
            points: positionPoints,
        });
    }
    /**
     * Completes the drag operation
     */
    finishDragging() {
        // Additional cleanup if needed
        this.dragState = null;
    }
    /**
     * Returns whether a segment is currently being dragged
     */
    isDragging() {
        return this.dragState !== null;
    }
    /**
     * Gets cursor style based on segment orientation
     */
    getSegmentCursor(connectionId, segmentIndex) {
        const connection = this.workflowState.getObjectById(connectionId);
        if (!connection || !connection.points)
            return 'default';
        const point = connection.points[segmentIndex];
        const nextPoint = connection.points[segmentIndex + 1];
        if (!point || !nextPoint)
            return 'default';
        // Return appropriate cursor based on segment orientation
        return point.y === nextPoint.y ? 'ns-resize' : 'ew-resize';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionSegmentInteractionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionSegmentInteractionService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionSegmentInteractionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/connection.service.ts
class ConnectionService {
    workflowState = inject(WorkflowStateService);
    canvasState = inject(CanvasStateService);
    nodeFinder = inject(NodeFinderService);
    rendering = inject(RenderingService);
    orthogonalRouter = inject(OrthogonalRouterService);
    segmentInteraction = inject(ConnectionSegmentInteractionService);
    connectionEndpoints = new Map();
    startConnection(sourceNode, point) {
        if (!this.canStartConnection(sourceNode))
            return;
        const startPoint = {
            ...this.orthogonalRouter.findConnectionPoint(sourceNode, point),
            type: 'start',
            position: point,
        };
        this.canvasState.setConnecting(true);
        this.workflowState.setSelectedObject(sourceNode.id);
        // Store the start point for later use
        const tempId = 'preview';
        this.connectionEndpoints.set(tempId, {
            startPoint,
            endPoint: { ...startPoint }, // Create a new object with the same properties
        });
        // Calculate initial preview route
        const previewPoints = this.orthogonalRouter.calculateRoute(sourceNode, { position: point, size: { width: 0, height: 0 } }, startPoint, startPoint);
        this.canvasState.setConnectionPreview(previewPoints);
    }
    updateConnectionPreview(point) {
        const sourceNodeId = this.workflowState.selectedObjectId();
        if (!sourceNodeId)
            return;
        const sourceNode = this.workflowState.getObjectById(sourceNodeId);
        if (!sourceNode)
            return;
        const endpoints = this.connectionEndpoints.get('preview');
        if (!endpoints)
            return;
        const endPoint = {
            x: point.x,
            y: point.y,
            side: this.determineEndSide(endpoints.startPoint, point),
            type: 'end',
            position: point,
        };
        // Update preview with new end point
        const previewPoints = this.orthogonalRouter.calculateRoute(sourceNode, { position: point, size: { width: 0, height: 0 } }, endpoints.startPoint, endPoint);
        this.canvasState.setConnectionPreview(previewPoints);
    }
    finalizeConnection(point) {
        const sourceNodeId = this.workflowState.selectedObjectId();
        if (!sourceNodeId)
            return;
        const sourceNode = this.workflowState.getObjectById(sourceNodeId);
        if (!sourceNode)
            return;
        const targetNode = this.nodeFinder.findNodeAtPoint(point);
        const endpoints = this.connectionEndpoints.get('preview');
        if (targetNode && endpoints && this.canConnect(sourceNode, targetNode)) {
            const endPoint = {
                ...this.orthogonalRouter.findConnectionPoint(targetNode, point),
                type: 'end',
                position: point,
            };
            // Calculate final route
            const routePoints = this.orthogonalRouter.calculateRoute(sourceNode, targetNode, endpoints.startPoint, endPoint);
            const newConnection = {
                id: crypto.randomUUID(),
                type: 'action',
                fromId: sourceNode.id,
                toId: targetNode.id,
                label: '',
                position: sourceNode.position,
                size: { width: 0, height: 0 },
                points: routePoints,
            };
            // Store the connection endpoints for later use
            this.connectionEndpoints.set(newConnection.id, {
                startPoint: endpoints.startPoint,
                endPoint,
            });
            this.workflowState.addObject(newConnection);
        }
        this.connectionEndpoints.delete('preview');
    }
    updateConnectionsForNode(nodeId) {
        const node = this.workflowState.getObjectById(nodeId);
        if (!node)
            return;
        const connections = this.workflowState
            .connections()
            .filter((conn) => conn.fromId === nodeId || conn.toId === nodeId);
        connections.forEach((connection) => {
            const sourceNode = this.workflowState.getObjectById(connection.fromId);
            const targetNode = this.workflowState.getObjectById(connection.toId);
            if (sourceNode && targetNode) {
                // Determine connection points based on current node positions
                const startPoint = {
                    ...this.orthogonalRouter.findConnectionPoint(sourceNode, {
                        x: sourceNode.position.x + sourceNode.size.width / 2,
                        y: sourceNode.position.y + sourceNode.size.height / 2,
                    }),
                    type: 'start',
                    position: sourceNode.position,
                };
                const endPoint = {
                    ...this.orthogonalRouter.findConnectionPoint(targetNode, {
                        x: targetNode.position.x + targetNode.size.width / 2,
                        y: targetNode.position.y + targetNode.size.height / 2,
                    }),
                    type: 'end',
                    position: targetNode.position,
                };
                // Calculate completely new route
                const newPoints = this.orthogonalRouter.calculateRoute(sourceNode, targetNode, startPoint, endPoint);
                // Update connection
                this.workflowState.updateObject(connection.id, {
                    points: newPoints,
                });
                // Store new endpoints
                this.connectionEndpoints.set(connection.id, { startPoint, endPoint });
            }
        });
    }
    determineEndSide(startPoint, endPoint) {
        // Determine the best side for the end point based on relative position
        const dx = endPoint.x - startPoint.x;
        const dy = endPoint.y - startPoint.y;
        if (Math.abs(dx) > Math.abs(dy)) {
            return dx > 0 ? 'left' : 'right';
        }
        else {
            return dy > 0 ? 'top' : 'bottom';
        }
    }
    /**
     * Handles clicking on a connection segment
     */
    handleSegmentClick(point) {
        const segment = this.segmentInteraction.findSegmentAtPoint(point);
        if (segment) {
            this.segmentInteraction.startDragging(segment.connectionId, segment.segmentIndex, point);
        }
    }
    /**
     * Updates segment position during drag
     */
    handleSegmentDrag(point) {
        if (this.segmentInteraction.isDragging()) {
            this.segmentInteraction.updateDragging(point);
        }
    }
    /**
     * Completes segment drag operation
     */
    finishSegmentDrag() {
        this.segmentInteraction.finishDragging();
    }
    /**
     * Gets cursor style for a segment
     */
    getSegmentCursor(connectionId, segmentIndex) {
        return this.segmentInteraction.getSegmentCursor(connectionId, segmentIndex);
    }
    getConnectionPath(connection) {
        if (!connection.points || connection.points.length < 2)
            return '';
        const points = connection.points;
        const [start, ...rest] = points;
        return (`M ${start.x} ${start.y} ` + rest.map((p) => `L ${p.x} ${p.y}`).join(' '));
    }
    canStartConnection(node) {
        if (node.type === 'start') {
            // Start node can only have one outgoing connection
            return !this.hasOutgoingConnections(node.id);
        }
        return ['stage', 'decision', 'form', 'subflow'].includes(node.type);
    }
    canConnect(source, target) {
        if (!target || source.id === target.id)
            return false;
        // Prevent connections to start node and swimlanes
        if (['start', 'swimlane'].includes(target.type))
            return false;
        // Prevent duplicate connections
        return !this.hasConnection(source.id, target.id);
    }
    hasConnection(sourceId, targetId) {
        return this.workflowState
            .connections()
            .some((conn) => conn.fromId === sourceId &&
            conn.toId === targetId);
    }
    getPreviewPath() {
        const preview = this.canvasState.canvasState().connectionPreview;
        if (!preview || preview.length < 2)
            return '';
        // Use the rendering service for consistent path generation
        return this.rendering.getConnectionPath(preview);
    }
    hasOutgoingConnections(nodeId) {
        return this.workflowState
            .connections()
            .some((conn) => conn.fromId === nodeId);
    }
    getConnectionPoint(node, type) {
        const center = {
            x: node.position.x + node.size.width / 2,
            y: node.position.y + node.size.height / 2,
        };
        switch (node.type) {
            case 'stage':
                return {
                    x: type === 'input'
                        ? node.position.x
                        : node.position.x + node.size.width,
                    y: center.y,
                };
            case 'decision':
                return type === 'input'
                    ? { x: center.x, y: node.position.y }
                    : { x: node.position.x + node.size.width, y: center.y };
            default:
                return type === 'input'
                    ? { x: node.position.x, y: center.y }
                    : { x: node.position.x + node.size.width, y: center.y };
        }
    }
    recalculateConnectionPoints(source, target, existingPoints) {
        // Start and end points
        const startPoint = this.getConnectionPoint(source, 'output');
        const endPoint = this.getConnectionPoint(target, 'input');
        // If it's a simple connection, just return direct path
        if (existingPoints.length <= 2) {
            return [startPoint, endPoint];
        }
        // For complex paths, maintain the middle points' relative positions
        const middlePoints = existingPoints.slice(1, -1).map((point) => ({
            x: point.x + (startPoint.x - existingPoints[0].x),
            y: point.y + (startPoint.y - existingPoints[0].y),
        }));
        return [startPoint, ...middlePoints, endPoint];
    }
    // Use nodeFinder methods instead of NodeInteractionService
    findTargetNode(point) {
        return this.nodeFinder.findNodeAtPoint(point);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ConnectionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/workflow-mapper.service.ts
class WorkflowMapperService {
    connectionService;
    constructor(connectionService) {
        this.connectionService = connectionService;
    }
    // Frontend to Backend transformation
    toBackendWorkflow(objects, workflowMetadata) {
        const swimlanes = objects.filter((obj) => obj.type === 'swimlane');
        const stages = objects.filter((obj) => obj.type === 'stage');
        const connections = objects.filter((obj) => obj.type === 'action' &&
            obj?.fromId &&
            obj?.toId);
        const startNode = objects.find((obj) => obj.type === 'start');
        const forms = objects.filter((obj) => obj.type === 'form');
        // Find entry points (stages connected to start node)
        const entryPointIds = connections
            .filter((conn) => conn.fromId === startNode?.id)
            .map((conn) => conn.toId);
        // Find exit points (stages with no outgoing connections)
        const exitPointIds = stages
            .filter((stage) => !connections.some((conn) => conn.fromId === stage.id))
            .map((stage) => stage.id);
        // Preserve original workflow code if it exists, otherwise generate a new one
        const code = workflowMetadata.code || this.generateCode(workflowMetadata.name);
        const workflow = {
            Id: workflowMetadata.id || '',
            id: workflowMetadata.id || '',
            Code: code,
            Name: workflowMetadata.name,
            Description: workflowMetadata.description || `Workflow for ${workflowMetadata.name}`,
            StageEntryRule: this.generateStageEntryRule(entryPointIds.length),
            Form: workflowMetadata.formId || '',
            AssignmentType: TaskAssignmentType.Queue,
            Status: Status.Active,
            Actions: connections.map((connection) => this.toBackendAction(connection, code)),
            Lanes: swimlanes.map((lane) => this.toBackendSwimlane(lane, code)),
            Stages: [],
            TenantId: workflowMetadata.tenantId || '',
            ServiceName: 'Workflow',
            CreatedAt: workflowMetadata.createdAt || new Date(),
            UpdatedAt: new Date(),
            DataState: workflowMetadata.isNew ? ObjectState.New : ObjectState.Changed,
        };
        // Map stages with entry/exit point information
        const mappedStages = stages.map((stage) => this.toBackendStage(stage, code, entryPointIds.includes(stage.id), exitPointIds.includes(stage.id), this.findSwimlaneForStage(stage, swimlanes), workflowMetadata.tenantId || ''));
        // Store stages in workflow
        workflow.Stages = mappedStages;
        return workflow;
    }
    generateCode(name) {
        return name
            .toLowerCase()
            .replace(/[^a-z0-9]+/g, '-')
            .replace(/^-+|-+$/g, '');
    }
    findSwimlaneForStage(stage, swimlanes) {
        return (swimlanes.find((lane) => stage.position.y >= lane.position.y &&
            stage.position.y <= lane.position.y + lane.size.height)?.id || '');
    }
    generateStageEntryRule(entryPointCount) {
        return entryPointCount > 1 ? 'parallel-entry' : 'single-entry';
    }
    toBackendSwimlane(frontendLane, workflow) {
        // Preserve original ID if available
        const originalId = frontendLane.originalId || '';
        return {
            Id: originalId,
            id: originalId,
            Code: frontendLane.originalCode || this.generateCode(frontendLane.label),
            Position: Math.floor(frontendLane.position.y / frontendLane.size.height),
            Workflow: workflow,
            Coordinates: {
                X: frontendLane.position.x,
                Y: frontendLane.position.y,
            },
            Size: {
                Width: frontendLane.size.width,
                Height: frontendLane.size.height,
            },
            Tags: frontendLane.tags || [], // This now correctly maps Tag[] to Tag[]
            TenantId: frontendLane.tenantId || '',
            ServiceName: 'Workflow',
            CreatedAt: frontendLane.createdAt || new Date(),
            UpdatedAt: new Date(),
            DataState: originalId ? ObjectState.Changed : ObjectState.New,
        };
    }
    toBackendStage(frontendStage, workflowId, isEntryPoint, isExitPoint, swimlaneId, tenantId) {
        const stage = frontendStage;
        const originalId = stage.originalId || '';
        return {
            Id: originalId,
            id: originalId,
            Code: stage.originalCode || this.generateCode(stage.label),
            Key: stage.id,
            Workflow: workflowId,
            Name: stage.label,
            Description: stage.description || '',
            Duration: stage.duration || 0,
            PassOnRule: stage.passOnRule || '',
            ActorRule: stage.actorRule || StageActorRule.Any,
            MinNoOfActor: stage.minNoOfActor || 1,
            IsParallel: stage.isParallel || false,
            IsEntryPoint: isEntryPoint,
            IsExitPoint: isExitPoint,
            Tags: stage.tags || [], // Now correctly maps Tag[] to Tag[]
            Form: stage.form || '',
            AllowMultiSubProcess: stage.allowMultiSubProcess || false,
            AssignmentType: stage.assignmentType ||
                TaskAssignmentType.Queue,
            SubWorkFlow: stage.subWorkflow || '',
            SwimLane: swimlaneId,
            Coordinates: {
                X: stage.position.x,
                Y: stage.position.y,
            },
            IsSubProcess: stage.isSubProcess || false,
            TenantId: tenantId,
            ServiceName: 'Workflow',
            CreatedAt: stage.createdAt || new Date(),
            UpdatedAt: new Date(),
            DataState: originalId ? ObjectState.Changed : ObjectState.New,
        };
    }
    toBackendAction(frontendAction, workflow) {
        const originalId = frontendAction.originalId || '';
        return {
            Id: originalId,
            id: originalId,
            Code: frontendAction.originalCode ||
                `${frontendAction.fromId}-to-${frontendAction.toId}`,
            Workflow: workflow,
            Name: frontendAction.label || 'Unnamed Action',
            FromStage: frontendAction.fromId,
            ToStage: frontendAction.toId,
            IsParallel: frontendAction.isParallel || false,
            PassOnRule: frontendAction.passOnRule || '',
            TenantId: frontendAction.tenantId || '',
            ServiceName: 'Workflow',
            CreatedAt: frontendAction.createdAt || new Date(),
            UpdatedAt: new Date(),
            DataState: originalId ? ObjectState.Changed : ObjectState.New,
        };
    }
    // Backend to Frontend transformation
    toFrontendObjects(workflow) {
        const objects = [];
        // Create metadata object to store workflow information
        const metadata = {
            id: workflow.Id,
            code: workflow.Code,
            name: workflow.Name,
            description: workflow.Description,
            tenantId: workflow.TenantId,
            formId: workflow.Form,
            createdAt: workflow.CreatedAt,
            isNew: workflow.DataState === ObjectState.New,
        };
        // Start with the start node
        const startNode = this.createStartNode();
        objects.push(startNode);
        // Convert swimlanes
        const swimlanes = workflow.Lanes.map((lane) => this.toFrontendSwimlane(lane));
        objects.push(...swimlanes);
        // Convert stages
        const stages = workflow.Stages.map((stage) => this.toFrontendStage(stage));
        objects.push(...stages);
        // Create connections, including from start node to entry points
        const connections = this.createConnections(workflow, startNode.id, stages);
        objects.push(...connections);
        return { objects, metadata };
    }
    createStartNode() {
        return {
            id: 'start-node',
            type: 'start',
            position: { x: 50, y: 37 },
            size: { width: 58, height: 46 },
            label: 'Start',
        };
    }
    toFrontendSwimlane(backendLane) {
        // Normalize the coordinates and size
        const coordinates = backendLane.Coordinates || {
            X: 0,
            Y: backendLane.Position * 120,
        };
        const position = {
            x: coordinates.X ?? 0,
            y: coordinates.Y ?? 0,
        };
        const size = backendLane.Size || { Width: 2960, Height: 120 };
        const normalizedSize = {
            width: size.Width ?? 2960,
            height: size.Height ?? 120,
        };
        return {
            id: backendLane.Code,
            type: 'swimlane',
            position,
            size: normalizedSize,
            label: backendLane.Code,
            // Store original backend information for later use
            originalId: backendLane.Id,
            originalCode: backendLane.Code,
            tags: backendLane.Tags || [],
            tenantId: backendLane.TenantId,
            createdAt: backendLane.CreatedAt,
        };
    }
    toFrontendStage(backendStage) {
        // Normalize coordinates
        const coordinates = backendStage.Coordinates || { X: 0, Y: 0 };
        const position = {
            x: coordinates.X ?? 0,
            y: coordinates.Y ?? 0,
        };
        return {
            id: backendStage.Key || backendStage.Code,
            type: 'stage',
            position,
            size: { width: 120, height: 80 }, // Default size for stages
            label: backendStage.Name,
            // Store original backend information
            originalId: backendStage.Id,
            originalCode: backendStage.Code,
            description: backendStage.Description,
            duration: backendStage.Duration,
            passOnRule: backendStage.PassOnRule,
            actorRule: backendStage.ActorRule,
            minNoOfActor: backendStage.MinNoOfActor,
            isParallel: backendStage.IsParallel,
            isEntryPoint: backendStage.IsEntryPoint,
            isExitPoint: backendStage.IsExitPoint,
            tags: backendStage.Tags,
            forms: backendStage.Form,
            allowMultiSubProcess: backendStage.AllowMultiSubProcess,
            assignmentType: backendStage.AssignmentType,
            subWorkflow: backendStage.SubWorkFlow,
            isSubProcess: backendStage.IsSubProcess,
            tenantId: backendStage.TenantId,
            createdAt: backendStage.CreatedAt,
        };
    }
    createConnections(workflow, startNodeId, stages) {
        const connections = [];
        const actions = workflow.Actions;
        // Create connections from start node to entry points
        stages
            .filter((stage) => workflow.Stages.find((s) => s.Key === stage.id || s.Code === stage.id)
            ?.IsEntryPoint)
            .forEach((entryStage) => {
            connections.push(this.createConnection(crypto.randomUUID(), startNodeId, entryStage.id, 'Start', stages));
        });
        // Create connections between stages
        actions.forEach((action) => {
            connections.push(this.createConnection(action.Code, action.FromStage, action.ToStage, action.Name || '', stages, {
                originalId: action.Id,
                originalCode: action.Code,
                isParallel: action.IsParallel,
                passOnRule: action.PassOnRule,
                tenantId: action.TenantId,
                createdAt: action.CreatedAt,
            }));
        });
        return connections;
    }
    createConnection(id, fromId, toId, label, stages, properties) {
        const sourceNode = stages.find((s) => s.id === fromId) || this.createStartNode();
        const targetNode = stages.find((s) => s.id === toId);
        if (!targetNode) {
            console.error(`Unable to find target stage with id: ${toId}`);
            // Return a minimal connection to avoid breaking the application
            return {
                id,
                type: 'action',
                fromId,
                toId,
                label,
                position: { x: 0, y: 0 },
                size: { width: 0, height: 0 },
                points: [],
                ...properties,
            };
        }
        const points = this.connectionService.recalculateConnectionPoints(sourceNode, targetNode, []);
        return {
            id,
            type: 'action',
            fromId,
            toId,
            label,
            position: sourceNode.position,
            size: { width: 0, height: 0 },
            points,
            // Store all additional properties from backend
            originalId: properties?.originalId,
            originalCode: properties?.originalCode,
            isParallel: properties?.isParallel,
            passOnRule: properties?.passOnRule,
            tenantId: properties?.tenantId,
            createdAt: properties?.createdAt,
            properties: properties?.properties,
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowMapperService, deps: [{ token: ConnectionService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowMapperService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowMapperService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: ConnectionService }] });

// services/workflow-persistence.service.ts
class WorkflowPersistenceService {
    workflowState = inject(WorkflowStateService);
    mapper = inject(WorkflowMapperService);
    service = inject(WorkflowsService);
    // Add a property to store the current workflow metadata
    currentWorkflowMetadata = {
        id: '',
        code: '',
        name: 'New Workflow',
        description: '',
        isNew: true,
    };
    // Getter for workflow metadata
    get workflowMetadata() {
        return { ...this.currentWorkflowMetadata };
    }
    // Save workflow with current metadata
    saveWorkflow() {
        const currentObjects = this.workflowState.objects();
        const workflow = this.mapper.toBackendWorkflow(currentObjects, this.currentWorkflowMetadata);
        return this.service.saveWorkflows([workflow]).then((results) => {
            // Update metadata with saved workflow info if successful
            if (results && results.length > 0) {
                const savedWorkflow = results[0];
                this.updateWorkflowMetadata({
                    id: savedWorkflow.Id,
                    code: savedWorkflow.Code,
                    name: savedWorkflow.Name,
                    description: savedWorkflow.Description,
                    tenantId: savedWorkflow.TenantId,
                    formId: savedWorkflow.Form,
                    createdAt: savedWorkflow.CreatedAt,
                    isNew: false,
                });
            }
            return results;
        });
    }
    // Load workflow by ID
    async loadWorkflow(workflowId) {
        try {
            const data = await this.service.getWorkflowWithParam(workflowId);
            const workflow = data.Result[0];
            if (workflow) {
                const result = this.mapper.toFrontendObjects(workflow);
                // Update metadata
                this.updateWorkflowMetadata({
                    id: workflow.Id,
                    code: workflow.Code,
                    name: workflow.Name,
                    description: workflow.Description,
                    tenantId: workflow.TenantId,
                    formId: workflow.Form,
                    createdAt: workflow.CreatedAt,
                    isNew: false,
                });
                // Clear existing state and load new objects
                this.workflowState.state.set({
                    objects: result.objects,
                    selectedObjectId: null,
                    selectedTool: null,
                });
            }
        }
        catch (error) {
            console.error('Error loading workflow:', error);
            throw error;
        }
    }
    // Update workflow metadata
    updateWorkflowMetadata(metadata) {
        this.currentWorkflowMetadata = {
            ...this.currentWorkflowMetadata,
            ...metadata,
        };
    }
    // Create a new workflow
    createNewWorkflow(name, description) {
        // Reset the state
        this.workflowState.initializeWorkflow();
        // Set up new metadata
        this.updateWorkflowMetadata({
            id: '',
            code: '',
            name: name,
            description: description || `New workflow: ${name}`,
            isNew: true,
        });
    }
    // Update existing workflow
    async updateWorkflow(workflowName, description) {
        // Update metadata
        this.updateWorkflowMetadata({
            name: workflowName,
            description: description || this.currentWorkflowMetadata.description,
        });
        // Save with updated metadata
        return this.saveWorkflow();
    }
    // Load all workflows
    async loadWorkflows() {
        try {
            const data = await this.service.getWorkflows(0, 0, 'createdAt', 'ASC');
            return data.Result;
        }
        catch (error) {
            console.error('Error loading workflows:', error);
            throw error;
        }
    }
    // Load forms
    async loadForms() {
        try {
            const data = await this.service.getForms(0, 0, 'createdAt', 'ASC');
            return data.Result;
        }
        catch (error) {
            console.error('Error loading forms:', error);
            throw error;
        }
    }
    // Load tags
    async loadTags() {
        try {
            const data = await this.service.getTags(0, 0, 'createdAt', 'ASC');
            return data.Result;
        }
        catch (error) {
            console.error('Error loading tags:', error);
            throw error;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowPersistenceService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowPersistenceService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowPersistenceService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/node-precondition.service.ts
class NodePreconditionService {
    persistence = inject(WorkflowPersistenceService);
    preconditionRequired = new Set([
        'form',
        'subflow',
        'swimlane',
        'decision',
    ]);
    pendingNodeSignal = signal(null);
    pendingNode = this.pendingNodeSignal.asReadonly();
    // Replace mock data signals with real data signals
    formOptions = signal([]);
    workflowOptions = signal([]);
    tagOptions = signal([]);
    // Add readonly accessors
    forms = this.formOptions.asReadonly();
    workflows = this.workflowOptions.asReadonly();
    tags = this.tagOptions.asReadonly();
    // Add initialization method to load real data
    async initializeData() {
        try {
            const [forms, workflows, tags] = await Promise.all([
                this.persistence.loadForms(),
                this.persistence.loadWorkflows(),
                this.persistence.loadTags(),
            ]);
            this.formOptions.set(forms.map((form) => ({
                type: 'form',
                id: form.Id,
                name: form.Name,
            })));
            this.workflowOptions.set(workflows.map((workflow) => ({
                type: 'subflow',
                id: workflow.Id,
                name: workflow.Name,
            })));
            this.tagOptions.set(tags);
        }
        catch (error) {
            console.error('Failed to load precondition data:', error);
        }
    }
    requiresPrecondition(type) {
        return this.preconditionRequired.has(type);
    }
    setPendingNode(type, position) {
        this.pendingNodeSignal.set({ type, position });
    }
    clearPendingNode() {
        this.pendingNodeSignal.set(null);
    }
    async getItems(type) {
        switch (type) {
            case 'form':
                return this.mapForms(await this.persistence.loadForms());
            case 'subflow':
                return this.mapWorkflows(await this.persistence.loadWorkflows());
            case 'swimlane':
                return this.mapTags(await this.persistence.loadTags());
            case 'decision':
                return this.getDecisionConditions();
            default:
                return [];
        }
    }
    mapForms(forms) {
        return forms.map((form) => ({
            type: 'form',
            id: form.Id,
            name: form.Name,
        }));
    }
    mapWorkflows(workflows) {
        return workflows.map((workflow) => ({
            type: 'subflow',
            id: workflow.Id,
            name: workflow.Name,
        }));
    }
    mapTags(tags) {
        return [
            {
                type: 'swimlane',
                tags: tags,
            },
        ];
    }
    getDecisionConditions() {
        return [
            {
                type: 'decision',
                condition: '', // Empty condition to be filled by user
            },
        ];
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodePreconditionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodePreconditionService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodePreconditionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// Update imports
class NodeSelectorComponent {
    // Replace existing properties with these
    selectedTags = [];
    selectedFormId = '';
    selectedWorkflowId = '';
    condition = '';
    preconditionService = inject(NodePreconditionService);
    select = new EventEmitter();
    // Methods for dropdown handling
    onTagSelectionChange(event) {
        // Handle tag selection change if needed
        console.log('Tag selection changed:', this.selectedTags);
    }
    onDropdownChange(event) {
        console.log('Dropdown selection changed:', event);
    }
    onFormSubmit() {
        const selectedForm = this.preconditionService
            .forms()
            .find((f) => f.id === this.selectedFormId);
        if (selectedForm) {
            this.select.emit(selectedForm);
        }
    }
    onWorkflowSubmit() {
        const selectedWorkflow = this.preconditionService
            .workflows()
            .find((w) => w.id === this.selectedWorkflowId);
        if (selectedWorkflow) {
            this.select.emit(selectedWorkflow);
        }
    }
    getDialogTitle() {
        const type = this.preconditionService.pendingNode()?.type;
        switch (type) {
            case 'form':
                return 'Select Form';
            case 'subflow':
                return 'Select Workflow';
            case 'swimlane':
                return 'Select Tags';
            case 'decision':
                return 'Set Condition';
            default:
                return 'Select';
        }
    }
    onTagsSubmit() {
        this.select.emit({
            type: 'swimlane',
            id: crypto.randomUUID(),
            name: 'Swimlane',
            tags: this.selectedTags,
        });
    }
    onConditionSubmit() {
        this.select.emit({
            type: 'decision',
            id: crypto.randomUUID(),
            name: 'Decision',
            condition: this.condition,
        });
    }
    onSelect(data) {
        this.select.emit(data);
    }
    onModalClose(event) {
        this.preconditionService.clearPendingNode();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeSelectorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: NodeSelectorComponent, isStandalone: true, selector: "wf-node-selector", outputs: { select: "select" }, ngImport: i0, template: `
    <verben-dialogue
      [isVisible]="!!preconditionService.pendingNode()"
      [showCloseIcon]="true"
      [dismissOutsideClick]="true"
      [closeOnEscape]="true"
      [size]="'small'"
      [mode]="'dialogue'"
      [customClass]="'precondition-dialogue'"
      [headerTemplate]="headerTemplate"
      [bodyTemplate]="bodyTemplate"
      (closeModal)="onModalClose($event)"
    >
    </verben-dialogue>

    <ng-template #headerTemplate>
      <h3 class="text-lg font-semibold">{{ getDialogTitle() }}</h3>
    </ng-template>

    <ng-template #bodyTemplate>
      <div class="p-6">
        @switch (preconditionService.pendingNode()?.type) { @case ('swimlane') {
        <div class="space-y-4">
          <verben-drop-down
            [multiselect]="true"
            display="chip"
            [required]="true"
            [filter]="true"
            [showClear]="true"
            placeholder="Select Tags"
            optionLabel="Name"
            styleClass="w-full"
            [options]="preconditionService.tags()"
            [(ngModel)]="selectedTags"
            (onChange)="onTagSelectionChange($event)"
          ></verben-drop-down>

          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!selectedTags.length"
            (click)="onTagsSubmit()"
          >
            Apply Tags
          </button>
        </div>
        } @case ('decision') {
        <div class="space-y-4">
          <div>
            <label class="block text-sm font-medium mb-2">Condition</label>
            <textarea
              class="w-full p-2 border rounded-md"
              rows="3"
              [(ngModel)]="condition"
              placeholder="Enter condition..."
            ></textarea>
          </div>
          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!condition"
            (click)="onConditionSubmit()"
          >
            Apply Condition
          </button>
        </div>
        } @case ('form') {
        <div class="space-y-4">
          <verben-drop-down
            [required]="true"
            [filter]="true"
            [showClear]="true"
            placeholder="Select Form"
            optionLabel="name"
            optionValue="id"
            styleClass="w-full"
            [options]="preconditionService.forms()"
            [(ngModel)]="selectedFormId"
            (onChange)="onDropdownChange($event)"
          ></verben-drop-down>

          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!selectedFormId"
            (click)="onFormSubmit()"
          >
            Select Form
          </button>
        </div>
        } @default {
        <div class="space-y-4">
          <verben-drop-down
            [required]="true"
            [filter]="true"
            [showClear]="true"
            placeholder="Select Workflow"
            optionLabel="name"
            optionValue="id"
            styleClass="w-full"
            [options]="preconditionService.workflows()"
            [(ngModel)]="selectedWorkflowId"
            (onChange)="onDropdownChange($event)"
          ></verben-drop-down>

          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!selectedWorkflowId"
            (click)="onWorkflowSubmit()"
          >
            Select Workflow
          </button>
        </div>
        } }
      </div>
    </ng-template>
  `, isInline: true, dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "ngmodule", type: VerbenDialogueModule }, { kind: "component", type: i8.VerbenDialogueComponent, selector: "verben-dialogue", inputs: ["dialogueWidth", "headerTemplate", "bodyTemplate", "footerTemplate", "showCloseIcon", "dismissOutsideClick", "closeOnEscape", "isVisible", "size", "backdropColor", "customClass", "disableFooter", "margin", "padding", "borderRadius", "dialogueBgColor", "width", "closeIconClass", "boxShadow", "enableTransition", "modalData", "mode", "position", "drawerWidth"], outputs: ["openModal", "closeModal"] }, { kind: "ngmodule", type: FormsModule$1 }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "ngmodule", type: DropDownModule }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeSelectorComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'wf-node-selector',
                    standalone: true,
                    imports: [CommonModule, VerbenDialogueModule, FormsModule$1, DropDownModule],
                    template: `
    <verben-dialogue
      [isVisible]="!!preconditionService.pendingNode()"
      [showCloseIcon]="true"
      [dismissOutsideClick]="true"
      [closeOnEscape]="true"
      [size]="'small'"
      [mode]="'dialogue'"
      [customClass]="'precondition-dialogue'"
      [headerTemplate]="headerTemplate"
      [bodyTemplate]="bodyTemplate"
      (closeModal)="onModalClose($event)"
    >
    </verben-dialogue>

    <ng-template #headerTemplate>
      <h3 class="text-lg font-semibold">{{ getDialogTitle() }}</h3>
    </ng-template>

    <ng-template #bodyTemplate>
      <div class="p-6">
        @switch (preconditionService.pendingNode()?.type) { @case ('swimlane') {
        <div class="space-y-4">
          <verben-drop-down
            [multiselect]="true"
            display="chip"
            [required]="true"
            [filter]="true"
            [showClear]="true"
            placeholder="Select Tags"
            optionLabel="Name"
            styleClass="w-full"
            [options]="preconditionService.tags()"
            [(ngModel)]="selectedTags"
            (onChange)="onTagSelectionChange($event)"
          ></verben-drop-down>

          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!selectedTags.length"
            (click)="onTagsSubmit()"
          >
            Apply Tags
          </button>
        </div>
        } @case ('decision') {
        <div class="space-y-4">
          <div>
            <label class="block text-sm font-medium mb-2">Condition</label>
            <textarea
              class="w-full p-2 border rounded-md"
              rows="3"
              [(ngModel)]="condition"
              placeholder="Enter condition..."
            ></textarea>
          </div>
          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!condition"
            (click)="onConditionSubmit()"
          >
            Apply Condition
          </button>
        </div>
        } @case ('form') {
        <div class="space-y-4">
          <verben-drop-down
            [required]="true"
            [filter]="true"
            [showClear]="true"
            placeholder="Select Form"
            optionLabel="name"
            optionValue="id"
            styleClass="w-full"
            [options]="preconditionService.forms()"
            [(ngModel)]="selectedFormId"
            (onChange)="onDropdownChange($event)"
          ></verben-drop-down>

          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!selectedFormId"
            (click)="onFormSubmit()"
          >
            Select Form
          </button>
        </div>
        } @default {
        <div class="space-y-4">
          <verben-drop-down
            [required]="true"
            [filter]="true"
            [showClear]="true"
            placeholder="Select Workflow"
            optionLabel="name"
            optionValue="id"
            styleClass="w-full"
            [options]="preconditionService.workflows()"
            [(ngModel)]="selectedWorkflowId"
            (onChange)="onDropdownChange($event)"
          ></verben-drop-down>

          <button
            class="w-full px-4 py-2 bg-purple-600 text-white rounded-md"
            [disabled]="!selectedWorkflowId"
            (click)="onWorkflowSubmit()"
          >
            Select Workflow
          </button>
        </div>
        } }
      </div>
    </ng-template>
  `,
                }]
        }], propDecorators: { select: [{
                type: Output
            }] } });

// services/viewport.service.ts
class ViewportService {
    getCanvasPoint(event, canvasRef) {
        const rect = canvasRef.nativeElement.getBoundingClientRect();
        return {
            x: event.clientX - rect.left,
            y: event.clientY - rect.top,
        };
    }
    snapToGrid(position, gridSize) {
        return {
            x: Math.round(position.x / gridSize) * gridSize,
            y: Math.round(position.y / gridSize) * gridSize,
        };
    }
    getObjectTransform(position) {
        return `translate(${position.x}, ${position.y})`;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ViewportService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ViewportService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ViewportService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/position-update.service.ts
class PositionUpdateService {
    workflowState = inject(WorkflowStateService);
    connection = inject(ConnectionService);
    updateNodeWithConnections(nodeId, newPosition) {
        // Update node position
        this.workflowState.updateObject(nodeId, { position: newPosition });
        // Update connected paths
        const connections = this.workflowState
            .connections()
            .filter((conn) => conn.fromId === nodeId || conn.toId === nodeId);
        const updates = this.getConnectionUpdates(nodeId, newPosition, connections);
        if (updates.length > 0) {
            this.workflowState.updateMultipleObjects(updates);
        }
    }
    getConnectionUpdates(nodeId, newPosition, connections) {
        return connections
            .map((conn) => {
            const sourceNode = this.workflowState.getObjectById(conn.fromId);
            const targetNode = this.workflowState.getObjectById(conn.toId);
            if (!sourceNode || !targetNode)
                return null;
            const points = this.connection.recalculateConnectionPoints(sourceNode, targetNode, conn.points);
            return {
                id: conn.id,
                changes: { points },
            };
        })
            .filter((update) => update !== null);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PositionUpdateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PositionUpdateService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: PositionUpdateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/node-interaction.service.ts
class NodeInteractionService {
    viewport = inject(ViewportService);
    workflowState = inject(WorkflowStateService);
    canvasState = inject(CanvasStateService);
    positionUpdate = inject(PositionUpdateService);
    nodeFinder = inject(NodeFinderService);
    // Use nodeFinder instead of direct implementation
    findNodeAtPoint(point) {
        return this.nodeFinder.findNodeAtPoint(point);
    }
    isPointInNode(point, node) {
        return (point.x >= node.position.x &&
            point.x <= node.position.x + node.size.width &&
            point.y >= node.position.y &&
            point.y <= node.position.y + node.size.height);
    }
    startDragging(node, point) {
        if (this.isProtectedNode(node))
            return;
        this.canvasState.setDragging(true);
        this.canvasState.setDragStartPosition(point);
        this.workflowState.setSelectedObject(node.id);
        // Calculate offset from node position to click position
        this.canvasState.setDragOffset({
            x: point.x - node.position.x,
            y: point.y - node.position.y,
        });
    }
    handleDragging(currentPoint, gridSize) {
        const objectId = this.workflowState.selectedObjectId();
        if (!objectId)
            return;
        const selectedNode = this.workflowState.getObjectById(objectId);
        if (!selectedNode)
            return;
        const { dragOffset } = this.canvasState.canvasState();
        const newPosition = {
            x: currentPoint.x - dragOffset.x,
            y: currentPoint.y - dragOffset.y,
        };
        // Snap to grid
        const snappedPosition = this.viewport.snapToGrid(newPosition, gridSize);
        // Find nearest swimlane if applicable
        const nearestSwimlane = this.findNearestSwimlane(snappedPosition);
        if (nearestSwimlane) {
            snappedPosition.y =
                nearestSwimlane.position.y +
                    (nearestSwimlane.size.height - selectedNode.size.height) / 2;
        }
        // Update node position
        this.workflowState.updateObject(selectedNode.id, {
            position: snappedPosition,
        });
        // Use the new service
        this.positionUpdate.updateNodeWithConnections(selectedNode.id, snappedPosition);
    }
    finalizeDragging(finalPoint) {
        const objectId = this.workflowState.selectedObjectId();
        if (!objectId)
            return;
        const selectedNode = this.workflowState.getObjectById(objectId);
        if (!selectedNode)
            return;
        // Perform any final position adjustments
        const boundedPosition = this.keepWithinBounds(selectedNode.position, this.canvasState.canvasState().width, this.canvasState.canvasState().height);
        if (boundedPosition !== selectedNode.position) {
            this.workflowState.updateObject(selectedNode.id, {
                position: boundedPosition,
            });
        }
    }
    findNearestSwimlane(position) {
        const swimlanes = this.workflowState.swimlanes();
        for (const swimlane of swimlanes) {
            if (position.y >= swimlane.position.y &&
                position.y <= swimlane.position.y + swimlane.size.height) {
                return swimlane;
            }
        }
        return null;
    }
    keepWithinBounds(position, width, height) {
        return {
            x: Math.max(0, Math.min(position.x, width - 100)), // 100 is minimum node width
            y: Math.max(0, Math.min(position.y, height - 60)), // 60 is minimum node height
        };
    }
    isProtectedNode(node) {
        return ['start', 'swimlane'].includes(node.type);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeInteractionService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeInteractionService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NodeInteractionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class SwimlaneManagementService {
    workflowState = inject(WorkflowStateService);
    canvasState = inject(CanvasStateService);
    DEFAULT_SWIMLANE_HEIGHT = 260;
    createSwimlane(clickPosition) {
        const swimlanes = this.workflowState.swimlanes();
        const canvasWidth = this.canvasState.canvasState().width;
        // Calculate the new swimlane's position
        const newPosition = this.calculateNewSwimlanePosition(clickPosition, swimlanes);
        const newSwimlane = {
            id: crypto.randomUUID(),
            type: 'swimlane',
            position: { x: 0, y: this.findNearestSwimlanePosition(clickPosition) },
            size: { width: canvasWidth - 40, height: this.DEFAULT_SWIMLANE_HEIGHT },
            label: `Swimlane ${swimlanes.length + 1}`,
        };
        this.workflowState.addObject(newSwimlane);
        this.reorderSwimlanes();
    }
    getVerticalCenterForSwimlane(swimlaneY) {
        return swimlaneY + this.DEFAULT_SWIMLANE_HEIGHT / 2;
    }
    getSwimlaneHeight() {
        return this.DEFAULT_SWIMLANE_HEIGHT;
    }
    calculateNewSwimlanePosition(clickY, swimlanes) {
        if (swimlanes.length === 0)
            return 0;
        // Sort swimlanes by vertical position
        const sortedSwimlanes = [...swimlanes].sort((a, b) => a.position.y - b.position.y);
        // Find the appropriate insertion point based on click position
        for (let i = 0; i < sortedSwimlanes.length; i++) {
            const swimlane = sortedSwimlanes[i];
            if (clickY < swimlane.position.y + swimlane.size.height / 2) {
                return i * this.DEFAULT_SWIMLANE_HEIGHT;
            }
        }
        // If click is below all existing swimlanes, add to the end
        return sortedSwimlanes.length * this.DEFAULT_SWIMLANE_HEIGHT;
    }
    // reorderSwimlanes(): void {
    //   const swimlanes = [...this.workflowState.swimlanes()].sort(
    //     (a, b) => a.position.y - b.position.y
    //   );
    //   const updates = swimlanes.map((swimlane, index) => ({
    //     id: swimlane.id,
    //     changes: {
    //       position: { x: 0, y: index * this.DEFAULT_SWIMLANE_HEIGHT },
    //       size: { ...swimlane.size },
    //     },
    //   }));
    //   this.workflowState.updateMultipleObjects(updates);
    // }
    reorderSwimlanes() {
        const swimlanes = [...this.workflowState.swimlanes()].sort((a, b) => a.position.y - b.position.y);
        // Update positions and adjust contained nodes
        swimlanes.forEach((swimlane, index) => {
            const oldY = swimlane.position.y;
            const newY = index * this.DEFAULT_SWIMLANE_HEIGHT;
            // Update swimlane position
            this.workflowState.updateObject(swimlane.id, {
                position: { x: 0, y: newY },
                size: { ...swimlane.size, height: this.DEFAULT_SWIMLANE_HEIGHT },
            });
            // If position changed, adjust contained nodes
            if (oldY !== newY) {
                this.adjustNodesInSwimlane(swimlane.id, oldY, newY);
            }
        });
    }
    adjustNodesInSwimlane(swimlaneId, oldY, newY) {
        const nodes = this.workflowState.nodes();
        const swimlane = this.workflowState.getObjectById(swimlaneId);
        if (!swimlane)
            return;
        nodes.forEach((node) => {
            if (this.isNodeInSwimlane(node, swimlane)) {
                const relativeY = node.position.y - oldY; // Position relative to old swimlane top
                const newNodeY = newY + relativeY; // Maintain relative position in new location
                this.workflowState.updateObject(node.id, {
                    position: { ...node.position, y: newNodeY },
                });
            }
        });
    }
    isNodeInSwimlane(node, swimlane) {
        return (node.position.y >= swimlane.position.y &&
            node.position.y <= swimlane.position.y + swimlane.size.height);
    }
    resizeSwimlanesForCanvas(canvasWidth) {
        const swimlanes = this.workflowState.swimlanes();
        const updates = swimlanes.map((swimlane) => ({
            id: swimlane.id,
            changes: {
                size: { width: canvasWidth - 40, height: this.DEFAULT_SWIMLANE_HEIGHT },
            },
        }));
        this.workflowState.updateMultipleObjects(updates);
    }
    getTotalHeight() {
        const swimlanes = this.workflowState.swimlanes();
        return swimlanes.length * this.DEFAULT_SWIMLANE_HEIGHT;
    }
    swapSwimlanes(swimlane1Id, swimlane2Id) {
        const swimlane1 = this.workflowState.getObjectById(swimlane1Id);
        const swimlane2 = this.workflowState.getObjectById(swimlane2Id);
        if (!swimlane1 || !swimlane2)
            return;
        const temp = swimlane1.position.y;
        this.workflowState.updateObject(swimlane1Id, {
            position: { ...swimlane1.position, y: swimlane2.position.y },
        });
        this.workflowState.updateObject(swimlane2Id, {
            position: { ...swimlane2.position, y: temp },
        });
        this.reorderSwimlanes();
    }
    findNearestSwimlanePosition(yPosition) {
        const swimlanes = this.workflowState.swimlanes();
        if (swimlanes.length === 0)
            return 0;
        const sortedSwimlanes = [...swimlanes].sort((a, b) => a.position.y - b.position.y);
        // Find the first swimlane that's below the given position
        for (let i = 0; i < sortedSwimlanes.length; i++) {
            if (sortedSwimlanes[i].position.y > yPosition) {
                return i * sortedSwimlanes[0].size.height;
            }
        }
        // If no swimlane is below, add to the end
        return sortedSwimlanes.length * sortedSwimlanes[0].size.height;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneManagementService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneManagementService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: SwimlaneManagementService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// services/workflow-facade.service.ts
class WorkflowFacadeService {
    workflowState = inject(WorkflowStateService);
    viewport = inject(ViewportService);
    nodeInteraction = inject(NodeInteractionService);
    connection = inject(ConnectionService);
    rendering = inject(RenderingService);
    selection = inject(NodeSelectionService);
    canvasStateService = inject(CanvasStateService);
    swimlaneManagement = inject(SwimlaneManagementService);
    persistence = inject(WorkflowPersistenceService);
    segmentInteraction = inject(ConnectionSegmentInteractionService);
    preconditionService = inject(NodePreconditionService);
    // Canvas State Accessors
    canvasState = this.canvasStateService.canvasState;
    workflowObjects = this.workflowState.objects;
    selectedObjectId = this.workflowState.selectedObjectId;
    selectedTool = this.workflowState.selectedTool;
    // Filtered Object Accessors
    nodes = this.workflowState.nodes;
    swimlanes = this.workflowState.swimlanes;
    connections = this.workflowState.connections;
    // Rendering Methods
    getNodeStyle = this.rendering.getNodeStyle;
    getConnectionStyle = this.rendering.getConnectionStyle;
    getStartNodePaths = this.rendering.getStartNodePaths;
    getNodeTransforms = this.rendering.getNodeTransforms;
    getGridPattern = this.rendering.getGridPattern;
    // Connection methods
    getConnectionPath(points) {
        return this.rendering.getConnectionPath(points);
    }
    // Added these getter methods to expose connection service functionality
    getConnectionPreviewPath = () => this.connection.getPreviewPath();
    hasOutgoingConnections = (nodeId) => this.connection.hasOutgoingConnections(nodeId);
    // Segment interaction methods
    handleSegmentMouseDown(event, canvasRef, connectionId, segmentIndex) {
        const point = this.viewport.getCanvasPoint(event, canvasRef);
        this.segmentInteraction.startDragging(connectionId, segmentIndex, point);
        this.canvasStateService.setDragging(true);
    }
    getSegmentCursor(connectionId, segmentIndex) {
        return this.segmentInteraction.getSegmentCursor(connectionId, segmentIndex);
    }
    // Mouse Event Handlers
    handleMouseDown(event, canvasRef) {
        if (event.button !== 0)
            return;
        const point = this.viewport.getCanvasPoint(event, canvasRef);
        const clickedNode = this.nodeInteraction.findNodeAtPoint(point
        //   this.nodes()
        );
        if (this.selectedTool() === 'action' && clickedNode) {
            this.connection.startConnection(clickedNode, point);
        }
        else if (this.selectedTool()) {
            this.handleToolPlacement(point);
        }
        else if (clickedNode) {
            if (event.target instanceof Element &&
                event.target.classList.contains('properties-indicator')) {
                // Handle properties click
                return;
            }
            this.nodeInteraction.startDragging(clickedNode, point);
        }
        else {
            this.selection.handleClickOutside(event);
        }
    }
    handleMouseMove(event, canvasRef) {
        const point = this.viewport.getCanvasPoint(event, canvasRef);
        const { isConnecting, isDragging } = this.canvasState();
        if (isConnecting) {
            this.connection.updateConnectionPreview(point);
        }
        else if (isDragging) {
            // this.nodeInteraction.handleDragging(point, this.canvasState().gridSize);
            if (this.segmentInteraction.isDragging()) {
                this.segmentInteraction.updateDragging(point);
            }
            else {
                this.nodeInteraction.handleDragging(point, this.canvasState().gridSize);
            }
        }
    }
    handleMouseUp(event, canvasRef) {
        const point = this.viewport.getCanvasPoint(event, canvasRef);
        const { isConnecting, isDragging } = this.canvasState();
        if (isConnecting) {
            this.connection.finalizeConnection(point);
        }
        else if (isDragging) {
            // this.nodeInteraction.finalizeDragging(point);
            if (this.segmentInteraction.isDragging()) {
                this.segmentInteraction.finishDragging();
            }
            else {
                this.nodeInteraction.finalizeDragging(point);
            }
        }
        this.canvasStateService.resetInteractionState();
    }
    handleMouseLeave() {
        this.canvasStateService.resetInteractionState();
    }
    // Tool and Object Management
    handleToolSelection(tool) {
        this.workflowState.setSelectedTool(tool);
        this.selection.handleToolSelection(tool);
    }
    // private handleToolPlacement(point: Position): void {
    //   console.log('Tool placement triggered', {
    //     selectedTool: this.selectedTool(),
    //     point,
    //   });
    //   if (this.selectedTool() === 'swimlane') {
    //     this.swimlaneManagement.createSwimlane(point.y);
    //     console.log(
    //       'Swimlane created, current swimlanes:',
    //       this.workflowState.swimlanes()
    //     );
    //     this.workflowState.setSelectedTool(null);
    //     return;
    //   }
    //   const newNode: WorkflowObject = {
    //     id: crypto.randomUUID(),
    //     type: this.selectedTool()!,
    //     position: this.viewport.snapToGrid(point, this.canvasState().gridSize),
    //     size: this.getDefaultSize(this.selectedTool()!),
    //     label: `New ${this.selectedTool()}`,
    //   };
    //   this.workflowState.addObject(newNode);
    //   this.workflowState.setSelectedTool(null);
    // }
    handleToolPlacement(point) {
        if (!this.selectedTool())
            return;
        const nodeType = this.selectedTool();
        // Check if precondition is required
        if (this.preconditionService.requiresPrecondition(nodeType)) {
            this.preconditionService.setPendingNode(nodeType, point);
            return; // Don't create node yet
        }
        // Create node immediately if no precondition required
        this.createNode(nodeType, point);
    }
    createNode(type, position, selectedData) {
        const baseNode = {
            id: crypto.randomUUID(),
            type: type,
            position: this.viewport.snapToGrid(position, this.canvasState().gridSize),
            size: this.getDefaultSize(type),
        };
        let nodeData;
        switch (type) {
            case 'form':
            case 'subflow':
                nodeData = {
                    ...baseNode,
                    label: selectedData?.name || `New ${type}`,
                    referenceId: selectedData?.id,
                };
                break;
            case 'swimlane':
                nodeData = {
                    ...baseNode,
                    label: selectedData?.name || 'Swimlane',
                    tags: selectedData?.tags || [],
                    order: this.workflowState.swimlanes().length, // Add order based on current swimlane count
                };
                break;
            case 'decision':
                nodeData = {
                    ...baseNode,
                    label: selectedData?.name || 'Decision',
                    condition: selectedData?.condition || '',
                };
                break;
            default:
                nodeData = {
                    ...baseNode,
                    label: `New ${type}`,
                };
        }
        this.workflowState.addObject(nodeData);
        this.workflowState.setSelectedTool(null);
    }
    // Call this when a form/subflow is selected
    finalizeNodeCreation(selectedData) {
        const pendingNode = this.preconditionService.pendingNode();
        if (!pendingNode)
            return;
        this.createNode(pendingNode.type, pendingNode.position, selectedData);
        this.preconditionService.clearPendingNode();
    }
    handleSwimlaneCreation(point) {
        const swimlaneManagement = inject(SwimlaneManagementService);
        swimlaneManagement.createSwimlane(point.y);
    }
    getDefaultSize(type) {
        const sizes = {
            stage: { width: 120, height: 80 },
            action: { width: 40, height: 40 },
            form: { width: 75, height: 96 }, // Exact size from design SVG
            decision: { width: 100, height: 100 },
            subflow: { width: 120, height: 80 },
            swimlane: { width: 0, height: 0 }, // Handled separately
            start: { width: 58, height: 46 },
        };
        return sizes[type];
    }
    // Initialization
    initializeWorkflow() {
        this.workflowState.initializeWorkflow();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFacadeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFacadeService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WorkflowFacadeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

// components/workflow/canvas/wf-canvas.component.ts
class WFCanvasComponent {
    facade;
    containerRef;
    canvasRef;
    labelService = inject(LabelManagementService);
    swimlaneStats = inject(SwimlaneStatsService);
    keyboardHandler = inject(KeyboardHandlerService);
    preconditionService = inject(NodePreconditionService);
    hoveredSegment = null;
    constructor(facade) {
        this.facade = facade;
    }
    onKeyDown(event) {
        // Only handle keyboard events if the canvas is focused
        if (this.containerRef.nativeElement.contains(document.activeElement)) {
            this.keyboardHandler.handleKeyDown(event);
        }
    }
    // Add click handler to ensure the canvas can receive keyboard events
    onClick() {
        this.containerRef.nativeElement.focus();
    }
    updateLabel(objectId, newLabel) {
        this.labelService.updateLabel(objectId, newLabel);
    }
    // Event handlers
    onMouseDown(event) {
        this.facade.handleMouseDown(event, this.canvasRef);
    }
    onMouseMove(event) {
        this.facade.handleMouseMove(event, this.canvasRef);
    }
    onMouseUp(event) {
        this.facade.handleMouseUp(event, this.canvasRef);
    }
    onMouseLeave() {
        this.facade.handleMouseLeave();
    }
    onSwimlaneAddClick(event, swimlane) {
        const rect = this.canvasRef.nativeElement.getBoundingClientRect();
        const position = {
            x: event.clientX - rect.left + 20,
            y: event.clientY - rect.top,
        };
        this.swimlaneStats.openPopup(position, swimlane.id);
    }
    onPopupAction(actionId) {
        const swimlaneId = this.swimlaneStats.popupStatus().swimlaneId;
        if (!swimlaneId)
            return;
        switch (actionId) {
            case 'add-above':
                // Handle adding swimlane above
                break;
            case 'add-below':
                // Handle adding swimlane below
                break;
            case 'delete':
                // Handle deletion
                break;
        }
    }
    getSegmentPath(start, end) {
        return `M ${start.x} ${start.y} L ${end.x} ${end.y}`;
    }
    isSegmentHovered(connectionId, index) {
        return (this.hoveredSegment?.connectionId === connectionId &&
            this.hoveredSegment?.index === index);
    }
    onSegmentMouseDown(event, connectionId, segmentIndex) {
        event.stopPropagation();
        this.facade.handleSegmentMouseDown(event, this.canvasRef, connectionId, segmentIndex);
    }
    onNodeSelected(data) {
        this.facade.finalizeNodeCreation(data);
    }
    onNodeSelectionCancelled() {
        this.facade.preconditionService.clearPendingNode();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WFCanvasComponent, deps: [{ token: WorkflowFacadeService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: WFCanvasComponent, isStandalone: true, selector: "wf-canvas", host: { listeners: { "window:keydown": "onKeyDown($event)", "click": "onClick()" } }, viewQueries: [{ propertyName: "containerRef", first: true, predicate: ["container"], descendants: true }, { propertyName: "canvasRef", first: true, predicate: ["canvas"], descendants: true }], ngImport: i0, template: `
    <div
      class="canvas-container"
      #container
      [class.connecting]="facade.canvasState().isConnecting"
      (mousedown)="onMouseDown($event)"
      (mousemove)="onMouseMove($event)"
      (mouseup)="onMouseUp($event)"
      (mouseleave)="onMouseLeave()"
    >
      <svg
        #canvas
        [attr.width]="facade.canvasState().width"
        [attr.height]="facade.canvasState().height"
      >
        <!-- Grid Pattern -->
        <defs>
          <pattern
            id="grid"
            [attr.width]="facade.canvasState().gridSize"
            [attr.height]="facade.canvasState().gridSize"
            patternUnits="userSpaceOnUse"
          >
            <path
              [attr.d]="facade.getGridPattern().path.d"
              [ngStyle]="facade.getGridPattern().path.style"
            />
          </pattern>
        </defs>

        <!-- Background grid -->
        <rect width="100%" height="100%" fill="url(#grid)" />

        <!-- Swimlanes -->
        @for (swimlane of facade.swimlanes(); track swimlane.id) {
        <g [attr.transform]="facade.getNodeTransforms(swimlane).node">
          <rect
            [attr.width]="swimlane.size.width"
            [attr.height]="swimlane.size.height"
            [ngStyle]="facade.rendering.getSwimlaneStyle()"
          />
          <!-- <text
            x="100"
            y="20"
            [ngStyle]="facade.rendering.getLabelStyle('swimlane')"
          >
            {{ swimlane.label }}
          </text> -->
          <!-- <foreignObject
            [attr.x]="labelService.getLabelPosition(swimlane).x"
            [attr.y]="labelService.getLabelPosition(swimlane).y"
            width="150"
            height="40"
            style="overflow: visible;"
          >
            <wf-label-editor
              [label]="swimlane.label || 'New Swimlane'"
              [x]="0"
              [y]="0"
              [isSwimlane]="true"
              (labelChange)="updateLabel(swimlane.id, $event)"
            />
          </foreignObject> -->

          <!-- <g
            wf-swimlane-label
            [label]="swimlane.label"
            [count]="swimlaneStats.getNodeCount(swimlane.id)"
            [x]="20"
            [y]="swimlane.size.height - 20"
            (addClick)="onSwimlaneAddClick($event, swimlane)"
            (labelChange)="updateLabel(swimlane.id, $event)"
          /> -->

          <g transform="translate(30, 20)">
            <g
              wf-swimlane-label
              [label]="swimlane.label"
              [count]="swimlaneStats.getNodeCount(swimlane.id)"
              (addClick)="onSwimlaneAddClick($event, swimlane)"
              (labelChange)="updateLabel(swimlane.id, $event)"
            />
          </g>

          <!-- <foreignObject
            [attr.x]="50"
            [attr.y]="20"
            width="150"
            height="40"
            style="overflow: visible;"
          >
            <wf-label-editor
              [label]="swimlane.label || 'New Swimlane'"
              [x]="0"
              [y]="0"
              [isSwimlane]="true"
              (labelChange)="updateLabel(swimlane.id, $event)"
            />
          </foreignObject> -->
        </g>
        }

        <!-- Connections with labels -->
        @for (connection of facade.connections(); track connection.id) {
        <g
          class="connection"
          [class.selected]="facade.selection.isSelected(connection.id)"
        >
          <!-- <path
            [attr.d]="facade.getConnectionPath(connection.points)"
            [ngStyle]="
              facade.getConnectionStyle(
                facade.selection.isSelected(connection.id)
              )
            "
          /> -->
          <!-- Complete connection path with arrowhead -->
          <path
            [attr.d]="facade.getConnectionPath(connection.points)"
            [ngStyle]="
              facade.getConnectionStyle(
                facade.selection.isSelected(connection.id)
              )
            "
          />
          <!-- Render segments -->
          @for (point of connection.points; let i = $index; track i) { @if (i <
          connection.points.length - 1) {
          <!-- Interactive segment -->
          <!-- <path
            [attr.d]="getSegmentPath(point, connection.points[i + 1])"
            [ngStyle]="
              facade.getConnectionStyle(
                facade.selection.isSelected(connection.id)
              )
            "
            [style.cursor]="facade.getSegmentCursor(connection.id, i)"
            (mousedown)="onSegmentMouseDown($event, connection.id, i)"
            class="connection-segment"
          /> -->
          <g
            class="segment-group"
            (mouseenter)="
              hoveredSegment = { connectionId: connection.id, index: i }
            "
            (mouseleave)="hoveredSegment = null"
          >
            <!-- Hit detection area -->
            <path
              [attr.d]="getSegmentPath(point, connection.points[i + 1])"
              class="segment-hitarea"
              [style.cursor]="facade.getSegmentCursor(connection.id, i)"
              (mousedown)="onSegmentMouseDown($event, connection.id, i)"
            />

            <!-- Visible segment -->
            <path
              [attr.d]="getSegmentPath(point, connection.points[i + 1])"
              [ngStyle]="
                facade.rendering.getConnectionSegmentStyle(
                  facade.selection.isSelected(connection.id),
                  isSegmentHovered(connection.id, i)
                )
              "
            />
          </g>
          } }
          <!-- Connection Label -->
          @if (connection.fromId && connection.toId) {
          <foreignObject
            [attr.x]="labelService.getLabelPosition(connection).x"
            [attr.y]="labelService.getLabelPosition(connection).y"
            width="150"
            height="40"
            style="overflow: visible; pointer-events: all;"
            [attr.transform]="'translate(-10, -10)'"
          >
            <wf-label-editor
              [label]="connection.label || 'New Action'"
              [x]="0"
              [y]="0"
              [isConnection]="true"
              (labelChange)="updateLabel(connection.id, $event)"
            />
          </foreignObject>
          }
        </g>
        }

        <!-- Nodes -->
        @for (node of facade.nodes(); track node.id) {
        <g
          [attr.transform]="facade.getNodeTransforms(node).node"
          [class.selected]="facade.selection.isSelected(node.id)"
          [class.dragging]="
            facade.canvasState().isDragging &&
            facade.selection.isSelected(node.id)
          "
        >
          @switch (node.type) { @case ('start') {
          <path
            [attr.d]="facade.getStartNodePaths().circle"
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          @if (!facade.hasOutgoingConnections(node.id)) {
          <path
            [attr.d]="facade.getStartNodePaths().arrow"
            [attr.transform]="facade.getNodeTransforms(node).arrow"
            fill="#D36CFF"
          />
          } }@case ('form') {
          <path
            [attr.d]="facade.rendering.generateNodePath(node)"
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } @case ('decision') {
          <path
            [attr.d]="
              facade.rendering.getDecisionPath(
                node.size.width,
                node.size.height
              )
            "
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } @case ('subflow') {
          <path
            [attr.d]="
              facade.rendering.getSubflowPath(node.size.width, node.size.height)
            "
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } @default {
          <rect
            [attr.width]="node.size.width"
            [attr.height]="node.size.height"
            [attr.rx]="4"
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } }

          <!-- Node label -->
          <!-- <text
            [attr.x]="node.size.width / 2"
            [attr.y]="node.size.height / 2"
            [ngStyle]="facade.rendering.getLabelStyle(node.type)"
          >
            {{ node.label }}
          </text> -->
          <foreignObject
            [attr.x]="0"
            [attr.y]="0"
            [attr.width]="node.size.width"
            [attr.height]="node.size.height"
            style="overflow: visible;"
          >
            <wf-label-editor
              [label]="node.label"
              [x]="labelService.getSVGTextPosition(node).x"
              [y]="labelService.getSVGTextPosition(node).y"
              (labelChange)="updateLabel(node.id, $event)"
            />
          </foreignObject>
        </g>
        }

        <!-- Connection preview with arrowhead -->
        @if (facade.canvasState().connectionPreview) {
        <path
          [attr.d]="facade.getConnectionPreviewPath()"
          [ngStyle]="facade.rendering.getConnectionPreviewStyle()"
        />
        }
      </svg>

      @if (swimlaneStats.popupStatus().isOpen) {
      <wf-swimlane-popup
        [position]="swimlaneStats.popupStatus().position"
        (close)="swimlaneStats.closePopup()"
        (actionSelected)="onPopupAction($event)"
      />
      }
    </div>

    <wf-node-selector
      (select)="onNodeSelected($event)"
      (cancel)="onNodeSelectionCancelled()"
    />
  `, isInline: true, styles: [".canvas-container{flex:1;overflow:auto;position:relative;background:#fff}.canvas-container.connecting{cursor:crosshair}.connection path{stroke:#d36cff;stroke-width:2;fill:none;pointer-events:none}.connection.selected path{stroke-width:3}.selected :not(text){stroke-width:3}.dragging{cursor:grabbing}.connection{pointer-events:none}.segment-group{pointer-events:all}.segment-hitarea{stroke:transparent;stroke-width:10;fill:none}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1$1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: LabelEditorComponent, selector: "wf-label-editor", inputs: ["label", "x", "y", "isConnection", "isSwimlane"], outputs: ["labelChange"] }, { kind: "component", type: SwimlaneLabelComponent, selector: "[wf-swimlane-label]", inputs: ["label", "count"], outputs: ["addClick", "labelChange"] }, { kind: "component", type: SwimLanePopupComponent, selector: "wf-swimlane-popup", inputs: ["position"], outputs: ["close", "actionSelected"] }, { kind: "component", type: NodeSelectorComponent, selector: "wf-node-selector", outputs: ["select"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WFCanvasComponent, decorators: [{
            type: Component,
            args: [{ selector: 'wf-canvas', standalone: true, imports: [
                        CommonModule,
                        LabelEditorComponent,
                        SwimlaneLabelComponent,
                        SwimLanePopupComponent,
                        NodeSelectorComponent,
                    ], template: `
    <div
      class="canvas-container"
      #container
      [class.connecting]="facade.canvasState().isConnecting"
      (mousedown)="onMouseDown($event)"
      (mousemove)="onMouseMove($event)"
      (mouseup)="onMouseUp($event)"
      (mouseleave)="onMouseLeave()"
    >
      <svg
        #canvas
        [attr.width]="facade.canvasState().width"
        [attr.height]="facade.canvasState().height"
      >
        <!-- Grid Pattern -->
        <defs>
          <pattern
            id="grid"
            [attr.width]="facade.canvasState().gridSize"
            [attr.height]="facade.canvasState().gridSize"
            patternUnits="userSpaceOnUse"
          >
            <path
              [attr.d]="facade.getGridPattern().path.d"
              [ngStyle]="facade.getGridPattern().path.style"
            />
          </pattern>
        </defs>

        <!-- Background grid -->
        <rect width="100%" height="100%" fill="url(#grid)" />

        <!-- Swimlanes -->
        @for (swimlane of facade.swimlanes(); track swimlane.id) {
        <g [attr.transform]="facade.getNodeTransforms(swimlane).node">
          <rect
            [attr.width]="swimlane.size.width"
            [attr.height]="swimlane.size.height"
            [ngStyle]="facade.rendering.getSwimlaneStyle()"
          />
          <!-- <text
            x="100"
            y="20"
            [ngStyle]="facade.rendering.getLabelStyle('swimlane')"
          >
            {{ swimlane.label }}
          </text> -->
          <!-- <foreignObject
            [attr.x]="labelService.getLabelPosition(swimlane).x"
            [attr.y]="labelService.getLabelPosition(swimlane).y"
            width="150"
            height="40"
            style="overflow: visible;"
          >
            <wf-label-editor
              [label]="swimlane.label || 'New Swimlane'"
              [x]="0"
              [y]="0"
              [isSwimlane]="true"
              (labelChange)="updateLabel(swimlane.id, $event)"
            />
          </foreignObject> -->

          <!-- <g
            wf-swimlane-label
            [label]="swimlane.label"
            [count]="swimlaneStats.getNodeCount(swimlane.id)"
            [x]="20"
            [y]="swimlane.size.height - 20"
            (addClick)="onSwimlaneAddClick($event, swimlane)"
            (labelChange)="updateLabel(swimlane.id, $event)"
          /> -->

          <g transform="translate(30, 20)">
            <g
              wf-swimlane-label
              [label]="swimlane.label"
              [count]="swimlaneStats.getNodeCount(swimlane.id)"
              (addClick)="onSwimlaneAddClick($event, swimlane)"
              (labelChange)="updateLabel(swimlane.id, $event)"
            />
          </g>

          <!-- <foreignObject
            [attr.x]="50"
            [attr.y]="20"
            width="150"
            height="40"
            style="overflow: visible;"
          >
            <wf-label-editor
              [label]="swimlane.label || 'New Swimlane'"
              [x]="0"
              [y]="0"
              [isSwimlane]="true"
              (labelChange)="updateLabel(swimlane.id, $event)"
            />
          </foreignObject> -->
        </g>
        }

        <!-- Connections with labels -->
        @for (connection of facade.connections(); track connection.id) {
        <g
          class="connection"
          [class.selected]="facade.selection.isSelected(connection.id)"
        >
          <!-- <path
            [attr.d]="facade.getConnectionPath(connection.points)"
            [ngStyle]="
              facade.getConnectionStyle(
                facade.selection.isSelected(connection.id)
              )
            "
          /> -->
          <!-- Complete connection path with arrowhead -->
          <path
            [attr.d]="facade.getConnectionPath(connection.points)"
            [ngStyle]="
              facade.getConnectionStyle(
                facade.selection.isSelected(connection.id)
              )
            "
          />
          <!-- Render segments -->
          @for (point of connection.points; let i = $index; track i) { @if (i <
          connection.points.length - 1) {
          <!-- Interactive segment -->
          <!-- <path
            [attr.d]="getSegmentPath(point, connection.points[i + 1])"
            [ngStyle]="
              facade.getConnectionStyle(
                facade.selection.isSelected(connection.id)
              )
            "
            [style.cursor]="facade.getSegmentCursor(connection.id, i)"
            (mousedown)="onSegmentMouseDown($event, connection.id, i)"
            class="connection-segment"
          /> -->
          <g
            class="segment-group"
            (mouseenter)="
              hoveredSegment = { connectionId: connection.id, index: i }
            "
            (mouseleave)="hoveredSegment = null"
          >
            <!-- Hit detection area -->
            <path
              [attr.d]="getSegmentPath(point, connection.points[i + 1])"
              class="segment-hitarea"
              [style.cursor]="facade.getSegmentCursor(connection.id, i)"
              (mousedown)="onSegmentMouseDown($event, connection.id, i)"
            />

            <!-- Visible segment -->
            <path
              [attr.d]="getSegmentPath(point, connection.points[i + 1])"
              [ngStyle]="
                facade.rendering.getConnectionSegmentStyle(
                  facade.selection.isSelected(connection.id),
                  isSegmentHovered(connection.id, i)
                )
              "
            />
          </g>
          } }
          <!-- Connection Label -->
          @if (connection.fromId && connection.toId) {
          <foreignObject
            [attr.x]="labelService.getLabelPosition(connection).x"
            [attr.y]="labelService.getLabelPosition(connection).y"
            width="150"
            height="40"
            style="overflow: visible; pointer-events: all;"
            [attr.transform]="'translate(-10, -10)'"
          >
            <wf-label-editor
              [label]="connection.label || 'New Action'"
              [x]="0"
              [y]="0"
              [isConnection]="true"
              (labelChange)="updateLabel(connection.id, $event)"
            />
          </foreignObject>
          }
        </g>
        }

        <!-- Nodes -->
        @for (node of facade.nodes(); track node.id) {
        <g
          [attr.transform]="facade.getNodeTransforms(node).node"
          [class.selected]="facade.selection.isSelected(node.id)"
          [class.dragging]="
            facade.canvasState().isDragging &&
            facade.selection.isSelected(node.id)
          "
        >
          @switch (node.type) { @case ('start') {
          <path
            [attr.d]="facade.getStartNodePaths().circle"
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          @if (!facade.hasOutgoingConnections(node.id)) {
          <path
            [attr.d]="facade.getStartNodePaths().arrow"
            [attr.transform]="facade.getNodeTransforms(node).arrow"
            fill="#D36CFF"
          />
          } }@case ('form') {
          <path
            [attr.d]="facade.rendering.generateNodePath(node)"
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } @case ('decision') {
          <path
            [attr.d]="
              facade.rendering.getDecisionPath(
                node.size.width,
                node.size.height
              )
            "
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } @case ('subflow') {
          <path
            [attr.d]="
              facade.rendering.getSubflowPath(node.size.width, node.size.height)
            "
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } @default {
          <rect
            [attr.width]="node.size.width"
            [attr.height]="node.size.height"
            [attr.rx]="4"
            [ngStyle]="
              facade.getNodeStyle(facade.selection.isSelected(node.id))
            "
          />
          } }

          <!-- Node label -->
          <!-- <text
            [attr.x]="node.size.width / 2"
            [attr.y]="node.size.height / 2"
            [ngStyle]="facade.rendering.getLabelStyle(node.type)"
          >
            {{ node.label }}
          </text> -->
          <foreignObject
            [attr.x]="0"
            [attr.y]="0"
            [attr.width]="node.size.width"
            [attr.height]="node.size.height"
            style="overflow: visible;"
          >
            <wf-label-editor
              [label]="node.label"
              [x]="labelService.getSVGTextPosition(node).x"
              [y]="labelService.getSVGTextPosition(node).y"
              (labelChange)="updateLabel(node.id, $event)"
            />
          </foreignObject>
        </g>
        }

        <!-- Connection preview with arrowhead -->
        @if (facade.canvasState().connectionPreview) {
        <path
          [attr.d]="facade.getConnectionPreviewPath()"
          [ngStyle]="facade.rendering.getConnectionPreviewStyle()"
        />
        }
      </svg>

      @if (swimlaneStats.popupStatus().isOpen) {
      <wf-swimlane-popup
        [position]="swimlaneStats.popupStatus().position"
        (close)="swimlaneStats.closePopup()"
        (actionSelected)="onPopupAction($event)"
      />
      }
    </div>

    <wf-node-selector
      (select)="onNodeSelected($event)"
      (cancel)="onNodeSelectionCancelled()"
    />
  `, styles: [".canvas-container{flex:1;overflow:auto;position:relative;background:#fff}.canvas-container.connecting{cursor:crosshair}.connection path{stroke:#d36cff;stroke-width:2;fill:none;pointer-events:none}.connection.selected path{stroke-width:3}.selected :not(text){stroke-width:3}.dragging{cursor:grabbing}.connection{pointer-events:none}.segment-group{pointer-events:all}.segment-hitarea{stroke:transparent;stroke-width:10;fill:none}\n"] }]
        }], ctorParameters: () => [{ type: WorkflowFacadeService }], propDecorators: { containerRef: [{
                type: ViewChild,
                args: ['container']
            }], canvasRef: [{
                type: ViewChild,
                args: ['canvas']
            }], onKeyDown: [{
                type: HostListener,
                args: ['window:keydown', ['$event']]
            }], onClick: [{
                type: HostListener,
                args: ['click']
            }] } });

// components/workflow/wf-designer.component.ts
class WFDesignerComponent {
    workflowId = input.required();
    facade = inject(WorkflowFacadeService);
    saving = signal(false);
    // Computed signals for reactive UI
    workflowName = computed(() => this.facade.persistence.workflowMetadata.name || 'Untitled Workflow');
    workflowDescription = computed(() => this.facade.persistence.workflowMetadata.description || '');
    isSaving = this.saving.asReadonly();
    constructor() {
        this.facade.initializeWorkflow();
    }
    ngOnInit() {
        const workflowId = this.workflowId();
        if (workflowId) {
            this.loadWorkflow(workflowId);
        }
    }
    loadWorkflow(workflowId) {
        this.facade.persistence.loadWorkflow(workflowId).catch((error) => {
            console.error('Failed to load workflow:', error);
            // Optionally show an error notification here
        });
    }
    handleToolSelection(tool) {
        this.facade.handleToolSelection(tool);
    }
    handleSave() {
        if (this.isSaving())
            return;
        this.saving.set(true);
        this.facade.persistence
            .saveWorkflow()
            .then((results) => {
            console.log('Workflow saved successfully:', results);
            // Optionally show a success notification
        })
            .catch((error) => {
            console.error('Error saving workflow:', error);
            // Optionally show an error notification
        })
            .finally(() => {
            this.saving.set(false);
        });
    }
    handleNodeSelection(data) {
        this.facade.finalizeNodeCreation(data);
    }
    handleNodeSelectionCancel() {
        // The node selection was canceled, clear the pending node
        this.facade.preconditionService.clearPendingNode();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WFDesignerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "18.2.13", type: WFDesignerComponent, isStandalone: true, selector: "wf-designer", inputs: { workflowId: { classPropertyName: "workflowId", publicName: "workflowId", isSignal: true, isRequired: true, transformFunction: null } }, providers: [EnvironmentService], ngImport: i0, template: `
    <div class="workflow-designer">
      <div class="workflow-header">
        <h1 class="workflow-title">{{ workflowName() }}</h1>
        <p *ngIf="workflowDescription()" class="workflow-description">
          {{ workflowDescription() }}
        </p>
      </div>

      <wf-toolbar
        [selectedTool]="facade.selectedTool()"
        (toolSelected)="handleToolSelection($event)"
      />

      <wf-canvas />

      <div class="workflow-actions">
        <button
          class="save-button"
          (click)="handleSave()"
          [disabled]="isSaving()"
        >
          {{ isSaving() ? 'Saving...' : 'Save' }}
        </button>
      </div>

      <!-- Node selector dialog for forms, subflows, etc. -->
      <wf-node-selector
        (select)="handleNodeSelection($event)"
        (cancel)="handleNodeSelectionCancel()"
      />
    </div>
  `, isInline: true, styles: [".workflow-designer{display:flex;flex-direction:column;height:100vh;background:#fff}.workflow-header{padding:1rem;border-bottom:1px solid #e5e7eb}.workflow-title{font-size:1.25rem;font-weight:600;color:#111827}.workflow-description{font-size:.875rem;color:#6b7280;margin-top:.25rem}.workflow-actions{padding:.75rem;border-top:1px solid #e5e7eb;display:flex;justify-content:flex-end}.save-button{padding:.5rem 1rem;background-color:#9333ea;color:#fff;font-weight:500;border-radius:.375rem;border:none;cursor:pointer;transition:background-color .2s}.save-button:hover{background-color:#7e22ce}.save-button:disabled{background-color:#d8b4fe;cursor:not-allowed}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: WFToolbarComponent, selector: "wf-toolbar", inputs: ["selectedTool"], outputs: ["toolSelected"] }, { kind: "component", type: WFCanvasComponent, selector: "wf-canvas" }, { kind: "component", type: NodeSelectorComponent, selector: "wf-node-selector", outputs: ["select"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: WFDesignerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'wf-designer', standalone: true, imports: [
                        CommonModule,
                        WFToolbarComponent,
                        WFCanvasComponent,
                        NodeSelectorComponent,
                    ], providers: [EnvironmentService], template: `
    <div class="workflow-designer">
      <div class="workflow-header">
        <h1 class="workflow-title">{{ workflowName() }}</h1>
        <p *ngIf="workflowDescription()" class="workflow-description">
          {{ workflowDescription() }}
        </p>
      </div>

      <wf-toolbar
        [selectedTool]="facade.selectedTool()"
        (toolSelected)="handleToolSelection($event)"
      />

      <wf-canvas />

      <div class="workflow-actions">
        <button
          class="save-button"
          (click)="handleSave()"
          [disabled]="isSaving()"
        >
          {{ isSaving() ? 'Saving...' : 'Save' }}
        </button>
      </div>

      <!-- Node selector dialog for forms, subflows, etc. -->
      <wf-node-selector
        (select)="handleNodeSelection($event)"
        (cancel)="handleNodeSelectionCancel()"
      />
    </div>
  `, styles: [".workflow-designer{display:flex;flex-direction:column;height:100vh;background:#fff}.workflow-header{padding:1rem;border-bottom:1px solid #e5e7eb}.workflow-title{font-size:1.25rem;font-weight:600;color:#111827}.workflow-description{font-size:.875rem;color:#6b7280;margin-top:.25rem}.workflow-actions{padding:.75rem;border-top:1px solid #e5e7eb;display:flex;justify-content:flex-end}.save-button{padding:.5rem 1rem;background-color:#9333ea;color:#fff;font-weight:500;border-radius:.375rem;border:none;cursor:pointer;transition:background-color .2s}.save-button:hover{background-color:#7e22ce}.save-button:disabled{background-color:#d8b4fe;cursor:not-allowed}\n"] }]
        }], ctorParameters: () => [] });

var OperationType;
(function (OperationType) {
    OperationType["Comment"] = "Comment";
    OperationType["Forms"] = "Forms";
    OperationType["Assignment"] = "Assignment";
})(OperationType || (OperationType = {}));

class TaskHistoryService {
    httpService;
    constructor(httpService) {
        this.httpService = httpService;
    }
    getTaskHistory(taskCode) {
        const url = `Task/GetTaskHistory/${taskCode}`;
        return this.httpService.get(url);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryService, deps: [{ token: HttpWebRequestService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: HttpWebRequestService }] });

class TaskHistoryComponent {
    _location;
    service;
    taskCode = input.required();
    operationType = OperationType;
    selectedDetail;
    showPopUp = false;
    active = 0;
    constructor(_location, service) {
        this._location = _location;
        this.service = service;
    }
    singleHistory = [
        {
            Date: '4:05 PM',
            Operation: OperationType.Comment,
            Details: {},
            Actions: [
                { Label: 'View Comments', Type: 'button', Action: 'viewComments' },
            ],
        },
        {
            Date: 'Yesterday',
            Operation: OperationType.Comment,
            Details: {},
            Actions: [
                { Label: 'View Comments', Type: 'button', Action: 'viewComments' },
            ],
        },
        {
            Date: 'Mar 2',
            Operation: OperationType.Forms,
            Details: {
                FilledBy: 'Anonymous',
            },
            Actions: [{ Label: 'View Form', Type: 'button', Action: 'viewForm' }],
        },
        {
            Date: 'Nov 4',
            Operation: OperationType.Assignment,
            Details: {
                From: 'John Doe',
                To: 'Jane Doe',
            },
            Actions: [],
        },
        {
            Date: 'Nov 6',
            Operation: OperationType.Comment,
            Details: {},
            Actions: [
                { Label: 'View Comments', Type: 'button', Action: 'viewComments' },
            ],
        },
    ];
    history = [];
    ngOnInit() {
        this.service.getTaskHistory(this.taskCode()).then((res) => {
            this.history = res;
            console.log(this.history);
        });
    }
    goBack() {
        this._location.back();
    }
    onPopUp(details) {
        this.showPopUp = true;
        this.selectedDetail = details;
    }
    offPopUp() {
        this.showPopUp = false;
        this.selectedDetail = null;
    }
    setActive(i) {
        this.active = i;
    }
    getTagsFromActor(actor) {
        return actor.Tags.map((tag) => tag.Name).join(', ');
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryComponent, deps: [{ token: i1$1.Location }, { token: TaskHistoryService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "18.2.13", type: TaskHistoryComponent, selector: "lib-task-history", inputs: { taskCode: { classPropertyName: "taskCode", publicName: "taskCode", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0, template: "<div class=\"bg-[#F9FAFB]\">\n  <header\n    class=\"mx-8 rounded-lg shadow-lg flex justify-between items-center px-6 py-2 bg-[#D4A00773]\"\n  >\n    <h4 class=\"font-semibold\">{{ taskCode() }}</h4>\n    <verben-svg\n      (click)=\"goBack()\"\n      class=\"cursor-pointer\"\n      [width]=\"17\"\n      [height]=\"17\"\n      [icon]=\"'go-back'\"\n    ></verben-svg>\n  </header>\n  <section class=\"grid grid-cols-12\">\n    <div class=\"bg-[#fff] col-span-7 pl-16 pt-20 relative\">\n      <span\n        class=\"absolute block h-[90%] border border-secondary-200 left-[150px]\"\n      ></span>\n      <div *ngFor=\"let timeline of history; let i = index\">\n        <div>\n          <div class=\"flex mb-7\">\n            <h5 class=\"w-[100px] cursor-pointer\" (click)=\"setActive(i)\">\n              {{ timeline?.CreatedAt | date }}\n            </h5>\n            <div\n              class=\"ml-24 cursor-pointer min-w-[250px] p-6 rounded-md\"\n              [ngClass]=\"{\n                'after:absolute after:-left-[90px] after:top-0 bg-[#d3d3d32a] after:h-full relative after:border-l-2':\n                  active === i,\n                'border-none': active !== i\n              }\"\n              (click)=\"setActive(i)\"\n            >\n              <h4 class=\"font-bold text-lg\">{{ timeline.ActionType }}</h4>\n              <div *ngIf=\"timeline.Description\">\n                <p class=\"my-2 text-sm text-[#667085]\">\n                  Operation:{{ timeline.ActionType }} Added\n                </p>\n                <button\n                  class=\"flex gap-2 items-center w-fit text-[#667085] text-sm border px-3 py-1 rounded-lg bg-[#FCFCFD] mt-2 border-[#E4E7EC]\"\n                >\n                  <verben-svg\n                    [width]=\"15\"\n                    [height]=\"15\"\n                    [icon]=\"'chat'\"\n                  ></verben-svg>\n                  view comments\n                </button>\n              </div>\n              <div *ngIf=\"true\">\n                <p class=\"my-2 text-sm text-[#667085]\">Operation: Pass-Back</p>\n                <div>\n                  <p class=\"text-sm\">\n                    <span class=\"text-[#667085]\">From</span>:<span\n                      class=\"ml-[3px] underline text-[#6172F3] cursor-pointer\"\n                      (mouseout)=\"offPopUp()\"\n                      (mouseover)=\"onPopUp(timeline.FromStage)\"\n                      >{{ timeline.FromStage }}</span\n                    >\n                  </p>\n                  <p class=\"text-sm mt-[4px]\">\n                    <span class=\"text-[#667085]\">To</span>:\n                    <span\n                      class=\"ml-[3px] underline text-[#6172F3] cursor-pointer\"\n                      (mouseout)=\"offPopUp()\"\n                      (mouseover)=\"onPopUp(timeline.ToStage)\"\n                      >{{ timeline.ToStage }}</span\n                    >\n                  </p>\n                  <verben-pop-Up\n                    [enableMouseLeave]=\"false\"\n                    [dropdownOpen]=\"showPopUp\"\n                  >\n                    <div\n                      dropdown-content\n                      class=\"bg-[#fff] z-[10000] border-primary border mt-2 p-6 rounded-lg w-[326px]\"\n                    >\n                      <div\n                        *ngIf=\"selectedDetail === timeline.FromStage\"\n                        class=\"\"\n                      >\n                        <div class=\"flex gap-4\">\n                          <div\n                            class=\"w-[50px] h-[50px] rounded-full bg-gradient-to-r from-[#D9AEAE] via-[#E3C79F] to-[#FFE681]\"\n                          ></div>\n                          <div>\n                            <p class=\"text-lg font-bold\">\n                              {{ timeline.FromStage }}\n                            </p>\n                            <p>{{ getTagsFromActor(timeline.Actor) }}</p>\n                          </div>\n                        </div>\n                        <!-- <p class=\"flex gap-3 mt-4\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'call'\"\n                          ></verben-svg>\n                          <span>+234- 123-456-6778</span>\n                        </p> -->\n                        <p class=\"flex gap-4 mt-2\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'mail'\"\n                          ></verben-svg>\n                          <span>{{ timeline.Actor.Identifier }}</span>\n                        </p>\n                      </div>\n                      <div *ngIf=\"selectedDetail === timeline.ToStage\" class=\"\">\n                        <div class=\"flex gap-4\">\n                          <div\n                            class=\"w-[50px] h-[50px] rounded-full bg-gradient-to-r from-[#D9AEAE] via-[#E3C79F] to-[#FFE681]\"\n                          ></div>\n                          <div>\n                            <p class=\"text-lg font-bold\">\n                              {{ timeline.ToStage }}\n                            </p>\n                            <p>{{ getTagsFromActor(timeline.Actor) }}</p>\n                          </div>\n                        </div>\n                        <!-- <p class=\"flex gap-3 mt-4\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'call'\"\n                          ></verben-svg>\n                          <span>+234- 123-456-6778</span>\n                        </p> -->\n                        <p class=\"flex gap-4 mt-2\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'mail'\"\n                          ></verben-svg>\n                          <span>{{ timeline.Actor.Identifier }}</span>\n                        </p>\n                      </div>\n                    </div>\n                  </verben-pop-Up>\n                </div>\n              </div>\n              <div *ngIf=\"timeline.Workflow\">\n                <p class=\"my-2 text-sm text-[#667085]\">\n                  Filled by: {{ timeline.Actor.Identifier }}\n                </p>\n                <button\n                  class=\"flex items-center gap-2 w-fit text-[#6172F3] text-sm border px-3 py-1 rounded-lg bg-[#FCFCFD] mt-2 border-[#E4E7EC]\"\n                >\n                  <verben-svg\n                    [width]=\"15\"\n                    [height]=\"15\"\n                    [icon]=\"'doc'\"\n                  ></verben-svg>\n                  View Forms\n                </button>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n    <div class=\"col-span-5\">\n      <div class=\"h-[50px] bg-[#fff]\"></div>\n      <div *ngIf=\"active >= 0\" class=\"w-[480px] pl-16 pt-10\">\n        <h1 class=\"font-bold text-lg py-2\">Comments</h1>\n        <p class=\"text-xs text-[#667085] text-right py-2\">\n          {{ history[active]?.CreatedAt | date }}\n        </p>\n        <div\n          class=\"bg-[#fff] text-[#101828] leading-relaxed p-8 shadow-md rounded-md\"\n        >\n          {{ history[active]?.Description }}\n        </div>\n      </div>\n    </div>\n  </section>\n</div>\n", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "pipe", type: i1$1.DatePipe, name: "date" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-task-history', template: "<div class=\"bg-[#F9FAFB]\">\n  <header\n    class=\"mx-8 rounded-lg shadow-lg flex justify-between items-center px-6 py-2 bg-[#D4A00773]\"\n  >\n    <h4 class=\"font-semibold\">{{ taskCode() }}</h4>\n    <verben-svg\n      (click)=\"goBack()\"\n      class=\"cursor-pointer\"\n      [width]=\"17\"\n      [height]=\"17\"\n      [icon]=\"'go-back'\"\n    ></verben-svg>\n  </header>\n  <section class=\"grid grid-cols-12\">\n    <div class=\"bg-[#fff] col-span-7 pl-16 pt-20 relative\">\n      <span\n        class=\"absolute block h-[90%] border border-secondary-200 left-[150px]\"\n      ></span>\n      <div *ngFor=\"let timeline of history; let i = index\">\n        <div>\n          <div class=\"flex mb-7\">\n            <h5 class=\"w-[100px] cursor-pointer\" (click)=\"setActive(i)\">\n              {{ timeline?.CreatedAt | date }}\n            </h5>\n            <div\n              class=\"ml-24 cursor-pointer min-w-[250px] p-6 rounded-md\"\n              [ngClass]=\"{\n                'after:absolute after:-left-[90px] after:top-0 bg-[#d3d3d32a] after:h-full relative after:border-l-2':\n                  active === i,\n                'border-none': active !== i\n              }\"\n              (click)=\"setActive(i)\"\n            >\n              <h4 class=\"font-bold text-lg\">{{ timeline.ActionType }}</h4>\n              <div *ngIf=\"timeline.Description\">\n                <p class=\"my-2 text-sm text-[#667085]\">\n                  Operation:{{ timeline.ActionType }} Added\n                </p>\n                <button\n                  class=\"flex gap-2 items-center w-fit text-[#667085] text-sm border px-3 py-1 rounded-lg bg-[#FCFCFD] mt-2 border-[#E4E7EC]\"\n                >\n                  <verben-svg\n                    [width]=\"15\"\n                    [height]=\"15\"\n                    [icon]=\"'chat'\"\n                  ></verben-svg>\n                  view comments\n                </button>\n              </div>\n              <div *ngIf=\"true\">\n                <p class=\"my-2 text-sm text-[#667085]\">Operation: Pass-Back</p>\n                <div>\n                  <p class=\"text-sm\">\n                    <span class=\"text-[#667085]\">From</span>:<span\n                      class=\"ml-[3px] underline text-[#6172F3] cursor-pointer\"\n                      (mouseout)=\"offPopUp()\"\n                      (mouseover)=\"onPopUp(timeline.FromStage)\"\n                      >{{ timeline.FromStage }}</span\n                    >\n                  </p>\n                  <p class=\"text-sm mt-[4px]\">\n                    <span class=\"text-[#667085]\">To</span>:\n                    <span\n                      class=\"ml-[3px] underline text-[#6172F3] cursor-pointer\"\n                      (mouseout)=\"offPopUp()\"\n                      (mouseover)=\"onPopUp(timeline.ToStage)\"\n                      >{{ timeline.ToStage }}</span\n                    >\n                  </p>\n                  <verben-pop-Up\n                    [enableMouseLeave]=\"false\"\n                    [dropdownOpen]=\"showPopUp\"\n                  >\n                    <div\n                      dropdown-content\n                      class=\"bg-[#fff] z-[10000] border-primary border mt-2 p-6 rounded-lg w-[326px]\"\n                    >\n                      <div\n                        *ngIf=\"selectedDetail === timeline.FromStage\"\n                        class=\"\"\n                      >\n                        <div class=\"flex gap-4\">\n                          <div\n                            class=\"w-[50px] h-[50px] rounded-full bg-gradient-to-r from-[#D9AEAE] via-[#E3C79F] to-[#FFE681]\"\n                          ></div>\n                          <div>\n                            <p class=\"text-lg font-bold\">\n                              {{ timeline.FromStage }}\n                            </p>\n                            <p>{{ getTagsFromActor(timeline.Actor) }}</p>\n                          </div>\n                        </div>\n                        <!-- <p class=\"flex gap-3 mt-4\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'call'\"\n                          ></verben-svg>\n                          <span>+234- 123-456-6778</span>\n                        </p> -->\n                        <p class=\"flex gap-4 mt-2\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'mail'\"\n                          ></verben-svg>\n                          <span>{{ timeline.Actor.Identifier }}</span>\n                        </p>\n                      </div>\n                      <div *ngIf=\"selectedDetail === timeline.ToStage\" class=\"\">\n                        <div class=\"flex gap-4\">\n                          <div\n                            class=\"w-[50px] h-[50px] rounded-full bg-gradient-to-r from-[#D9AEAE] via-[#E3C79F] to-[#FFE681]\"\n                          ></div>\n                          <div>\n                            <p class=\"text-lg font-bold\">\n                              {{ timeline.ToStage }}\n                            </p>\n                            <p>{{ getTagsFromActor(timeline.Actor) }}</p>\n                          </div>\n                        </div>\n                        <!-- <p class=\"flex gap-3 mt-4\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'call'\"\n                          ></verben-svg>\n                          <span>+234- 123-456-6778</span>\n                        </p> -->\n                        <p class=\"flex gap-4 mt-2\">\n                          <verben-svg\n                            [width]=\"17\"\n                            [height]=\"17\"\n                            [icon]=\"'mail'\"\n                          ></verben-svg>\n                          <span>{{ timeline.Actor.Identifier }}</span>\n                        </p>\n                      </div>\n                    </div>\n                  </verben-pop-Up>\n                </div>\n              </div>\n              <div *ngIf=\"timeline.Workflow\">\n                <p class=\"my-2 text-sm text-[#667085]\">\n                  Filled by: {{ timeline.Actor.Identifier }}\n                </p>\n                <button\n                  class=\"flex items-center gap-2 w-fit text-[#6172F3] text-sm border px-3 py-1 rounded-lg bg-[#FCFCFD] mt-2 border-[#E4E7EC]\"\n                >\n                  <verben-svg\n                    [width]=\"15\"\n                    [height]=\"15\"\n                    [icon]=\"'doc'\"\n                  ></verben-svg>\n                  View Forms\n                </button>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n    <div class=\"col-span-5\">\n      <div class=\"h-[50px] bg-[#fff]\"></div>\n      <div *ngIf=\"active >= 0\" class=\"w-[480px] pl-16 pt-10\">\n        <h1 class=\"font-bold text-lg py-2\">Comments</h1>\n        <p class=\"text-xs text-[#667085] text-right py-2\">\n          {{ history[active]?.CreatedAt | date }}\n        </p>\n        <div\n          class=\"bg-[#fff] text-[#101828] leading-relaxed p-8 shadow-md rounded-md\"\n        >\n          {{ history[active]?.Description }}\n        </div>\n      </div>\n    </div>\n  </section>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i1$1.Location }, { type: TaskHistoryService }] });

class TaskHistoryModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryModule, declarations: [TaskHistoryComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule], exports: [TaskHistoryComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskHistoryModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TaskHistoryComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        DataTableModule,
                        SvgModule,
                        VerbenPopUpModule
                    ],
                    exports: [TaskHistoryComponent],
                }]
        }] });

const baseStyle$2 = {
    width: '100%',
    fontFamily: '"Fraunces", serif',
    fontSize: '125%',
    whiteSpace: 'nowrap',
    margin: '0',
    border: '1px solid #D4A007',
    borderRadius: '16px',
    borderCollapse: 'separate',
    borderSpacing: '0',
    // tableLayout: 'fixed',
    overflow: 'hidden',
    rows: {
        even: {
            backgroundColor: '#FDFDFD',
        },
        odd: {
            backgroundColor: '#F1F4FB',
        },
        height: '68px',
    },
    cells: {
        padding: '0.5rem 1rem',
    },
    header: {
        // stickyTop: true,
        // zIndex: 2,
        backgroundColor: '#EFF2FB',
        fontWeight: 'bold',
        textAlign: 'left',
        padding: '12px 16px',
        height: '30px',
    },
    footer: {
        // stickyBottom: true,
        // zIndex: 2,
        padding: '3px',
    },
    //   body: {
    //     background: '#fff',
    //     padding: '4px 5px',
    //     textAlign: 'center',
    //   },
    // firstColumn: {
    //   stickyLeft: true,
    //   zIndex: 1,
    // },
    lastColumn: {
    // stickyRight: true,
    // zIndex: 1,
    },
};

let FormsService$1 = class FormsService {
    constructor() { }
    get formColumns() {
        return [
            {
                id: 'select',
                header: '',
            },
            {
                id: 'createdAt',
                header: 'DATE',
                accessorKey: 'CreatedAt',
            },
            {
                id: 'name',
                header: 'NAME',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'groups',
                header: 'FORM GROUPS',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'expiry',
                header: 'EXPIRY DATE',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'anonymous',
                header: 'ANONYMOUS',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'actions',
                header: 'ACTIONS',
                accessorFn: (row) => {
                    return row;
                },
            },
        ];
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsService, providedIn: 'root' });
};
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsService$1, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [] });

var FormPropertyName;
(function (FormPropertyName) {
    FormPropertyName["Name"] = "Name";
    FormPropertyName["CreatedAt"] = "Created At";
    FormPropertyName["Anonymous"] = "Anonymous";
    FormPropertyName["ExpiryDate"] = "Expiry Date";
})(FormPropertyName || (FormPropertyName = {}));
var FormPropertyMap;
(function (FormPropertyMap) {
    FormPropertyMap["Name"] = "Name";
    FormPropertyMap["CreatedAt"] = "CreatedAt";
    FormPropertyMap["Anonymous"] = "AllowAnonymous";
    FormPropertyMap["ExpiryDate"] = "ExpiryDate";
})(FormPropertyMap || (FormPropertyMap = {}));
var FilterTypes$4;
(function (FilterTypes) {
    FilterTypes["Before"] = "LT";
    FilterTypes["On"] = "EQ";
    FilterTypes["After"] = "GT";
    FilterTypes["NEQ"] = "NEQ";
})(FilterTypes$4 || (FilterTypes$4 = {}));
class FormsComponent {
    utilService;
    server;
    cdr;
    fb;
    envSvc;
    formsSvc;
    visibleColumnDef = [];
    styles = baseStyle$2;
    data = [];
    cardData = [];
    currentData = null;
    cardDataView;
    dataView;
    tableView;
    popUps;
    pageSize = 10;
    searchDebounceTime = 500;
    pageState = null;
    isOpen = false;
    openDropdownId = null;
    isGroupOpen = false;
    openGroupDropdownId = null;
    currentFilters = [];
    currentSorts = [];
    searchTerm$ = new Subject();
    groups = [];
    visibleColumns = [];
    filterArray = [
        {
            name: FormPropertyName.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormPropertyName.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
        {
            name: FormPropertyName.Anonymous,
            type: DataFilterType.Bool,
            checked: false,
        },
        {
            name: FormPropertyName.ExpiryDate,
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    sortOptions = [
        {
            name: FormPropertyName.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormPropertyName.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
        {
            name: FormPropertyName.Anonymous,
            type: DataFilterType.Bool,
            checked: false,
        },
        {
            name: FormPropertyName.ExpiryDate,
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    currentSearchTerm = '';
    constructor(utilService, server, cdr, fb, envSvc, formsSvc) {
        this.utilService = utilService;
        this.server = server;
        this.cdr = cdr;
        this.fb = fb;
        this.envSvc = envSvc;
        this.formsSvc = formsSvc;
        this.visibleColumnDef = formsSvc.formColumns;
        this.visibleColumns = formsSvc.formColumns.map((col) => ({
            checked: true,
            name: typeof col.header === 'string' ? col.header : col.id,
            type: DataFilterType.Bool,
        }));
    }
    async ngOnInit() {
        this.getFormEntities().then((res) => {
            if (res) {
                this.groups = res;
            }
        });
        const forms = await this.getAllForms();
        if (forms) {
            this.data = forms.map((x) => {
                return {
                    ...x,
                    Id: x.Code,
                    id: x.Code,
                    ExpiryDate: new Date(x.ExpiryDate.toString()),
                    Entities: x.Entities.map((y) => {
                        return {
                            ...y,
                            DataState: ObjectState.Unchanged,
                        };
                    }),
                };
            });
            this.setUpCardData();
        }
        this.searchTerm$
            .pipe(debounceTime(this.searchDebounceTime)) // Adjust debounce time here (in ms)
            .subscribe(async (searchTerm) => {
            this.currentSearchTerm = searchTerm;
            this.updateFiltersAndSorts(true);
        });
    }
    async getFormEntities() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`Form/GetFormEntities/0/${this.pageSize}`);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async loadMoreFormEntities(event) {
        const res = await this.server.get(`Form/GetFormEntities/${event.loadTimes * this.pageSize}/${this.pageSize}`);
        if (res instanceof ErrorResponse) {
            return [];
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async searchFormEntities(data, event) {
        const res = await this.server.get(`Form/GetFormEntitiesWithParam/${data}/${event.loadTimes * this.pageSize}/${this.pageSize}`);
        if (res instanceof ErrorResponse) {
            return [];
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async getAsyncLabel(value) {
        return value ? value.Name : '';
    }
    async getAllForms() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`Form/GetForms/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            return result;
        }
    }
    async loadMore() {
        if (!this.pageState) {
            return;
        }
        this.utilService.sendBI(true);
        const res = this.currentFilters.length > 0 ||
            this.currentSorts.length > 0 ||
            this.currentSearchTerm.trim().length > 0
            ? await this.loadMoreFiltersAndSorts()
            : await this.server.get(`Form/GetForms/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = this.data.concat(result.map((x) => {
                return {
                    ...x,
                    id: x.Code,
                    Id: x.Code
                };
            }));
            this.setUpCardDataExtra(result);
        }
    }
    setUpCardData() {
        const cardData = this.data.map((x) => {
            return {
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = cardData;
    }
    setUpCardDataExtra(baseData) {
        const cardData = baseData.map((x) => {
            return {
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = this.cardData.concat(cardData);
    }
    goToCardView(data) {
        const item = this.cardData.find((x) => x.data == data);
        if (item) {
            this.formCardClicked(item, true);
        }
    }
    goToTableView() {
        if (!this.currentData) {
            return;
        }
        this.dataView.toggleView();
        const id = this.currentData.data ? this.currentData.data.Id : '';
        if (id.trim().length > 0 && !this.tableView.isRowEditing(id)) {
            this.tableView.toggleRowEdit(id);
        }
    }
    viewResponses(code) {
        if (code.trim().length == 0) {
            return;
        }
        // this.onViewProcessClicked.emit(code);
        this.closePopUp();
    }
    formCardClicked(item, toggleView = false) {
        this.currentData = this.cardDataView.onItemClick(item);
        if (toggleView) {
            this.dataView.toggleView();
        }
    }
    async saveForm() {
        if (this.currentData) {
            var form = this.currentData.data;
            if (this.currentData.data.Name.trim().length == 0) {
                this.utilService.showInfo('Name cannot be empty');
                return;
            }
            form.DataState =
                form.DataState == ObjectState.New
                    ? ObjectState.New
                    : ObjectState.Changed;
            form.Id = '';
            this.utilService.sendBI(true);
            const res = await this.server.post(`Form/SaveForms`, [form], this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
            }
            else {
                this.utilService.showSuccess('Form saved successfully');
                const result = res;
                if (result.length > 0) {
                    var userResult = result[0];
                    const itemIndex = this.data.findIndex((x) => x == this.currentData?.data);
                    if (itemIndex > -1) {
                        this.data[itemIndex].Code = userResult.Code;
                        this.data[itemIndex].Id = userResult.Code;
                        this.data[itemIndex].id = userResult.Code;
                        this.data[itemIndex].DataState = userResult.DataState;
                        this.data[itemIndex].TenantId = userResult.TenantId;
                        this.data[itemIndex].ServiceName = userResult.ServiceName;
                        this.data = this.data.map((x) => x);
                    }
                }
            }
        }
    }
    async tableSaveForm(form, callBack) {
        if (form.Name.trim().length == 0) {
            this.utilService.showInfo('Name cannot be empty');
            return;
        }
        form.DataState =
            form.DataState == ObjectState.New ? ObjectState.New : ObjectState.Changed;
        form.Id = '';
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SaveForms`, [form], this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
        }
        else {
            this.utilService.showSuccess('Form saved successfully');
            const result = res;
            if (result.length > 0) {
                var userResult = result[0];
                const itemIndex = this.data.findIndex((x) => x == form);
                if (itemIndex > -1) {
                    this.data[itemIndex].Code = userResult.Code;
                    this.data[itemIndex].Id = userResult.Code;
                    this.data[itemIndex].id = userResult.Code;
                    this.data[itemIndex].DataState = userResult.DataState;
                    this.data[itemIndex].TenantId = userResult.TenantId;
                    this.data[itemIndex].ServiceName = userResult.ServiceName;
                    this.data = this.data.map((x) => x);
                }
                callBack();
            }
        }
    }
    updateTable() {
        this.data = this.data.map((x) => x);
    }
    updateItem(value, key) {
        return {
            [key]: value,
        };
    }
    closePopUp() {
        this.openDropdownId = null;
        this.popUps.forEach((popUp) => {
            if (popUp.dropdownOpen) {
                popUp.toggleDropdown();
            }
        });
    }
    closeGroupPopUp() {
        this.openGroupDropdownId = null;
    }
    onViewChange(isGridView) { }
    onStateChange(event) {
        switch (event.key) {
            case 'create':
                var newForm = {
                    Name: '',
                    TenantId: '',
                    ServiceName: '',
                    id: (this.cardData.length + 1).toString(),
                    Id: (this.cardData.length + 1).toString(),
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                    Code: '',
                    Entities: [],
                    IsValid: false,
                    AllowAnonymous: false,
                    Workflow: '',
                    URL: '',
                    Duration: 0,
                    ExpiryDate: new Date(),
                    FormValuesModified: false,
                };
                const cardData = {
                    selected: false,
                    title: newForm.Name,
                    data: newForm,
                    body: [],
                    children: [],
                };
                this.data = this.data.concat([newForm]);
                this.cardData.push(cardData);
                this.formCardClicked(cardData);
                this.dataView.isTableView = false;
                break;
            default:
                break;
        }
    }
    showTableView = false;
    onSelectionChange(selectedRows) { }
    onColumnsUpdated(updatedColumns) {
        const updatedColumnDef = [];
        updatedColumns.forEach((col) => {
            const matchingCol = this.formsSvc.formColumns.find((column) => column.header === col.name || column.id === col.name);
            if (matchingCol) {
                updatedColumnDef.push(matchingCol);
            }
        });
        this.visibleColumnDef = [...updatedColumnDef];
    }
    async updateFiltersAndSorts(isSearch = false) {
        if (!isSearch) {
            this.dataView.onClearSearch();
            this.currentSearchTerm = '';
            this.cdr.detectChanges();
            const clickEvent = new MouseEvent('click', {
                bubbles: true,
                cancelable: true,
                view: window,
            });
            document.dispatchEvent(clickEvent);
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: FormPropertyMap[x.name.split(' ').join('')],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$4).includes(x.condition)
                    ? FilterTypes$4[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == FormPropertyName.CreatedAt ||
                    x.name == FormPropertyName.ExpiryDate
                    ? SearchPropertyValueType.Date
                    : x.name == FormPropertyName.Anonymous
                        ? SearchPropertyValueType.Bool
                        : SearchPropertyValueType.String,
            };
        });
        // payload.push({
        //   PropertyName: 'APIKey',
        //   EntityValue: this.envSvc.environment.APIKey,
        //   Operator: SearchOperator.And,
        //   Sign: SearchPropertySign.EQ,
        // });
        for (let sort of this.currentSorts) {
            payload.push({
                PropertyName: FormPropertyMap[sort.name.split(' ').join('')],
                EntityValue: '',
                Operator: SearchOperator.And,
                Sign: SearchPropertySign.EQ,
                Sort: sort.value.toLowerCase() == SortDirection.Asc.toLowerCase()
                    ? SortDirection.Asc
                    : sort.value.toLowerCase() == SortDirection.Desc.toLowerCase()
                        ? SortDirection.Desc
                        : SortDirection.None,
            });
        }
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Form/GetFormWithParam/${this.currentSearchTerm.trim()}/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : payload.length == 0
                ? await this.server.get(`Form/GetForms/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
                : await this.server.post(`Form/SearchForms/0/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            this.currentFilters = [];
            this.currentSorts = [];
            return undefined;
        }
        else {
            this.cardDataView.clearData();
            this.currentData = null;
            this.pageState = res;
            var result = res.Result;
            this.data = result.map((x) => {
                return {
                    ...x,
                    Id: x.Code,
                    id: x.Code,
                };
            });
            this.setUpCardData();
        }
    }
    async loadMoreFiltersAndSorts() {
        if (!this.pageState) {
            return;
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: FormPropertyMap[x.name.split(' ').join('')],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$4).includes(x.condition)
                    ? FilterTypes$4[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == FormPropertyName.CreatedAt ||
                    x.name == FormPropertyName.ExpiryDate
                    ? SearchPropertyValueType.Date
                    : x.name == FormPropertyName.Anonymous
                        ? SearchPropertyValueType.Bool
                        : SearchPropertyValueType.String,
            };
        });
        for (let sort of this.currentSorts) {
            payload.push({
                PropertyName: FormPropertyMap[sort.name.split(' ').join('')],
                EntityValue: '',
                Operator: SearchOperator.And,
                Sign: SearchPropertySign.EQ,
                Sort: sort.value.toLowerCase() == SortDirection.Asc.toLowerCase()
                    ? SortDirection.Asc
                    : sort.value.toLowerCase() == SortDirection.Desc.toLowerCase()
                        ? SortDirection.Desc
                        : SortDirection.None,
            });
        }
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Form/GetFormWithParam/${this.currentSearchTerm.trim()}/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : payload.length == 0
                ? await this.server.get(`Form/GetForms/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
                : await this.server.post(`Form/SearchForms/${this.pageState.Skip}/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            var result = res;
            return result;
        }
    }
    onFilterUpdated(updatedFilters) {
        // Ensure updatedFilters is an array
        if (Array.isArray(updatedFilters)) {
            this.currentFilters = updatedFilters;
            this.updateFiltersAndSorts();
        }
    }
    onSortUpdated(updatedSorts) {
        this.currentSorts = updatedSorts;
        this.updateFiltersAndSorts();
    }
    handleSearch(event) {
        this.searchTerm$.next(event.value);
    }
    handleExport(exportedData) {
        // console.log('Exported data:', exportedData);
        this.downloadCSV(exportedData);
    }
    downloadCSV(data) {
        const headers = Object.keys(data[0]);
        const csvContent = [
            headers.join(','),
            ...data.map((row) => headers.map((header) => row[header]).join(',')),
        ].join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'export.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsComponent, deps: [{ token: UtilService }, { token: HttpWebRequestService }, { token: i0.ChangeDetectorRef }, { token: i1$2.FormBuilder }, { token: EnvironmentService }, { token: FormsService$1 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FormsComponent, selector: "lib-forms", inputs: { pageSize: "pageSize", searchDebounceTime: "searchDebounceTime" }, viewQueries: [{ propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }, { propertyName: "tableView", first: true, predicate: ["dt"], descendants: true }, { propertyName: "popUps", predicate: ["popup"], descendants: true }], ngImport: i0, template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n\n  <verben-data-view #vdv [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: true,\n      isToggle:true,\n    }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"0\" [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\" (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\"\n    (onSearchChange)=\"handleSearch($event)\">\n    <div class=\"mt-2\" table-content>\n      <lib-data-table [dataKey]=\"'Id'\" class=\"form-table\" #dt [data]=\"data\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\">\n        <ng-container libColumn=\"select\">\n          <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n            <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n          </ng-template>\n          <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n            let-toggleAllRows=\"toggleAllRows\">\n            <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n              (change)=\"toggleAllRows()\" />\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"createdAt\">\n          <ng-template #cell let-value>\n            {{ value | date }}\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"name\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{value.Name}}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <div class=\"width-max\">\n              <verbena-input [(ngModel)]=\"value.Name\"></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"groups\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <div class=\"flex flex-col gap-1\">\n              <div class=\"groups-summary-container gap-2\">\n                <div *ngFor=\"let group of value.Entities.slice(0, 4)\" class=\"group-chip px-2\">\n                  {{group.Name}}\n                </div>\n              </div>\n              <verben-pop-Up *ngIf=\"value.Entities.length > 3\" [customStyles]=\"{'z-index': '99'}\"\n                [enableMouseLeave]=\"false\">\n                <span class=\"see-more-section flex\" dropdown-trigger>\n                  <div>See more</div>\n                  <verben-svg icon=\"chevron-down\" fill=\"#3479E9\" [width]=\"10\" [height]=\"6\"></verben-svg>\n                </span>\n                <div class=\"groups-summary-container pop-up gap-2 p-2\" dropdown-content>\n                  <div class=\"group-chip px-2\" *ngFor=\"let group of value.Entities\">\n                    {{group.Name}}\n                  </div>\n                </div>\n              </verben-pop-Up>\n            </div>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <verben-drop-down selectKey=\"Code\" display=\"chip\" width=\"100%\" placeholder=\"Select Groups\"\n              [showClear]=\"true\" [filter]=\"true\" [load]=\"this.loadMoreFormEntities.bind(this)\"\n              [search]=\"this.searchFormEntities.bind(this)\" [(options)]=\"groups\" optionLabel=\"Name\" [multiselect]=\"true\"\n              [(ngModel)]=\"value.Entities\" [lazyLoad]=\"true\" [asyncLabel]=\"this.getAsyncLabel.bind(this)\">\n\n            </verben-drop-down>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"expiry\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{value.ExpiryDate | date}}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <div class=\"width-max\">\n              <input class=\"date-picker\" type=\"date\" [(ngModel)]=\"value.ExpiryDate\" />\n              <!-- <verbena-input [(ngModel)]=\"value.ExpiryDate\"></verbena-input> -->\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"anonymous\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <verben-svg [width]=\"15\" [height]=\"15\" [icon]=\"value.IsProtected? 'on':'off'\"></verben-svg>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <verbena-switch onText=\"\" offText=\"\" [(ngModel)]=\"value.AllowAnonymous\"\n              [onColor]=\"'#1A237E'\"></verbena-switch>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <verben-pop-Up #popup [customStyles]=\"{'z-index': '99'}\" [enableMouseLeave]=\"false\">\n              <verben-svg class=\"cursor-pointer actions-icon\" dropdown-trigger icon=\"list\"></verben-svg>\n              <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                <div (click)=\"viewResponses(value.Code)\" class=\"pop-up-value cursor-pointer\">View responses</div>\n                <div (click)=\"toggleRowEdit(); closePopUp();\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                <div class=\"pop-up-value cursor-pointer\">Delete</div>\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <div class=\"flex gap-2 items-center\">\n              <verben-svg icon=\"tick\" [width]=\"15\" [height]=\"15\"\n                (click)=\"tableSaveForm(value, toggleRowEdit)\"></verben-svg>\n              <verben-svg (click)=\"toggleRowEdit()\" icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n              <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view borderRadius=\"12px\" #vdcv dataId=\"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n        rbgColor=\"#f5f6f9\" mg=\"0px\">\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId=\"MailAddress\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n            <ng-template #card let-item>\n              <div (click)=\"formCardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                  [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                  class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                <div class=\"flex  w-full bg-secondary rounded-xl\">\n                  <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"></div>\n                  <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                    <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                      <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                        <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">{{\n                          item.data.Name\n                          }}</h3>\n                        <span class=\"flex items-center gap-1\">\n                          <span class=\"!text-[10px] font-light text-[#404040]\">Expiry Date:</span> <span\n                            class=\"!text-[12px]\">{{item.data.ExpiryDate | date}}</span>\n                        </span>\n                      </div>\n\n                      <div class=\"flex items-end h-[100%]\">\n                        <!-- <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span> -->\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <div *ngIf=\"this.currentData\"\n              class=\"flex flex-col rounded-xl h-full w-full justify-between relative space-y-4\">\n              <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"this.currentData.data.Name\" />\n              <div class=\"flex flex-col gap-1\">\n                <div>Expiry Date</div>\n                <input class=\"date-picker\" type=\"date\" [(ngModel)]=\"this.currentData.data.ExpiryDate\" />\n              </div>\n              <!-- <verbena-input name=\"ExpiryDate\" label=\"Expiry Date\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"this.currentData.data.ExpiryDate\" /> -->\n              <div class=\"flex flex-col gap-1\">\n                <div>Anonymous</div>\n                <verbena-switch onText=\"\" offText=\"\" [(ngModel)]=\"this.currentData.data.AllowAnonymous\"\n                  [onColor]=\"'#1A237E'\"></verbena-switch>\n              </div>\n              <div class=\"flex flex-col gap-1\">\n                <div>Form Groups</div>\n                <verben-drop-down selectKey=\"Code\" display=\"chip\" width=\"100%\" placeholder=\"Select Groups\"\n                  [showClear]=\"true\" [filter]=\"true\" [load]=\"this.loadMoreFormEntities.bind(this)\"\n                  [search]=\"this.searchFormEntities.bind(this)\" [(options)]=\"groups\" optionLabel=\"Name\"\n                  [multiselect]=\"true\" [(ngModel)]=\"this.currentData.data.Entities\" [lazyLoad]=\"true\"\n                  [asyncLabel]=\"this.getAsyncLabel.bind(this)\">\n\n                </verben-drop-down>\n              </div>\n\n              <!-- buttons -->\n              <div class=\"flex justify-between bottom-8 left-0 right-0\">\n                <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button>\n                <div class=\"flex gap-3\">\n                  <verbena-button class=\"verben-switch-button\"\n                    (click)=\"viewResponses(this.currentData? this.currentData.data? this.currentData.data.Code: '':'')\"\n                    text=\"View Responses\"></verbena-button>\n                  <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                    text=\"Switch To Table\"></verbena-button>\n                  <verbena-button class=\"verben-primary-button\" (click)=\"this.saveForm()\" text=\"Save\"></verbena-button>\n                </div>\n              </div>\n            </div>\n\n          </ng-template>\n        </verben-right-card-data-view>\n        <!-- <verben-right-card-data-view>\n          yeshhhhhh\n        </verben-right-card-data-view> -->\n\n        <verben-card-data-view-footer>\n          <div class=\"flex gap-2 justify-between\">\n            <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n              <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                [text]=\"'Delete'\">\n              </verbena-button>\n            </div>\n            <div class=\"flex {{vdcv.hasCurrentItem()?'flex-1':''}} justify-end items-center gap-5\">\n              <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n              <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <verben-visible-column (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"></verben-visible-column>\n    </div>\n    <div filter-content>\n      <verben-table-filter (filtersApplied)=\"onFilterUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"></verben-table-filter>\n    </div>\n    <div sort-content>\n      <verben-sort-table (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"></verben-sort-table>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n        [text]=\"'Delete'\">\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n      <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n    </div>\n  </div>\n</div>\n", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.groups-summary-container{display:grid;grid-template-columns:repeat(2,1fr)}.groups-summary-container.pop-up{border:1px solid rgba(212,161,7,.5);border-radius:4px;width:27vw;min-width:250px;max-width:300px;background-color:#fff;max-height:400px;overflow-y:auto}.group-chip{background-color:#3479e980;text-align:center;border-radius:5px;font-weight:500;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.see-more-section{justify-content:right;gap:2px;align-items:center;cursor:pointer}.see-more-section>div{font-size:14px;color:#3479e9}.see-more-section:hover>div{text-decoration:underline;text-underline-offset:2px}.date-picker{padding:8px;border:1px solid #cbd5e1;background-color:inherit;border-radius:4px}::ng-deep .form-table>table>tbody>tr>td:nth-child(4){width:25%}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.SortTableComponent, selector: "verben-sort-table", inputs: ["enableDragAndDrop", "sortOptions", "resetText", "displayedOptions", "propertyText", "showMoreText", "sortButtonText", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "containerHeight"], outputs: ["selectedOptions", "resetSortData"] }, { kind: "component", type: i8.VisibleColumnComponent, selector: "verben-visible-column", inputs: ["columns", "items", "enableDragAndDrop", "displayedColumns", "showMore", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "closeColumn"], outputs: ["columnsUpdated", "resetFilter"] }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "directive", type: i1$2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.VerbenaSwitchComponent, selector: "verbena-switch", inputs: ["label", "checked", "disabled", "offColor", "onColor", "onText", "offText", "width", "height", "customStyles"], outputs: ["change"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "pipe", type: i1$1.DatePipe, name: "date" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-forms', template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n\n  <verben-data-view #vdv [viewState]=\"{\n      isSearch: true,\n      isColumn: true,\n      isFilter: true,\n      isSort: true,\n      isExport: true,\n      isSelect: true,\n      isCreate: true,\n      isToggle:true,\n    }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n    [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"0\" [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\" (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\"\n    (onSearchChange)=\"handleSearch($event)\">\n    <div class=\"mt-2\" table-content>\n      <lib-data-table [dataKey]=\"'Id'\" class=\"form-table\" #dt [data]=\"data\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\">\n        <ng-container libColumn=\"select\">\n          <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n            <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n          </ng-template>\n          <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n            let-toggleAllRows=\"toggleAllRows\">\n            <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n              (change)=\"toggleAllRows()\" />\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"createdAt\">\n          <ng-template #cell let-value>\n            {{ value | date }}\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"name\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{value.Name}}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <div class=\"width-max\">\n              <verbena-input [(ngModel)]=\"value.Name\"></verbena-input>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"groups\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <div class=\"flex flex-col gap-1\">\n              <div class=\"groups-summary-container gap-2\">\n                <div *ngFor=\"let group of value.Entities.slice(0, 4)\" class=\"group-chip px-2\">\n                  {{group.Name}}\n                </div>\n              </div>\n              <verben-pop-Up *ngIf=\"value.Entities.length > 3\" [customStyles]=\"{'z-index': '99'}\"\n                [enableMouseLeave]=\"false\">\n                <span class=\"see-more-section flex\" dropdown-trigger>\n                  <div>See more</div>\n                  <verben-svg icon=\"chevron-down\" fill=\"#3479E9\" [width]=\"10\" [height]=\"6\"></verben-svg>\n                </span>\n                <div class=\"groups-summary-container pop-up gap-2 p-2\" dropdown-content>\n                  <div class=\"group-chip px-2\" *ngFor=\"let group of value.Entities\">\n                    {{group.Name}}\n                  </div>\n                </div>\n              </verben-pop-Up>\n            </div>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <verben-drop-down selectKey=\"Code\" display=\"chip\" width=\"100%\" placeholder=\"Select Groups\"\n              [showClear]=\"true\" [filter]=\"true\" [load]=\"this.loadMoreFormEntities.bind(this)\"\n              [search]=\"this.searchFormEntities.bind(this)\" [(options)]=\"groups\" optionLabel=\"Name\" [multiselect]=\"true\"\n              [(ngModel)]=\"value.Entities\" [lazyLoad]=\"true\" [asyncLabel]=\"this.getAsyncLabel.bind(this)\">\n\n            </verben-drop-down>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"expiry\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{value.ExpiryDate | date}}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <div class=\"width-max\">\n              <input class=\"date-picker\" type=\"date\" [(ngModel)]=\"value.ExpiryDate\" />\n              <!-- <verbena-input [(ngModel)]=\"value.ExpiryDate\"></verbena-input> -->\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"anonymous\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <verben-svg [width]=\"15\" [height]=\"15\" [icon]=\"value.IsProtected? 'on':'off'\"></verben-svg>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n            <verbena-switch onText=\"\" offText=\"\" [(ngModel)]=\"value.AllowAnonymous\"\n              [onColor]=\"'#1A237E'\"></verbena-switch>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <verben-pop-Up #popup [customStyles]=\"{'z-index': '99'}\" [enableMouseLeave]=\"false\">\n              <verben-svg class=\"cursor-pointer actions-icon\" dropdown-trigger icon=\"list\"></verben-svg>\n              <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                <div (click)=\"viewResponses(value.Code)\" class=\"pop-up-value cursor-pointer\">View responses</div>\n                <div (click)=\"toggleRowEdit(); closePopUp();\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                <div class=\"pop-up-value cursor-pointer\">Delete</div>\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <div class=\"flex gap-2 items-center\">\n              <verben-svg icon=\"tick\" [width]=\"15\" [height]=\"15\"\n                (click)=\"tableSaveForm(value, toggleRowEdit)\"></verben-svg>\n              <verben-svg (click)=\"toggleRowEdit()\" icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n              <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view borderRadius=\"12px\" #vdcv dataId=\"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n        rbgColor=\"#f5f6f9\" mg=\"0px\">\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId=\"MailAddress\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n            <ng-template #card let-item>\n              <div (click)=\"formCardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                  [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                  class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                <div class=\"flex  w-full bg-secondary rounded-xl\">\n                  <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"></div>\n                  <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                    <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                      <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                        <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">{{\n                          item.data.Name\n                          }}</h3>\n                        <span class=\"flex items-center gap-1\">\n                          <span class=\"!text-[10px] font-light text-[#404040]\">Expiry Date:</span> <span\n                            class=\"!text-[12px]\">{{item.data.ExpiryDate | date}}</span>\n                        </span>\n                      </div>\n\n                      <div class=\"flex items-end h-[100%]\">\n                        <!-- <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span> -->\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <div *ngIf=\"this.currentData\"\n              class=\"flex flex-col rounded-xl h-full w-full justify-between relative space-y-4\">\n              <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"this.currentData.data.Name\" />\n              <div class=\"flex flex-col gap-1\">\n                <div>Expiry Date</div>\n                <input class=\"date-picker\" type=\"date\" [(ngModel)]=\"this.currentData.data.ExpiryDate\" />\n              </div>\n              <!-- <verbena-input name=\"ExpiryDate\" label=\"Expiry Date\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"this.currentData.data.ExpiryDate\" /> -->\n              <div class=\"flex flex-col gap-1\">\n                <div>Anonymous</div>\n                <verbena-switch onText=\"\" offText=\"\" [(ngModel)]=\"this.currentData.data.AllowAnonymous\"\n                  [onColor]=\"'#1A237E'\"></verbena-switch>\n              </div>\n              <div class=\"flex flex-col gap-1\">\n                <div>Form Groups</div>\n                <verben-drop-down selectKey=\"Code\" display=\"chip\" width=\"100%\" placeholder=\"Select Groups\"\n                  [showClear]=\"true\" [filter]=\"true\" [load]=\"this.loadMoreFormEntities.bind(this)\"\n                  [search]=\"this.searchFormEntities.bind(this)\" [(options)]=\"groups\" optionLabel=\"Name\"\n                  [multiselect]=\"true\" [(ngModel)]=\"this.currentData.data.Entities\" [lazyLoad]=\"true\"\n                  [asyncLabel]=\"this.getAsyncLabel.bind(this)\">\n\n                </verben-drop-down>\n              </div>\n\n              <!-- buttons -->\n              <div class=\"flex justify-between bottom-8 left-0 right-0\">\n                <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button>\n                <div class=\"flex gap-3\">\n                  <verbena-button class=\"verben-switch-button\"\n                    (click)=\"viewResponses(this.currentData? this.currentData.data? this.currentData.data.Code: '':'')\"\n                    text=\"View Responses\"></verbena-button>\n                  <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                    text=\"Switch To Table\"></verbena-button>\n                  <verbena-button class=\"verben-primary-button\" (click)=\"this.saveForm()\" text=\"Save\"></verbena-button>\n                </div>\n              </div>\n            </div>\n\n          </ng-template>\n        </verben-right-card-data-view>\n        <!-- <verben-right-card-data-view>\n          yeshhhhhh\n        </verben-right-card-data-view> -->\n\n        <verben-card-data-view-footer>\n          <div class=\"flex gap-2 justify-between\">\n            <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n              <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                [text]=\"'Delete'\">\n              </verbena-button>\n            </div>\n            <div class=\"flex {{vdcv.hasCurrentItem()?'flex-1':''}} justify-end items-center gap-5\">\n              <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n              <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <verben-visible-column (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"></verben-visible-column>\n    </div>\n    <div filter-content>\n      <verben-table-filter (filtersApplied)=\"onFilterUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"></verben-table-filter>\n    </div>\n    <div sort-content>\n      <verben-sort-table (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"></verben-sort-table>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n        [text]=\"'Delete'\">\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n      <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n    </div>\n  </div>\n</div>\n", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.groups-summary-container{display:grid;grid-template-columns:repeat(2,1fr)}.groups-summary-container.pop-up{border:1px solid rgba(212,161,7,.5);border-radius:4px;width:27vw;min-width:250px;max-width:300px;background-color:#fff;max-height:400px;overflow-y:auto}.group-chip{background-color:#3479e980;text-align:center;border-radius:5px;font-weight:500;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.see-more-section{justify-content:right;gap:2px;align-items:center;cursor:pointer}.see-more-section>div{font-size:14px;color:#3479e9}.see-more-section:hover>div{text-decoration:underline;text-underline-offset:2px}.date-picker{padding:8px;border:1px solid #cbd5e1;background-color:inherit;border-radius:4px}::ng-deep .form-table>table>tbody>tr>td:nth-child(4){width:25%}\n"] }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }, { type: i0.ChangeDetectorRef }, { type: i1$2.FormBuilder }, { type: EnvironmentService }, { type: FormsService$1 }], propDecorators: { cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }], tableView: [{
                type: ViewChild,
                args: ['dt']
            }], popUps: [{
                type: ViewChildren,
                args: ['popup']
            }], pageSize: [{
                type: Input
            }], searchDebounceTime: [{
                type: Input
            }] } });

class FormsModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FormsModule, declarations: [FormsComponent], imports: [SharedModule], exports: [FormsComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsModule, imports: [SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FormsComponent],
                    imports: [SharedModule],
                    exports: [FormsComponent],
                }]
        }] });

const baseStyle$1 = {
    width: '100%',
    fontFamily: '"Fraunces", serif',
    fontSize: '125%',
    whiteSpace: 'nowrap',
    margin: '0',
    border: '1px solid #D4A007',
    borderRadius: '16px',
    borderCollapse: 'separate',
    borderSpacing: '0',
    // tableLayout: 'fixed',
    overflow: 'hidden',
    rows: {
        even: {
            backgroundColor: '#FDFDFD',
        },
        odd: {
            backgroundColor: '#F1F4FB',
        },
        height: '68px',
    },
    cells: {
        padding: '2rem 1rem',
    },
    header: {
        // stickyTop: true,
        // zIndex: 2,
        backgroundColor: '#EFF2FB',
        fontWeight: 'bold',
        textAlign: 'left',
        padding: '12px 16px',
        height: '30px',
    },
    footer: {
        // stickyBottom: true,
        // zIndex: 2,
        padding: '3px',
    },
    //   body: {
    //     background: '#fff',
    //     padding: '4px 5px',
    //     textAlign: 'center',
    //   },
    // firstColumn: {
    //   stickyLeft: true,
    //   zIndex: 1,
    // },
    lastColumn: {
    // stickyRight: true,
    // zIndex: 1,
    },
};

class FormsService {
    constructor() { }
    get FormGroupColumns() {
        return [
            {
                id: 'select',
                header: '',
            },
            {
                id: 'name',
                header: 'NAME',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'description',
                header: 'DESCRIPTION',
                accessorKey: 'Description',
            },
            {
                id: 'workflow',
                header: 'WORK FLOW',
                accessorKey: 'Workflow',
            },
            {
                id: 'isValidated',
                header: 'VALIDATED',
                accessorKey: 'IsValidated',
            },
            {
                id: 'actions',
                header: 'ACTIONS',
                accessorFn: (row) => {
                    return row;
                },
            },
        ];
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [] });

var FormFieldProperty$1;
(function (FormFieldProperty) {
    FormFieldProperty["Name"] = "Name";
    FormFieldProperty["Description"] = "Description";
    FormFieldProperty["IsValidated"] = "IsValidated";
    FormFieldProperty["WorkFlow"] = "WorkFlow";
    FormFieldProperty["ServiceName"] = "ServiceName";
    FormFieldProperty["CreatedAt"] = "CreatedAt";
})(FormFieldProperty$1 || (FormFieldProperty$1 = {}));
var TaskUserPropertyMap$1;
(function (TaskUserPropertyMap) {
    TaskUserPropertyMap["User"] = "Name";
    TaskUserPropertyMap["Date"] = "CreatedAt";
    TaskUserPropertyMap["Role"] = "RoleID";
    TaskUserPropertyMap["Service"] = "ServiceName";
    TaskUserPropertyMap["Application"] = "Application";
    TaskUserPropertyMap["Tenant"] = "TenantId";
    TaskUserPropertyMap["Email"] = "MailAddress";
    TaskUserPropertyMap["Status"] = "Status";
})(TaskUserPropertyMap$1 || (TaskUserPropertyMap$1 = {}));
var FilterTypes$3;
(function (FilterTypes) {
    FilterTypes["Before"] = "LT";
    FilterTypes["On"] = "EQ";
    FilterTypes["After"] = "GT";
    FilterTypes["NEQ"] = "NEQ";
})(FilterTypes$3 || (FilterTypes$3 = {}));
class FormGroupComponent {
    utilService;
    server;
    cdr;
    envSvc;
    router;
    FormGroupSvc;
    visibleColumnDef = [];
    styles = baseStyle$1;
    data = [];
    path = '/documentation/form-group/fields';
    cardData = [];
    selectedFilterTableCount = 0;
    selectedSortTableCount = 0;
    selectedColumnTableCount = 0;
    showFilter = false;
    showSort = false;
    showColumn = false;
    currentData = null;
    cardDataView;
    dataView;
    tableView;
    application = null;
    pageSize = 10;
    skip = 0;
    hasMore = true;
    onViewProcessClicked = new EventEmitter();
    searchTerm = '';
    pageState = null;
    isOpen = false;
    openDropdownId = null;
    currentFilters = [];
    currentSorts = [];
    searchTerm$ = new Subject();
    statusOptions = Object.values(Status);
    users = [];
    visibleColumns = [];
    filterArray = [
        {
            name: FormFieldProperty$1.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.Description,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.IsValidated,
            type: DataFilterType.Bool,
            checked: false,
        },
        {
            name: FormFieldProperty$1.ServiceName,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.WorkFlow,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    closePopUp(row) {
        if (this.openDropdownId === row.id) {
            this.openDropdownId = null; // Properly reset when closing
        }
        this.onClose(); // Call any additional logic for closure
    }
    toggleTable(row) {
        this.tableView.toggleRowEdit(row.Code);
    }
    sortOptions = [
        {
            name: FormFieldProperty$1.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.Description,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.IsValidated,
            type: DataFilterType.Bool,
            checked: false,
        },
        {
            name: FormFieldProperty$1.ServiceName,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.WorkFlow,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty$1.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    currentSearchTerm = '';
    constructor(utilService, server, cdr, envSvc, router, FormGroupSvc) {
        this.utilService = utilService;
        this.server = server;
        this.cdr = cdr;
        this.envSvc = envSvc;
        this.router = router;
        this.FormGroupSvc = FormGroupSvc;
        this.visibleColumnDef = FormGroupSvc.FormGroupColumns;
        this.visibleColumns = FormGroupSvc.FormGroupColumns.map((col) => ({
            checked: true,
            name: typeof col.header === 'string' ? col.header : col.id,
            type: DataFilterType.Bool,
        }));
    }
    async ngOnInit() {
        this.getForms();
    }
    async getAllTaskUsers() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`TaskUser/GetTaskUsers/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            return result;
        }
    }
    clearLogs(sortValue = 'CreatedAt', order = 'asc') {
        this.data = [];
        this.skip = 0;
        this.hasMore = true;
        this.getForms();
    }
    async getForms() {
        if (this.showColumn) {
            this.showColumn = false;
            this.selectedColumnTableCount = 0;
            this.reset();
        }
        if (this.showFilter) {
            this.showFilter = false;
            this.selectedFilterTableCount = 0;
            this.reset();
        }
        if (this.showSort) {
            this.showSort = false;
            this.reset();
            this.selectedSortTableCount = 0;
        }
        this.utilService.sendBI(true);
        const res = await this.server.get(`Form/GetFormEntities/${this.skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        this.pageState = res;
        const result = this.pageState.Result;
        if (this.data && Array.isArray(this.data)) {
            this.data = [...this.data, ...result];
        }
        else {
            this.data = result;
        }
        this.data.forEach((x) => (x.id = x.Id));
        this.skip += this.pageSize;
        this.hasMore = this.skip < this.pageState.Total;
        this.setUpCardData();
        return result;
    }
    loadMore() {
        if (this.hasMore) {
            this.getForms();
        }
    }
    reset() {
        this.data = [];
        this.skip = 0;
        this.pageSize = 10;
    }
    onUserSelected(event, item) {
        const user = this.users.find((x) => x.Name == event.value);
        if (user) {
            item.Name = user.Name;
            item.Description = user.Description;
            item.Workflow = user.Workflow;
            item.IsValidated = user.IsValidated;
        }
    }
    onClear(event, item) {
        item.Name = '';
        item.Description = '';
        item.Workflow = '0';
        item.IsValidated = false;
    }
    getItemLabel(name) {
        const item = this.users.find((user) => user.Name === name);
        const otherCheck = this.data.find((data) => data.Name === name);
        return item ? item.Name : otherCheck ? otherCheck.Name : '';
    }
    getAsyncLabel(value) {
        const data = this.data.find((x) => x.Name == value);
        return data ? data.Name : '';
    }
    setUpCardData() {
        const cardData = this.data.map((x) => {
            return {
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = cardData;
    }
    setUpCardDataExtra(baseData) {
        const cardData = baseData.map((x) => {
            return {
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = this.cardData.concat(cardData);
    }
    goToCardView(data) {
        const item = this.cardData.find((x) => x.data == data);
        if (item) {
            this.userCardClicked(item, true);
        }
    }
    goToTableView() {
        if (!this.currentData) {
            return;
        }
        this.dataView.toggleView();
        const id = this.currentData.data ? this.currentData.data.Id : '';
        if (id.trim().length > 0 && !this.tableView.isRowEditing(id)) {
            console.log(id);
            this.tableView.toggleRowEdit(id);
        }
    }
    viewProcesses(code) {
        if (code.trim().length == 0) {
            return;
        }
        this.onViewProcessClicked.emit(code);
    }
    userCardClicked(item, toggleView = false) {
        this.currentData = this.cardDataView.onItemClick(item);
        if (toggleView) {
            this.dataView.toggleView();
        }
    }
    async saveFormGroup() {
        if (this.currentData) {
            var form = this.currentData.data;
            if (this.currentData.data.Name.trim().length == 0) {
                this.utilService.showInfo('Name cannot be empty');
                return;
            }
            form.DataState =
                form.DataState == ObjectState.New
                    ? ObjectState.New
                    : ObjectState.Changed;
            form.Id = form.DataState == ObjectState.New ? '' : form.Id;
            this.utilService.sendBI(true);
            const res = await this.server.post(`Form/SaveFormEntities`, [form], this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
            }
            else {
                this.utilService.showSuccess('Form group saved successfully');
                const result = res;
                if (result.length > 0) {
                    var formResult = result[0];
                    const itemIndex = this.data.findIndex((x) => x == this.currentData?.data);
                    if (itemIndex > -1) {
                        this.data[itemIndex].Name = formResult.Name;
                        this.data[itemIndex].Id = formResult.Id;
                        this.data[itemIndex].id = formResult.id;
                        this.data[itemIndex].DataState = formResult.DataState;
                        this.data[itemIndex].Description = formResult.Description;
                        this.data[itemIndex].IsValidated = formResult.IsValidated;
                        this.data[itemIndex].Workflow = formResult.Workflow;
                        this.data = this.data.map((x) => x);
                    }
                }
            }
        }
    }
    toggleIsValidate(value, row) {
        const newValue = !value;
        row.IsValidated = newValue;
        console.log(row);
    }
    async tableSaveUser(form, callBack) {
        form.DataState =
            form.DataState == ObjectState.New ? ObjectState.New : ObjectState.Changed;
        form.Id = form.DataState == ObjectState.New ? '' : form.Id;
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SaveFormEntities`, [form], this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
        }
        else {
            this.utilService.showSuccess('Form group saved successfully');
            const result = res;
            if (result.length > 0) {
                var formResult = result[0];
                const itemIndex = this.data.findIndex((x) => x == form);
                if (itemIndex > -1) {
                    this.data[itemIndex].Name = formResult.Name;
                    this.data[itemIndex].Id = formResult.Id;
                    this.data[itemIndex].id = formResult.id;
                    this.data[itemIndex].DataState = formResult.DataState;
                    this.data[itemIndex].Description = formResult.Description;
                    this.data[itemIndex].IsValidated = formResult.IsValidated;
                    this.data[itemIndex].Workflow = formResult.Workflow;
                    this.data = this.data.map((x) => x);
                }
                this.closePopUp(form);
                callBack();
            }
        }
    }
    updateTable() {
        this.data = this.data.map((x) => x);
        console.log(this.data);
    }
    onFieldCountChange(value, source) {
        source.Workflow = value;
    }
    getFieldCount(source) {
        return source.Workflow;
    }
    navigateToFields(card) {
        const queryParams = { FormId: card.Id, Name: card.Name };
        this.router.navigate([`${this.path}`], { queryParams });
    }
    onClose() {
        this.isOpen = false;
    }
    openDropdown(item) {
        if (this.openDropdownId === item.Id) {
            this.openDropdownId = null;
        }
        else {
            this.openDropdownId = item.Id;
        }
    }
    async onSearch(event) {
        this.searchTerm = event.value;
        this.reset();
        if (!this.searchTerm) {
            this.getForms();
            return;
        }
        this.utilService.sendBI(true);
        try {
            const res = await this.server.get(`Form/GetFormEntitiesWithParam/${this.searchTerm}/${this.skip}/${this.pageSize}/CreatedAt/asc`);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
                console.error('Error during search:', res);
            }
            else {
                this.pageState = res;
                var result = res.Result;
                this.data = result;
                this.setUpCardData();
            }
        }
        catch (error) {
            console.error('Search error:', error);
        }
        finally {
        }
    }
    isDropdownOpen(item) {
        return this.openDropdownId === item.id;
    }
    onViewChange(isGridView) { }
    onStateChange(event) {
        switch (event.key) {
            case 'create':
                var newGroup = {
                    Code: '',
                    TenantId: '',
                    Id: '',
                    id: '',
                    ServiceName: '',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                    Name: '',
                    Description: '',
                    Workflow: '',
                    Form: '',
                    Properties: [],
                    IsValidated: false,
                    Tags: [],
                };
                const cardData = {
                    selected: false,
                    title: newGroup.Name,
                    data: newGroup,
                    body: [],
                    children: [],
                };
                this.data = this.data.concat([newGroup]);
                this.cardData.push(cardData);
                this.userCardClicked(cardData);
                this.dataView.isTableView = false;
                break;
            case 'filter':
                this.showFilter = event.value;
                break;
            case 'sort':
                this.showSort = event.value;
                break;
            case 'column':
                this.showColumn = event.value;
                break;
            default:
                break;
        }
    }
    showTableView = false;
    onSelectionChange(selectedRows) { }
    onColumnsUpdated(updatedColumns) {
        this.selectedColumnTableCount = updatedColumns.length;
        this.showColumn = false;
        const updatedColumnDef = [];
        updatedColumns.forEach((col) => {
            const matchingCol = this.FormGroupSvc.FormGroupColumns.find((column) => column.header === col.name || column.id === col.name);
            if (matchingCol) {
                updatedColumnDef.push(matchingCol);
            }
        });
        this.visibleColumnDef = [...updatedColumnDef];
    }
    async updateFiltersAndSorts(isSearch = false) {
        if (!isSearch) {
            this.dataView.onClearSearch();
            this.currentSearchTerm = '';
            this.cdr.detectChanges();
            const clickEvent = new MouseEvent('click', {
                bubbles: true,
                cancelable: true,
                view: window,
            });
            document.dispatchEvent(clickEvent);
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: FormFieldProperty$1[x.name],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$3).includes(x.condition)
                    ? FilterTypes$3[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == FormFieldProperty$1.CreatedAt
                    ? SearchPropertyValueType.Date
                    : SearchPropertyValueType.String,
            };
        });
        // payload.push({
        //   PropertyName: 'APIKey',
        //   EntityValue: this.envSvc.environment.APIKey,
        //   Operator: SearchOperator.And,
        //   Sign: SearchPropertySign.EQ,
        // });
        const sortParam = this.currentSorts.length > 0
            ? {
                Param: FormFieldProperty$1[this.currentSorts[0].name],
                Order: this.currentSorts[0].value,
            }
            : null;
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Form/GetFormEntitiesWithParam/${this.currentSearchTerm.trim()}/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : await this.server.post(sortParam
                ? `Form/SearchFormEntities/0/${this.pageSize}/${sortParam.Param}/${sortParam.Order}`
                : `Form/SearchFormEntities/0/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            this.currentFilters = [];
            this.currentSorts = [];
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = result;
            this.setUpCardData();
        }
    }
    async postSearch(payload) {
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SearchFormEntities/0/${this.pageSize}`, payload);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = result;
            this.setUpCardData();
            // this.setUpCardDataExtra(this.data)
            return result;
        }
    }
    onFilterApplied(appliedFilter) {
        this.showFilter = false;
        if (Array.isArray(appliedFilter)) {
            this.selectedFilterTableCount = appliedFilter.length;
            console.log(appliedFilter);
            const queryParams = appliedFilter
                .filter((filter) => filter.checked)
                .map((filter) => ({
                PropertyName: filter.name,
                EntityValue: filter.value,
                Type: filter.type,
                Operator: 'And',
                Sign: this.getCondition(filter.condition),
            }));
            this.postSearch(queryParams);
        }
    }
    getCondition(value) {
        switch (value) {
            case ConditionalOptions.On:
                return SearchPropertySign.EQ;
            case ConditionalOptions.After:
                return SearchPropertySign.EQ;
            case ConditionalOptions.Before:
                return SearchPropertySign.LT;
            case ConditionalOptions.NotEqual:
                return SearchPropertySign.NEQ;
            default:
                return value;
        }
    }
    onSortUpdated(updatedSorts) {
        this.currentSorts = updatedSorts;
        this.showSort = false;
        this.selectedSortTableCount = updatedSorts.length;
        this.updateFiltersAndSorts();
    }
    handleSearch(event) {
        this.searchTerm$.next(event.value);
    }
    handleExport(exportedData) {
        // console.log('Exported data:', exportedData);
        this.downloadCSV(exportedData);
    }
    downloadCSV(data) {
        const headers = Object.keys(data[0]);
        const csvContent = [
            headers.join(','),
            ...data.map((row) => headers.map((header) => row[header]).join(',')),
        ].join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'export.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormGroupComponent, deps: [{ token: UtilService }, { token: HttpWebRequestService }, { token: i0.ChangeDetectorRef }, { token: EnvironmentService }, { token: i5.Router }, { token: FormsService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FormGroupComponent, selector: "lib-form-group", inputs: { path: "path", application: "application", pageSize: "pageSize" }, outputs: { onViewProcessClicked: "onViewProcessClicked" }, viewQueries: [{ propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }, { propertyName: "tableView", first: true, predicate: ["dt"], descendants: true }], ngImport: i0, template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n\n    <verben-data-view #vdv [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true,\n        \n      }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n      [searchValue]=\"searchTerm\"\n      (onSearchChange)=\"onSearch($event)\"\n      [showFilterChild]=\"showFilter\"\n      [showSortChild]=\"showSort\"\n      [showColumnChild]=\"showColumn\"\n      [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"selectedColumnTableCount\" [selectedSortCount]=\"selectedSortTableCount\"\n      [selectedFilterTableCount]=\"selectedFilterTableCount\" (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\"\n      >\n      <div class=\"mt-2\" table-content>\n        <lib-data-table #dt [data]=\"data\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n          (selectionChange)=\"onSelectionChange($event)\">\n          <ng-container libColumn=\"select\">\n            <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n              <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n            </ng-template>\n            <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n              let-toggleAllRows=\"toggleAllRows\">\n              <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n                (change)=\"toggleAllRows()\" />\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"name\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Name}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n               <verbena-input inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Name\"></verbena-input>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"workflow\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n               <verbena-input  inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Workflow\"></verbena-input>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"description\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n               <verbena-input inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Description\"></verbena-input>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"isValidated\">\n            <ng-template #cell let-row=\"row\" let-value>\n              <verben-svg *ngIf=\"value===true\" [icon]=\"'check'\"></verben-svg>\n              <verben-svg *ngIf=\"value===false\" [icon]=\"'error'\"></verben-svg>\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n              <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"row.IsValidated\"></verbena-switch>\n            </ng-template>\n            \n        </ng-container>\n      \n          <ng-container libColumn=\"actions\">\n            <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <verben-pop-Up [customStyles]=\"{'z-index': '99'}\" [dropdownOpen]=\"isDropdownOpen(row)\"\n                [enableMouseLeave]=\"false\" (close)=\"onClose()\">\n                <verben-svg class=\"cursor-pointer actions-icon\" (click)=\"openDropdown(row)\" dropdown-trigger\n                  icon=\"list\"></verben-svg>\n                <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                  <div (click)=\"navigateToFields(row)\" class=\"pop-up-value cursor-pointer\">View Fields</div>\n                  <div (click)=\"toggleRowEdit()\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                  <!-- <div class=\"pop-up-value cursor-pointer\">Delete</div> -->\n                </div>\n              </verben-pop-Up>\n            </ng-template>\n            <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <div class=\"flex gap-2 items-center\">\n                <verben-svg icon=\"check\" [width]=\"15\" [height]=\"15\"\n                  (click)=\"tableSaveUser(value, toggleRowEdit)\"></verben-svg>\n                <!-- <verben-svg icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg> -->\n                <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n              </div>\n            </ng-template>\n          </ng-container>\n        </lib-data-table>\n      </div>\n      <div card-content>\n        <verben-card-data-view borderRadius=\"12px\" #vdcv dataId=\"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n          rbgColor=\"#f5f6f9\" mg=\"0px\">\n          <verben-left-card-data-view class=\"space-y-7\">\n            <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId=\"MailAddress\"\n              class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n              <ng-template #card let-item>\n                <div (click)=\"userCardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                  <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                  <div class=\"flex  w-full bg-secondary rounded-xl\">\n                    <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                        item.selected ? 'bg-primary' : 'bg-secondary-200'\n                      \"></div>\n                    <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                      <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                        <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                          <div class=\"flex justify-between\">\n                            <div>\n                              <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">{{\n                                item.data.Name\n                                }}</h3>\n                              <span class=\"flex mt-2 items-center gap-1\">\n                                <span class=\"!text-[10px] font-light text-[#404040]\">Description:</span> <span\n                                  class=\"!text-[12px] font-semibold\">{{item.data.Description}}</span>\n                              </span>\n                            </div>\n                          \n                               <div>\n                                <span class=\"!text-[10px] text-[#404040]\"\n                                  >Work Flow</span\n                                >\n                                <p class=\"!text-[12px]\">{{ item.data.Workflow }}</p>\n                              </div>\n                          </div>\n                         \n                        </div>\n  \n                        <!-- <div class=\"flex items-end h-[100%]\">\n                          <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span>\n                        </div> -->\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </ng-template>\n            </verben-left-card-data>\n          </verben-left-card-data-view>\n          <verben-right-card-data-view>\n            <ng-template #parent>\n              <div *ngIf=\"this.currentData\"\n                class=\"flex flex-col rounded-xl h-full  w-full relative gap-6\">\n                <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n                  [(ngModel)]=\"currentData.data.Name\" />\n                <verbena-input name=\"Description\" label=\"Description\" (ngModelChange)=\"updateTable()\"\n                  [(ngModel)]=\"currentData.data.Description\" />\n                <verbena-input  name=\"Workflow\" label=\"Work Flow\" [(ngModel)]='currentData.data.Workflow' />\n                 <div>\n                  <p class=\"mb-2\">Validate</p>\n                   <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"currentData.data.IsValidated\"></verbena-switch>\n               \n                 </div>\n                <!-- <div class=\"flex flex-col gap-1\">\n                  <div>Status</div>\n                  <verben-drop-down width=\"100%\" placeholder=\"Change Status\" [(options)]=\"statusOptions\"\n                    [(ngModel)]=\"this.currentData.data.Status\">\n                  </verben-drop-down>\n                </div> -->\n  \n                <!-- buttons -->\n                <div class=\"flex  justify-between w-full bottom-8 left-0 right-0\">\n                  <div></div>\n                  <!-- <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button> -->\n                  <div class=\"flex gap-3\">\n                    <verbena-button *ngIf=\"currentData.data.DataState !=='New'\" class=\"verben-switch-button\"\n                      (click)=\"navigateToFields(currentData.data)\"\n                      text=\"View Fields\"></verbena-button>\n                    <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                      text=\"Switch To Table\"></verbena-button>\n                    <verbena-button class=\"verben-primary-button\" (click)=\"this.saveFormGroup()\" text=\"Save\"></verbena-button>\n                  </div>\n                </div>\n              </div>\n  \n            </ng-template>\n          </verben-right-card-data-view>\n          <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n  \n          <verben-card-data-view-footer>\n            <div class=\"flex gap-2 justify-between\">\n              <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n                <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                  [text]=\"'Delete'\">\n                </verbena-button> -->\n              </div>\n              <div class=\"flex {{vdcv.hasCurrentItem()?'flex-1':''}} justify-end items-center gap-5\">\n                <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n                <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n              </div>\n            </div>\n          </verben-card-data-view-footer>\n        </verben-card-data-view>\n      </div>\n      <div column-content>\n        <verben-visible-column (resetFilter)=\"getForms()\" (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n          [displayedColumns]=\"5\"></verben-visible-column>\n      </div>\n      <div filter-content>\n        <verben-table-filter (resetSortData)=\"getForms()\"  (filtersApplied)=\"onFilterApplied($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n          [maxFilterLength]=\"3\"></verben-table-filter>\n      </div>\n      <div  sort-content>\n        <verben-sort-table (resetSortData)=\"getForms()\" (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n          [sortOptions]=\"sortOptions\"></verben-sort-table>\n      </div>\n      <div export-content>\n        <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n        </lib-data-export>\n      </div>\n      \n    </verben-data-view>\n    <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n      <div class=\"message-log-button-container flex justify-between\">\n        <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n          [text]=\"'Delete'\">\n        </verbena-button> -->\n      </div>\n      <div class=\"flex justify-end items-center gap-5\">\n        <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n        <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n      </div>\n    </div>\n  </div>", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}::ng-deep .toolbar{margin-bottom:15px}::ng-deep .master-only-container{margin:0!important;padding:0!important}::ng-deep .master-detail-container{margin:0!important;padding:0!important}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.toggle-container{width:53px;padding:1px;color:#fff;height:22px;position:relative;background-color:#1a237e;border-radius:2rem;cursor:pointer}.toggle-circle{width:50%;height:100%;position:absolute;left:0;padding:5px;top:0;background-color:#fff;border-radius:50%;transform:scale(1);transition:transform .3s}.translate-100{transform:translate(100%)}.translate-0{transform:translate(0)}.toggle-text-on{display:block;font-size:12px;margin-left:4px}.toggle-text-off{display:block;font-size:12px;margin-right:4px;text-align:right}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.VerbenaSwitchComponent, selector: "verbena-switch", inputs: ["label", "checked", "disabled", "offColor", "onColor", "onText", "offText", "width", "height", "customStyles"], outputs: ["change"] }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.VisibleColumnComponent, selector: "verben-visible-column", inputs: ["columns", "items", "enableDragAndDrop", "displayedColumns", "showMore", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "closeColumn"], outputs: ["columnsUpdated", "resetFilter"] }, { kind: "component", type: i8.SortTableComponent, selector: "verben-sort-table", inputs: ["enableDragAndDrop", "sortOptions", "resetText", "displayedOptions", "propertyText", "showMoreText", "sortButtonText", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "containerHeight"], outputs: ["selectedOptions", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormGroupComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-form-group', template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n\n    <verben-data-view #vdv [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true,\n        \n      }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n      [searchValue]=\"searchTerm\"\n      (onSearchChange)=\"onSearch($event)\"\n      [showFilterChild]=\"showFilter\"\n      [showSortChild]=\"showSort\"\n      [showColumnChild]=\"showColumn\"\n      [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"selectedColumnTableCount\" [selectedSortCount]=\"selectedSortTableCount\"\n      [selectedFilterTableCount]=\"selectedFilterTableCount\" (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\"\n      >\n      <div class=\"mt-2\" table-content>\n        <lib-data-table #dt [data]=\"data\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n          (selectionChange)=\"onSelectionChange($event)\">\n          <ng-container libColumn=\"select\">\n            <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n              <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n            </ng-template>\n            <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n              let-toggleAllRows=\"toggleAllRows\">\n              <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n                (change)=\"toggleAllRows()\" />\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"name\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Name}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n               <verbena-input inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Name\"></verbena-input>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"workflow\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n               <verbena-input  inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Workflow\"></verbena-input>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"description\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n               <verbena-input inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Description\"></verbena-input>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"isValidated\">\n            <ng-template #cell let-row=\"row\" let-value>\n              <verben-svg *ngIf=\"value===true\" [icon]=\"'check'\"></verben-svg>\n              <verben-svg *ngIf=\"value===false\" [icon]=\"'error'\"></verben-svg>\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n              <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"row.IsValidated\"></verbena-switch>\n            </ng-template>\n            \n        </ng-container>\n      \n          <ng-container libColumn=\"actions\">\n            <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <verben-pop-Up [customStyles]=\"{'z-index': '99'}\" [dropdownOpen]=\"isDropdownOpen(row)\"\n                [enableMouseLeave]=\"false\" (close)=\"onClose()\">\n                <verben-svg class=\"cursor-pointer actions-icon\" (click)=\"openDropdown(row)\" dropdown-trigger\n                  icon=\"list\"></verben-svg>\n                <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                  <div (click)=\"navigateToFields(row)\" class=\"pop-up-value cursor-pointer\">View Fields</div>\n                  <div (click)=\"toggleRowEdit()\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                  <!-- <div class=\"pop-up-value cursor-pointer\">Delete</div> -->\n                </div>\n              </verben-pop-Up>\n            </ng-template>\n            <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <div class=\"flex gap-2 items-center\">\n                <verben-svg icon=\"check\" [width]=\"15\" [height]=\"15\"\n                  (click)=\"tableSaveUser(value, toggleRowEdit)\"></verben-svg>\n                <!-- <verben-svg icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg> -->\n                <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n              </div>\n            </ng-template>\n          </ng-container>\n        </lib-data-table>\n      </div>\n      <div card-content>\n        <verben-card-data-view borderRadius=\"12px\" #vdcv dataId=\"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n          rbgColor=\"#f5f6f9\" mg=\"0px\">\n          <verben-left-card-data-view class=\"space-y-7\">\n            <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId=\"MailAddress\"\n              class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n              <ng-template #card let-item>\n                <div (click)=\"userCardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                  <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                  <div class=\"flex  w-full bg-secondary rounded-xl\">\n                    <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                        item.selected ? 'bg-primary' : 'bg-secondary-200'\n                      \"></div>\n                    <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                      <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                        <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                          <div class=\"flex justify-between\">\n                            <div>\n                              <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">{{\n                                item.data.Name\n                                }}</h3>\n                              <span class=\"flex mt-2 items-center gap-1\">\n                                <span class=\"!text-[10px] font-light text-[#404040]\">Description:</span> <span\n                                  class=\"!text-[12px] font-semibold\">{{item.data.Description}}</span>\n                              </span>\n                            </div>\n                          \n                               <div>\n                                <span class=\"!text-[10px] text-[#404040]\"\n                                  >Work Flow</span\n                                >\n                                <p class=\"!text-[12px]\">{{ item.data.Workflow }}</p>\n                              </div>\n                          </div>\n                         \n                        </div>\n  \n                        <!-- <div class=\"flex items-end h-[100%]\">\n                          <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span>\n                        </div> -->\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </ng-template>\n            </verben-left-card-data>\n          </verben-left-card-data-view>\n          <verben-right-card-data-view>\n            <ng-template #parent>\n              <div *ngIf=\"this.currentData\"\n                class=\"flex flex-col rounded-xl h-full  w-full relative gap-6\">\n                <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n                  [(ngModel)]=\"currentData.data.Name\" />\n                <verbena-input name=\"Description\" label=\"Description\" (ngModelChange)=\"updateTable()\"\n                  [(ngModel)]=\"currentData.data.Description\" />\n                <verbena-input  name=\"Workflow\" label=\"Work Flow\" [(ngModel)]='currentData.data.Workflow' />\n                 <div>\n                  <p class=\"mb-2\">Validate</p>\n                   <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"currentData.data.IsValidated\"></verbena-switch>\n               \n                 </div>\n                <!-- <div class=\"flex flex-col gap-1\">\n                  <div>Status</div>\n                  <verben-drop-down width=\"100%\" placeholder=\"Change Status\" [(options)]=\"statusOptions\"\n                    [(ngModel)]=\"this.currentData.data.Status\">\n                  </verben-drop-down>\n                </div> -->\n  \n                <!-- buttons -->\n                <div class=\"flex  justify-between w-full bottom-8 left-0 right-0\">\n                  <div></div>\n                  <!-- <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button> -->\n                  <div class=\"flex gap-3\">\n                    <verbena-button *ngIf=\"currentData.data.DataState !=='New'\" class=\"verben-switch-button\"\n                      (click)=\"navigateToFields(currentData.data)\"\n                      text=\"View Fields\"></verbena-button>\n                    <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                      text=\"Switch To Table\"></verbena-button>\n                    <verbena-button class=\"verben-primary-button\" (click)=\"this.saveFormGroup()\" text=\"Save\"></verbena-button>\n                  </div>\n                </div>\n              </div>\n  \n            </ng-template>\n          </verben-right-card-data-view>\n          <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n  \n          <verben-card-data-view-footer>\n            <div class=\"flex gap-2 justify-between\">\n              <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n                <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                  [text]=\"'Delete'\">\n                </verbena-button> -->\n              </div>\n              <div class=\"flex {{vdcv.hasCurrentItem()?'flex-1':''}} justify-end items-center gap-5\">\n                <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n                <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n              </div>\n            </div>\n          </verben-card-data-view-footer>\n        </verben-card-data-view>\n      </div>\n      <div column-content>\n        <verben-visible-column (resetFilter)=\"getForms()\" (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n          [displayedColumns]=\"5\"></verben-visible-column>\n      </div>\n      <div filter-content>\n        <verben-table-filter (resetSortData)=\"getForms()\"  (filtersApplied)=\"onFilterApplied($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n          [maxFilterLength]=\"3\"></verben-table-filter>\n      </div>\n      <div  sort-content>\n        <verben-sort-table (resetSortData)=\"getForms()\" (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n          [sortOptions]=\"sortOptions\"></verben-sort-table>\n      </div>\n      <div export-content>\n        <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n        </lib-data-export>\n      </div>\n      \n    </verben-data-view>\n    <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n      <div class=\"message-log-button-container flex justify-between\">\n        <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n          [text]=\"'Delete'\">\n        </verbena-button> -->\n      </div>\n      <div class=\"flex justify-end items-center gap-5\">\n        <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n        <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n      </div>\n    </div>\n  </div>", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}::ng-deep .toolbar{margin-bottom:15px}::ng-deep .master-only-container{margin:0!important;padding:0!important}::ng-deep .master-detail-container{margin:0!important;padding:0!important}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.toggle-container{width:53px;padding:1px;color:#fff;height:22px;position:relative;background-color:#1a237e;border-radius:2rem;cursor:pointer}.toggle-circle{width:50%;height:100%;position:absolute;left:0;padding:5px;top:0;background-color:#fff;border-radius:50%;transform:scale(1);transition:transform .3s}.translate-100{transform:translate(100%)}.translate-0{transform:translate(0)}.toggle-text-on{display:block;font-size:12px;margin-left:4px}.toggle-text-off{display:block;font-size:12px;margin-right:4px;text-align:right}\n"] }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }, { type: i0.ChangeDetectorRef }, { type: EnvironmentService }, { type: i5.Router }, { type: FormsService }], propDecorators: { path: [{
                type: Input
            }], cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }], tableView: [{
                type: ViewChild,
                args: ['dt']
            }], application: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], onViewProcessClicked: [{
                type: Output
            }] } });

class FormsFieldService {
    constructor() { }
    get formFieldColumns() {
        return [
            {
                id: 'select',
                header: '',
            },
            {
                id: 'name',
                header: 'NAME',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'dataType',
                header: 'DATA TYPE',
                accessorKey: 'DataType',
            },
            {
                id: 'minValue',
                header: 'MIN VALUE',
                accessorKey: 'MinValue',
            },
            {
                id: 'maxValue',
                header: 'MAX VALUE',
                accessorKey: 'MaxValue',
            },
            {
                id: 'defaultValue',
                header: 'DEFAULT VALUE',
                accessorKey: 'DefaultValue',
            },
            {
                id: 'isRequired',
                header: 'REQUIRED',
                accessorKey: 'IsRequired',
            },
            {
                id: 'actions',
                header: 'ACTIONS',
                accessorFn: (row) => {
                    return row;
                },
            },
        ];
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [] });

var TaskUserPropertyName;
(function (TaskUserPropertyName) {
    TaskUserPropertyName["User"] = "User";
    TaskUserPropertyName["Date"] = "Date";
    TaskUserPropertyName["Role"] = "Role";
    TaskUserPropertyName["Service"] = "Service";
    TaskUserPropertyName["Application"] = "Application";
    TaskUserPropertyName["Tenant"] = "Tenant";
    TaskUserPropertyName["Email"] = "Email";
    TaskUserPropertyName["Status"] = "Status";
})(TaskUserPropertyName || (TaskUserPropertyName = {}));
var TaskUserPropertyMap;
(function (TaskUserPropertyMap) {
    TaskUserPropertyMap["User"] = "Name";
    TaskUserPropertyMap["Date"] = "CreatedAt";
    TaskUserPropertyMap["Role"] = "RoleID";
    TaskUserPropertyMap["Service"] = "ServiceName";
    TaskUserPropertyMap["Application"] = "Application";
    TaskUserPropertyMap["Tenant"] = "TenantId";
    TaskUserPropertyMap["Email"] = "MailAddress";
    TaskUserPropertyMap["Status"] = "Status";
})(TaskUserPropertyMap || (TaskUserPropertyMap = {}));
var FilterTypes$2;
(function (FilterTypes) {
    FilterTypes["Before"] = "LT";
    FilterTypes["On"] = "EQ";
    FilterTypes["After"] = "GT";
    FilterTypes["NEQ"] = "NEQ";
})(FilterTypes$2 || (FilterTypes$2 = {}));
class FormFieldsComponent {
    utilService;
    server;
    cdr;
    fb;
    envSvc;
    router;
    route;
    taskUsersSvc;
    _location;
    elRef;
    renderer;
    visibleColumnDef = [];
    styles = baseStyle$1;
    data = [];
    hideMinMax = true;
    path = '/documentation/workflow-forms/fields';
    cardData = [];
    queryParams = {};
    showSort = false;
    showColumn = false;
    currentData = null;
    fileInput;
    cardDataView;
    dataView;
    tableView;
    application = null;
    pageSize = 10;
    searchDebounceTime = 500;
    onViewProcessClicked = new EventEmitter();
    currentExpandedCard = null;
    pageState = null;
    isOpen = false;
    openDropdownId = null;
    currentFilters = [];
    currentSorts = [];
    selectedFilterTableCount = 0;
    selectedSortTableCount = 0;
    selectedColumnTableCount = 0;
    showFilter = false;
    formName = '';
    searchTerm$ = new Subject();
    properties = [];
    searchTerm = '';
    skip = 0;
    chipArray = [];
    Id = '';
    chips;
    statusOptions = Object.values(Status);
    dataType = Object.values(DataType);
    dataType2 = DataType.Text;
    users = [];
    visibleColumns = [];
    filterArray = [
        {
            name: 'Name',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'DataType',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'DefaultValue',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'Value',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'MaxValue',
            type: DataFilterType.Number,
            checked: false,
        },
        {
            name: 'MinValue',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'IsRequired',
            type: DataFilterType.Bool,
            checked: false,
        },
    ];
    sortOptions = [
        {
            name: 'Name',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'DataType',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'DefaultValue',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'Value',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'MaxValue',
            type: DataFilterType.Number,
            checked: false,
        },
        {
            name: 'MinValue',
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: 'IsRequired',
            type: DataFilterType.Bool,
            checked: false,
        },
    ];
    currentSearchTerm = '';
    constructor(utilService, server, cdr, fb, envSvc, router, route, taskUsersSvc, _location, elRef, renderer) {
        this.utilService = utilService;
        this.server = server;
        this.cdr = cdr;
        this.fb = fb;
        this.envSvc = envSvc;
        this.router = router;
        this.route = route;
        this.taskUsersSvc = taskUsersSvc;
        this._location = _location;
        this.elRef = elRef;
        this.renderer = renderer;
        this.visibleColumnDef = taskUsersSvc.formFieldColumns;
        this.visibleColumns = taskUsersSvc.formFieldColumns.map((col) => ({
            checked: true,
            name: typeof col.header === 'string' ? col.header : col.id,
            type: DataFilterType.Bool,
        }));
    }
    async ngOnInit() {
        this.searchTerm$
            .pipe(debounceTime(this.searchDebounceTime)) // Adjust debounce time here (in ms)
            .subscribe(async (searchTerm) => {
            this.currentSearchTerm = searchTerm;
            this.updateFiltersAndSorts(true);
        });
        this.route.queryParams.subscribe((params) => {
            const Id = params['FormId'];
            const Name = params['Name'];
            this.Id = Id;
            this.formName = Name;
            if (Id) {
                this.getProperties(Id);
                this.properties = this.data[0].Properties;
            }
        });
    }
    onChipChange(chips) {
        this.chips = chips;
    }
    async postSearch(payload) {
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SearchFormEntities/0/${this.pageSize}`, payload);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            this.utilService.showError("Error occurred while searching.");
            return;
        }
        const pageState = res;
        const result = pageState?.Result;
        if (!result || result.length === 0) {
            this.utilService.showInfo("No results found.");
            this.data = [];
            return;
        }
        // Assign and ensure Properties exist
        this.data = result.map((item) => ({
            ...item,
            Properties: item.Properties || [],
        }));
        this.setUpCardData();
        return result;
    }
    onDropDownChange(event) {
        if (event) {
            this.checkMinMax(event);
        }
    }
    async getProperties(Id, show = false) {
        if (this.showColumn) {
            this.showColumn = false;
            this.selectedColumnTableCount = 0;
            this.reset();
        }
        if (this.showFilter) {
            this.showFilter = false;
            this.selectedFilterTableCount = 0;
            this.reset();
        }
        if (this.showSort) {
            this.showSort = false;
            this.reset();
            this.selectedSortTableCount = 0;
        }
        var payload = [
            {
                PropertyName: `Id`,
                EntityValue: Id,
                Operator: SearchOperator.And,
                Sign: SearchPropertySign.EQ,
                Type: SearchPropertyValueType.String,
            },
        ];
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SearchFormEntities/${this.skip}/${this.pageSize}`, payload);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            var result = res.Result;
            this.data = result;
            this.data.map((x) => x.Properties.forEach((p, i) => (p.Id = i.toString())));
            this.setUpCardData();
            show = false;
            return result;
        }
    }
    onUserSelected(event, item) {
        const user = this.users.find((x) => x.Name == event.value);
        if (user) {
            item.Name = user.Name;
            item.Description = user.Description;
            item.Properties = user.Properties;
            item.IsValidated = user.IsValidated;
        }
    }
    onClear(event, item) {
        item.Name = '';
        item.Description = '';
        item.Properties = [];
        item.IsValidated = false;
    }
    async getForms() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`Form/GetFormEntitiesWithParams/Group/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = result;
            this.setUpCardData();
            this.properties = result[0].Properties;
            return result;
        }
    }
    getItemLabel(name) {
        const item = this.users.find((user) => user.Name === name);
        const otherCheck = this.data.find((data) => data.Name === name);
        return item ? item.Name : otherCheck ? otherCheck.Name : '';
    }
    getAsyncLabel(value) {
        const data = this.data.find((x) => x.Name == value);
        return data ? data.Name : '';
    }
    async loadMore() {
        if (!this.pageState) {
            return;
        }
        this.utilService.sendBI(true);
        const res = this.currentFilters.length > 0 ||
            this.currentSorts.length > 0 ||
            this.currentSearchTerm.trim().length > 0
            ? await this.loadMoreFiltersAndSorts()
            : await this.server.get(`TaskUser/GetTaskUsers/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = this.data.concat(result.map((x) => {
                return {
                    ...x,
                    id: x.Name,
                };
            }));
            this.setUpCardDataExtra(result);
        }
    }
    cardClicked(item, toggleView = false) {
        this.currentData = this.cardDataView.onItemClick(item);
        if (toggleView) {
            this.dataView.toggleView();
        }
    }
    toggleChildren(item) {
        var currToggleState = item.isChildrenExpanded;
        this.cardData.forEach((_) => {
            _.isChildrenExpanded = false;
        });
        item.isChildrenExpanded = !currToggleState;
        if (item.isChildrenExpanded) {
            this.currentExpandedCard = item;
        }
        else {
            this.currentExpandedCard = null;
        }
    }
    setUpCardData() {
        const cardData = this.data[0]?.Properties?.map((x) => {
            return {
                ...x,
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = cardData; // Assign the transformed array to `cardData`
    }
    openDropdown(item) {
        this.openDropdownId = this.openDropdownId === item.Id ? null : item.Id;
    }
    closePopUp(row) {
        if (this.openDropdownId === row.Id) {
            this.openDropdownId = null; // Properly reset when closing
        }
        this.onClose(); // Call any additional logic for closure
    }
    setUpCardDataExtra(baseData) {
        const cardData = baseData.map((x) => {
            return {
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = this.cardData.concat(cardData);
    }
    goToCardView(data) {
        const item = this.cardData.find((x) => x.data == data);
        if (item) {
            this.userCardClicked(item, true);
        }
    }
    goToTableView() {
        if (!this.currentData) {
            return;
        }
        this.dataView.toggleView();
        const id = this.currentData.data ? this.currentData.data.Id : '';
        if (id.trim().length > 0 && !this.tableView.isRowEditing(id)) {
            this.tableView.toggleRowEdit(id);
        }
    }
    viewProcesses(code) {
        if (code.trim().length == 0) {
            return;
        }
        this.onViewProcessClicked.emit(code);
    }
    userCardClicked(item, toggleView = false) {
        this.cardData.forEach((card) => (card.selected = false));
        item.selected = true;
        this.currentData = this.cardDataView.onItemClick(item);
        this.chipArray = JSON.parse(this.currentData?.data.Value);
        if (toggleView) {
            this.dataView.toggleView();
        }
    }
    async saveFormProperty() {
        if (!this.currentData) {
            return;
        }
        const formProperty = this.data;
        this.utilService.sendBI(true);
        try {
            // API call to save user
            const res = await this.server.post(`Form/SaveFormEntities`, formProperty, this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (!(res instanceof ErrorResponse)) {
                this.utilService.showSuccess('Form property saved successfully');
                const result = res;
                if (result.length > 0) {
                    const userResult = result[0];
                    const itemIndex = this.data.findIndex((x) => x === this.currentData?.data);
                }
            }
        }
        catch (error) {
            this.utilService.sendBI(false);
            // Optional: Handle errors if needed
        }
    }
    stringify(val) {
        return JSON.stringify(val);
    }
    async saveUser() {
        if (this.currentData) {
            var property = this.currentData.data;
            property.MaxValue = Number(property.MaxValue);
            property.MinValue = Number(property.MinValue);
            property.Options = this.chipArray?.toString();
            property.Value = '';
            if (this.currentData.data.Name.trim().length === 0) {
                this.utilService.showInfo('Name cannot be empty');
                return;
            }
            this.utilService.sendBI(true);
            const updatedData = this.data.map((form) => {
                const propertyIndex = form.Properties.findIndex((p) => p.id === property.id);
                if (propertyIndex > -1) {
                    form.Properties[propertyIndex] = property;
                }
                else {
                    form.Properties = [...form.Properties, property];
                }
                form.DataState =
                    form.DataState === ObjectState.New
                        ? ObjectState.New
                        : ObjectState.Changed;
                return form;
            });
            const res = await this.server.post(`Form/SaveFormEntities`, updatedData, this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
                this.utilService.showError('An error occurred while saving');
            }
            else {
                this.utilService.showSuccess('Form property saved successfully');
                const result = res;
                if (result.length > 0) {
                    var userResult = result[0];
                    const itemIndex = this.data.findIndex((x) => x === this.currentData?.data);
                    if (itemIndex > -1) {
                        this.data[itemIndex].Properties = userResult.Properties;
                        this.data = [...this.data];
                    }
                }
            }
        }
    }
    async saveViaTable(row, callBack) {
        if (!row)
            return;
        const property = {
            ...row,
            MaxValue: Number(row.MaxValue),
            MinValue: Number(row.MinValue),
        };
        if (property.Name.trim().length === 0) {
            this.utilService.showInfo('Name cannot be empty');
            return;
        }
        this.utilService.sendBI(true);
        const updatedData = this.data.map((form) => {
            const propertyIndex = form.Properties.findIndex((p) => p.id === property.id);
            if (propertyIndex > -1) {
                form.Properties[propertyIndex] = property;
            }
            else {
                form.Properties = [...form.Properties, property];
            }
            form.DataState =
                form.DataState === ObjectState.New
                    ? ObjectState.New
                    : ObjectState.Changed;
            return form;
        });
        try {
            const res = await this.server.post(`Form/SaveFormEntities`, updatedData, this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
                this.utilService.showError('An error occurred while saving');
                return;
            }
            this.utilService.showSuccess('Form property saved successfully');
            const result = res;
            if (result.length > 0) {
                const userResult = result[0];
                const itemIndex = this.data.findIndex((x) => x.Properties.some((p) => p.id === row.id));
                if (itemIndex > -1) {
                    this.data[itemIndex].Properties = userResult.Properties;
                    this.data.map((x) => x.Properties.forEach((p, i) => (p.Id = i.toString())));
                    this.data = [...this.data];
                }
            }
            this.closePopUp(row);
            callBack();
        }
        catch (error) {
            this.utilService.sendBI(false);
            this.utilService.showError('Failed to save the form property');
        }
    }
    toggleIsValidate(value, row) {
        const newValue = !value;
        row.IsRequired = newValue;
        console.log(row);
    }
    updateTable() {
        this.data = this.data.map((x) => x);
        console.log(this.data);
    }
    convertToInt(value, data, prop) {
        data[prop] = parseInt(value);
    }
    getStringValue(data, prop) {
        return data[prop].toString();
    }
    checkMinMax(value) {
        var showMinmax = false;
        switch (value) {
            case 'String':
                showMinmax = true;
                break;
            case 'Int':
                showMinmax = true;
                break;
            case 'Decimal':
                showMinmax = true;
                break;
            case 'Float':
                showMinmax = true;
                break;
            default:
                showMinmax = false;
                break;
        }
        return (this.hideMinMax = showMinmax);
    }
    navigateToFields() {
        const queryParams = this.queryParams;
        this.router.navigate([`${this.path}`], { queryParams });
    }
    onClose() {
        this.isOpen = false;
    }
    goBack() {
        this._location.back();
    }
    isDropdownOpen(item) {
        return this.openDropdownId === item.id;
    }
    onViewChange(isGridView) { }
    onStateChange(event) {
        switch (event.key) {
            case 'create':
                var newUser = {
                    MaxValue: 100,
                    Name: '',
                    Value: '',
                    MinValue: 100,
                    Options: '',
                    IsRequired: false,
                    DataType: DataType.Text,
                    DefaultValue: '',
                    id: '',
                    Id: ''
                };
                this.chipArray = [];
                const cardData = {
                    selected: false,
                    title: newUser.Name,
                    data: newUser,
                    body: [],
                    children: [],
                };
                this.cardData.push(cardData);
                this.userCardClicked(cardData);
                this.dataView.isTableView = false;
                break;
            case 'filter':
                this.showFilter = event.value;
                break;
            case 'sort':
                this.showSort = event.value;
                break;
            case 'column':
                this.showColumn = event.value;
                break;
            default:
                break;
        }
    }
    reset() {
        this.skip = 0;
        this.pageSize = 10;
    }
    async onSearch(event) {
        this.searchTerm = event.value;
        this.reset();
        if (!this.searchTerm) {
            this.getProperties(this.Id);
            return;
        }
        this.utilService.sendBI(true);
        try {
            const res = await this.server.get(`Form/GetFormEntitiesWithParam/${this.searchTerm}/${this.skip}/${this.pageSize}/CreatedAt/asc`);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
                console.error('Error during search:', res);
            }
            else {
                this.pageState = res;
                var result = res.Result;
                this.data = result;
                this.setUpCardData();
            }
        }
        catch (error) {
            console.error('Search error:', error);
        }
        finally {
        }
    }
    showTableView = false;
    onSelectionChange(selectedRows) { }
    retryMessage() { }
    onColumnsUpdated(updatedColumns) {
        const updatedColumnDef = [];
        this.showColumn = false;
        this.selectedColumnTableCount = updatedColumns.length;
        updatedColumns.forEach((col) => {
            const matchingCol = this.taskUsersSvc.formFieldColumns.find((column) => column.header === col.name || column.id === col.name);
            if (matchingCol) {
                updatedColumnDef.push(matchingCol);
            }
        });
        this.visibleColumnDef = [...updatedColumnDef];
    }
    async updateFiltersAndSorts(isSearch = false) {
        if (!isSearch) {
            this.dataView.onClearSearch();
            this.currentSearchTerm = '';
            this.cdr.detectChanges();
            const clickEvent = new MouseEvent('click', {
                bubbles: true,
                cancelable: true,
                view: window,
            });
            document.dispatchEvent(clickEvent);
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: TaskUserPropertyMap[x.name],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$2).includes(x.condition)
                    ? FilterTypes$2[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == TaskUserPropertyName.Date
                    ? SearchPropertyValueType.Date
                    : SearchPropertyValueType.String,
            };
        });
        // payload.push({
        //   PropertyName: 'APIKey',
        //   EntityValue: this.envSvc.environment.APIKey,
        //   Operator: SearchOperator.And,
        //   Sign: SearchPropertySign.EQ,
        // });
        const sortParam = this.currentSorts.length > 0
            ? {
                Param: TaskUserPropertyMap[this.currentSorts[0].name],
                Order: this.currentSorts[0].value,
            }
            : null;
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`TaskUser/GetTaskUserWithParam/${this.currentSearchTerm.trim()}/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : await this.server.post(sortParam
                ? `TaskUser/SearchTaskUsers/0/${this.pageSize}/${sortParam.Param}/${sortParam.Order}`
                : `TaskUser/SearchTaskUsers/0/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            this.currentFilters = [];
            this.currentSorts = [];
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = result.map((x) => {
                return {
                    ...x,
                    id: x.Id,
                };
            });
            this.setUpCardData();
        }
    }
    async loadMoreFiltersAndSorts() {
        if (!this.pageState) {
            return;
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: TaskUserPropertyMap[x.name],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$2).includes(x.condition)
                    ? FilterTypes$2[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == TaskUserPropertyName.Date
                    ? SearchPropertyValueType.Date
                    : SearchPropertyValueType.String,
            };
        });
        const sortParam = this.currentSorts.length > 0
            ? {
                Param: TaskUserPropertyMap[this.currentSorts[0].name],
                Order: this.currentSorts[0].value,
            }
            : null;
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`TaskUser/GetTaskUserWithParam/${this.currentSearchTerm.trim()}/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : await this.server.post(sortParam
                ? `TaskUser/SearchTaskUsers/${this.pageState.Skip}/${this.pageSize}/${sortParam.Param}/${sortParam.Order}`
                : `TaskUser/SearchTaskUsers/${this.pageState.Skip}/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            var result = res;
            return result;
        }
    }
    onFilterApplied(appliedFilter) {
        if (Array.isArray(appliedFilter)) {
            this.selectedFilterTableCount = appliedFilter.length;
            this.showFilter = false;
            const queryParams = appliedFilter
                .filter((filter) => filter.checked)
                .map((filter) => ({
                PropertyName: filter.name,
                EntityValue: filter.value,
                Type: filter.type,
                Operator: 'And',
                Sign: this.getCondition(filter.condition),
            }));
            this.postSearch(queryParams);
        }
    }
    getCondition(value) {
        switch (value) {
            case ConditionalOptions.On:
                return SearchPropertySign.EQ;
            case ConditionalOptions.After:
                return SearchPropertySign.EQ;
            case ConditionalOptions.Before:
                return SearchPropertySign.LT;
            case ConditionalOptions.NotEqual:
                return SearchPropertySign.NEQ;
            default:
                return value;
        }
    }
    onSortUpdated(updatedSorts) {
        this.currentSorts = updatedSorts;
        this.showSort = false;
        this.selectedSortTableCount = updatedSorts.length;
        this.updateFiltersAndSorts();
    }
    handleSearch(event) {
        this.searchTerm$.next(event.value);
    }
    handleExport(exportedData) {
        // console.log('Exported data:', exportedData);
        this.downloadCSV(exportedData);
    }
    downloadCSV(data) {
        const headers = Object.keys(data[0]);
        const csvContent = [
            headers.join(','),
            ...data.map((row) => headers.map((header) => row[header]).join(',')),
        ].join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'export.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormFieldsComponent, deps: [{ token: UtilService }, { token: HttpWebRequestService }, { token: i0.ChangeDetectorRef }, { token: i1$2.FormBuilder }, { token: EnvironmentService }, { token: i5.Router }, { token: i5.ActivatedRoute }, { token: FormsFieldService }, { token: i1$1.Location }, { token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FormFieldsComponent, selector: "lib-form-fields", inputs: { path: "path", application: "application", pageSize: "pageSize", searchDebounceTime: "searchDebounceTime" }, outputs: { onViewProcessClicked: "onViewProcessClicked" }, viewQueries: [{ propertyName: "fileInput", first: true, predicate: ["fileInput"], descendants: true, static: true }, { propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }, { propertyName: "tableView", first: true, predicate: ["dt"], descendants: true }], ngImport: i0, template: "<header class=\"rounded-lg shadow-lg flex justify-between items-center px-6 py-2 bg-[#D4A00773]\">\n  <h4 class=\"font-semibold\">{{formName}}</h4>\n  <verben-svg (click)=\"goBack()\" class=\"cursor-pointer\" [width]=\"17\" [height]=\"17\" [icon]=\"'close'\"></verben-svg>\n</header>\n<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n  <verben-data-view #vdv [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true,\n      }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n      [showSortChild]=\"showSort\" [showColumnChild]=\"showColumn\"\n    [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"selectedColumnTableCount\" [selectedSortCount]=\"selectedSortTableCount\"\n    [selectedFilterTableCount]=\"selectedFilterTableCount\" [showFilterChild]=\"showFilter\" [searchValue]=\"searchTerm\"\n    (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\" (onSearchChange)=\"onSearch($event)\">\n    <div class=\"mt-2\" table-content>\n      <lib-data-table #dt [data]=\"data[0].Properties\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\">\n        <ng-container libColumn=\"select\">\n          <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n            <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n          </ng-template>\n          <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n            let-toggleAllRows=\"toggleAllRows\">\n            <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n              (change)=\"toggleAllRows()\" />\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"name\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value.Name }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Name\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"minValue\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input [type]=\"'number'\" [ngModel]=\"getStringValue(row, 'MinValue')\"\n              (valueChange)=\"convertToInt($event, row, 'MinValue')\" inputContainerClass=\"w-[130px]\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"maxValue\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input [type]=\"'number'\" inputContainerClass=\"w-[130px]\" [ngModel]=\"getStringValue(row, 'MaxValue')\"\n              (valueChange)=\"convertToInt($event, row, 'MaxValue')\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"defaultValue\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input [type]=\"'text'\" inputContainerClass=\"w-[130px]\"\n              [(ngModel)]=\"row.DefaultValue\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"dataType\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <div class=\"flex flex-col gap-1\">\n              <verben-drop-down width=\"100%\" placeholder=\"Change Data Type\" [(options)]=\"dataType\"\n                [(ngModel)]=\"row.DataType\">\n              </verben-drop-down>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"isRequired\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <verben-svg *ngIf=\"value === true\" [icon]=\"'check'\"></verben-svg>\n            <verben-svg *ngIf=\"value === false\" [icon]=\"'error'\"></verben-svg>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"row.IsRequired\"></verbena-switch>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <verben-pop-Up [customStyles]=\"{'z-index': '99'}\" [dropdownOpen]=\"openDropdownId===row.id\"\n              [enableMouseLeave]=\"false\" (close)=\"onClose()\">\n              <verben-svg class=\"cursor-pointer actions-icon\" (click)=\"openDropdown(row)\" dropdown-trigger\n                icon=\"list\"></verben-svg>\n              <div class=\"pop-up-content flex flex-col\" *ngIf=\"openDropdownId===row.Id\" dropdown-content>\n                <div (click)=\"toggleRowEdit()\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                <div class=\"pop-up-value cursor-pointer\">Delete</div>\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <div class=\"flex gap-2 items-center\">\n              <verben-svg icon=\"check\" [width]=\"15\" [height]=\"15\"\n                (click)=\"saveViaTable(row, toggleRowEdit)\"></verben-svg>\n              <verben-svg icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n              <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view borderRadius=\"12px\" #vdcv dataId=\"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n        rbgColor=\"#f5f6f9\" mg=\"0px\">\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId=\"id\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n            <ng-template #card let-item>\n              <div (click)=\"userCardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                <div class=\"flex w-full bg-secondary rounded-xl\">\n                  <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"></div>\n                  <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                    <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                      <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                        <div class=\"flex justify-between mr-4\">\n                          <div>\n                            <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">\n                              {{ item.data.Name }}\n                            </h3>\n                            <span class=\"flex items-center gap-1 mt-2\">\n                              <span class=\"!text-[10px] text-[#404040]\">Data Type:</span>\n                              <span class=\"!text-[13px] font-bold\">{{\n                                item.data.DataType\n                                }}</span>\n                            </span>\n                          </div>\n\n                          <div>\n                            <span class=\"!text-[10px] text-[#404040]\">Default Value:</span>\n                            <p class=\"!text-[12px]\">\n                              {{ item.data.DefaultValue }}\n                            </p>\n                          </div>\n                        </div>\n                      </div>\n\n                      <!-- <div class=\"flex items-end h-[100%]\">\n                          <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span>\n                        </div> -->\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <div *ngIf=\"currentData\" class=\"flex flex-col rounded-xl h-full w-full relative gap-6\">\n              <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"currentData.data.Name\" />\n              <div class=\"flex flex-col gap-1\">\n                <div>Data Type</div>\n                <verben-drop-down width=\"100%\" placeholder=\"Change Data Type\" [(options)]=\"dataType\"\n                  [(ngModel)]=\"currentData.data.DataType\" (ngModelChange)=\"onDropDownChange($event)\">\n                </verben-drop-down>\n              </div>\n\n              <div *ngIf=\"currentData.data.DataType==='SingleSelection' || currentData.data.DataType==='MultiSelection'\">\n                <p class=\"mb-2\">Enter Options</p>\n                <verben-chip [placeholder]=\"'Enter Options'\" [(ngModel)]=\"chipArray\" (onChange)=\"onChipChange($event)\"></verben-chip>\n              </div>\n                <div>\n                  <verbena-input\n                    [placeHolder]=\"'Enter default text'\"\n                    [(ngModel)]=\"currentData.data.DefaultValue\"\n                    name=\"DefaultValue\"\n                    label=\"Default Value (optional)\"\n                    (ngModelChange)=\"updateTable()\"\n                  />\n           \n              \n              </div>\n              <div>\n                <p class=\"mb-2\">Required</p>\n\n                <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"currentData.data.IsRequired\"></verbena-switch>\n              </div>\n            <div *ngIf=\"currentData.data.DataType==='Number'||currentData.data.DataType==='Text' \" class=\" flex flex-col gap-6\">\n              <verbena-input\n              [type]=\"'number'\"\n              name=\"minValue\"\n              label=\"Min Value\"\n              (ngModelChange)=\"updateTable()\"\n              [ngModel]=\"getStringValue(currentData.data, 'MinValue')\"\n              (valueChange)=\"\n                convertToInt($event, currentData.data, 'MinValue')\n              \" />\n                <verbena-input [type]=\"'number'\" name=\"maxValue\" label=\"Max Value\" (ngModelChange)=\"updateTable()\"\n                  [ngModel]=\"getStringValue(currentData.data, 'MaxValue')\" (valueChange)=\"\n                convertToInt($event, currentData.data, 'MaxValue')\n              \" />\n              </div>\n              <!-- buttons -->\n              <div class=\"flex justify-between w-full bottom-8 left-0 right-0\">\n                <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button>\n                <div class=\"flex gap-3\">\n                  <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                    text=\"Switch To Table\"></verbena-button>\n                  <verbena-button class=\"verben-primary-button\" (click)=\"saveUser()\" text=\"Save\"></verbena-button>\n                </div>\n              </div>\n            </div>\n          </ng-template>\n        </verben-right-card-data-view>\n        <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n\n        <verben-card-data-view-footer>\n          <div class=\"flex gap-2 justify-between\">\n            <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n              <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                [text]=\"'Delete'\">\n              </verbena-button>\n            </div>\n            <div class=\"flex {{\n                vdcv.hasCurrentItem() ? 'flex-1' : ''\n              }} justify-end items-center gap-5\">\n              <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <verben-visible-column (resetFilter)=\"getProperties(Id, showColumn)\" (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"></verben-visible-column>\n    </div>\n    <div filter-content>\n      <verben-table-filter (resetSortData)=\"getProperties(Id, showFilter)\" (filtersApplied)=\"onFilterApplied($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"></verben-table-filter>\n    </div>\n    <div sort-content>\n      <verben-sort-table (resetSortData)=\"getProperties(Id, showSort)\" (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"></verben-sort-table>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data[0].Properties\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n        [text]=\"'Delete'\">\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n      <button (click)=\"loadMore()\" class=\"load-more view-links\">\n        Load more\n      </button>\n    </div>\n  </div>\n</div>\n<!-- <div class=\"w-[400px] bg-white p-4 shadow-lg border\">\n  <form-control  [dataType]=\"dataType2\" [formProperties]=\"data[0].Properties\"></form-control>\n</div> -->\n", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}::ng-deep .toolbar{margin-bottom:15px}::ng-deep .master-only-container{margin:0!important;padding:0!important}::ng-deep .master-detail-container{margin:0!important;padding:0!important}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.toggle-container{width:53px;padding:1px;color:#fff;height:22px;position:relative;background-color:#1a237e;border-radius:2rem;cursor:pointer}.toggle-circle{width:50%;height:100%;position:absolute;left:0;padding:5px;top:0;background-color:#fff;border-radius:50%;transform:scale(1);transition:transform .3s}.translate-100{transform:translate(100%)}.translate-0{transform:translate(0)}.toggle-text-on{display:block;font-size:12px;margin-left:4px}.toggle-text-off{display:block;font-size:12px;margin-right:4px;text-align:right}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.VisibleColumnComponent, selector: "verben-visible-column", inputs: ["columns", "items", "enableDragAndDrop", "displayedColumns", "showMore", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "closeColumn"], outputs: ["columnsUpdated", "resetFilter"] }, { kind: "component", type: i8.SortTableComponent, selector: "verben-sort-table", inputs: ["enableDragAndDrop", "sortOptions", "resetText", "displayedOptions", "propertyText", "showMoreText", "sortButtonText", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "containerHeight"], outputs: ["selectedOptions", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaSwitchComponent, selector: "verbena-switch", inputs: ["label", "checked", "disabled", "offColor", "onColor", "onText", "offText", "width", "height", "customStyles"], outputs: ["change"] }, { kind: "component", type: i8.ChipComponent, selector: "verben-chip", inputs: ["width", "placeholder", "max", "styleClass", "separator", "disabled", "required", "invalidMessage", "errorPosition"], outputs: ["onChange"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormFieldsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-form-fields', template: "<header class=\"rounded-lg shadow-lg flex justify-between items-center px-6 py-2 bg-[#D4A00773]\">\n  <h4 class=\"font-semibold\">{{formName}}</h4>\n  <verben-svg (click)=\"goBack()\" class=\"cursor-pointer\" [width]=\"17\" [height]=\"17\" [icon]=\"'close'\"></verben-svg>\n</header>\n<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n  <verben-data-view #vdv [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true,\n      }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n      [showSortChild]=\"showSort\" [showColumnChild]=\"showColumn\"\n    [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"selectedColumnTableCount\" [selectedSortCount]=\"selectedSortTableCount\"\n    [selectedFilterTableCount]=\"selectedFilterTableCount\" [showFilterChild]=\"showFilter\" [searchValue]=\"searchTerm\"\n    (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\" (onSearchChange)=\"onSearch($event)\">\n    <div class=\"mt-2\" table-content>\n      <lib-data-table #dt [data]=\"data[0].Properties\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\">\n        <ng-container libColumn=\"select\">\n          <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n            <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n          </ng-template>\n          <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n            let-toggleAllRows=\"toggleAllRows\">\n            <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n              (change)=\"toggleAllRows()\" />\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"name\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value.Name }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input inputContainerClass=\"w-fit\" [(ngModel)]=\"row.Name\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"minValue\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input [type]=\"'number'\" [ngModel]=\"getStringValue(row, 'MinValue')\"\n              (valueChange)=\"convertToInt($event, row, 'MinValue')\" inputContainerClass=\"w-[130px]\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"maxValue\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input [type]=\"'number'\" inputContainerClass=\"w-[130px]\" [ngModel]=\"getStringValue(row, 'MaxValue')\"\n              (valueChange)=\"convertToInt($event, row, 'MaxValue')\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"defaultValue\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-input [type]=\"'text'\" inputContainerClass=\"w-[130px]\"\n              [(ngModel)]=\"row.DefaultValue\"></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"dataType\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <div class=\"flex flex-col gap-1\">\n              <verben-drop-down width=\"100%\" placeholder=\"Change Data Type\" [(options)]=\"dataType\"\n                [(ngModel)]=\"row.DataType\">\n              </verben-drop-down>\n            </div>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"isRequired\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <verben-svg *ngIf=\"value === true\" [icon]=\"'check'\"></verben-svg>\n            <verben-svg *ngIf=\"value === false\" [icon]=\"'error'\"></verben-svg>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"row.IsRequired\"></verbena-switch>\n          </ng-template>\n        </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <verben-pop-Up [customStyles]=\"{'z-index': '99'}\" [dropdownOpen]=\"openDropdownId===row.id\"\n              [enableMouseLeave]=\"false\" (close)=\"onClose()\">\n              <verben-svg class=\"cursor-pointer actions-icon\" (click)=\"openDropdown(row)\" dropdown-trigger\n                icon=\"list\"></verben-svg>\n              <div class=\"pop-up-content flex flex-col\" *ngIf=\"openDropdownId===row.Id\" dropdown-content>\n                <div (click)=\"toggleRowEdit()\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                <div class=\"pop-up-value cursor-pointer\">Delete</div>\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n            <div class=\"flex gap-2 items-center\">\n              <verben-svg icon=\"check\" [width]=\"15\" [height]=\"15\"\n                (click)=\"saveViaTable(row, toggleRowEdit)\"></verben-svg>\n              <verben-svg icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n              <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view borderRadius=\"12px\" #vdcv dataId=\"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n        rbgColor=\"#f5f6f9\" mg=\"0px\">\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId=\"id\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n            <ng-template #card let-item>\n              <div (click)=\"userCardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                <div class=\"flex w-full bg-secondary rounded-xl\">\n                  <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"></div>\n                  <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                    <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                      <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                        <div class=\"flex justify-between mr-4\">\n                          <div>\n                            <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">\n                              {{ item.data.Name }}\n                            </h3>\n                            <span class=\"flex items-center gap-1 mt-2\">\n                              <span class=\"!text-[10px] text-[#404040]\">Data Type:</span>\n                              <span class=\"!text-[13px] font-bold\">{{\n                                item.data.DataType\n                                }}</span>\n                            </span>\n                          </div>\n\n                          <div>\n                            <span class=\"!text-[10px] text-[#404040]\">Default Value:</span>\n                            <p class=\"!text-[12px]\">\n                              {{ item.data.DefaultValue }}\n                            </p>\n                          </div>\n                        </div>\n                      </div>\n\n                      <!-- <div class=\"flex items-end h-[100%]\">\n                          <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span>\n                        </div> -->\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <div *ngIf=\"currentData\" class=\"flex flex-col rounded-xl h-full w-full relative gap-6\">\n              <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"currentData.data.Name\" />\n              <div class=\"flex flex-col gap-1\">\n                <div>Data Type</div>\n                <verben-drop-down width=\"100%\" placeholder=\"Change Data Type\" [(options)]=\"dataType\"\n                  [(ngModel)]=\"currentData.data.DataType\" (ngModelChange)=\"onDropDownChange($event)\">\n                </verben-drop-down>\n              </div>\n\n              <div *ngIf=\"currentData.data.DataType==='SingleSelection' || currentData.data.DataType==='MultiSelection'\">\n                <p class=\"mb-2\">Enter Options</p>\n                <verben-chip [placeholder]=\"'Enter Options'\" [(ngModel)]=\"chipArray\" (onChange)=\"onChipChange($event)\"></verben-chip>\n              </div>\n                <div>\n                  <verbena-input\n                    [placeHolder]=\"'Enter default text'\"\n                    [(ngModel)]=\"currentData.data.DefaultValue\"\n                    name=\"DefaultValue\"\n                    label=\"Default Value (optional)\"\n                    (ngModelChange)=\"updateTable()\"\n                  />\n           \n              \n              </div>\n              <div>\n                <p class=\"mb-2\">Required</p>\n\n                <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"currentData.data.IsRequired\"></verbena-switch>\n              </div>\n            <div *ngIf=\"currentData.data.DataType==='Number'||currentData.data.DataType==='Text' \" class=\" flex flex-col gap-6\">\n              <verbena-input\n              [type]=\"'number'\"\n              name=\"minValue\"\n              label=\"Min Value\"\n              (ngModelChange)=\"updateTable()\"\n              [ngModel]=\"getStringValue(currentData.data, 'MinValue')\"\n              (valueChange)=\"\n                convertToInt($event, currentData.data, 'MinValue')\n              \" />\n                <verbena-input [type]=\"'number'\" name=\"maxValue\" label=\"Max Value\" (ngModelChange)=\"updateTable()\"\n                  [ngModel]=\"getStringValue(currentData.data, 'MaxValue')\" (valueChange)=\"\n                convertToInt($event, currentData.data, 'MaxValue')\n              \" />\n              </div>\n              <!-- buttons -->\n              <div class=\"flex justify-between w-full bottom-8 left-0 right-0\">\n                <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button>\n                <div class=\"flex gap-3\">\n                  <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                    text=\"Switch To Table\"></verbena-button>\n                  <verbena-button class=\"verben-primary-button\" (click)=\"saveUser()\" text=\"Save\"></verbena-button>\n                </div>\n              </div>\n            </div>\n          </ng-template>\n        </verben-right-card-data-view>\n        <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n\n        <verben-card-data-view-footer>\n          <div class=\"flex gap-2 justify-between\">\n            <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n              <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                [text]=\"'Delete'\">\n              </verbena-button>\n            </div>\n            <div class=\"flex {{\n                vdcv.hasCurrentItem() ? 'flex-1' : ''\n              }} justify-end items-center gap-5\">\n              <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <verben-visible-column (resetFilter)=\"getProperties(Id, showColumn)\" (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"></verben-visible-column>\n    </div>\n    <div filter-content>\n      <verben-table-filter (resetSortData)=\"getProperties(Id, showFilter)\" (filtersApplied)=\"onFilterApplied($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"></verben-table-filter>\n    </div>\n    <div sort-content>\n      <verben-sort-table (resetSortData)=\"getProperties(Id, showSort)\" (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n        primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"></verben-sort-table>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data[0].Properties\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n        [text]=\"'Delete'\">\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n      <button (click)=\"loadMore()\" class=\"load-more view-links\">\n        Load more\n      </button>\n    </div>\n  </div>\n</div>\n<!-- <div class=\"w-[400px] bg-white p-4 shadow-lg border\">\n  <form-control  [dataType]=\"dataType2\" [formProperties]=\"data[0].Properties\"></form-control>\n</div> -->\n", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}::ng-deep .toolbar{margin-bottom:15px}::ng-deep .master-only-container{margin:0!important;padding:0!important}::ng-deep .master-detail-container{margin:0!important;padding:0!important}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.toggle-container{width:53px;padding:1px;color:#fff;height:22px;position:relative;background-color:#1a237e;border-radius:2rem;cursor:pointer}.toggle-circle{width:50%;height:100%;position:absolute;left:0;padding:5px;top:0;background-color:#fff;border-radius:50%;transform:scale(1);transition:transform .3s}.translate-100{transform:translate(100%)}.translate-0{transform:translate(0)}.toggle-text-on{display:block;font-size:12px;margin-left:4px}.toggle-text-off{display:block;font-size:12px;margin-right:4px;text-align:right}\n"] }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }, { type: i0.ChangeDetectorRef }, { type: i1$2.FormBuilder }, { type: EnvironmentService }, { type: i5.Router }, { type: i5.ActivatedRoute }, { type: FormsFieldService }, { type: i1$1.Location }, { type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { path: [{
                type: Input
            }], fileInput: [{
                type: ViewChild,
                args: ['fileInput', { static: true }]
            }], cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }], tableView: [{
                type: ViewChild,
                args: ['dt']
            }], application: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], searchDebounceTime: [{
                type: Input
            }], onViewProcessClicked: [{
                type: Output
            }] } });

class FormsFieldLibModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldLibModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldLibModule, declarations: [FormFieldsComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            VerbenaSwitchModule,
            FormControlerModule,
            ChipModule], exports: [FormFieldsComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldLibModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            VerbenaSwitchModule,
            FormControlerModule,
            ChipModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormsFieldLibModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FormFieldsComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        DataTableModule,
                        SvgModule,
                        VerbenPopUpModule,
                        DataViewModule, VerbenaButtonModule,
                        CardDataViewModule,
                        DropDownModule,
                        TableFilterModule,
                        VisibleColumnModule,
                        SortTableModule,
                        DataExportModule,
                        VerbenaInputModule,
                        VerbenaSwitchModule,
                        FormControlerModule,
                        ChipModule
                    ],
                    exports: [FormFieldsComponent],
                }]
        }] });

const appRoutes = [
    { path: '', component: FormGroupComponent, title: 'Form' },
    { path: 'fields', component: FormFieldsComponent, title: 'Fields' },
];
class FormGroupLibModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormGroupLibModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FormGroupLibModule, declarations: [FormGroupComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            VerbenaSwitchModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            FormsFieldLibModule, i5.RouterModule], exports: [FormGroupComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormGroupLibModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            VerbenaSwitchModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            FormsFieldLibModule,
            RouterModule.forChild(appRoutes)] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormGroupLibModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FormGroupComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        DataTableModule,
                        SvgModule,
                        VerbenPopUpModule,
                        DataViewModule, VerbenaButtonModule,
                        CardDataViewModule,
                        DropDownModule,
                        VerbenaSwitchModule,
                        TableFilterModule,
                        VisibleColumnModule,
                        SortTableModule,
                        DataExportModule,
                        VerbenaInputModule,
                        FormsFieldLibModule,
                        RouterModule.forChild(appRoutes),
                    ],
                    exports: [FormGroupComponent],
                }]
        }] });

class FormResponseService {
    constructor() { }
    get taskUsersColumns() {
        return [
            {
                id: 'select',
                header: '',
            },
            {
                id: 'createdAt',
                header: 'CREATED',
                accessorKey: 'CreatedAt',
            },
            {
                id: 'name',
                header: 'NAME',
                accessorKey: 'Name',
            },
            {
                id: 'isValid',
                header: 'ISVAliDATED',
                accessorKey: 'IsValid',
            },
            {
                id: 'expiryDate',
                header: 'EXPIRY DATE',
                accessorKey: 'ExpiryDate',
            },
            {
                id: 'duration',
                header: 'Duration',
                accessorKey: 'Duration',
            },
            {
                id: 'actions',
                header: 'ACTIONS',
                accessorFn: (row) => {
                    return row;
                },
            },
        ];
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [] });

var FormFieldProperty;
(function (FormFieldProperty) {
    FormFieldProperty["Name"] = "Name";
    FormFieldProperty["Description"] = "Description";
    FormFieldProperty["IsValidated"] = "IsValidated";
    FormFieldProperty["WorkFlow"] = "WorkFlow";
    FormFieldProperty["ServiceName"] = "ServiceName";
    FormFieldProperty["CreatedAt"] = "CreatedAt";
})(FormFieldProperty || (FormFieldProperty = {}));
var FilterTypes$1;
(function (FilterTypes) {
    FilterTypes["Before"] = "LT";
    FilterTypes["On"] = "EQ";
    FilterTypes["After"] = "GT";
    FilterTypes["NEQ"] = "NEQ";
})(FilterTypes$1 || (FilterTypes$1 = {}));
class FormResponseComponent {
    utilService;
    server;
    cdr;
    fb;
    envSvc;
    router;
    taskUsersSvc;
    _location;
    visibleColumnDef = [];
    styles = baseStyle$3;
    data = [];
    path = '/documentation/form-group/fields';
    cardData = [];
    selectedFilterTableCount = 0;
    showFilter = false;
    currentData = null;
    cardDataView;
    dataView;
    tableView;
    application = null;
    pageSize = 10;
    skip = 0;
    hasMore = true;
    onViewProcessClicked = new EventEmitter();
    searchTerm = '';
    pageState = null;
    isOpen = false;
    openDropdownId = null;
    currentFilters = [];
    currentSorts = [];
    dataType = DataType.Text;
    searchTerm$ = new Subject();
    statusOptions = Object.values(Status);
    active = 0;
    users = [];
    visibleColumns = [];
    filterArray = [
        {
            name: FormFieldProperty.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.Description,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.IsValidated,
            type: DataFilterType.Bool,
            checked: false,
        },
        {
            name: FormFieldProperty.ServiceName,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.WorkFlow,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    closePopUp(row) {
        this.openDropdownId = row.Id;
        this.onClose();
    }
    toggleTable(rowId) {
        this.tableView.toggleRowEdit(rowId);
    }
    sortOptions = [
        {
            name: FormFieldProperty.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.Description,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.IsValidated,
            type: DataFilterType.Bool,
            checked: false,
        },
        {
            name: FormFieldProperty.ServiceName,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.WorkFlow,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: FormFieldProperty.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
    ];
    currentSearchTerm = '';
    constructor(utilService, server, cdr, fb, envSvc, router, taskUsersSvc, _location) {
        this.utilService = utilService;
        this.server = server;
        this.cdr = cdr;
        this.fb = fb;
        this.envSvc = envSvc;
        this.router = router;
        this.taskUsersSvc = taskUsersSvc;
        this._location = _location;
        this.visibleColumnDef = taskUsersSvc.taskUsersColumns;
        this.visibleColumns = taskUsersSvc.taskUsersColumns.map((col) => ({
            checked: true,
            name: typeof col.header === 'string' ? col.header : col.id,
            type: DataFilterType.Bool,
        }));
    }
    goBack() {
        this._location.back();
    }
    async ngOnInit() {
        this.active = 0;
        this.getForms();
    }
    setActive(i = 0) {
        this.active = i;
    }
    async getAllTaskUsers() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`TaskUser/GetTaskUsers/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            return result;
        }
    }
    clearLogs(sortValue = 'CreatedAt', order = 'asc') {
        this.data = [];
        this.skip = 0;
        this.hasMore = true;
        this.getForms();
    }
    async getForms() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`Form/GetForms/${this.skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        this.pageState = res;
        const result = this.pageState.Result;
        if (this.data && Array.isArray(this.data)) {
            this.data = [...this.data, ...result];
        }
        else {
            this.data = result;
        }
        this.data.forEach(x => x.id = x.Id);
        this.skip += this.pageSize;
        this.hasMore = this.skip < this.pageState.Total;
        this.setUpCardData();
        return result;
    }
    loadMore() {
        if (this.hasMore) {
            this.getForms();
        }
    }
    reset() {
        this.skip = 0;
        this.pageSize = 10;
    }
    onUserSelected(event, item) {
        const user = this.users.find((x) => x.Name == event.value);
        if (user) {
            item.Name = user.Name;
            item.Duration = user.Duration;
            item.ExpiryDate = user.ExpiryDate;
            item.IsValid = user.IsValid;
            item.ServiceName = user.ServiceName;
        }
    }
    onClear(event, item) {
    }
    setUpCardData() {
        const cardData = this.data.map((x) => {
            return {
                selected: false,
                title: x.Name,
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = cardData;
    }
    goToCardView(data) {
        const item = this.cardData.find((x) => x.data == data);
        if (item) {
            this.userCardClicked(item, true);
            this.onClose();
        }
    }
    areRequiredPropertiesFilled(data) {
        const properties = data.Entities[this.active].Properties || [];
        // Check if all required properties have valid values
        return properties.every((property) => {
            return !property.isRequired || (property.Value !== undefined && property.Value !== null && property.Value !== '');
        });
    }
    goToTableView() {
        if (!this.currentData) {
            return;
        }
        this.dataView.toggleView();
        const id = this.currentData.data ? this.currentData.data.Id : '';
        if (id.trim().length > 0 && !this.tableView.isRowEditing(id)) {
            console.log(id);
            this.tableView.toggleRowEdit(id);
        }
    }
    viewProcesses(code) {
        if (code.trim().length == 0) {
            return;
        }
        this.onViewProcessClicked.emit(code);
    }
    userCardClicked(item, toggleView = false) {
        this.cardData.forEach((card) => (card.selected = false));
        item.selected = true;
        this.setActive(0);
        this.currentData = this.cardDataView.onItemClick(item);
        if (toggleView) {
            this.dataView.toggleView();
        }
    }
    async saveUser() {
        if (this.currentData) {
            var user = this.currentData.data;
            if (this.currentData.data.Name.trim().length == 0) {
                this.utilService.showInfo('Name cannot be empty');
                return;
            }
            user.DataState =
                user.DataState == ObjectState.New
                    ? ObjectState.New
                    : ObjectState.Changed;
            user.Id = user.DataState == ObjectState.New ? '' : user.Id;
            this.utilService.sendBI(true);
            const res = await this.server.post(`Form/SaveFormEntities`, [user], this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
            }
            else {
                this.utilService.showSuccess('Form entity saved successfully');
                const result = res;
                if (result.length > 0) {
                    var userResult = result[0];
                    const itemIndex = this.data.findIndex((x) => x == this.currentData?.data);
                    if (itemIndex > -1) {
                        this.data[itemIndex].Name = userResult.Name;
                        this.data[itemIndex].Id = userResult.Id;
                        this.data[itemIndex].id = userResult.id;
                        this.data[itemIndex].DataState = userResult.DataState;
                        this.data[itemIndex].Name = userResult.Name;
                        this.data[itemIndex].Duration = userResult.Duration;
                        this.data[itemIndex].Entities = userResult.Entities;
                        this.data[itemIndex].ExpiryDate = userResult.ExpiryDate;
                        this.data[itemIndex].IsValid = userResult.IsValid;
                        this.data = this.data.map((x) => x);
                    }
                }
            }
        }
    }
    async tableSaveUser(user, callBack) {
        user.DataState =
            user.DataState == ObjectState.New ? ObjectState.New : ObjectState.Changed;
        user.Id = user.DataState == ObjectState.New ? '' : user.Id;
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SaveFormEntities`, [user], this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
        }
        else {
            this.utilService.showSuccess('Form saved successfully');
            const result = res;
            if (result.length > 0) {
                var userResult = result[0];
                const itemIndex = this.data.findIndex((x) => x == user);
                if (itemIndex > -1) {
                    this.data[itemIndex].Name = userResult.Name;
                    this.data[itemIndex].Id = userResult.Id;
                    this.data[itemIndex].id = userResult.id;
                    this.data[itemIndex].DataState = userResult.DataState;
                    this.data[itemIndex].Name = userResult.Name;
                    this.data[itemIndex].Duration = userResult.Duration;
                    this.data[itemIndex].Entities = userResult.Entities;
                    this.data[itemIndex].ExpiryDate = userResult.ExpiryDate;
                    this.data[itemIndex].IsValid = userResult.IsValid;
                    this.data = this.data.map((x) => x);
                }
                callBack();
            }
        }
    }
    updateTable() {
        this.data = this.data.map((x) => x);
        console.log(this.data);
    }
    navigateToFields(card) {
        const queryParams = { FormId: card.Id, Name: card.Name };
        this.router.navigate([`${this.path}`], { queryParams });
    }
    onClose() {
        this.isOpen = false;
    }
    openDropdown(item) {
        if (this.openDropdownId === item.Id) {
            this.openDropdownId = null;
        }
        else {
            this.openDropdownId = item.Id;
        }
    }
    async onSearch(event) {
        this.searchTerm = event.value;
        this.reset();
        if (!this.searchTerm) {
            this.getForms();
            return;
        }
        this.utilService.sendBI(true);
        try {
            const res = await this.server.get(`Form/GetFormEntitiesWithParam/${this.searchTerm}/${this.skip}/${this.pageSize}/CreatedAt/asc`);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
                console.error('Error during search:', res);
            }
            else {
                this.pageState = res;
                var result = res.Result;
                this.data = result;
                this.setUpCardData();
            }
        }
        catch (error) {
            console.error('Search error:', error);
        }
        finally {
        }
    }
    isDropdownOpen(item) {
        return this.openDropdownId === item.id;
    }
    onViewChange(isGridView) { }
    onStateChange(event) {
        switch (event.key) {
            case 'filter':
                this.showFilter = event.value;
                break;
            default:
                break;
        }
    }
    showTableView = false;
    onSelectionChange(selectedRows) { }
    retryMessage() { }
    onColumnsUpdated(updatedColumns) {
        const updatedColumnDef = [];
        updatedColumns.forEach((col) => {
            const matchingCol = this.taskUsersSvc.taskUsersColumns.find((column) => column.header === col.name || column.id === col.name);
            if (matchingCol) {
                updatedColumnDef.push(matchingCol);
            }
        });
        this.visibleColumnDef = [...updatedColumnDef];
    }
    async updateFiltersAndSorts(isSearch = false) {
        if (!isSearch) {
            this.dataView.onClearSearch();
            this.currentSearchTerm = '';
            this.cdr.detectChanges();
            const clickEvent = new MouseEvent('click', {
                bubbles: true,
                cancelable: true,
                view: window,
            });
            document.dispatchEvent(clickEvent);
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: FormFieldProperty[x.name],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$1).includes(x.condition)
                    ? FilterTypes$1[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == FormFieldProperty.CreatedAt
                    ? SearchPropertyValueType.Date
                    : SearchPropertyValueType.String,
            };
        });
        // payload.push({
        //   PropertyName: 'APIKey',
        //   EntityValue: this.envSvc.environment.APIKey,
        //   Operator: SearchOperator.And,
        //   Sign: SearchPropertySign.EQ,
        // });
        const sortParam = this.currentSorts.length > 0
            ? {
                Param: FormFieldProperty[this.currentSorts[0].name],
                Order: this.currentSorts[0].value,
            }
            : null;
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Form/GetFormEntitiesWithParam/${this.currentSearchTerm.trim()}/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : await this.server.post(sortParam
                ? `Form/SearchFormEntities/0/${this.pageSize}/${sortParam.Param}/${sortParam.Order}`
                : `Form/SearchFormEntities/0/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            this.currentFilters = [];
            this.currentSorts = [];
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = result;
            this.setUpCardData();
        }
    }
    async postSearch(payload) {
        this.utilService.sendBI(true);
        const res = await this.server.post(`Form/SearchFormEntities/0/${this.pageSize}`, payload);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            this.data = result;
            this.setUpCardData();
            // this.setUpCardDataExtra(this.data)
            return result;
        }
    }
    async loadMoreFiltersAndSorts() {
        if (!this.pageState) {
            return;
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: FormFieldProperty[x.name],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes$1).includes(x.condition)
                    ? FilterTypes$1[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == FormFieldProperty.CreatedAt
                    ? SearchPropertyValueType.Date
                    : SearchPropertyValueType.String,
            };
        });
        const sortParam = this.currentSorts.length > 0
            ? {
                Param: FormFieldProperty[this.currentSorts[0].name],
                Order: this.currentSorts[0].value,
            }
            : null;
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Form/GetFormEntitiesWithParam/${this.currentSearchTerm.trim()}/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : await this.server.post(sortParam
                ? `Form/SearchFormEntities/${this.pageState.Skip}/${this.pageSize}/${sortParam.Param}/${sortParam.Order}`
                : `Form/SearchFormEntities/${this.pageState.Skip}/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            var result = res;
            this.data = result.Result;
            return result;
        }
    }
    onFilterApplied(appliedFilter) {
        this.showFilter = false;
        if (Array.isArray(appliedFilter)) {
            this.selectedFilterTableCount = appliedFilter.length;
            console.log(appliedFilter);
            const queryParams = appliedFilter
                .filter((filter) => filter.checked)
                .map((filter) => ({
                PropertyName: filter.name,
                EntityValue: filter.value,
                Type: filter.type,
                Operator: 'And',
                Sign: this.getCondition(filter.condition),
            }));
            this.postSearch(queryParams);
        }
    }
    getCondition(value) {
        switch (value) {
            case ConditionalOptions.On:
                return SearchPropertySign.EQ;
            case ConditionalOptions.After:
                return SearchPropertySign.EQ;
            case ConditionalOptions.Before:
                return SearchPropertySign.LT;
            case ConditionalOptions.NotEqual:
                return SearchPropertySign.NEQ;
            default:
                return value;
        }
    }
    onSortUpdated(updatedSorts) {
        this.currentSorts = updatedSorts;
        this.updateFiltersAndSorts();
    }
    handleSearch(event) {
        this.searchTerm$.next(event.value);
    }
    handleExport(exportedData) {
        // console.log('Exported data:', exportedData);
        this.downloadCSV(exportedData);
    }
    downloadCSV(data) {
        const headers = Object.keys(data[0]);
        const csvContent = [
            headers.join(','),
            ...data.map((row) => headers.map((header) => row[header]).join(',')),
        ].join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'export.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseComponent, deps: [{ token: UtilService }, { token: HttpWebRequestService }, { token: i0.ChangeDetectorRef }, { token: i1$2.FormBuilder }, { token: EnvironmentService }, { token: i5.Router }, { token: FormResponseService }, { token: i1$1.Location }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: FormResponseComponent, selector: "lib-form-response", inputs: { path: "path", application: "application", pageSize: "pageSize" }, outputs: { onViewProcessClicked: "onViewProcessClicked" }, viewQueries: [{ propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }, { propertyName: "tableView", first: true, predicate: ["dt"], descendants: true }], ngImport: i0, template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n  <header\n    class=\"rounded-lg shadow-lg flex justify-between items-center px-6 py-2 bg-[#D4A00773]\"\n  >\n    <h4 class=\"font-semibold\">{{ \"Contact Info\" }}</h4>\n    <verben-svg\n      (click)=\"goBack()\"\n      class=\"cursor-pointer\"\n      [width]=\"17\"\n      [height]=\"17\"\n      [icon]=\"'close'\"\n    ></verben-svg>\n  </header>\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: false,\n        isToggle:true,\n        \n      }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [searchValue]=\"searchTerm\"\n    (onSearchChange)=\"onSearch($event)\"\n    [showFilterChild]=\"showFilter\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div class=\"mt-2\" table-content>\n      <lib-data-table\n        #dt\n        [data]=\"data\"\n        [columns]=\"visibleColumnDef\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n      >\n        <ng-container libColumn=\"select\">\n          <ng-template\n            #cell\n            let-isSelected=\"isSelected\"\n            let-toggleRowSelection=\"toggleRowSelection\"\n          >\n            <input\n              type=\"checkbox\"\n              [checked]=\"isSelected\"\n              (change)=\"toggleRowSelection()\"\n            />\n          </ng-template>\n          <ng-template\n            #header\n            let-allRowsSelected=\"allRowsSelected\"\n            let-someRowsSelected=\"someRowsSelected\"\n            let-toggleAllRows=\"toggleAllRows\"\n          >\n            <input\n              type=\"checkbox\"\n              [checked]=\"allRowsSelected()\"\n              [indeterminate]=\"someRowsSelected()\"\n              (change)=\"toggleAllRows()\"\n            />\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"createdAt\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value | date }}\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"expiryDate\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value | date }}\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"name\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n        <!-- <ng-container libColumn=\"status\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <span *ngIf=\"value === 'Completed'\" class=\"bg-[#4ABB54]\">\n              {{ value }}\n            </span>\n            <span\n              *ngIf=\"value === 'Saved'\"\n              class=\"bg-[#BEB8FF] rounded-xl px-4 py-1\"\n            >\n              {{ value }}\n            </span>\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container> -->\n      \n     \n        <ng-container libColumn=\"isValid\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <verben-svg *ngIf=\"value===true\" [icon]=\"'check'\"></verben-svg>\n            <verben-svg *ngIf=\"value===false\" [icon]=\"'error'\"></verben-svg>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"row.IsValidated\"></verbena-switch>\n          </ng-template>\n          \n      </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template\n            #cell\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-value\n          >\n            <verben-pop-Up\n              [customStyles]=\"{ 'z-index': '99' }\"\n              [dropdownOpen]=\"isDropdownOpen(row)\"\n              [enableMouseLeave]=\"false\"\n              (close)=\"onClose()\"\n            >\n              <verben-svg\n                class=\"cursor-pointer actions-icon\"\n                (click)=\"openDropdown(row)\"\n                dropdown-trigger\n                icon=\"list\"\n              ></verben-svg>\n              <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                <div\n                  (click)=\"goToCardView(value)\"\n                  class=\"pop-up-value cursor-pointer\"\n                >\n                  View Form Group\n                </div>\n                <div class=\"pop-up-value cursor-pointer\">Delete</div>\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-value\n          >\n            <div class=\"flex gap-2 items-center\">\n              <verben-svg\n                icon=\"check\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"tableSaveUser(value, toggleRowEdit)\"\n              ></verben-svg>\n              <verben-svg icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n              <verben-svg\n                icon=\"cardViewAlt\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"goToCardView(value)\"\n              ></verben-svg>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        #vdcv\n        dataId=\"Id\"\n        border=\"5px\"\n        [cardDataList]=\"cardData\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"0px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"MailAddress\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData\"\n          >\n            <ng-template #card let-item>\n              <div\n                (click)=\"userCardClicked(item)\"\n                class=\"flex cursor-pointer h-[max-content]\"\n              >\n                <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                <div class=\"flex w-full bg-secondary rounded-xl\">\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                    <div\n                      class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\"\n                    >\n                      <div\n                        class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\"\n                      >\n                        <div class=\"flex justify-between\">\n                          <div>\n                            <h3\n                              class=\"my-0 font-bold text-[#404040] leading-[19.5px]\"\n                            >\n                              {{ item.data.Name??'Null' }}\n                            </h3>\n                            <span class=\"flex mt-2 items-center gap-1\">\n                              <span\n                                class=\"!text-[10px] font-light text-[#404040]\"\n                                >Expiry Date:</span\n                              >\n                              <span class=\"!text-[12px] font-semibold\">{{\n                                item.data.ExpiryDate|date\n                              }}</span>\n                            </span>\n                          </div>\n\n                          <div>\n                            <span class=\"!text-[10px] text-[#404040]\"\n                              >Duration</span\n                            >\n                            <p class=\"!text-[12px]\">{{ item.data.Duration }}</p>\n                         \n                          </div>\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <div *ngIf=\"this.currentData\">\n        \n              <div *ngIf=\"currentData.data.Entities[active]\"  class=\"flex flex-wrap bg-[#9A9FBF80] rounded-xl px-3 py-2 w-full relative gap-6\">\n                <app-form-timer></app-form-timer>\n                <div *ngFor=\"let group of currentData.data.Entities; let index = index\">\n                  <p \n                    (click)=\"setActive(index)\" \n                    [ngClass]=\"{'bg-[#fff] text-primary rounded-lg shadow-lg': active === index}\" \n                    class=\"px-6 py-2 cursor-pointer\">\n                    {{ group.Name }}group\n                  </p>\n                </div>\n              </div>\n              \n<div *ngIf=\"currentData.data.Entities[active]; else emptyState\" class=\"mt-4\">\n  <form-control [dataType]=\"dataType\" [formProperties]=\"currentData.data.Entities[active].Properties\"></form-control>\n  <div class=\"flex justify-between w-full bottom-8 left-0 right-0 mt-4\">\n    <verbena-button\n      class=\"verben-delete-button\"\n      text=\"Delete\"\n    ></verbena-button>\n\n    <div class=\"flex gap-3\">\n      <verbena-button\n        class=\"verben-switch-button\"\n        (click)=\"goToTableView()\"\n        text=\"Switch To Table\"\n      ></verbena-button>\n      <verbena-button\n        class=\"verben-primary-button\"\n        (click)=\"saveUser()\"\n        [disable]=\"areRequiredPropertiesFilled(currentData.data)\"\n        text=\"Save\"\n      ></verbena-button>\n    </div>\n  </div>\n</div>\n\n<!-- Empty state template -->\n<ng-template #emptyState>\n  <p class=\"mt-4 p-4 text-gray-600 text-center\">\n    No entries available for the selected form group.\n  </p>\n</ng-template>\n\n            </div>\n            \n          </ng-template>\n        </verben-right-card-data-view>\n        <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n\n        <verben-card-data-view-footer>\n          <div class=\"flex gap-2 justify-between\">\n            <div\n              *ngIf=\"!vdcv.hasCurrentItem()\"\n              class=\"message-log-button-container flex justify-between\"\n            >\n              <verbena-button\n                [fontWeight]=\"'bold'\"\n                [bgColor]=\"'#8E8D87'\"\n                [borderRadius]=\"'4px'\"\n                [textColor]=\"'#fff'\"\n                [text]=\"'Delete'\"\n              >\n              </verbena-button>\n            </div>\n            <div\n              class=\"flex {{\n                vdcv.hasCurrentItem() ? 'flex-1' : ''\n              }} justify-end items-center gap-5\"\n            >\n              <span class=\"paginator-text\"\n                >{{ cardData.length }} records loaded</span\n              >\n              <button (click)=\"loadMore()\" class=\"load-more view-links\">\n                Load more\n              </button>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <verben-visible-column\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"\n      ></verben-visible-column>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        (filtersApplied)=\"onFilterApplied($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <verben-sort-table\n        (selectedOptions)=\"onSortUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"\n      ></verben-sort-table>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button\n        [fontWeight]=\"'bold'\"\n        [bgColor]=\"'#8E8D87'\"\n        [borderRadius]=\"'4px'\"\n        [textColor]=\"'#fff'\"\n        [text]=\"'Delete'\"\n      >\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n      <button (click)=\"loadMore()\" class=\"load-more view-links\">\n        Load more\n      </button>\n    </div>\n  </div>\n</div>\n", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}::ng-deep .toolbar{margin-bottom:15px}::ng-deep .master-only-container{margin:0!important;padding:0!important}::ng-deep .master-detail-container{margin:0!important;padding:0!important}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.toggle-container{width:53px;padding:1px;color:#fff;height:22px;position:relative;background-color:#1a237e;border-radius:2rem;cursor:pointer}.toggle-circle{width:50%;height:100%;position:absolute;left:0;padding:5px;top:0;background-color:#fff;border-radius:50%;transform:scale(1);transition:transform .3s}.translate-100{transform:translate(100%)}.translate-0{transform:translate(0)}.toggle-text-on{display:block;font-size:12px;margin-left:4px}.toggle-text-off{display:block;font-size:12px;margin-right:4px;text-align:right}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.VerbenaSwitchComponent, selector: "verbena-switch", inputs: ["label", "checked", "disabled", "offColor", "onColor", "onText", "offText", "width", "height", "customStyles"], outputs: ["change"] }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.VisibleColumnComponent, selector: "verben-visible-column", inputs: ["columns", "items", "enableDragAndDrop", "displayedColumns", "showMore", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "closeColumn"], outputs: ["columnsUpdated", "resetFilter"] }, { kind: "component", type: i8.SortTableComponent, selector: "verben-sort-table", inputs: ["enableDragAndDrop", "sortOptions", "resetText", "displayedOptions", "propertyText", "showMoreText", "sortButtonText", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "containerHeight"], outputs: ["selectedOptions", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: FormControlComponent, selector: "form-control", inputs: ["dataType", "value", "boolInputType", "formProperties"] }, { kind: "component", type: FormTimerComponent, selector: "app-form-timer", inputs: ["expiryDate"] }, { kind: "pipe", type: i1$1.DatePipe, name: "date" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-form-response', template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n  <header\n    class=\"rounded-lg shadow-lg flex justify-between items-center px-6 py-2 bg-[#D4A00773]\"\n  >\n    <h4 class=\"font-semibold\">{{ \"Contact Info\" }}</h4>\n    <verben-svg\n      (click)=\"goBack()\"\n      class=\"cursor-pointer\"\n      [width]=\"17\"\n      [height]=\"17\"\n      [icon]=\"'close'\"\n    ></verben-svg>\n  </header>\n  <verben-data-view\n    #vdv\n    [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: false,\n        isToggle:true,\n        \n      }\"\n    [buttonClass]=\"'my-custom-button-class'\"\n    [iconClass]=\"'my-icon-class'\"\n    [searchValue]=\"searchTerm\"\n    (onSearchChange)=\"onSearch($event)\"\n    [showFilterChild]=\"showFilter\"\n    [activeIconClass]=\"'my-active-icon-class'\"\n    [selectedColumnCount]=\"0\"\n    [selectedSortCount]=\"0\"\n    [selectedFilterTableCount]=\"0\"\n    (viewChange)=\"onViewChange($event)\"\n    (stateChange)=\"onStateChange($event)\"\n  >\n    <div class=\"mt-2\" table-content>\n      <lib-data-table\n        #dt\n        [data]=\"data\"\n        [columns]=\"visibleColumnDef\"\n        [styleConfig]=\"styles\"\n        (selectionChange)=\"onSelectionChange($event)\"\n      >\n        <ng-container libColumn=\"select\">\n          <ng-template\n            #cell\n            let-isSelected=\"isSelected\"\n            let-toggleRowSelection=\"toggleRowSelection\"\n          >\n            <input\n              type=\"checkbox\"\n              [checked]=\"isSelected\"\n              (change)=\"toggleRowSelection()\"\n            />\n          </ng-template>\n          <ng-template\n            #header\n            let-allRowsSelected=\"allRowsSelected\"\n            let-someRowsSelected=\"someRowsSelected\"\n            let-toggleAllRows=\"toggleAllRows\"\n          >\n            <input\n              type=\"checkbox\"\n              [checked]=\"allRowsSelected()\"\n              [indeterminate]=\"someRowsSelected()\"\n              (change)=\"toggleAllRows()\"\n            />\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"createdAt\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value | date }}\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"expiryDate\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value | date }}\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n        <ng-container libColumn=\"name\">\n          <ng-template #cell let-row=\"row\" let-value>\n            {{ value }}\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container>\n        <!-- <ng-container libColumn=\"status\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <span *ngIf=\"value === 'Completed'\" class=\"bg-[#4ABB54]\">\n              {{ value }}\n            </span>\n            <span\n              *ngIf=\"value === 'Saved'\"\n              class=\"bg-[#BEB8FF] rounded-xl px-4 py-1\"\n            >\n              {{ value }}\n            </span>\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-row=\"row\"\n            let-updateValue=\"updateValue\"\n            let-value\n          >\n            <verbena-input\n              inputContainerClass=\"w-fit\"\n              [(ngModel)]=\"row.Workflow\"\n            ></verbena-input>\n          </ng-template>\n        </ng-container> -->\n      \n     \n        <ng-container libColumn=\"isValid\">\n          <ng-template #cell let-row=\"row\" let-value>\n            <verben-svg *ngIf=\"value===true\" [icon]=\"'check'\"></verben-svg>\n            <verben-svg *ngIf=\"value===false\" [icon]=\"'error'\"></verben-svg>\n          </ng-template>\n          <ng-template #cellEdit let-row=\"row\" let-updateValue=\"updateValue\" let-value>\n            <verbena-switch [onColor]=\"'#1A237E'\" [(ngModel)]=\"row.IsValidated\"></verbena-switch>\n          </ng-template>\n          \n      </ng-container>\n\n        <ng-container libColumn=\"actions\">\n          <ng-template\n            #cell\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-value\n          >\n            <verben-pop-Up\n              [customStyles]=\"{ 'z-index': '99' }\"\n              [dropdownOpen]=\"isDropdownOpen(row)\"\n              [enableMouseLeave]=\"false\"\n              (close)=\"onClose()\"\n            >\n              <verben-svg\n                class=\"cursor-pointer actions-icon\"\n                (click)=\"openDropdown(row)\"\n                dropdown-trigger\n                icon=\"list\"\n              ></verben-svg>\n              <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                <div\n                  (click)=\"goToCardView(value)\"\n                  class=\"pop-up-value cursor-pointer\"\n                >\n                  View Form Group\n                </div>\n                <div class=\"pop-up-value cursor-pointer\">Delete</div>\n              </div>\n            </verben-pop-Up>\n          </ng-template>\n          <ng-template\n            #cellEdit\n            let-isEditing=\"isEditing\"\n            let-toggleRowEdit=\"toggleRowEdit\"\n            let-row=\"row\"\n            let-value\n          >\n            <div class=\"flex gap-2 items-center\">\n              <verben-svg\n                icon=\"check\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"tableSaveUser(value, toggleRowEdit)\"\n              ></verben-svg>\n              <verben-svg icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n              <verben-svg\n                icon=\"cardViewAlt\"\n                [width]=\"15\"\n                [height]=\"15\"\n                (click)=\"goToCardView(value)\"\n              ></verben-svg>\n            </div>\n          </ng-template>\n        </ng-container>\n      </lib-data-table>\n    </div>\n    <div card-content>\n      <verben-card-data-view\n        borderRadius=\"12px\"\n        #vdcv\n        dataId=\"Id\"\n        border=\"5px\"\n        [cardDataList]=\"cardData\"\n        rbgColor=\"#f5f6f9\"\n        mg=\"0px\"\n      >\n        <verben-left-card-data-view class=\"space-y-7\">\n          <verben-left-card-data\n            #vlcd\n            [parent]=\"vdcv\"\n            dataId=\"MailAddress\"\n            class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\"\n            [cardDataList]=\"cardData\"\n          >\n            <ng-template #card let-item>\n              <div\n                (click)=\"userCardClicked(item)\"\n                class=\"flex cursor-pointer h-[max-content]\"\n              >\n                <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                <div class=\"flex w-full bg-secondary rounded-xl\">\n                  <div\n                    class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\"\n                    [ngClass]=\"\n                      item.selected ? 'bg-primary' : 'bg-secondary-200'\n                    \"\n                  ></div>\n                  <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                    <div\n                      class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\"\n                    >\n                      <div\n                        class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\"\n                      >\n                        <div class=\"flex justify-between\">\n                          <div>\n                            <h3\n                              class=\"my-0 font-bold text-[#404040] leading-[19.5px]\"\n                            >\n                              {{ item.data.Name??'Null' }}\n                            </h3>\n                            <span class=\"flex mt-2 items-center gap-1\">\n                              <span\n                                class=\"!text-[10px] font-light text-[#404040]\"\n                                >Expiry Date:</span\n                              >\n                              <span class=\"!text-[12px] font-semibold\">{{\n                                item.data.ExpiryDate|date\n                              }}</span>\n                            </span>\n                          </div>\n\n                          <div>\n                            <span class=\"!text-[10px] text-[#404040]\"\n                              >Duration</span\n                            >\n                            <p class=\"!text-[12px]\">{{ item.data.Duration }}</p>\n                         \n                          </div>\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </ng-template>\n          </verben-left-card-data>\n        </verben-left-card-data-view>\n        <verben-right-card-data-view>\n          <ng-template #parent>\n            <div *ngIf=\"this.currentData\">\n        \n              <div *ngIf=\"currentData.data.Entities[active]\"  class=\"flex flex-wrap bg-[#9A9FBF80] rounded-xl px-3 py-2 w-full relative gap-6\">\n                <app-form-timer></app-form-timer>\n                <div *ngFor=\"let group of currentData.data.Entities; let index = index\">\n                  <p \n                    (click)=\"setActive(index)\" \n                    [ngClass]=\"{'bg-[#fff] text-primary rounded-lg shadow-lg': active === index}\" \n                    class=\"px-6 py-2 cursor-pointer\">\n                    {{ group.Name }}group\n                  </p>\n                </div>\n              </div>\n              \n<div *ngIf=\"currentData.data.Entities[active]; else emptyState\" class=\"mt-4\">\n  <form-control [dataType]=\"dataType\" [formProperties]=\"currentData.data.Entities[active].Properties\"></form-control>\n  <div class=\"flex justify-between w-full bottom-8 left-0 right-0 mt-4\">\n    <verbena-button\n      class=\"verben-delete-button\"\n      text=\"Delete\"\n    ></verbena-button>\n\n    <div class=\"flex gap-3\">\n      <verbena-button\n        class=\"verben-switch-button\"\n        (click)=\"goToTableView()\"\n        text=\"Switch To Table\"\n      ></verbena-button>\n      <verbena-button\n        class=\"verben-primary-button\"\n        (click)=\"saveUser()\"\n        [disable]=\"areRequiredPropertiesFilled(currentData.data)\"\n        text=\"Save\"\n      ></verbena-button>\n    </div>\n  </div>\n</div>\n\n<!-- Empty state template -->\n<ng-template #emptyState>\n  <p class=\"mt-4 p-4 text-gray-600 text-center\">\n    No entries available for the selected form group.\n  </p>\n</ng-template>\n\n            </div>\n            \n          </ng-template>\n        </verben-right-card-data-view>\n        <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n\n        <verben-card-data-view-footer>\n          <div class=\"flex gap-2 justify-between\">\n            <div\n              *ngIf=\"!vdcv.hasCurrentItem()\"\n              class=\"message-log-button-container flex justify-between\"\n            >\n              <verbena-button\n                [fontWeight]=\"'bold'\"\n                [bgColor]=\"'#8E8D87'\"\n                [borderRadius]=\"'4px'\"\n                [textColor]=\"'#fff'\"\n                [text]=\"'Delete'\"\n              >\n              </verbena-button>\n            </div>\n            <div\n              class=\"flex {{\n                vdcv.hasCurrentItem() ? 'flex-1' : ''\n              }} justify-end items-center gap-5\"\n            >\n              <span class=\"paginator-text\"\n                >{{ cardData.length }} records loaded</span\n              >\n              <button (click)=\"loadMore()\" class=\"load-more view-links\">\n                Load more\n              </button>\n            </div>\n          </div>\n        </verben-card-data-view-footer>\n      </verben-card-data-view>\n    </div>\n    <div column-content>\n      <verben-visible-column\n        (columnsUpdated)=\"onColumnsUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        [columns]=\"visibleColumns\"\n        [displayedColumns]=\"5\"\n      ></verben-visible-column>\n    </div>\n    <div filter-content>\n      <verben-table-filter\n        (filtersApplied)=\"onFilterApplied($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"420px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [filterOptions]=\"filterArray\"\n        [maxFilterLength]=\"3\"\n      ></verben-table-filter>\n    </div>\n    <div sort-content>\n      <verben-sort-table\n        (selectedOptions)=\"onSortUpdated($event)\"\n        [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n        borderRadius=\"10px\"\n        boxShadow=\"2px 2px 2px 0px silver\"\n        bgColor=\"white\"\n        width=\"400px\"\n        textColor=\"black\"\n        pd=\"1rem\"\n        primaryColor=\"#FFE681\"\n        secondaryColor=\"#3479E9\"\n        tertiaryColor=\"#404040\"\n        [enableDragAndDrop]=\"true\"\n        [sortOptions]=\"sortOptions\"\n      ></verben-sort-table>\n    </div>\n    <div export-content>\n      <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n      </lib-data-export>\n    </div>\n  </verben-data-view>\n  <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n    <div class=\"message-log-button-container flex justify-between\">\n      <verbena-button\n        [fontWeight]=\"'bold'\"\n        [bgColor]=\"'#8E8D87'\"\n        [borderRadius]=\"'4px'\"\n        [textColor]=\"'#fff'\"\n        [text]=\"'Delete'\"\n      >\n      </verbena-button>\n    </div>\n    <div class=\"flex justify-end items-center gap-5\">\n      <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n      <button (click)=\"loadMore()\" class=\"load-more view-links\">\n        Load more\n      </button>\n    </div>\n  </div>\n</div>\n", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}::ng-deep .toolbar{margin-bottom:15px}::ng-deep .master-only-container{margin:0!important;padding:0!important}::ng-deep .master-detail-container{margin:0!important;padding:0!important}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.enum-val{padding:2px 10px;width:100%;min-width:max-content;text-align:center}.enum-val.Active{background-color:#d6f3e6;color:#2db76f}.enum-val.InActive{background-color:#ffdfdf;color:#eb5757}.toggle-container{width:53px;padding:1px;color:#fff;height:22px;position:relative;background-color:#1a237e;border-radius:2rem;cursor:pointer}.toggle-circle{width:50%;height:100%;position:absolute;left:0;padding:5px;top:0;background-color:#fff;border-radius:50%;transform:scale(1);transition:transform .3s}.translate-100{transform:translate(100%)}.translate-0{transform:translate(0)}.toggle-text-on{display:block;font-size:12px;margin-left:4px}.toggle-text-off{display:block;font-size:12px;margin-right:4px;text-align:right}\n"] }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }, { type: i0.ChangeDetectorRef }, { type: i1$2.FormBuilder }, { type: EnvironmentService }, { type: i5.Router }, { type: FormResponseService }, { type: i1$1.Location }], propDecorators: { path: [{
                type: Input
            }], cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }], tableView: [{
                type: ViewChild,
                args: ['dt']
            }], application: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], onViewProcessClicked: [{
                type: Output
            }] } });

class FormResponseLibModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseLibModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: FormResponseLibModule, declarations: [FormResponseComponent], imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            VerbenaSwitchModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            FormControlerModule,
            FormTimerModule], exports: [FormResponseComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseLibModule, imports: [CommonModule,
            FormsModule$1,
            ReactiveFormsModule,
            DataTableModule,
            SvgModule,
            VerbenPopUpModule,
            DataViewModule, VerbenaButtonModule,
            CardDataViewModule,
            DropDownModule,
            VerbenaSwitchModule,
            TableFilterModule,
            VisibleColumnModule,
            SortTableModule,
            DataExportModule,
            VerbenaInputModule,
            FormControlerModule,
            FormTimerModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: FormResponseLibModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [FormResponseComponent],
                    imports: [
                        CommonModule,
                        FormsModule$1,
                        ReactiveFormsModule,
                        DataTableModule,
                        SvgModule,
                        VerbenPopUpModule,
                        DataViewModule, VerbenaButtonModule,
                        CardDataViewModule,
                        DropDownModule,
                        VerbenaSwitchModule,
                        TableFilterModule,
                        VisibleColumnModule,
                        SortTableModule,
                        DataExportModule,
                        VerbenaInputModule,
                        FormControlerModule,
                        FormTimerModule
                    ],
                    exports: [FormResponseComponent],
                }]
        }] });

var Rules;
(function (Rules) {
    Rules["Pass"] = "Pass";
})(Rules || (Rules = {}));
var Tags;
(function (Tags) {
    Tags["WorkFlow"] = "Workflow";
})(Tags || (Tags = {}));
class StageDetailsComponent {
    RulesOptions = Object.keys(Rules);
    TagsOptions = Object.keys(Tags);
    isModalVisible = false;
    stageDetail;
    modalVisibilityChange = new EventEmitter();
    onModalOpen(eventData) {
        console.log('Modal opened, received data:', eventData);
        this.modalVisibilityChange.emit(true);
    }
    onModalClose(eventData) {
        console.log('Modal closed, received data:', eventData);
        this.isModalVisible = false;
        this.modalVisibilityChange.emit(false);
    }
    convertToInt(value, data, prop) {
        data[prop] = parseInt(value);
    }
    getStringValue(data, prop) {
        return data[prop].toString();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDetailsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: StageDetailsComponent, selector: "lib-stage-details", inputs: { RulesOptions: "RulesOptions", TagsOptions: "TagsOptions", isModalVisible: "isModalVisible", stageDetail: "stageDetail" }, outputs: { modalVisibilityChange: "modalVisibilityChange" }, ngImport: i0, template: "<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [mode]=\"'drawer'\"\n  [padding]=\"'0px'\"\n  [drawerWidth]=\"'400px'\"\n  [disableFooter]=\"false\"\n  (openModal)=\"onModalOpen($event)\"\n  (closeModal)=\"onModalClose($event)\"\n  [isVisible]=\"isModalVisible\"\n  [modalData]=\"stageDetail\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [showCloseIcon]=\"false\"\n  (closeModal)=\"onModalClose($event)\"\n>\n</verben-dialogue>\n<ng-template #headerTemplate>\n  <div class=\"bg-[#FFE681] px-6 py-4 flex justify-between items-center\">\n    <h1>Stage</h1>\n    <verben-svg\n      class=\"cursor-pointer\"\n      [icon]=\"'close-circle'\"\n      (click)=\"isModalVisible = false\"\n      [width]=\"15\"\n      [height]=\"15\"\n      [stroke]=\"'#fff'\"\n    ></verben-svg>\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div>\n    <div class=\"px-6 py-4 flex flex-col gap-6\">\n      <verbena-input\n        label=\"Stage Name\"\n        [(ngModel)]=\"stageDetail.Name\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Stage Name\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <verbena-input\n        label=\"Description\"\n        [(ngModel)]=\"stageDetail.Description\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Description\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <verbena-input\n        label=\"Receipient Count\"\n        [ngModel]=\"getStringValue(stageDetail, 'Count')\"\n        (valueChange)=\"convertToInt($event, stageDetail, 'Count')\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Receipient Count\"\n        type=\"number\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <div class=\"flex flex-col gap-1\">\n        <div>Pass On Rule</div>\n        <verben-drop-down\n          width=\"100%\"\n          [(ngModel)]=\"stageDetail.Rule\"\n          placeholder=\"Select Pass On Rule\"\n          [(options)]=\"RulesOptions\"\n        >\n        </verben-drop-down>\n      </div>\n      <verbena-input\n        [ngModel]=\"getStringValue(stageDetail, 'Duration')\"\n        (valueChange)=\"convertToInt($event, stageDetail, 'Duration')\"\n        label=\"Duration\"\n        type=\"number\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Duration\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <div class=\"flex flex-col gap-1\">\n        <div>Tag</div>\n        <verben-drop-down\n          width=\"100%\"\n          [(ngModel)]=\"stageDetail.Tag\"\n          placeholder=\"Select Tag\"\n          [(options)]=\"TagsOptions\"\n        >\n        </verben-drop-down>\n      </div>\n      <verbena-button\n        bgColor=\"#FFE681\"\n        [width]=\"'100%'\"\n        [text]=\"'Save'\"\n      ></verbena-button>\n    </div>\n  </div>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.VerbenDialogueComponent, selector: "verben-dialogue", inputs: ["dialogueWidth", "headerTemplate", "bodyTemplate", "footerTemplate", "showCloseIcon", "dismissOutsideClick", "closeOnEscape", "isVisible", "size", "backdropColor", "customClass", "disableFooter", "margin", "padding", "borderRadius", "dialogueBgColor", "width", "closeIconClass", "boxShadow", "enableTransition", "modalData", "mode", "position", "drawerWidth"], outputs: ["openModal", "closeModal"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDetailsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-stage-details', template: "<verben-dialogue\n  [showCloseIcon]=\"true\"\n  [dismissOutsideClick]=\"true\"\n  [closeOnEscape]=\"true\"\n  [mode]=\"'drawer'\"\n  [padding]=\"'0px'\"\n  [drawerWidth]=\"'400px'\"\n  [disableFooter]=\"false\"\n  (openModal)=\"onModalOpen($event)\"\n  (closeModal)=\"onModalClose($event)\"\n  [isVisible]=\"isModalVisible\"\n  [modalData]=\"stageDetail\"\n  [headerTemplate]=\"headerTemplate\"\n  [bodyTemplate]=\"bodyTemplate\"\n  [showCloseIcon]=\"false\"\n  (closeModal)=\"onModalClose($event)\"\n>\n</verben-dialogue>\n<ng-template #headerTemplate>\n  <div class=\"bg-[#FFE681] px-6 py-4 flex justify-between items-center\">\n    <h1>Stage</h1>\n    <verben-svg\n      class=\"cursor-pointer\"\n      [icon]=\"'close-circle'\"\n      (click)=\"isModalVisible = false\"\n      [width]=\"15\"\n      [height]=\"15\"\n      [stroke]=\"'#fff'\"\n    ></verben-svg>\n  </div>\n</ng-template>\n\n<ng-template #bodyTemplate>\n  <div>\n    <div class=\"px-6 py-4 flex flex-col gap-6\">\n      <verbena-input\n        label=\"Stage Name\"\n        [(ngModel)]=\"stageDetail.Name\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Stage Name\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <verbena-input\n        label=\"Description\"\n        [(ngModel)]=\"stageDetail.Description\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Description\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <verbena-input\n        label=\"Receipient Count\"\n        [ngModel]=\"getStringValue(stageDetail, 'Count')\"\n        (valueChange)=\"convertToInt($event, stageDetail, 'Count')\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Receipient Count\"\n        type=\"number\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <div class=\"flex flex-col gap-1\">\n        <div>Pass On Rule</div>\n        <verben-drop-down\n          width=\"100%\"\n          [(ngModel)]=\"stageDetail.Rule\"\n          placeholder=\"Select Pass On Rule\"\n          [(options)]=\"RulesOptions\"\n        >\n        </verben-drop-down>\n      </div>\n      <verbena-input\n        [ngModel]=\"getStringValue(stageDetail, 'Duration')\"\n        (valueChange)=\"convertToInt($event, stageDetail, 'Duration')\"\n        label=\"Duration\"\n        type=\"number\"\n        [border]=\"'1px solid #9A9FBF66'\"\n        placeHolder=\"Enter Duration\"\n        [bgColor]=\"'white'\"\n      ></verbena-input>\n      <div class=\"flex flex-col gap-1\">\n        <div>Tag</div>\n        <verben-drop-down\n          width=\"100%\"\n          [(ngModel)]=\"stageDetail.Tag\"\n          placeholder=\"Select Tag\"\n          [(options)]=\"TagsOptions\"\n        >\n        </verben-drop-down>\n      </div>\n      <verbena-button\n        bgColor=\"#FFE681\"\n        [width]=\"'100%'\"\n        [text]=\"'Save'\"\n      ></verbena-button>\n    </div>\n  </div>\n</ng-template>\n" }]
        }], propDecorators: { RulesOptions: [{
                type: Input
            }], TagsOptions: [{
                type: Input
            }], isModalVisible: [{
                type: Input
            }], stageDetail: [{
                type: Input
            }], modalVisibilityChange: [{
                type: Output
            }] } });

class StageDetailsModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDetailsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: StageDetailsModule, declarations: [StageDetailsComponent], imports: [CommonModule, SharedModule], exports: [StageDetailsComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDetailsModule, imports: [CommonModule, SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: StageDetailsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [StageDetailsComponent],
                    imports: [CommonModule, SharedModule],
                    exports: [StageDetailsComponent]
                }]
        }] });

class ExpirationComponent {
    idOptions = ['12uio899920000', '12uio8999299000', '896o899920000'];
    chipArray = [];
    cycle = [
        {
            id: 0,
            expanded: false,
            messages: [{ messageId: 'Default ID 1', subject: 'Default Subject 1', recipients: 'Default Recipients 1' }]
        },
        {
            id: 1,
            expanded: false,
            messages: [{ messageId: 'Default ID 2', subject: 'Default Subject 2', recipients: 'Default Recipients 2' }]
        },
        {
            id: 2,
            expanded: false,
            messages: [{ messageId: 'Default ID 3', subject: 'Default Subject 3', recipients: 'Default Recipients 3' }]
        }
    ];
    toggle = new EventEmitter();
    toggleCycle(index) {
        this.cycle[index].expanded = !this.cycle[index].expanded;
        this.toggle.emit(this.cycle[index].id);
    }
    addMessage(index) {
        this.cycle[index].messages.push({
            messageId: 'New Message ID',
            subject: 'New Subject',
            recipients: 'New Recipients'
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExpirationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: ExpirationComponent, selector: "lib-expiration", inputs: { cycle: "cycle" }, outputs: { toggle: "toggle" }, ngImport: i0, template: "<div class=\"w-full bg-white p-4\">\n    <div *ngFor=\"let item of cycle; let i = index\">\n      <div class=\"bg-[#FFE681B2] px-6 py-3 flex items-center mb-6 justify-between\" (click)=\"toggleCycle(i)\">\n        <span>Cycle {{ item.id + 1 }}</span>\n        <span class=\" cursor-pointer\">{{ item.expanded ? '\u25B2' : '\u25BC' }}</span>\n      </div>\n  \n      <div *ngIf=\"item.expanded\" class=\"cycle-content border border-primary p-6\">\n        <div *ngFor=\"let message of item.messages\" class=\"flex flex-col gap-6 mb-4\">\n          <verben-drop-down width=\"100%\" placeholder=\"Select Message ID\" [(options)]=\"idOptions\"></verben-drop-down>\n          <verbena-input type=\"text\" placeHolder=\"Message Subject\" bgColor=\"white\"></verbena-input>\n          <verben-chip [(ngModel)]=\"chipArray\" placeholder=\"Recipients\"></verben-chip>\n        </div>\n  \n        <div class=\"flex justify-end mt-4\">\n          <verbena-button text=\"+ Add Message\" bgColor=\"transparent\" pd=\"0\" textColor=\"blue\" (click)=\"addMessage(i)\"></verbena-button>\n        </div>\n      </div>\n    </div>\n  </div>\n  ", styles: [""], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.ChipComponent, selector: "verben-chip", inputs: ["width", "placeholder", "max", "styleClass", "separator", "disabled", "required", "invalidMessage", "errorPosition"], outputs: ["onChange"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExpirationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-expiration', template: "<div class=\"w-full bg-white p-4\">\n    <div *ngFor=\"let item of cycle; let i = index\">\n      <div class=\"bg-[#FFE681B2] px-6 py-3 flex items-center mb-6 justify-between\" (click)=\"toggleCycle(i)\">\n        <span>Cycle {{ item.id + 1 }}</span>\n        <span class=\" cursor-pointer\">{{ item.expanded ? '\u25B2' : '\u25BC' }}</span>\n      </div>\n  \n      <div *ngIf=\"item.expanded\" class=\"cycle-content border border-primary p-6\">\n        <div *ngFor=\"let message of item.messages\" class=\"flex flex-col gap-6 mb-4\">\n          <verben-drop-down width=\"100%\" placeholder=\"Select Message ID\" [(options)]=\"idOptions\"></verben-drop-down>\n          <verbena-input type=\"text\" placeHolder=\"Message Subject\" bgColor=\"white\"></verbena-input>\n          <verben-chip [(ngModel)]=\"chipArray\" placeholder=\"Recipients\"></verben-chip>\n        </div>\n  \n        <div class=\"flex justify-end mt-4\">\n          <verbena-button text=\"+ Add Message\" bgColor=\"transparent\" pd=\"0\" textColor=\"blue\" (click)=\"addMessage(i)\"></verbena-button>\n        </div>\n      </div>\n    </div>\n  </div>\n  " }]
        }], propDecorators: { cycle: [{
                type: Input
            }], toggle: [{
                type: Output
            }] } });

class ExpirationModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExpirationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: ExpirationModule, declarations: [ExpirationComponent], imports: [CommonModule, SharedModule], exports: [ExpirationComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExpirationModule, imports: [CommonModule, SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: ExpirationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ExpirationComponent],
                    imports: [CommonModule, SharedModule],
                    exports: [ExpirationComponent]
                }]
        }] });

class JournalComponent {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JournalComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: JournalComponent, selector: "lib-journal", ngImport: i0, template: "<p>journal works!</p>\n", styles: [""] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JournalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-journal', template: "<p>journal works!</p>\n" }]
        }] });

class JournalModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JournalModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: JournalModule, declarations: [JournalComponent], imports: [SharedModule], exports: [JournalComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JournalModule, imports: [SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JournalModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [JournalComponent],
                    imports: [SharedModule],
                    exports: [JournalComponent],
                }]
        }] });

const baseStyle = {
    width: '100%',
    fontFamily: '"Fraunces", serif',
    fontSize: '125%',
    whiteSpace: 'nowrap',
    margin: '0',
    border: '1px solid #D4A007',
    borderRadius: '16px',
    borderCollapse: 'separate',
    borderSpacing: '0',
    // tableLayout: 'fixed',
    overflow: 'hidden',
    rows: {
        even: {
            backgroundColor: '#FDFDFD',
        },
        odd: {
            backgroundColor: '#F1F4FB',
        },
        height: '68px',
    },
    cells: {
        padding: '0.5rem 1rem',
    },
    header: {
        // stickyTop: true,
        // zIndex: 2,
        backgroundColor: '#EFF2FB',
        fontWeight: 'bold',
        textAlign: 'left',
        padding: '12px 16px',
        height: '30px',
    },
    footer: {
        // stickyBottom: true,
        // zIndex: 2,
        padding: '3px',
    },
    //   body: {
    //     background: '#fff',
    //     padding: '4px 5px',
    //     textAlign: 'center',
    //   },
    // firstColumn: {
    //   stickyLeft: true,
    //   zIndex: 1,
    // },
    lastColumn: {
    // stickyRight: true,
    // zIndex: 1,
    },
};

var MessageMedium;
(function (MessageMedium) {
    MessageMedium["Mail"] = "Mail";
    MessageMedium["SMS"] = "SMS";
})(MessageMedium || (MessageMedium = {}));

var TaskNotificationType;
(function (TaskNotificationType) {
    TaskNotificationType["Assignment"] = "Assignment";
    TaskNotificationType["Escalation"] = "Escalation";
})(TaskNotificationType || (TaskNotificationType = {}));

var FilterTypes;
(function (FilterTypes) {
    FilterTypes["Before"] = "LT";
    FilterTypes["On"] = "EQ";
    FilterTypes["After"] = "GT";
    FilterTypes["NEQ"] = "NEQ";
})(FilterTypes || (FilterTypes = {}));

class TaskNotificationService {
    utilService;
    server;
    envSvc;
    pageSize = 10;
    constructor(utilService, server, envSvc) {
        this.utilService = utilService;
        this.server = server;
        this.envSvc = envSvc;
    }
    get taskNotificationColumns() {
        return [
            {
                id: 'select',
                header: '',
            },
            {
                id: 'createdAt',
                header: 'CREATED',
                accessorKey: 'CreatedAt',
            },
            // {
            //   id: 'code',
            //   header: 'CODE',
            //   accessorKey: 'Code',
            // },
            {
                id: 'name',
                header: 'NAME',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'subject',
                header: 'SUBJECT',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'notificationType',
                header: 'NOTIFICATION TYPE',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'medium',
                header: 'MEDIUM',
                accessorFn: (row) => {
                    return row;
                },
            },
            {
                id: 'senderConfig',
                header: 'SENDER CONFIG',
                accessorFn: (row) => {
                    return row;
                },
            },
            // {
            //   id: 'isMessageId',
            //   header: 'IS MESSAGE ID',
            //   accessorFn: (row: TaskNotification) => {
            //     return row;
            //   },
            // },
            {
                id: 'actions',
                header: 'ACTIONS',
                accessorFn: (row) => {
                    return row;
                },
            },
        ];
    }
    async getAllReportSchedules() {
        const fields = ['Code', 'Name'];
        return await this.loadEntitiesOld("ReportSchedule", fields, `${this.envSvc.environment.ReportingAPI}/Report`);
    }
    async loadMoreReportSchedules(event) {
        const fields = ['Code', 'Name'];
        return await this.loadEntitiesOld("ReportSchedule", fields, `${this.envSvc.environment.ReportingAPI}/Report`, event);
    }
    async searchReportSchedules(param, event) {
        const fields = ['Code', 'Name'];
        const searchBy = ['Code', 'Name'];
        return await this.searchEntitiesOld("ReportSchedule", fields, searchBy, `${this.envSvc.environment.ReportingAPI}/Report`, param, event);
    }
    async getAsyncReportScheduleLabel(value) {
        return await this.getAsyncLabelOld("ReportSchedule", "Name", value, `${this.envSvc.environment.ReportingAPI}/Report`);
    }
    async getAllSMSConfigs() {
        const fields = ['Code', 'Name'];
        return await this.loadEntities("SMSConfig", fields, `${this.envSvc.environment.MessagingAPI}/Config`);
    }
    async loadMoreSMSConfigs(event) {
        const fields = ['Code', 'Name'];
        return await this.loadEntities("SMSConfig", fields, `${this.envSvc.environment.MessagingAPI}/Config`, event);
    }
    async searchSMSConfigs(param, event) {
        const fields = ['Code', 'Name'];
        const searchBy = ['Code', 'Name'];
        return await this.searchEntities("SMSConfig", fields, searchBy, `${this.envSvc.environment.MessagingAPI}/Config`, param, event);
    }
    async getAsyncSMSConfigLabel(value) {
        return await this.getAsyncLabel("SMSConfig", "Name", value, `${this.envSvc.environment.MessagingAPI}/Config`);
    }
    async getAllMailConfigs() {
        const fields = ['Code', 'Name'];
        return await this.loadEntities("MailConfig", fields, `${this.envSvc.environment.MessagingAPI}/Config`);
    }
    async loadMoreMailConfigs(event) {
        const fields = ['Code', 'Name'];
        return await this.loadEntities("MailConfig", fields, `${this.envSvc.environment.MessagingAPI}/Config`, event);
    }
    async searchMailConfigs(param, event) {
        const fields = ['Code', 'Name'];
        const searchBy = ['Code', 'Name'];
        return await this.searchEntities("MailConfig", fields, searchBy, `${this.envSvc.environment.MessagingAPI}/Config`, param, event);
    }
    async getAsyncMailConfigLabel(value) {
        return await this.getAsyncLabel("MailConfig", "Name", value, `${this.envSvc.environment.MessagingAPI}/Config`);
    }
    async loadEntities(entity, fields, env, event = null) {
        var payload = {
            Fields: fields,
            SearchKeyValues: [
                {
                    PropertyName: 'Code',
                    EntityValue: '',
                    Operator: SearchOperator.And,
                    Sign: SearchPropertySign.EQ,
                    Sort: SortDirection.Asc
                },
            ],
        };
        if (!event) {
            this.utilService.sendBI(true);
        }
        const res = await this.server.post(`SearchDynamic${entity}/${event ? event.loadTimes * this.pageSize : 0}/${this.pageSize}`, payload, env);
        if (!event) {
            this.utilService.sendBI(false);
        }
        if (res instanceof ErrorResponse) {
            return [];
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async loadEntitiesOld(entity, fields, env, event = null) {
        if (!event) {
            this.utilService.sendBI(true);
        }
        const res = await this.server.get(`Get${entity}s/${event ? event.loadTimes * this.pageSize : 0}/${this.pageSize}`, env);
        if (!event) {
            this.utilService.sendBI(false);
        }
        if (res instanceof ErrorResponse) {
            return [];
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async searchEntities(entity, fields, searchBy, env, param, event = null) {
        var payload = {
            Fields: fields,
            SearchKeyValues: searchBy.map(x => {
                return {
                    PropertyName: x,
                    EntityValue: param,
                    Operator: SearchOperator.Or,
                    Sign: SearchPropertySign.EQ,
                };
            })
        };
        // this.utilService.sendBI(true);
        const res = await this.server.post(`SearchDynamic${entity}/${event ? event.loadTimes * this.pageSize : 0}/${this.pageSize}`, payload, env);
        // this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return [];
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async searchEntitiesOld(entity, fields, searchBy, env, param, event = null) {
        // this.utilService.sendBI(true);
        const res = await this.server.get(`Search${entity}s/${param}/${event ? event.loadTimes * this.pageSize : 0}/${this.pageSize}`, env);
        // this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return [];
        }
        else {
            var result = res.Result;
            return result;
        }
    }
    async getAsyncLabel(entity, labelProp, value, env, key = 'Code') {
        var payload = {
            Fields: [labelProp],
            SearchKeyValues: [
                {
                    PropertyName: key,
                    EntityValue: value,
                    Operator: SearchOperator.And,
                    Sign: SearchPropertySign.EQ,
                }
            ],
        };
        this.utilService.sendBI(true);
        const res = await this.server.post(`SearchDynamic${entity}/0/1`, payload, env);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return value;
        }
        else {
            var result = res.Result;
            return result.length > 0 ? result[0] : '';
        }
    }
    async getAsyncLabelOld(entity, labelProp, value, env, key = 'Code') {
        if (!value || (value.length && value.length == 0)) {
            return value;
        }
        this.utilService.sendBI(true);
        const res = await this.server.get(`Search${entity}s/${value}/0/1`, env);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return value;
        }
        else {
            var result = res.Result;
            return result.length > 0 ? result[0][labelProp] : '';
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationService, deps: [{ token: UtilService }, { token: HttpWebRequestService }, { token: EnvironmentService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }, { type: EnvironmentService }] });

var TaskNotificationPropertyName;
(function (TaskNotificationPropertyName) {
    TaskNotificationPropertyName["CreatedAt"] = "Created At";
    TaskNotificationPropertyName["Name"] = "Name";
    TaskNotificationPropertyName["Subject"] = "Subject";
    TaskNotificationPropertyName["SenderConfig"] = "Sendor Config";
    TaskNotificationPropertyName["Medium"] = "Medium";
    TaskNotificationPropertyName["NotificationType"] = "Notification Type";
    TaskNotificationPropertyName["IsMessageId"] = "Is Message Id";
})(TaskNotificationPropertyName || (TaskNotificationPropertyName = {}));
var TaskNotificationPropertyMap;
(function (TaskNotificationPropertyMap) {
    TaskNotificationPropertyMap["CreatedAt"] = "CreatedAt";
    TaskNotificationPropertyMap["Name"] = "Name";
    TaskNotificationPropertyMap["Subject"] = "Subject";
    TaskNotificationPropertyMap["SenderConfig"] = "SendorConfig";
    TaskNotificationPropertyMap["Medium"] = "Medium";
    TaskNotificationPropertyMap["NotificationType"] = "NotificationType";
    TaskNotificationPropertyMap["IsMessageId"] = "IsMessageId";
})(TaskNotificationPropertyMap || (TaskNotificationPropertyMap = {}));
class TaskNotificationComponent {
    utilService;
    server;
    cdr;
    fb;
    envSvc;
    service;
    visibleColumnDef = [];
    styles = baseStyle;
    data = [];
    cardData = [];
    currentData = null;
    workflowAPI = '';
    configAPI = '';
    cardDataView;
    dataView;
    tableView;
    popUps;
    pageSize = 10;
    searchDebounceTime = 500;
    pageState = null;
    isOpen = false;
    openDropdownId = null;
    currentFilters = [];
    currentSorts = [];
    searchTerm$ = new Subject();
    // searchTermHistory: string[] = [];
    smsConfigs = [];
    mailConfigs = [];
    reportSchedules = [];
    mediumOptions = Object.keys(MessageMedium);
    notificationTypeOptions = Object.keys(TaskNotificationType);
    smsRef = MessageMedium.SMS;
    mailRef = MessageMedium.Mail;
    editorMode = EditorMode.Designer;
    editorConfig = {
        editable: true,
        height: '',
        width: '',
        showToolbar: true,
        menuItems: [
            {
                Label: 'ToggleView',
                Icon: 'code-toggle',
                IconWidth: 20,
                IconHeight: 20,
                IsStroke: false,
                GroupBy: 'local',
                OnClick: (event) => {
                    this.editorMode = this.editorMode == EditorMode.Designer ? EditorMode.Code : EditorMode.Designer;
                },
                IsDisabled: (event) => {
                    return false;
                },
                IsEnabled: (event) => {
                    return this.editorMode == EditorMode.Code;
                },
            },
        ]
    };
    visibleColumns = [];
    filterArray = [
        {
            name: TaskNotificationPropertyName.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.Subject,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.SenderConfig,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.Medium,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.NotificationType,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.IsMessageId,
            type: DataFilterType.String,
            checked: false,
        }
    ];
    sortOptions = [
        {
            name: TaskNotificationPropertyName.CreatedAt,
            type: DataFilterType.Date,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.Name,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.Subject,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.SenderConfig,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.Medium,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.NotificationType,
            type: DataFilterType.String,
            checked: false,
        },
        {
            name: TaskNotificationPropertyName.IsMessageId,
            type: DataFilterType.String,
            checked: false,
        }
    ];
    currentSearchTerm = '';
    constructor(utilService, server, cdr, fb, envSvc, service) {
        this.utilService = utilService;
        this.server = server;
        this.cdr = cdr;
        this.fb = fb;
        this.envSvc = envSvc;
        this.service = service;
        this.visibleColumnDef = service.taskNotificationColumns;
        this.visibleColumns = service.taskNotificationColumns.map((col) => ({
            checked: true,
            name: typeof col.header === 'string' ? col.header : col.id,
            type: DataFilterType.Bool,
        }));
        this.workflowAPI = this.envSvc.environment.WorkFlowAPI;
        this.configAPI = `${this.envSvc.environment.MessagingAPI}/Config`;
    }
    async ngOnInit() {
        const groups = await this.getAllTaskNotifications();
        if (groups) {
            this.data = groups.map((x) => {
                return {
                    ...x,
                    Id: x.Code
                };
            });
            this.setUpCardData();
        }
        this.service.getAllSMSConfigs().then((res) => {
            if (res) {
                this.smsConfigs = res;
            }
        });
        this.service.getAllMailConfigs().then((res) => {
            if (res) {
                this.mailConfigs = res;
            }
        });
        this.service.getAllReportSchedules().then((res) => {
            if (res) {
                this.reportSchedules = res;
            }
        });
        this.searchTerm$
            .pipe(debounceTime(this.searchDebounceTime)) // Adjust debounce time here (in ms)
            .subscribe(async (searchTerm) => {
            this.currentSearchTerm = searchTerm;
            this.updateFiltersAndSorts(true);
        });
    }
    async getAllTaskNotifications() {
        this.utilService.sendBI(true);
        const res = await this.server.get(`Task/GetTaskNotifications/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            return result;
        }
    }
    async loadMore() {
        if (!this.pageState) {
            return;
        }
        this.utilService.sendBI(true);
        const res = this.currentFilters.length > 0 ||
            this.currentSorts.length > 0 ||
            this.currentSearchTerm.trim().length > 0
            ? await this.loadMoreFiltersAndSorts()
            : await this.server.get(`Task/GetTaskNotifications/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return;
        }
        else {
            this.pageState = res;
            var result = res.Result;
            const mappedData = result.map((x) => {
                return {
                    ...x,
                    Id: x.Code,
                };
            });
            this.data = this.data.concat(mappedData);
            this.setUpCardDataExtra(mappedData);
        }
    }
    setUpCardData() {
        const cardData = this.data.map((x) => {
            return {
                selected: false,
                title: x.Id.toString(),
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = cardData;
    }
    setUpCardDataExtra(baseData) {
        const cardData = baseData.map((x) => {
            return {
                selected: false,
                title: x.Id.toString(),
                data: x,
                body: [],
                children: [],
            };
        });
        this.cardData = this.cardData.concat(cardData);
    }
    goToCardView(data) {
        const item = this.cardData.find((x) => x.data == data);
        if (item) {
            this.cardClicked(item, true);
        }
    }
    goToTableView() {
        if (!this.currentData) {
            return;
        }
        this.dataView.toggleView();
        const id = this.currentData.data ? this.currentData.data.Id : '';
        if (id.trim().length > 0 && !this.tableView.isRowEditing(id)) {
            this.tableView.toggleRowEdit(id);
        }
    }
    viewVendors(code) {
        if (code.trim().length == 0) {
            return;
        }
        // this.onViewProcessClicked.emit(code);
        this.closePopUp();
    }
    cardClicked(item, toggleView = false) {
        this.currentData = this.cardDataView.onItemClick(item);
        if (toggleView) {
            this.dataView.toggleView();
        }
    }
    async saveTaskNotification() {
        if (this.currentData) {
            var group = this.currentData.data;
            if (this.currentData.data.Name.trim().length == 0) {
                this.utilService.showInfo('Name cannot be empty');
                return;
            }
            group.DataState =
                group.DataState == ObjectState.New
                    ? ObjectState.New
                    : ObjectState.Changed;
            group.Id = '';
            this.utilService.sendBI(true);
            const res = await this.server.post(`Task/SaveTaskNotifications`, [group], this.envSvc.environment.WorkFlowAPI);
            this.utilService.sendBI(false);
            if (res instanceof ErrorResponse) {
            }
            else {
                this.utilService.showSuccess('Vendor Group saved successfully');
                const result = res;
                if (result.length > 0) {
                    var resultItem = result[0];
                    const itemIndex = this.data.findIndex((x) => x == this.currentData?.data);
                    if (itemIndex > -1) {
                        this.data[itemIndex].Code = resultItem.Code;
                        this.data[itemIndex].Id = resultItem.Code;
                        this.data[itemIndex].id = resultItem.Code;
                        this.data[itemIndex].DataState = resultItem.DataState;
                        this.data[itemIndex].TenantId = resultItem.TenantId;
                        this.data[itemIndex].ServiceName = resultItem.ServiceName;
                        this.data = this.data.map((x) => x);
                    }
                }
            }
        }
    }
    async tableSaveTaskNotification(form, callBack) {
        if (form.Name.trim().length == 0) {
            this.utilService.showInfo('Name cannot be empty');
            return;
        }
        form.DataState =
            form.DataState == ObjectState.New ? ObjectState.New : ObjectState.Changed;
        form.Id = '';
        this.utilService.sendBI(true);
        const res = await this.server.post(`Task/SaveTaskNotifications`, [form], this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
        }
        else {
            this.utilService.showSuccess('Vendor Group saved successfully');
            const result = res;
            if (result.length > 0) {
                var resultItem = result[0];
                const itemIndex = this.data.findIndex((x) => x == form);
                if (itemIndex > -1) {
                    this.data[itemIndex].Code = resultItem.Code;
                    this.data[itemIndex].Id = resultItem.Code;
                    this.data[itemIndex].id = resultItem.Code;
                    this.data[itemIndex].DataState = resultItem.DataState;
                    this.data[itemIndex].TenantId = resultItem.TenantId;
                    this.data[itemIndex].ServiceName = resultItem.ServiceName;
                    this.data = this.data.map((x) => x);
                }
                callBack();
            }
        }
    }
    updateTable() {
        this.data = this.data.map((x) => x);
    }
    updateItem(value, key) {
        return {
            [key]: value,
        };
    }
    closePopUp() {
        this.openDropdownId = null;
        this.popUps.forEach((popUp) => {
            if (popUp.dropdownOpen) {
                popUp.toggleDropdown();
            }
        });
    }
    onViewChange(isGridView) { }
    onStateChange(event) {
        switch (event.key) {
            case 'create':
                var newGroup = {
                    Name: '',
                    Message: '',
                    Subject: '',
                    SenderConfig: '',
                    Medium: MessageMedium.Mail,
                    NotificationType: TaskNotificationType.Assignment,
                    IsMessageId: false,
                    id: this.data.length.toString(),
                    Id: this.data.length.toString(),
                    Code: '',
                    TenantId: '',
                    ServiceName: '',
                    CreatedAt: new Date(),
                    UpdatedAt: new Date(),
                    DataState: ObjectState.New,
                };
                const cardData = {
                    selected: false,
                    title: newGroup.Name,
                    data: newGroup,
                    body: [],
                    children: [],
                };
                this.data = this.data.concat([newGroup]);
                this.cardData.push(cardData);
                this.cardClicked(cardData);
                this.dataView.isTableView = false;
                break;
            default:
                break;
        }
    }
    showTableView = false;
    onSelectionChange(selectedRows) { }
    onColumnsUpdated(updatedColumns) {
        const updatedColumnDef = [];
        updatedColumns.forEach((col) => {
            const matchingCol = this.service.taskNotificationColumns.find((column) => column.header === col.name || column.id === col.name);
            if (matchingCol) {
                updatedColumnDef.push(matchingCol);
            }
        });
        this.visibleColumnDef = [...updatedColumnDef];
    }
    async updateFiltersAndSorts(isSearch = false) {
        if (!isSearch) {
            this.dataView.onClearSearch();
            this.currentSearchTerm = '';
            this.cdr.detectChanges();
            const clickEvent = new MouseEvent('click', {
                bubbles: true,
                cancelable: true,
                view: window,
            });
            document.dispatchEvent(clickEvent);
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: TaskNotificationPropertyMap[x.name.split(' ').join('')],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes).includes(x.condition)
                    ? FilterTypes[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == TaskNotificationPropertyName.CreatedAt
                    ? SearchPropertyValueType.Date : x.name == TaskNotificationPropertyName.IsMessageId ? SearchPropertyValueType.Bool
                    : SearchPropertyValueType.String,
            };
        });
        // payload.push({
        //   PropertyName: 'APIKey',
        //   EntityValue: this.envSvc.environment.APIKey,
        //   Operator: SearchOperator.And,
        //   Sign: SearchPropertySign.EQ,
        // });
        for (let sort of this.currentSorts) {
            payload.push({
                PropertyName: TaskNotificationPropertyMap[sort.name.split(' ').join('')],
                EntityValue: '',
                Operator: SearchOperator.And,
                Sign: SearchPropertySign.EQ,
                Sort: sort.value.toLowerCase() == SortDirection.Asc.toLowerCase()
                    ? SortDirection.Asc
                    : sort.value.toLowerCase() == SortDirection.Desc.toLowerCase()
                        ? SortDirection.Desc
                        : SortDirection.None,
            });
        }
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Task/GetTaskNotificationWithParam/${this.currentSearchTerm.trim()}/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : payload.length == 0
                ? await this.server.get(`Task/GetTaskNotifications/0/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
                : await this.server.post(`Task/SearchTaskNotification/0/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            this.currentFilters = [];
            this.currentSorts = [];
            return undefined;
        }
        else {
            this.cardDataView.clearData();
            this.currentData = null;
            this.pageState = res;
            var result = res.Result;
            this.data = result.map((x) => {
                return {
                    ...x,
                    Id: x.Code
                };
            });
            this.setUpCardData();
        }
    }
    async loadMoreFiltersAndSorts() {
        if (!this.pageState) {
            return;
        }
        var payload = this.currentFilters.map((x) => {
            return {
                PropertyName: TaskNotificationPropertyMap[x.name.split(' ').join('')],
                EntityValue: x.value,
                Operator: SearchOperator.And,
                Sign: x.condition && Object.keys(FilterTypes).includes(x.condition)
                    ? FilterTypes[x.condition]
                    : SearchPropertySign.EQ,
                Type: x.name == TaskNotificationPropertyName.CreatedAt
                    ? SearchPropertyValueType.Date : x.name == TaskNotificationPropertyName.IsMessageId ? SearchPropertyValueType.Bool
                    : SearchPropertyValueType.String,
            };
        });
        for (let sort of this.currentSorts) {
            payload.push({
                PropertyName: TaskNotificationPropertyMap[sort.name.split(' ').join('')],
                EntityValue: '',
                Operator: SearchOperator.And,
                Sign: SearchPropertySign.EQ,
                Sort: sort.value.toLowerCase() == SortDirection.Asc.toLowerCase()
                    ? SortDirection.Asc
                    : sort.value.toLowerCase() == SortDirection.Desc.toLowerCase()
                        ? SortDirection.Desc
                        : SortDirection.None,
            });
        }
        const searchTermExists = this.currentSearchTerm.trim().length > 0;
        this.utilService.sendBI(true);
        const res = searchTermExists
            ? await this.server.get(`Task/GetTaskNotificationsWithParam/${this.currentSearchTerm.trim()}/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
            : payload.length == 0
                ? await this.server.get(`Task/GetTaskNotifications/${this.pageState.Skip}/${this.pageSize}`, this.envSvc.environment.WorkFlowAPI)
                : await this.server.post(`Task/SearchTaskNotification/${this.pageState.Skip}/${this.pageSize}`, payload, this.envSvc.environment.WorkFlowAPI);
        this.utilService.sendBI(false);
        if (res instanceof ErrorResponse) {
            return undefined;
        }
        else {
            var result = res;
            return result;
        }
    }
    onFilterUpdated(updatedFilters) {
        // Ensure updatedFilters is an array
        if (Array.isArray(updatedFilters)) {
            this.currentFilters = updatedFilters;
            this.updateFiltersAndSorts();
        }
    }
    onSortUpdated(updatedSorts) {
        this.currentSorts = updatedSorts;
        this.updateFiltersAndSorts();
    }
    handleSearch(event) {
        this.searchTerm$.next(event.value);
    }
    handleExport(exportedData) {
        // console.log('Exported data:', exportedData);
        this.downloadCSV(exportedData);
    }
    downloadCSV(data) {
        const headers = Object.keys(data[0]);
        const csvContent = [
            headers.join(','),
            ...data.map((row) => headers.map((header) => row[header]).join(',')),
        ].join('\n');
        const blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
        const link = document.createElement('a');
        if (link.download !== undefined) {
            const url = URL.createObjectURL(blob);
            link.setAttribute('href', url);
            link.setAttribute('download', 'export.csv');
            link.style.visibility = 'hidden';
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        }
    }
    toggleIsMessageId(item, isMessageId) {
        item.Message = '';
        item.IsMessageId = isMessageId;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationComponent, deps: [{ token: UtilService }, { token: HttpWebRequestService }, { token: i0.ChangeDetectorRef }, { token: i1$2.FormBuilder }, { token: EnvironmentService }, { token: TaskNotificationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: TaskNotificationComponent, selector: "lib-task-notification", viewQueries: [{ propertyName: "cardDataView", first: true, predicate: ["vdcv"], descendants: true }, { propertyName: "dataView", first: true, predicate: ["vdv"], descendants: true }, { propertyName: "tableView", first: true, predicate: ["dt"], descendants: true }, { propertyName: "popUps", predicate: ["popup"], descendants: true }], ngImport: i0, template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n\n    <verben-data-view #vdv [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true,\n      }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n      [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"0\" [selectedSortCount]=\"0\"\n      [selectedFilterTableCount]=\"0\" (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\"\n      (onSearchChange)=\"handleSearch($event)\">\n      <div class=\"mt-2\" table-content>\n        <lib-data-table [dataKey]=\"'Id'\" class=\"form-table\" #dt [data]=\"data\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n          (selectionChange)=\"onSelectionChange($event)\">\n          <ng-container libColumn=\"select\">\n            <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n              <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n            </ng-template>\n            <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n              let-toggleAllRows=\"toggleAllRows\">\n              <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n                (change)=\"toggleAllRows()\" />\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"createdAt\">\n            <ng-template #cell let-value>\n              {{ value | date }}\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"medium\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Medium}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <verben-drop-down width=\"100%\" placeholder=\"Select Message Medium\" [(options)]=\"mediumOptions\"\n                [(ngModel)]=\"value.Medium\">\n              </verben-drop-down>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"name\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Name}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <div class=\"width-max\">\n                <verbena-input [(ngModel)]=\"value.Name\"></verbena-input>\n              </div>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"subject\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Subject}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <div class=\"width-max\">\n                <verbena-input [(ngModel)]=\"value.Subject\"></verbena-input>\n              </div>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"senderConfig\">\n            <ng-template #cell let-row=\"row\" let-value>\n              <div *ngIf=\"value.Medium == this.smsRef\">{{value.SenderConfig | asyncLabel: 'SMSConfig': 'Name': configAPI | async}}</div>\n              <div *ngIf=\"value.Medium == this.mailRef\">{{value.SenderConfig | asyncLabel: 'MailConfig': 'Name': configAPI | async}}</div>\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <verben-drop-down *ngIf=\"value.Medium == this.smsRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreSMSConfigs.bind(service)\"\n                  [search]=\"service.searchSMSConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncSMSConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"smsConfigs\" [(ngModel)]=\"value.SenderConfig\">\n                  </verben-drop-down>\n                  <verben-drop-down *ngIf=\"value.Medium == this.mailRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreMailConfigs.bind(service)\"\n                  [search]=\"service.searchMailConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncMailConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"mailConfigs\" [(ngModel)]=\"value.SenderConfig\">\n                  </verben-drop-down>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"notificationType\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.NotificationType}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <verben-drop-down width=\"100%\" placeholder=\"Select Notification Type\" [(options)]=\"notificationTypeOptions\"\n                [(ngModel)]=\"value.NotificationType\">\n              </verben-drop-down>\n            </ng-template>\n          </ng-container>\n  \n          <ng-container libColumn=\"actions\">\n            <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <verben-pop-Up #popup [customStyles]=\"{'z-index': '99'}\" [enableMouseLeave]=\"false\">\n                <verben-svg class=\"cursor-pointer actions-icon\" dropdown-trigger icon=\"list\"></verben-svg>\n                <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                  <!-- <div (click)=\"viewVendors(value.Code)\" class=\"pop-up-value cursor-pointer\">View vendors</div> -->\n                  <div (click)=\"toggleRowEdit(); closePopUp();\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                  <!-- <div class=\"pop-up-value cursor-pointer\">Delete</div> -->\n                </div>\n              </verben-pop-Up>\n            </ng-template>\n            <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <div class=\"flex gap-2 items-center\">\n                <verben-svg icon=\"tick\" [width]=\"15\" [height]=\"15\"\n                  (click)=\"tableSaveTaskNotification(value, toggleRowEdit)\"></verben-svg>\n                <verben-svg (click)=\"toggleRowEdit()\" icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n                <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n              </div>\n            </ng-template>\n          </ng-container>\n        </lib-data-table>\n      </div>\n      <div card-content>\n        <verben-card-data-view borderRadius=\"12px\" #vdcv dataId = \"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n          rbgColor=\"#f5f6f9\" mg=\"0px\">\n          <verben-left-card-data-view class=\"space-y-7\">\n            <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId = \"Id\"\n              class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n              <ng-template #card let-item>\n                <div (click)=\"cardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                  <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                  <div class=\"flex  w-full bg-secondary rounded-xl\">\n                    <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                        item.selected ? 'bg-primary' : 'bg-secondary-200'\n                      \"></div>\n                    <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                      <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                        <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                          <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">{{\n                            item.data.Name\n                            }}</h3>\n                          <!-- <span class=\"flex items-center gap-1\">\n                            <span class=\"!text-[10px] font-light text-[#404040]\">Ledger Header:</span> <span\n                              class=\"!text-[12px]\">{{item.data.SenderConfig}}</span>\n                          </span> -->\n                        </div>\n  \n                        <div class=\"flex flex-col items-between h-[100%]\">\n                          <div class=\"flex flex-col gap-1\">\n                            <span class=\"!text-[10px] font-light text-[#404040]\">Medium:</span>\n                            <div>{{item.data.Medium}}</div>\n                          </div>\n                          <!-- <p [ngClass]=\"{'disabled': item.data.DataState == 'New'}\" (click)=\"viewVendors(item.data.Code) ;$event.stopPropagation()\"\n                            class=\"view-lines my-0 underline text-[#3479E9] text-[12px] leading-[16.6px] cursor-pointer font-medium\">\n                            view vendors</p> -->\n                          <!-- <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span> -->\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </ng-template>\n            </verben-left-card-data>\n          </verben-left-card-data-view>\n          <verben-right-card-data-view>\n            <ng-template #parent>\n              <div *ngIf=\"this.currentData\"\n                class=\"flex flex-col rounded-xl h-full w-full justify-between relative space-y-4\">\n                <div class=\"options-container flex flex-col gap-2\">\n                  <div class=\"options-item flex gap-2 items-center\">\n                    <div (click)=\"toggleIsMessageId(this.currentData.data, false)\" [ngClass]=\"{'active': !this.currentData.data.IsMessageId}\" class=\"option-toggle rounded-full flex items-center justify-center\">\n                      <div class=\"option-toggle-dot rounded-full\"></div>\n                    </div>\n                    <div>Type Message</div>\n                  </div>\n                  <div class=\"options-item flex gap-2 items-center\">\n                    <div (click)=\"toggleIsMessageId(this.currentData.data, true)\" [ngClass]=\"{'active': this.currentData.data.IsMessageId}\" class=\"option-toggle rounded-full flex items-center justify-center\">\n                      <div class=\"option-toggle-dot rounded-full\"></div>\n                    </div>\n                    <div>Select Existing Message</div>\n                  </div>\n                </div>\n                <div class=\"task-notification-inputs-container flex flex-col gap-3\">\n                <!-- <verbena-input [disabled]=\"true\" name=\"Code\" label=\"Code\" [(ngModel)]=\"this.currentData.data.Code\" /> -->\n\n                <div *ngIf=\"this.currentData.data.IsMessageId\" class=\"flex flex-col gap-1\">\n                  <div>Message Config</div>\n                  <verben-drop-down\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreReportSchedules.bind(service)\"\n                  [search]=\"service.searchReportSchedules.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncReportScheduleLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Message Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"reportSchedules\" [(ngModel)]=\"this.currentData.data.Message\">\n                  </verben-drop-down>\n                </div>\n\n              <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n              [(ngModel)]=\"this.currentData.data.Name\" />\n              <verbena-input name=\"Subject\" label=\"Subject\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"this.currentData.data.Subject\" />\n              <div class=\"flex flex-col gap-1\">\n                <div>Notification Type</div>\n                <verben-drop-down width=\"100%\" placeholder=\"Select Notification Type\" [(options)]=\"notificationTypeOptions\"\n                    [(ngModel)]=\"this.currentData.data.NotificationType\">\n                </verben-drop-down>\n              </div>\n                <div class=\"flex flex-col gap-1\">\n                    <div>Message Medium</div>\n                    <verben-drop-down width=\"100%\" placeholder=\"Select Message Medium\" [(options)]=\"mediumOptions\"\n                        [(ngModel)]=\"this.currentData.data.Medium\">\n                    </verben-drop-down>\n                </div>\n  \n                <div class=\"flex flex-col gap-1\">\n                  <div>Sender Config</div>\n                  <verben-drop-down *ngIf=\"this.currentData.data.Medium == this.smsRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreSMSConfigs.bind(service)\"\n                  [search]=\"service.searchSMSConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncSMSConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"smsConfigs\" [(ngModel)]=\"this.currentData.data.SenderConfig\">\n                  </verben-drop-down>\n                  <verben-drop-down *ngIf=\"this.currentData.data.Medium == this.mailRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreMailConfigs.bind(service)\"\n                  [search]=\"service.searchMailConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncMailConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"mailConfigs\" [(ngModel)]=\"this.currentData.data.SenderConfig\">\n                  </verben-drop-down>\n                </div>\n\n                <div *ngIf=\"!this.currentData.data.IsMessageId\" class=\"flex editor-container-wrapper flex-col gap-1\">\n                    <lib-editor [editorConfig]=\"editorConfig\" [editorMode]=\"editorMode\" [(ngModel)]=\"this.currentData.data.Message\"></lib-editor>\n                </div>\n\n                </div>\n                <!-- buttons -->\n                <div class=\"flex justify-between bottom-8 left-0 right-0\">\n                  <div></div>\n                  <!-- <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button> -->\n                  <div class=\"flex gap-3\">\n                    <!-- <verbena-button class=\"verben-switch-button\"\n                      (click)=\"viewVendors(this.currentData? this.currentData.data? this.currentData.data.Code: '':'')\"\n                      text=\"View Vendors\"></verbena-button> -->\n                    <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                      text=\"Switch To Table\"></verbena-button>\n                    <verbena-button class=\"verben-primary-button\" (click)=\"this.saveTaskNotification()\"\n                      text=\"Save\"></verbena-button>\n                  </div>\n                </div>\n              </div>\n  \n            </ng-template>\n          </verben-right-card-data-view>\n          <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n  \n          <verben-card-data-view-footer>\n            <div class=\"flex gap-2 justify-between\">\n              <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n                <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                  [text]=\"'Delete'\">\n                </verbena-button> -->\n              </div>\n              <div class=\"flex {{vdcv.hasCurrentItem()?'flex-1':''}} justify-end items-center gap-5\">\n                <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n                <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n              </div>\n            </div>\n          </verben-card-data-view-footer>\n        </verben-card-data-view>\n      </div>\n      <div column-content>\n        <verben-visible-column (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n          [displayedColumns]=\"5\"></verben-visible-column>\n      </div>\n      <div filter-content>\n        <verben-table-filter (filtersApplied)=\"onFilterUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n          [maxFilterLength]=\"3\"></verben-table-filter>\n      </div>\n      <div sort-content>\n        <verben-sort-table (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n          [sortOptions]=\"sortOptions\"></verben-sort-table>\n      </div>\n      <div export-content>\n        <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n        </lib-data-export>\n      </div>\n    </verben-data-view>\n    <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n      <div class=\"message-log-button-container flex justify-between\">\n        <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n          [text]=\"'Delete'\">\n        </verbena-button> -->\n      </div>\n      <div class=\"flex justify-end items-center gap-5\">\n        <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n        <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n      </div>\n    </div>\n  </div>\n  ", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.width-max{min-width:max-content}.editor-container-wrapper{border-top:1px solid #D4A007;margin-left:-19px;margin-right:-19px;padding:5px}::ng-deep .editor-container{gap:0!important}.option-toggle{border:1px solid #B3BAC5;width:20px;height:20px;cursor:pointer}.option-toggle-dot{width:10px;height:10px}.option-toggle.active{border:1px solid #0075FF}.option-toggle.active>div{background-color:#0075ff}.task-notification-inputs-container{border:1px solid #D4A007;border-radius:16px;padding:15px 20px;margin-left:-19px;margin-right:-19px}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i8.DataTableComponent, selector: "lib-data-table", inputs: ["data", "columns", "dataKey", "formGroupConfig", "groupBy", "styleConfig"], outputs: ["rowEdit", "rowSave", "rowRevert", "rowDelete", "selectionChange"] }, { kind: "directive", type: i8.ColumnDirective, selector: "[libColumn]", inputs: ["libColumn"] }, { kind: "component", type: i8.SvgComponent, selector: "verben-svg", inputs: ["icon", "width", "height", "fill", "stroke", "type", "size"] }, { kind: "component", type: i8.DataViewComponent, selector: "verben-data-view", inputs: ["buttonClass", "iconClass", "activeIconClass", "columnCustomClass", "filterCustomClass", "sortCustomClass", "extendCustomClass", "exportCustomClass", "selectCustomClass", "importCustomClass", "zIndex", "createCustomClass", "tableIcon", "cardIcon", "cardClass", "tableClass", "searchKey", "searchValue", "viewState", "searchTemplate", "importTemplate", "columnTemplate", "extendTemplate", "filterTemplate", "sortTemplate", "children", "exportTemplate", "createTemplate", "selectedColumnCount", "selectedSortCount", "selectedFilterTableCount", "inputWidth", "milliseconds", "showColumnChild", "showSortChild", "showFilterChild", "showImportChild", "showExportChild", "showExtendChild", "create", "showSelected", "isTableView"], outputs: ["viewChange", "stateChange", "onSearchChange"] }, { kind: "component", type: i8.CardDataViewComponent, selector: "verben-card-data-view", inputs: ["pd", "mg", "lHeight", "rHeight", "rWidth", "lWidth", "textColor", "lbgColor", "rbgColor", "border", "display", "borderRadius", "activeCss", "inActiveCss", "displayAsRow", "cardDataList", "dataId", "totalRecords", "footer", "noOfVisibleChildren", "onItemClick", "onCardChildClick"], outputs: ["loadMoreClick"] }, { kind: "component", type: i8.LeftCardDataComponent, selector: "verben-left-card-data", inputs: ["pd", "mg", "height", "weight", "activeCss", "inActiveCss", "cardDataList", "iconCollapse", "iconExpanded", "parent", "dataId"] }, { kind: "component", type: i8.LeftCardDataViewComponent, selector: "verben-left-card-data-view", inputs: ["cardDataList"] }, { kind: "component", type: i8.RightCardDataViewComponent, selector: "verben-right-card-data-view", inputs: ["parentData", "chilData", "meth"] }, { kind: "component", type: i8.CardDataViewFooterComponent, selector: "verben-card-data-view-footer" }, { kind: "component", type: i8.SortTableComponent, selector: "verben-sort-table", inputs: ["enableDragAndDrop", "sortOptions", "resetText", "displayedOptions", "propertyText", "showMoreText", "sortButtonText", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "containerHeight"], outputs: ["selectedOptions", "resetSortData"] }, { kind: "component", type: i8.VisibleColumnComponent, selector: "verben-visible-column", inputs: ["columns", "items", "enableDragAndDrop", "displayedColumns", "showMore", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "closeColumn"], outputs: ["columnsUpdated", "resetFilter"] }, { kind: "component", type: i8.TableFilterComponent, selector: "verben-table-filter", inputs: ["filterOptions", "pd", "mg", "height", "width", "bgColor", "boxShadow", "textColor", "primaryColor", "secondaryColor", "tertiaryColor", "border", "borderRadius", "selectWidth", "maxFilterLength", "tooltip"], outputs: ["filtersApplied", "resetSortData"] }, { kind: "component", type: i8.DataExportComponent, selector: "lib-data-export", inputs: ["columns", "data"], outputs: ["exportDataEvent"] }, { kind: "directive", type: i1$2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i8.VerbenaInputComponent, selector: "verbena-input", inputs: ["label", "placeHolder", "required", "svgPosition", "minLength", "maxLength", "type", "bgColor", "border", "borderRadius", "textColor", "value", "labelPosition", "labelColor", "disable", "readOnly", "min", "max", "showBorder", "showErrorMessage", "errorMessageColor", "errorBorderColor", "errorPosition", "svg", "fontSize", "svgWidth", "svgHeight", "svgColor", "capitalization", "inputContainerClass", "inputFieldClass", "passLength", "inputWrapperClass", "passwordToggle", "customErrorMessages", "icon", "textPass"], outputs: ["valueChange"] }, { kind: "component", type: i8.VerbenaButtonComponent, selector: "verbena-button", inputs: ["text", "icon", "useIcon", "svgPosition", "iconPosition", "bgColor", "textColor", "border", "borderRadius", "pd", "width", "height", "fontSize", "fontWeight", "disable", "svgSize", "weight", "variant", "styleType", "svg", "svgWidth", "svgHeight", "iconColor", "svgColor", "buttonClass", "buttonTextClass", "isLoading", "spinnerSize", "spinnerColor"] }, { kind: "component", type: i8.DropDownComponent, selector: "verben-drop-down", inputs: ["options", "width", "showHorizontalLine", "horizontalLineColor", "optionLabel", "optionSubLabel", "optionValue", "placeholder", "invalidMessage", "errorPosition", "loadMoreCaption", "display", "showClear", "lazyLoad", "selectKey", "styleClass", "group", "multiselect", "filter", "avoidDuplication", "filterBy", "debounceTime", "minChar", "disabled", "required", "load", "asyncLabel", "search"], outputs: ["optionsChange", "onChange", "onClick", "onClear"] }, { kind: "component", type: i8.VerbenPopUpComponent, selector: "verben-pop-Up", inputs: ["dropdownOpen", "dropdownWidth", "color", "customStyles", "popUpClass", "border", "borderRadius", "enableMouseLeave", "cdkPosition"], outputs: ["dropdownOpenChange", "close"] }, { kind: "component", type: i8$1.EditorComponent, selector: "lib-editor", inputs: ["themeColor", "editorMode", "editorConfig", "content"] }, { kind: "pipe", type: i1$1.AsyncPipe, name: "async" }, { kind: "pipe", type: i1$1.DatePipe, name: "date" }, { kind: "pipe", type: AsyncLabelPipe, name: "asyncLabel" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-task-notification', template: "<div #messageLog class=\"flex flex-col gap-4 message-log-container\">\n\n    <verben-data-view #vdv [viewState]=\"{\n        isSearch: true,\n        isColumn: true,\n        isFilter: true,\n        isSort: true,\n        isExport: true,\n        isSelect: true,\n        isCreate: true,\n        isToggle:true,\n      }\" [buttonClass]=\"'my-custom-button-class'\" [iconClass]=\"'my-icon-class'\"\n      [activeIconClass]=\"'my-active-icon-class'\" [selectedColumnCount]=\"0\" [selectedSortCount]=\"0\"\n      [selectedFilterTableCount]=\"0\" (viewChange)=\"onViewChange($event)\" (stateChange)=\"onStateChange($event)\"\n      (onSearchChange)=\"handleSearch($event)\">\n      <div class=\"mt-2\" table-content>\n        <lib-data-table [dataKey]=\"'Id'\" class=\"form-table\" #dt [data]=\"data\" [columns]=\"visibleColumnDef\" [styleConfig]=\"styles\"\n          (selectionChange)=\"onSelectionChange($event)\">\n          <ng-container libColumn=\"select\">\n            <ng-template #cell let-isSelected=\"isSelected\" let-toggleRowSelection=\"toggleRowSelection\">\n              <input type=\"checkbox\" [checked]=\"isSelected\" (change)=\"toggleRowSelection()\" />\n            </ng-template>\n            <ng-template #header let-allRowsSelected=\"allRowsSelected\" let-someRowsSelected=\"someRowsSelected\"\n              let-toggleAllRows=\"toggleAllRows\">\n              <input type=\"checkbox\" [checked]=\"allRowsSelected()\" [indeterminate]=\"someRowsSelected()\"\n                (change)=\"toggleAllRows()\" />\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"createdAt\">\n            <ng-template #cell let-value>\n              {{ value | date }}\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"medium\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Medium}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <verben-drop-down width=\"100%\" placeholder=\"Select Message Medium\" [(options)]=\"mediumOptions\"\n                [(ngModel)]=\"value.Medium\">\n              </verben-drop-down>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"name\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Name}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <div class=\"width-max\">\n                <verbena-input [(ngModel)]=\"value.Name\"></verbena-input>\n              </div>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"subject\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.Subject}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <div class=\"width-max\">\n                <verbena-input [(ngModel)]=\"value.Subject\"></verbena-input>\n              </div>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"senderConfig\">\n            <ng-template #cell let-row=\"row\" let-value>\n              <div *ngIf=\"value.Medium == this.smsRef\">{{value.SenderConfig | asyncLabel: 'SMSConfig': 'Name': configAPI | async}}</div>\n              <div *ngIf=\"value.Medium == this.mailRef\">{{value.SenderConfig | asyncLabel: 'MailConfig': 'Name': configAPI | async}}</div>\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <verben-drop-down *ngIf=\"value.Medium == this.smsRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreSMSConfigs.bind(service)\"\n                  [search]=\"service.searchSMSConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncSMSConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"smsConfigs\" [(ngModel)]=\"value.SenderConfig\">\n                  </verben-drop-down>\n                  <verben-drop-down *ngIf=\"value.Medium == this.mailRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreMailConfigs.bind(service)\"\n                  [search]=\"service.searchMailConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncMailConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"mailConfigs\" [(ngModel)]=\"value.SenderConfig\">\n                  </verben-drop-down>\n            </ng-template>\n          </ng-container>\n          <ng-container libColumn=\"notificationType\">\n            <ng-template #cell let-row=\"row\" let-value>\n              {{value.NotificationType}}\n            </ng-template>\n            <ng-template #cellEdit let-row=\"row\" let-updateData=\"updateData\" let-value>\n              <verben-drop-down width=\"100%\" placeholder=\"Select Notification Type\" [(options)]=\"notificationTypeOptions\"\n                [(ngModel)]=\"value.NotificationType\">\n              </verben-drop-down>\n            </ng-template>\n          </ng-container>\n  \n          <ng-container libColumn=\"actions\">\n            <ng-template #cell let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <verben-pop-Up #popup [customStyles]=\"{'z-index': '99'}\" [enableMouseLeave]=\"false\">\n                <verben-svg class=\"cursor-pointer actions-icon\" dropdown-trigger icon=\"list\"></verben-svg>\n                <div class=\"pop-up-content flex flex-col\" dropdown-content>\n                  <!-- <div (click)=\"viewVendors(value.Code)\" class=\"pop-up-value cursor-pointer\">View vendors</div> -->\n                  <div (click)=\"toggleRowEdit(); closePopUp();\" class=\"pop-up-value cursor-pointer\">Edit</div>\n                  <!-- <div class=\"pop-up-value cursor-pointer\">Delete</div> -->\n                </div>\n              </verben-pop-Up>\n            </ng-template>\n            <ng-template #cellEdit let-isEditing=\"isEditing\" let-toggleRowEdit=\"toggleRowEdit\" let-row=\"row\" let-value>\n              <div class=\"flex gap-2 items-center\">\n                <verben-svg icon=\"tick\" [width]=\"15\" [height]=\"15\"\n                  (click)=\"tableSaveTaskNotification(value, toggleRowEdit)\"></verben-svg>\n                <verben-svg (click)=\"toggleRowEdit()\" icon=\"delete\" [width]=\"15\" [height]=\"15\"></verben-svg>\n                <verben-svg icon=\"cardViewAlt\" [width]=\"15\" [height]=\"15\" (click)=\"goToCardView(value)\"></verben-svg>\n              </div>\n            </ng-template>\n          </ng-container>\n        </lib-data-table>\n      </div>\n      <div card-content>\n        <verben-card-data-view borderRadius=\"12px\" #vdcv dataId = \"Id\" border=\"5px\" [cardDataList]=\"cardData\"\n          rbgColor=\"#f5f6f9\" mg=\"0px\">\n          <verben-left-card-data-view class=\"space-y-7\">\n            <verben-left-card-data #vlcd [parent]=\"vdcv\" dataId = \"Id\"\n              class=\"bg-secondary-100 rounded-xl border-primary border-[1px]\" [cardDataList]=\"cardData\">\n              <ng-template #card let-item>\n                <div (click)=\"cardClicked(item)\" class=\"flex cursor-pointer h-[max-content]\">\n                  <!-- <verben-svg [width]=\"15\" [height]=\"15\" (click)=\"toggleChildren(item); $event.stopPropagation()\"\n                    [ngClass]=\"item.children && item.children.length?'visible':'invisible'\"\n                    class=\"items-center flex  pr-1 cursor-pointer\" [icon]=\"item.isChildrenExpanded?'minus':'plus'\" /> -->\n                  <div class=\"flex  w-full bg-secondary rounded-xl\">\n                    <div class=\"w-3 rounded-xl rounded-tr-none rounded-br-none\" [ngClass]=\"\n                        item.selected ? 'bg-primary' : 'bg-secondary-200'\n                      \"></div>\n                    <div class=\"py-3 px-4 flex-1 h-[100%]\">\n                      <div class=\"flex items-start flex-1 gap-1 justify-between h-[100%]\">\n                        <div class=\"flex flex-col flex-1 card-min-height justify-between h-[100%]\">\n                          <h3 class=\"my-0 font-bold text-[#404040] leading-[19.5px]\">{{\n                            item.data.Name\n                            }}</h3>\n                          <!-- <span class=\"flex items-center gap-1\">\n                            <span class=\"!text-[10px] font-light text-[#404040]\">Ledger Header:</span> <span\n                              class=\"!text-[12px]\">{{item.data.SenderConfig}}</span>\n                          </span> -->\n                        </div>\n  \n                        <div class=\"flex flex-col items-between h-[100%]\">\n                          <div class=\"flex flex-col gap-1\">\n                            <span class=\"!text-[10px] font-light text-[#404040]\">Medium:</span>\n                            <div>{{item.data.Medium}}</div>\n                          </div>\n                          <!-- <p [ngClass]=\"{'disabled': item.data.DataState == 'New'}\" (click)=\"viewVendors(item.data.Code) ;$event.stopPropagation()\"\n                            class=\"view-lines my-0 underline text-[#3479E9] text-[12px] leading-[16.6px] cursor-pointer font-medium\">\n                            view vendors</p> -->\n                          <!-- <span class=\"enum-val {{item.data.Status}}\">{{item.data.Status}}</span> -->\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </ng-template>\n            </verben-left-card-data>\n          </verben-left-card-data-view>\n          <verben-right-card-data-view>\n            <ng-template #parent>\n              <div *ngIf=\"this.currentData\"\n                class=\"flex flex-col rounded-xl h-full w-full justify-between relative space-y-4\">\n                <div class=\"options-container flex flex-col gap-2\">\n                  <div class=\"options-item flex gap-2 items-center\">\n                    <div (click)=\"toggleIsMessageId(this.currentData.data, false)\" [ngClass]=\"{'active': !this.currentData.data.IsMessageId}\" class=\"option-toggle rounded-full flex items-center justify-center\">\n                      <div class=\"option-toggle-dot rounded-full\"></div>\n                    </div>\n                    <div>Type Message</div>\n                  </div>\n                  <div class=\"options-item flex gap-2 items-center\">\n                    <div (click)=\"toggleIsMessageId(this.currentData.data, true)\" [ngClass]=\"{'active': this.currentData.data.IsMessageId}\" class=\"option-toggle rounded-full flex items-center justify-center\">\n                      <div class=\"option-toggle-dot rounded-full\"></div>\n                    </div>\n                    <div>Select Existing Message</div>\n                  </div>\n                </div>\n                <div class=\"task-notification-inputs-container flex flex-col gap-3\">\n                <!-- <verbena-input [disabled]=\"true\" name=\"Code\" label=\"Code\" [(ngModel)]=\"this.currentData.data.Code\" /> -->\n\n                <div *ngIf=\"this.currentData.data.IsMessageId\" class=\"flex flex-col gap-1\">\n                  <div>Message Config</div>\n                  <verben-drop-down\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreReportSchedules.bind(service)\"\n                  [search]=\"service.searchReportSchedules.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncReportScheduleLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Message Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"reportSchedules\" [(ngModel)]=\"this.currentData.data.Message\">\n                  </verben-drop-down>\n                </div>\n\n              <verbena-input name=\"Name\" label=\"Name\" (ngModelChange)=\"updateTable()\"\n              [(ngModel)]=\"this.currentData.data.Name\" />\n              <verbena-input name=\"Subject\" label=\"Subject\" (ngModelChange)=\"updateTable()\"\n                [(ngModel)]=\"this.currentData.data.Subject\" />\n              <div class=\"flex flex-col gap-1\">\n                <div>Notification Type</div>\n                <verben-drop-down width=\"100%\" placeholder=\"Select Notification Type\" [(options)]=\"notificationTypeOptions\"\n                    [(ngModel)]=\"this.currentData.data.NotificationType\">\n                </verben-drop-down>\n              </div>\n                <div class=\"flex flex-col gap-1\">\n                    <div>Message Medium</div>\n                    <verben-drop-down width=\"100%\" placeholder=\"Select Message Medium\" [(options)]=\"mediumOptions\"\n                        [(ngModel)]=\"this.currentData.data.Medium\">\n                    </verben-drop-down>\n                </div>\n  \n                <div class=\"flex flex-col gap-1\">\n                  <div>Sender Config</div>\n                  <verben-drop-down *ngIf=\"this.currentData.data.Medium == this.smsRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreSMSConfigs.bind(service)\"\n                  [search]=\"service.searchSMSConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncSMSConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"smsConfigs\" [(ngModel)]=\"this.currentData.data.SenderConfig\">\n                  </verben-drop-down>\n                  <verben-drop-down *ngIf=\"this.currentData.data.Medium == this.mailRef\"\n                  [filter]=\"true\"\n                  [load]=\"service.loadMoreMailConfigs.bind(service)\"\n                  [search]=\"service.searchMailConfigs.bind(service)\"\n                  [lazyLoad]=\"true\"\n                  [asyncLabel]=\"service.getAsyncMailConfigLabel.bind(service)\"\n                  width=\"100%\" placeholder=\"Select Sender Config\" optionLabel=\"Name\" optionValue=\"Code\"\n                    [(options)]=\"mailConfigs\" [(ngModel)]=\"this.currentData.data.SenderConfig\">\n                  </verben-drop-down>\n                </div>\n\n                <div *ngIf=\"!this.currentData.data.IsMessageId\" class=\"flex editor-container-wrapper flex-col gap-1\">\n                    <lib-editor [editorConfig]=\"editorConfig\" [editorMode]=\"editorMode\" [(ngModel)]=\"this.currentData.data.Message\"></lib-editor>\n                </div>\n\n                </div>\n                <!-- buttons -->\n                <div class=\"flex justify-between bottom-8 left-0 right-0\">\n                  <div></div>\n                  <!-- <verbena-button class=\"verben-delete-button\" text=\"Delete\"></verbena-button> -->\n                  <div class=\"flex gap-3\">\n                    <!-- <verbena-button class=\"verben-switch-button\"\n                      (click)=\"viewVendors(this.currentData? this.currentData.data? this.currentData.data.Code: '':'')\"\n                      text=\"View Vendors\"></verbena-button> -->\n                    <verbena-button class=\"verben-switch-button\" (click)=\"goToTableView()\"\n                      text=\"Switch To Table\"></verbena-button>\n                    <verbena-button class=\"verben-primary-button\" (click)=\"this.saveTaskNotification()\"\n                      text=\"Save\"></verbena-button>\n                  </div>\n                </div>\n              </div>\n  \n            </ng-template>\n          </verben-right-card-data-view>\n          <!-- <verben-right-card-data-view>\n            yeshhhhhh\n          </verben-right-card-data-view> -->\n  \n          <verben-card-data-view-footer>\n            <div class=\"flex gap-2 justify-between\">\n              <div *ngIf=\"!vdcv.hasCurrentItem()\" class=\"message-log-button-container flex justify-between\">\n                <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n                  [text]=\"'Delete'\">\n                </verbena-button> -->\n              </div>\n              <div class=\"flex {{vdcv.hasCurrentItem()?'flex-1':''}} justify-end items-center gap-5\">\n                <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n                <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n              </div>\n            </div>\n          </verben-card-data-view-footer>\n        </verben-card-data-view>\n      </div>\n      <div column-content>\n        <verben-visible-column (columnsUpdated)=\"onColumnsUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" [columns]=\"visibleColumns\"\n          [displayedColumns]=\"5\"></verben-visible-column>\n      </div>\n      <div filter-content>\n        <verben-table-filter (filtersApplied)=\"onFilterUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"420px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [filterOptions]=\"filterArray\"\n          [maxFilterLength]=\"3\"></verben-table-filter>\n      </div>\n      <div sort-content>\n        <verben-sort-table (selectedOptions)=\"onSortUpdated($event)\" [border]=\"'1px solid rgba(212, 160, 7, 1)'\"\n          borderRadius=\"10px\" boxShadow=\"2px 2px 2px 0px silver\" bgColor=\"white\" width=\"400px\" textColor=\"black\" pd=\"1rem\"\n          primaryColor=\"#FFE681\" secondaryColor=\"#3479E9\" tertiaryColor=\"#404040\" [enableDragAndDrop]=\"true\"\n          [sortOptions]=\"sortOptions\"></verben-sort-table>\n      </div>\n      <div export-content>\n        <lib-data-export [data]=\"data\" (exportDataEvent)=\"handleExport($event)\">\n        </lib-data-export>\n      </div>\n    </verben-data-view>\n    <div *ngIf=\"vdv.isTableView\" class=\"flex gap-2 justify-between\">\n      <div class=\"message-log-button-container flex justify-between\">\n        <!-- <verbena-button [fontWeight]=\"'bold'\" [bgColor]=\"'#8E8D87'\" [borderRadius]=\"'4px'\" [textColor]=\"'#fff'\"\n          [text]=\"'Delete'\">\n        </verbena-button> -->\n      </div>\n      <div class=\"flex justify-end items-center gap-5\">\n        <span class=\"paginator-text\">{{ cardData.length }} records loaded</span>\n        <button (click)=\"loadMore()\" class=\"load-more view-links\">Load more</button>\n      </div>\n    </div>\n  </div>\n  ", styles: [".view-links{font-size:14px!important;color:#00f;font-weight:600;cursor:pointer}.view-links:hover{text-decoration:underline;text-underline-offset:3px}.context-banner{background-color:#d4a00773}.card-min-height{gap:10px}::ng-deep .childrenPadding{max-height:300px;overflow-y:auto}.pop-up-content{border-radius:4px;background-color:#fff;border:1px solid rgba(212,161,7,.5)}.pop-up-value{padding:10px 20px}.pop-up-content>div:nth-child(1){border-bottom:4px solid #FFE681}.width-max{min-width:max-content}.editor-container-wrapper{border-top:1px solid #D4A007;margin-left:-19px;margin-right:-19px;padding:5px}::ng-deep .editor-container{gap:0!important}.option-toggle{border:1px solid #B3BAC5;width:20px;height:20px;cursor:pointer}.option-toggle-dot{width:10px;height:10px}.option-toggle.active{border:1px solid #0075FF}.option-toggle.active>div{background-color:#0075ff}.task-notification-inputs-container{border:1px solid #D4A007;border-radius:16px;padding:15px 20px;margin-left:-19px;margin-right:-19px}\n"] }]
        }], ctorParameters: () => [{ type: UtilService }, { type: HttpWebRequestService }, { type: i0.ChangeDetectorRef }, { type: i1$2.FormBuilder }, { type: EnvironmentService }, { type: TaskNotificationService }], propDecorators: { cardDataView: [{
                type: ViewChild,
                args: ['vdcv']
            }], dataView: [{
                type: ViewChild,
                args: ['vdv']
            }], tableView: [{
                type: ViewChild,
                args: ['dt']
            }], popUps: [{
                type: ViewChildren,
                args: ['popup']
            }] } });

class TaskNotificationModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationModule, declarations: [TaskNotificationComponent], imports: [SharedModule], exports: [TaskNotificationComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationModule, imports: [SharedModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TaskNotificationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [TaskNotificationComponent],
                    imports: [SharedModule],
                    exports: [TaskNotificationComponent],
                }]
        }] });

/*
 * Public API Surface of verben-ng-ui
 */
// export * from './lib/verben-ng-ui.service';
// export * from './lib/verben-ng-ui.component';
// Exporting modules

/**
 * Generated bundle index. Do not edit.
 */

export { ENVIRONMENT, EnvironmentService, ExpirationComponent, ExpirationModule, FormFieldsComponent, FormGroupComponent, FormGroupLibModule, FormResponseComponent, FormResponseLibModule, FormsComponent, FormsFieldLibModule, FormsModule, JournalComponent, JournalModule, MyQueueComponent, MyQueueModule, MyQueueService, StageDetailsComponent, StageDetailsModule, TaskHistoryComponent, TaskHistoryModule, TaskNotificationComponent, TaskNotificationModule, TasksComponent, TasksModule, TasksService, WFDesignerComponent, WfComponent, WfModule, WfService, WorkflowComponent, WorkflowDesignerComponent, WorkflowDesignerModule, WorkflowModule, WorkflowsComponent, WorkflowsModule, WorkflowsService, appRoutes };
//# sourceMappingURL=verben-workflow-ui.mjs.map
